drop database if exists Stellar;
create database Stellar;
use Stellar;

create table cuerpo_celeste(
id int unsigned primary key auto_increment,
nombre varchar(50),
tipo varchar(50),
radio float unsigned,
masa float unsigned,
densidad float unsigned

);


create table coalicion(
id int unsigned  primary key auto_increment,
nombre varchar(50),
valores varchar(250)
);

create table especie(
id int unsigned  primary key auto_increment,
nombre varchar(50),
reino varchar(30),
tipo_alimentacion enum('hervíboro', 'carnívoro', 'omnívoro', 'vampirismo', 'geovoro'),
n_estimado int unsigned

);

create table nave(
id int unsigned  primary key auto_increment,
nombre varchar(50),
identificador varchar(15) unique not null,
tipo enum('combate', 'carga','pasajeros','exploración'),
capacidad_carga float,
n_tripulantes int unsigned,
id_cuerpo_celeste int references cuerpo_celeste,
id_coalicion int references coalicion
);

create table persona(
id int unsigned primary key auto_increment,
nombre varchar(50),
edad int unsigned,
id_cuerpo_celeste int references cuerpo_celeste
);

create table tripulante(
id int unsigned primary key auto_increment,
fecha_inicio date,
fecha_fin date,
cargo varchar(25),
id_persona int references persona
);

create table direcciones(
id int unsigned primary key auto_increment,
direccion varchar(70) unique,
id_persona int references persona
);

create table galaxia(
id int unsigned primary key auto_increment,
numero long,
id_cuerpo_celeste int references  cuerpo_celeste);

create table estrella(
id int unsigned primary key auto_increment,
tipo varchar(30),
temperatura float unsigned,
luminosidad float unsigned,
id_cuerpo_celeste int references cuerpo_celeste,
id_galaxia int references galaxia
);

create table cuerpo_celeste_orbita_cuerpo_celeste(
id_cuerpo_celeste_orbitador int references cuerpo_celeste,
id_cuerpo_celeste_orbitado int references cuerpo_celeste,
primary key(id_cuerpo_celeste_orbitador,id_cuerpo_celeste_orbitado));

create table estrella_galaxia(
id_estrella int references estrella,
id_galaxia int references galaxia,
primary key(id_estrella,id_galaxia));

create table especie_cuerpo_celeste(
id_especie int references especie,
id_cuerpo_celeste int references cuerpo_celeste,
primary key(id_especie,id_cuerpo_celeste));

create table coalicion_cuerpo_celeste(
id_coalicion int references coalicion,
id_cuerpo_celeste int references cuerpo_celeste,
primary key(id_coalicion,id_cuerpo_celeste));

create table especie_persona(
id_especie int references especie,
id_persona int references persona,
primary key(id_especie,id_persona));

create table nave_tripulante(
id_nave int references nave,
id_tripulante int references tripulante,
primary key(id_nave,id_tripulante));




SET NAMES 'utf8';
USE stellar;
/*!40014 SET @OLD_FOREIGN_KEY_CHECKS=@@FOREIGN_KEY_CHECKS, FOREIGN_KEY_CHECKS=0 */;

ALTER TABLE direcciones 
   DROP INDEX direccion;

ALTER TABLE nave 
   DROP INDEX identificador;

INSERT INTO coalicion(id, nombre, valores) VALUES
(1, 'Gran Agrupación del Orden  de Jinokuqa', 'paz, '),
(2, 'Excelentísim@ Industria Militar  de Kiaasale', 'paz, exploración, ciencia, comercio, '),
(3, 'Excels@ Federación Oscur@  de Exoke', 'paz, exploración, '),
(4, 'Industria Oscur@  de Qaceru', 'neutralidad, exploración, '),
(5, 'Federación Oscur@  de Jedusudu', 'neutralidad, '),
(6, 'Gran Agrupación  de Cahegisihe', 'guerra, '),
(7, 'Industria Militar  de Fabipaii', 'guerra, '),
(8, 'Excels@ Federación Oscur@  de Gasuweqi', 'neutralidad, ciencia, '),
(9, 'Agrupación Oscur@  de Keaihani', 'paz, '),
(10, 'Industria  de Vooigova', 'paz, conocimiento, comercio, '),
(11, 'Imperio del Orden  de Daxaaaue', 'guerra, '),
(12, 'Excelentísim@ Federación  de Nuyifo', 'guerra, '),
(13, 'Excelentísim@ Imperio Oscur@  de Jofadove', 'paz, conocimiento, '),
(14, 'Excels@ Agrupación  de Orixo', 'neutralidad, exploración, comercio, '),
(15, 'Excelentísim@ Federación  de Ucuba', 'paz, '),
(16, 'Industria  de Baqibucero', 'paz, '),
(17, 'Industria  de Ecioagi', 'paz, ciencia, '),
(18, 'Imperio  de Mupezuoaju', 'paz, mediación, exploración, comercio, '),
(19, 'Gran Federación  de Keua', 'guerra, diálogo, '),
(20, 'Gran Industria Militar  de Ajege', 'neutralidad, exploración, ciencia, '),
(21, 'Excelentísim@ Imperio Comercial  de Ozojadawo', 'neutralidad, conocimiento, '),
(22, 'Imperio Comercial  de Ouu', 'guerra, exploración, '),
(23, 'Excelentísim@ Agrupación  de Mumeheue', 'paz, ciencia, comercio, '),
(24, 'Excelentísim@ Federación del Orden  de Sibojoea', 'paz, exploración, ciencia, '),
(25, 'Excelentísim@ Imperio del Orden  de Riji', 'guerra, comercio, '),
(26, 'Gran Industria Oscur@  de Sifilaia', 'guerra, comercio, '),
(27, 'Agrupación  de Pu', 'guerra, '),
(28, 'Imperio del Orden  de Iderane', 'neutralidad, mediación, '),
(29, 'Agrupación  de Xomamu', 'paz, mediación, exploración, '),
(30, 'Gran Industria  de Ajoieoi', 'guerra, ciencia, comercio, '),
(31, 'Excels@ Agrupación  de Upuxizala', 'guerra, conocimiento, exploración, '),
(32, 'Imperio  de Jopayi', 'guerra, '),
(33, 'Agrupación Oscur@  de Pefije', 'paz, comercio, '),
(34, 'Excelentísim@ Federación  de Rigage', 'guerra, '),
(35, 'Federación  de Vi', 'neutralidad, '),
(36, 'Imperio Oscur@  de Ziiuyi', 'guerra, '),
(37, 'Imperio Militar  de Aue', 'guerra, exploración, comercio, '),
(38, 'Excelentísim@ Imperio Comercial  de Voyuni', 'guerra, '),
(39, 'Gran Federación  de Xecevino', 'guerra, ciencia, '),
(40, 'Federación  de Zeyu', 'paz, diálogo, '),
(41, 'Gran Agrupación Oscur@  de Ciqo', 'guerra, ciencia, '),
(42, 'Excels@ Industria Comercial  de Kikipa', 'neutralidad, conocimiento, ciencia, comercio, '),
(43, 'Industria  de Opimuei', 'neutralidad, '),
(44, 'Imperio  de Bixa', 'guerra, '),
(45, 'Excels@ Industria  de Obauubo', 'guerra, diálogo, '),
(46, 'Federación Militar  de Hepizeea', 'guerra, exploración, '),
(47, 'Gran Industria  de Zeciuo', 'neutralidad, diálogo, '),
(48, 'Excels@ Industria  de Idiki', 'paz, exploración, '),
(49, 'Industria  de Gojesu', 'paz, exploración, comercio, '),
(50, 'Industria Oscur@  de Humidusu', 'paz, '),
(51, 'Federación  de Ehihe', 'paz, '),
(52, 'Federación  de Raya', 'guerra, comercio, '),
(53, 'Imperio  de Xumipe', 'guerra, ciencia, comercio, '),
(54, 'Imperio Comercial  de Gooove', 'neutralidad, exploración, comercio, '),
(55, 'Gran Industria  de Hauazula', 'paz, comercio, '),
(56, 'Agrupación Oscur@  de I', 'paz, '),
(57, 'Gran Federación  de Cumipuse', 'guerra, '),
(58, 'Excelentísim@ Federación Comercial  de Fulu', 'guerra, exploración, comercio, '),
(59, 'Excelentísim@ Imperio  de Pujoiaju', 'neutralidad, '),
(60, 'Excels@ Federación del Orden  de Aueuu', 'paz, '),
(61, 'Industria Oscur@  de Veromiqa', 'guerra, '),
(62, 'Excelentísim@ Agrupación  de Upuza', 'neutralidad, mediación, '),
(63, 'Gran Agrupación  de Ze', 'paz, '),
(64, 'Imperio  de Widi', 'guerra, diálogo, exploración, '),
(65, 'Excels@ Imperio  de Muba', 'guerra, conocimiento, '),
(66, 'Excelentísim@ Imperio Comercial  de Weyuya', 'paz, comercio, '),
(67, 'Excels@ Industria  de Zubaiaoe', 'guerra, comercio, '),
(68, 'Imperio  de Ekeji', 'neutralidad, '),
(69, 'Imperio  de Sazudi', 'guerra, diálogo, comercio, '),
(70, 'Gran Industria  de Wona', 'guerra, '),
(71, 'Industria Oscur@  de Qooegu', 'guerra, '),
(72, 'Excelentísim@ Imperio del Orden  de Kimutisa', 'paz, ciencia, '),
(73, 'Excelentísim@ Industria  de Ziyu', 'paz, comercio, '),
(74, 'Gran Industria del Orden  de Auinu', 'guerra, mediación, '),
(75, 'Industria  de Bomuye', 'guerra, '),
(76, 'Excelentísim@ Agrupación Oscur@  de Dahouicu', 'paz, '),
(77, 'Excelentísim@ Imperio  de Haai', 'neutralidad, '),
(78, 'Industria  de Veyooaoo', 'guerra, ciencia, '),
(79, 'Federación Oscur@  de Oxieipu', 'neutralidad, '),
(80, 'Agrupación Oscur@  de Coae', 'guerra, '),
(81, 'Federación  de Miya', 'paz, '),
(82, 'Excels@ Industria Comercial  de Exu', 'paz, '),
(83, 'Excels@ Agrupación  de Qerine', 'guerra, '),
(84, 'Excels@ Federación  de Jugiyo', 'paz, exploración, '),
(85, 'Agrupación  de Uzilo', 'paz, diálogo, '),
(86, 'Excelentísim@ Federación del Orden  de Meyi', 'paz, '),
(87, 'Industria Militar  de Boye', 'neutralidad, conocimiento, '),
(88, 'Gran Industria Comercial  de Bivoiini', 'neutralidad, '),
(89, 'Agrupación  de Jaye', 'neutralidad, ciencia, '),
(90, 'Federación  de Zaiaei', 'guerra, conocimiento, comercio, '),
(91, 'Industria  de A', 'paz, '),
(92, 'Excels@ Agrupación Comercial  de Tocaxemo', 'neutralidad, '),
(93, 'Gran Federación Oscur@  de Fioi', 'paz, comercio, '),
(94, 'Gran Federación Militar  de Weoa', 'neutralidad, '),
(95, 'Industria Militar  de Nesega', 'neutralidad, mediación, '),
(96, 'Agrupación  de Peaoauro', 'paz, '),
(97, 'Agrupación  de Dibora', 'paz, exploración, '),
(98, 'Federación  de Ewa', 'guerra, exploración, comercio, '),
(99, 'Gran Federación  de Tevuza', 'guerra, mediación, '),
(100, 'Imperio Comercial  de Wohihuxi', 'neutralidad, ciencia, ');

INSERT INTO coalicion_cuerpo_celeste(id_coalicion, id_cuerpo_celeste) VALUES
(63, 698),
(17, 242),
(99, 348),
(22, 620),
(6, 84),
(44, 712),
(31, 425),
(65, 930),
(88, 107),
(82, 374),
(97, 966),
(52, 248),
(16, 311),
(33, 581),
(50, 349),
(88, 119),
(75, 481),
(58, 908),
(5, 4),
(37, 7),
(8, 991),
(51, 274),
(43, 19),
(100, 48),
(89, 894),
(57, 734),
(52, 162),
(41, 375),
(6, 400),
(65, 422),
(36, 52),
(30, 108),
(66, 941),
(50, 300),
(22, 211),
(13, 992),
(3, 413),
(25, 869),
(16, 249),
(17, 854),
(35, 799),
(41, 526),
(2, 523),
(34, 514),
(57, 459),
(70, 493),
(32, 120),
(23, 8),
(90, 20),
(55, 822),
(72, 212),
(32, 385),
(96, 594),
(53, 149),
(26, 967),
(100, 414),
(66, 634),
(80, 844),
(84, 121),
(40, 105),
(57, 664),
(29, 571),
(23, 691),
(44, 72),
(68, 699),
(3, 560),
(75, 343),
(92, 333),
(63, 811),
(53, 426),
(77, 870),
(45, 49),
(31, 474),
(73, 895),
(4, 222),
(67, 275),
(90, 792),
(6, 746),
(72, 833),
(2, 109),
(34, 350),
(12, 968),
(43, 920),
(12, 460),
(38, 909),
(49, 823),
(29, 735),
(52, 931),
(7, 993),
(70, 243),
(27, 62),
(4, 812),
(49, 956),
(89, 790),
(39, 494),
(72, 825),
(77, 437),
(80, 942),
(37, 401),
(10, 344),
(83, 646),
(2, 692),
(68, 635),
(51, 721),
(92, 285),
(79, 800),
(31, 163),
(17, 527),
(52, 859),
(94, 5),
(50, 301),
(62, 538),
(2, 471),
(60, 9),
(42, 173),
(24, 63),
(76, 185),
(6, 700),
(8, 923),
(9, 153),
(8, 423),
(70, 747),
(1, 197),
(95, 595),
(60, 603),
(46, 885),
(80, 690),
(3, 503),
(59, 621),
(64, 572),
(52, 97),
(41, 21),
(83, 73),
(40, 110),
(23, 524),
(73, 53),
(10, 834),
(3, 386),
(4, 515),
(2, 313),
(73, 495),
(52, 896),
(21, 596),
(23, 424),
(91, 582),
(3, 250),
(46, 765),
(20, 655),
(95, 647),
(62, 351),
(25, 260),
(30, 561),
(86, 957),
(9, 665),
(6, 361),
(41, 801),
(53, 251),
(61, 427),
(25, 983),
(9, 122),
(44, 261),
(96, 415),
(2, 528),
(7, 352),
(27, 244),
(3, 323),
(92, 403),
(28, 164),
(62, 233),
(7, 472),
(58, 376),
(91, 428),
(71, 736),
(53, 223),
(47, 312),
(8, 362),
(18, 402),
(42, 826),
(91, 461),
(3, 252),
(5, 952),
(24, 482),
(53, 353),
(45, 438),
(66, 921),
(21, 780),
(65, 106),
(1, 562),
(63, 504),
(52, 793),
(13, 539),
(68, 529),
(1, 729),
(89, 701),
(54, 516),
(77, 429),
(23, 289),
(8, 748),
(25, 302),
(59, 154),
(9, 997),
(14, 583),
(58, 636),
(13, 334),
(91, 22),
(68, 871),
(56, 680),
(76, 253),
(28, 900),
(57, 573),
(17, 38),
(10, 648),
(59, 416),
(12, 855),
(32, 998),
(8, 213),
(33, 54),
(34, 802),
(42, 202),
(88, 483),
(20, 737),
(36, 262),
(5, 901),
(13, 637),
(7, 462),
(50, 496),
(59, 314),
(95, 85),
(3, 64),
(95, 324),
(3, 910),
(38, 756),
(67, 860),
(61, 390),
(52, 994),
(22, 517),
(57, 629),
(100, 722),
(46, 473),
(90, 749),
(12, 10),
(50, 738),
(26, 584),
(28, 597),
(39, 191),
(59, 404),
(27, 638),
(98, 123),
(31, 139),
(70, 303),
(2, 174),
(62, 999),
(85, 203),
(57, 165),
(5, 730),
(37, 186),
(55, 74),
(39, 530),
(22, 234),
(37, 354),
(93, 86),
(89, 363),
(94, 574),
(69, 91),
(95, 175),
(22, 198),
(85, 845),
(48, 224),
(24, 187),
(31, 693),
(2, 325),
(62, 254),
(73, 214),
(34, 969),
(34, 276),
(4, 702),
(70, 150),
(48, 155),
(33, 669),
(91, 304),
(4, 335),
(46, 345),
(56, 872),
(3, 286),
(29, 75),
(49, 315),
(16, 225),
(54, 235),
(4, 770),
(72, 328),
(55, 958),
(67, 263),
(97, 563),
(29, 781),
(66, 111),
(82, 87),
(10, 355),
(38, 290),
(12, 932),
(20, 803),
(70, 656),
(60, 649),
(70, 575),
(37, 39),
(70, 215),
(17, 448),
(65, 23),
(7, 970),
(57, 204),
(79, 463),
(38, 387),
(42, 55),
(74, 1000),
(48, 750),
(92, 156),
(55, 176),
(81, 430),
(67, 188),
(7, 336),
(48, 757),
(53, 703),
(1, 316),
(68, 65),
(96, 897),
(79, 407),
(94, 681),
(39, 133),
(6, 475),
(100, 657),
(26, 124),
(49, 670),
(89, 873),
(53, 861),
(31, 531),
(37, 140),
(7, 439),
(27, 782),
(8, 364),
(100, 505),
(54, 56),
(29, 33),
(70, 886),
(33, 971),
(16, 771),
(77, 682),
(42, 924),
(44, 564),
(99, 391),
(29, 766),
(24, 984),
(58, 783),
(5, 192),
(77, 666),
(50, 377),
(17, 835),
(38, 767),
(44, 464),
(29, 326),
(20, 739),
(37, 166),
(1, 216),
(43, 98),
(1, 804),
(4, 317),
(5, 255),
(72, 134),
(87, 236),
(65, 650),
(93, 356),
(93, 76),
(45, 291),
(70, 683),
(2, 549),
(79, 704),
(44, 88),
(7, 66),
(23, 92),
(99, 784),
(30, 902),
(49, 305),
(1, 887),
(65, 995),
(74, 392),
(88, 794),
(8, 576),
(65, 24),
(76, 11),
(85, 813),
(88, 671),
(52, 417),
(67, 805),
(21, 226),
(77, 217),
(36, 874),
(58, 177),
(95, 287),
(74, 497),
(99, 405),
(32, 157),
(68, 684),
(63, 604),
(35, 318),
(36, 758),
(31, 622),
(13, 292),
(78, 449),
(82, 205),
(95, 772),
(100, 40),
(69, 306),
(60, 540),
(100, 898),
(69, 550),
(38, 658),
(100, 694),
(8, 506),
(53, 125),
(77, 431),
(65, 508),
(7, 77),
(65, 141),
(47, 972),
(65, 996),
(9, 911),
(41, 393),
(17, 440),
(10, 814),
(52, 408),
(89, 959),
(42, 532),
(41, 327),
(31, 933),
(100, 264),
(19, 723),
(53, 112),
(32, 785),
(55, 836),
(81, 293),
(33, 57),
(46, 943),
(78, 875),
(78, 639),
(23, 206),
(8, 934),
(25, 509),
(12, 365),
(15, 307),
(11, 256),
(78, 759),
(39, 541),
(45, 903),
(38, 518),
(26, 795),
(23, 705),
(6, 388),
(73, 659),
(88, 167),
(48, 695),
(8, 189),
(68, 227),
(33, 178),
(82, 12),
(1, 862),
(95, 41),
(46, 441),
(26, 394),
(64, 450),
(52, 565),
(2, 912),
(10, 228),
(20, 667),
(50, 337),
(81, 409),
(73, 760),
(36, 484),
(53, 815),
(61, 294),
(2, 406),
(74, 827),
(12, 960),
(41, 612),
(61, 973),
(33, 357),
(14, 78),
(8, 265),
(93, 863),
(49, 585),
(89, 89),
(48, 985),
(1, 257),
(32, 366),
(65, 846),
(25, 476),
(50, 67),
(61, 207),
(1, 740),
(84, 837),
(35, 899),
(2, 168),
(67, 605),
(22, 961),
(76, 672),
(40, 199),
(61, 485),
(31, 888),
(19, 288),
(59, 113),
(51, 640),
(94, 277),
(79, 25),
(2, 218),
(21, 542),
(91, 13),
(7, 944),
(47, 442),
(34, 713),
(74, 806),
(49, 925),
(64, 99),
(28, 768),
(11, 179),
(1, 507),
(22, 193),
(6, 876),
(45, 685),
(17, 741),
(51, 543),
(84, 660),
(55, 432),
(20, 847),
(16, 395),
(79, 551),
(94, 623),
(64, 443),
(49, 533),
(62, 190),
(26, 79),
(97, 613),
(44, 706),
(40, 114),
(19, 751),
(19, 465),
(85, 126),
(40, 418),
(64, 358),
(27, 389),
(62, 68),
(80, 935),
(98, 180),
(36, 90),
(14, 510),
(96, 864),
(60, 796),
(87, 913),
(5, 598),
(85, 544),
(56, 945),
(3, 651),
(68, 668),
(18, 451),
(1, 773),
(33, 498),
(1, 769),
(4, 986),
(15, 258),
(79, 828),
(9, 816),
(93, 26),
(48, 586),
(25, 962),
(71, 410),
(50, 69),
(37, 926),
(22, 444),
(91, 974),
(40, 865),
(11, 889),
(90, 14),
(16, 848),
(73, 486),
(83, 34),
(4, 200),
(75, 127),
(35, 963),
(12, 266),
(95, 577),
(12, 169),
(16, 589),
(5, 987),
(73, 829),
(65, 489),
(29, 237),
(40, 673),
(76, 606),
(30, 552),
(23, 696),
(3, 378),
(73, 268),
(79, 477),
(31, 587),
(88, 27),
(42, 866),
(27, 433),
(56, 142),
(85, 545),
(13, 452),
(36, 761),
(73, 534),
(34, 877),
(64, 946),
(30, 878),
(30, 714),
(59, 578),
(75, 975),
(38, 849),
(17, 614),
(12, 80),
(79, 641),
(24, 338),
(63, 707),
(5, 914),
(33, 487),
(26, 752),
(90, 158),
(6, 904),
(83, 661),
(77, 115),
(72, 128),
(97, 817),
(62, 976),
(3, 15),
(51, 715),
(15, 278),
(95, 807),
(49, 170),
(22, 519),
(11, 445),
(6, 319),
(88, 367),
(28, 742),
(99, 607),
(31, 267),
(83, 238),
(94, 58),
(97, 379),
(75, 70),
(5, 116),
(19, 588),
(23, 905),
(45, 329),
(98, 964),
(41, 368),
(44, 642),
(78, 279),
(26, 419),
(92, 879),
(11, 511),
(69, 181),
(78, 488),
(36, 652),
(65, 724),
(7, 380),
(9, 229),
(7, 28),
(53, 359),
(25, 369),
(18, 599),
(64, 100),
(7, 808),
(88, 245),
(13, 478),
(22, 915),
(23, 219),
(47, 129),
(11, 42),
(9, 269),
(43, 838),
(41, 630),
(24, 320),
(28, 159),
(46, 411),
(19, 280),
(9, 339),
(61, 201),
(71, 936),
(55, 753),
(90, 29),
(10, 566),
(99, 330),
(54, 16),
(50, 239),
(88, 953),
(21, 499),
(58, 93),
(91, 553),
(28, 59),
(91, 731),
(1, 340),
(5, 130),
(55, 839),
(59, 240),
(5, 937),
(24, 977),
(9, 762),
(51, 117),
(84, 101),
(52, 743),
(28, 50),
(74, 160),
(93, 947),
(27, 151),
(7, 880),
(42, 890),
(61, 135),
(91, 708),
(23, 774),
(90, 643),
(1, 856),
(24, 520),
(15, 797),
(100, 295),
(99, 579),
(84, 1),
(79, 608),
(5, 954),
(33, 220),
(1, 466),
(12, 479),
(52, 674),
(32, 30),
(39, 840),
(92, 850),
(28, 631),
(97, 434),
(52, 60),
(83, 370),
(49, 546),
(49, 786),
(90, 927),
(48, 81),
(27, 453),
(78, 978),
(43, 131),
(2, 321),
(30, 988),
(35, 171),
(50, 31),
(42, 182),
(11, 17),
(28, 590),
(88, 446),
(15, 697),
(60, 381),
(60, 948),
(46, 490),
(68, 194),
(1, 281),
(3, 308),
(83, 346),
(96, 709),
(13, 881),
(80, 554),
(85, 600),
(75, 979),
(73, 341),
(7, 744),
(3, 857),
(39, 775),
(33, 798),
(96, 662),
(83, 420),
(18, 396),
(16, 270),
(67, 644),
(21, 686),
(47, 35),
(26, 891),
(16, 296),
(93, 653),
(40, 787),
(4, 851),
(42, 94),
(34, 246),
(4, 161),
(76, 609),
(92, 347),
(48, 382),
(26, 454),
(47, 591),
(45, 500),
(12, 830),
(76, 259),
(65, 732),
(20, 132),
(95, 118),
(37, 32),
(95, 535),
(83, 745),
(78, 687),
(7, 143),
(81, 955),
(17, 867),
(72, 397),
(56, 858),
(85, 208),
(37, 965),
(66, 632),
(62, 645),
(74, 733),
(5, 868),
(25, 633),
(17, 675),
(63, 580),
(44, 371),
(74, 710),
(89, 435),
(71, 547),
(66, 51),
(88, 989),
(51, 536),
(86, 447),
(76, 615),
(86, 43),
(22, 360),
(36, 491),
(48, 82),
(21, 152),
(62, 102),
(74, 480),
(5, 928),
(84, 716),
(80, 144),
(31, 610),
(27, 247),
(4, 271),
(26, 436),
(2, 548),
(63, 616),
(7, 776),
(44, 818),
(26, 221),
(8, 61),
(67, 711),
(48, 282),
(81, 624),
(70, 717),
(92, 831),
(53, 611),
(20, 241),
(46, 938),
(25, 512),
(58, 537),
(41, 525),
(95, 754),
(74, 567),
(52, 230),
(11, 183),
(12, 929),
(47, 44),
(83, 791),
(27, 788),
(95, 322),
(8, 372),
(76, 555),
(27, 949),
(77, 297),
(52, 6),
(23, 455),
(29, 725),
(92, 832),
(100, 824),
(79, 309),
(12, 18),
(87, 922),
(80, 383),
(84, 882),
(71, 136),
(7, 852),
(53, 83),
(48, 980),
(16, 906),
(50, 841),
(4, 916),
(43, 283),
(8, 272),
(1, 625),
(86, 556),
(1, 763),
(65, 195),
(96, 373),
(98, 467),
(30, 663),
(68, 521),
(51, 36),
(71, 71),
(28, 384),
(24, 726),
(79, 456),
(1, 592),
(8, 626),
(72, 398),
(25, 819),
(52, 331),
(86, 727),
(11, 557),
(49, 809),
(56, 950),
(92, 421),
(10, 676),
(90, 617),
(79, 145),
(3, 601),
(73, 209),
(38, 654),
(89, 907),
(59, 892),
(25, 172),
(84, 184),
(4, 688),
(74, 777),
(23, 917),
(7, 883),
(88, 939),
(14, 627),
(84, 501),
(97, 842),
(3, 728),
(59, 677),
(72, 940),
(34, 820),
(85, 810),
(19, 918),
(14, 412),
(9, 568),
(20, 789),
(82, 95),
(63, 137),
(12, 981),
(56, 602),
(15, 492),
(43, 2),
(8, 853),
(83, 298),
(63, 284),
(48, 593),
(81, 103),
(25, 990),
(1, 457),
(89, 45),
(41, 196),
(16, 821),
(85, 755),
(80, 764),
(82, 513),
(30, 718),
(67, 468),
(4, 273),
(22, 522),
(70, 778),
(12, 310),
(24, 399),
(94, 231),
(57, 689),
(52, 299),
(86, 893),
(60, 884),
(8, 502),
(95, 982),
(17, 342),
(63, 37),
(89, 3),
(37, 569),
(72, 618),
(63, 678),
(71, 210),
(85, 779),
(32, 104),
(44, 96),
(48, 919),
(34, 679),
(61, 628),
(14, 332),
(35, 146),
(90, 843),
(75, 46),
(79, 558),
(90, 147),
(1, 458),
(73, 47),
(11, 719),
(54, 469),
(80, 619),
(37, 951),
(52, 232),
(31, 570),
(42, 138),
(8, 470),
(55, 720),
(94, 148),
(96, 559);

INSERT INTO cuerpo_celeste(id, nombre, tipo, radio, masa, densidad) VALUES
(1, 'Oikecodi', 'Satélite', 6270296, 7584209, 8114709),
(2, 'Humigiha', 'Satélite', 6186779, 5778489, NULL),
(3, 'Xu', 'Satélite', 8714746, 6666267, 5370346),
(4, 'Xacifodo', 'Planeta', 9776406, 2563784, 6838328),
(5, 'Yugo', 'Planeta', 2487301, 9661439, 269542),
(6, 'Buqoyu', 'Planeta', 9454612, 4201343, 3673611),
(7, 'Junoki', 'Satélite', 7075702, 6016594, 175921),
(8, 'Dojimubo', 'Satélite', 8056742, 3890345, 566),
(9, 'Wupage', 'Satélite', 60475, 919204, 914),
(10, 'Uupeno', 'Satélite', 2432134, 9807650, 2755315),
(11, 'Keboye', 'Planeta', 4867183, 759049, 5243397),
(12, 'Kedahepu', 'Planeta', 86335, 9454549, 4815189),
(13, 'Hetaqa', 'Planeta', 2984006, 7747137, 30),
(14, 'Iuyulita', 'Planeta', 3132544, 948578, 6503037),
(15, 'Qobaqa', 'Asteroide', 536962, 8555518, 4932110),
(16, 'Eo', 'Planeta', 2173596, 1752934, 13),
(17, 'Zofinu', 'Planeta', 6067756, 6550893, NULL),
(18, 'Qohufuhu', 'Planeta', 7403564, 7047921, 4398021),
(19, 'Xeqomo', 'Planeta', 436551, 1022245, 965064),
(20, 'Xunoje', 'Planeta', 3664741, 4542087, 9171985),
(21, 'Simeruye', 'Planeta', 4694832, NULL, NULL),
(22, 'Zuyifi', 'Cometa', 3623521, 7457956, 5),
(23, 'Winaye', 'Planeta', 123116, 47511, 8933188),
(24, 'Furosu', 'Planeta', 773093, 2288570, 8175),
(25, 'Xihakucu', 'Planeta', NULL, 8802028, 3433),
(26, 'Yeruje', 'Planeta', 4780308, 1228289, 3946721),
(27, 'Aupuxo', 'Satélite', 3834551, 7271200, 646),
(28, 'Napunuyo', 'Planeta', 6370336, 5991176, 5227929),
(29, 'Muje', 'Satélite', 5685677, 7736988, 232623),
(30, 'Luvo', 'Planeta', 4850010, 2121295, 4947028),
(31, 'Iozusahu', 'Planeta', 6563574, 3821649, 5729761),
(32, 'Uugede', 'Satélite', 7722488, 9952737, 5228261),
(33, 'Tejo', 'Satélite', 5883919, 7541852, 5981694),
(34, 'Zuruwu', 'Satélite', 5247692, 5897364, 9733202),
(35, 'Uuhuxoxofu', 'Planeta', 4357987, 8716501, 622),
(36, 'Guyagohe', 'Asteroide', 8556575, 513752, 6981815),
(37, 'Miki', 'Planeta', 4036632, 774429, 5004362),
(38, 'Rilo', 'Planeta', 5925796, 162965, 6448981),
(39, 'Qurabu', 'Planeta', 5461298, 1767859, 4),
(40, 'Joda', 'Planeta', 4440248, 7166739, 8135001),
(41, 'Pasopo', 'Planeta', 410953, 6870056, 97),
(42, 'Domu', 'Planeta', NULL, 9064727, 7140599),
(43, 'Tadi', 'Cometa', 8954345, 9182789, 8747908),
(44, 'Johidu', 'Cometa', 7558569, NULL, 57),
(45, 'Eenoze', 'Planeta', 2878148, 7278671, 3087),
(46, 'Dogo', 'Planeta', 6635972, 4472129, 53),
(47, 'Muqusa', 'Satélite', 4608670, 3480527, 382),
(48, 'Radaruxu', 'Asteroide', 1221209, 4492710, 243),
(49, 'Jibihe', 'Satélite', NULL, NULL, 6362856),
(50, 'Hisa', 'Planeta', 2137363, 5003742, 5147468),
(51, 'Yiyu', 'Satélite', 5860743, 5961659, 9285859),
(52, 'Eoki', 'Satélite', 5320091, 8568352, 4832155),
(53, 'Kuve', 'Planeta', 7476090, 4462215, 952694),
(54, 'Lekesigi', 'Planeta', 1034151, NULL, 6614950),
(55, 'Uokizo', 'Planeta', 5306829, 8149177, 138039),
(56, 'Ai', 'Planeta', 4501680, 2387490, 8915554),
(57, 'Yeyo', 'Planeta', 5123130, 1741735, 76812),
(58, 'Nuduxi', 'Planeta', 671100, 5424350, 8218122),
(59, 'Kufezize', 'Planeta', 9498589, 7919003, 8659842),
(60, 'Bitaguqa', 'Planeta', 2520552, 1917081, 1292205),
(61, 'Aine', 'Planeta', 8658832, 7872286, 5),
(62, 'Toyehi', 'Satélite', 50124, 4225765, NULL),
(63, 'Iuva', 'Satélite', 9908511, 4558794, 8770202),
(64, 'Siwufe', 'Planeta', 7926531, 9550729, 1),
(65, 'Suliha', 'Satélite', 9098265, 1439091, 2433128),
(66, 'Iigifoja', 'Planeta', 322627, 3074983, 6645097),
(67, 'Salemo', 'Satélite', 3099382, 98489, 1966146),
(68, 'Riheva', 'Planeta', 5760359, 4619424, NULL),
(69, 'Gubamaqodu', 'Planeta', 5061346, 9269160, NULL),
(70, 'Nakina', 'Satélite', 1784101, 3084446, 3616418),
(71, 'Cosoyimi', 'Planeta', 905423, 8542242, 257846),
(72, 'Yamige', 'Satélite', 7016669, NULL, 9),
(73, 'Je', 'Cometa', 3689533, 3526635, 6829927),
(74, 'Humepijogu', 'Satélite', 5368734, 6278171, 72),
(75, 'Pofu', 'Planeta', 6777734, 6432708, NULL),
(76, 'Lajoqu', 'Planeta', 3574003, 2529933, 7504837),
(77, 'Sagoqafe', 'Satélite', 3620660, 6329440, 6),
(78, 'Ruyewe', 'Planeta', 3924871, 8204241, 8297452),
(79, 'Zibuheco', 'Planeta', NULL, 6865202, 1174813),
(80, 'Pubakiqi', 'Satélite', 1196499, 799506, 8),
(81, 'Ge', 'Satélite', 1417585, 7966773, 8637791),
(82, 'Sawedeyoda', 'Satélite', 7373000, 7256075, 894),
(83, 'Reviso', 'Satélite', 5025447, 5943418, 8179443),
(84, 'Iihewa', 'Planeta', 6498468, 3663141, 963),
(85, 'Du', 'Planeta', 2040754, 1886605, 735173),
(86, 'Waye', 'Planeta', 8835330, 581492, 2210677),
(87, 'Digika', 'Planeta', 1302791, NULL, 7931724),
(88, 'Ni', 'Planeta', 5475836, 707671, 1874965),
(89, 'Lazaha', 'Planeta', 1259246, 7488868, 540),
(90, 'Uoluwu', 'Satélite', 2585630, 551338, 720126),
(91, 'Jirujida', 'Planeta', 2483625, 6058131, 83),
(92, 'Fekuja', 'Planeta', 4153064, 6707514, 2257991),
(93, 'Vobi', 'Planeta', 7432039, 6609387, NULL),
(94, 'Bukuho', 'Planeta', 1869920, 1756583, 5130412),
(95, 'Wupuno', 'Planeta', 544512, 982842, 677),
(96, 'Pejoca', 'Satélite', 5949316, NULL, 2868995),
(97, 'Wesesefeca', 'Planeta', 8398772, 573518, 8201722),
(98, 'Xidu', 'Planeta', 9996623, 9615567, 2821793),
(99, 'Hizozi', 'Planeta', 4802627, 1805491, 460729),
(100, 'Iomedexi', 'Satélite', 6159317, 8233879, 59),
(101, 'Nopupa', 'Planeta', 65001, 8680266, 9886305),
(102, 'Huqu', 'Planeta', 1670374, 4183674, 9422344),
(103, 'Wehafehi', 'Cometa', 747351, 4776433, 358),
(104, 'Xaqizo', 'Planeta', 4031415, 3235835, NULL),
(105, 'Euxanu', 'Satélite', 9480282, NULL, 7166889),
(106, 'Lakifi', 'Satélite', NULL, 1199655, 2096730),
(107, 'Kayapu', 'Planeta', 3792024, 1160605, 7648017),
(108, 'Yokica', 'Satélite', 4394967, 7316919, 8977630),
(109, 'Qevi', 'Planeta', 2915505, 3952833, 4991450),
(110, 'Qalaje', 'Planeta', 2507704, 825186, 7478039),
(111, 'Rexejala', 'Asteroide', 6346927, 76862, 28),
(112, 'Vibaviyu', 'Planeta', 9150158, 3699455, 9367984),
(113, 'Gewo', 'Planeta', 2365320, 7523292, 6933),
(114, 'Negiharu', 'Satélite', 6032412, 7160601, 324226),
(115, 'Sogago', 'Asteroide', 6028322, 4862317, 1675),
(116, 'Oijiwo', 'Planeta', 9989094, 9044155, 8753245),
(117, 'Wafiju', 'Planeta', 3957684, 8588228, 5252355),
(118, 'Faze', 'Cometa', 1712491, 1377063, NULL),
(119, 'Uuze', 'Planeta', 2168318, 7380525, 1764386),
(120, 'Loyecome', 'Planeta', 1983327, 6412471, 41),
(121, 'Qitemi', 'Asteroide', NULL, 7130593, NULL),
(122, 'Mozuse', 'Planeta', 4618668, 5235575, 7242),
(123, 'Vajegecija', 'Satélite', 5439887, 198461, 9945302),
(124, 'Jiqeceta', 'Planeta', 2172067, 7993317, 428877),
(125, 'Jewido', 'Satélite', 805510, 7343980, 1597721),
(126, 'De', 'Planeta', 4873598, 74911, 8),
(127, 'Oiwodo', 'Planeta', 7175826, 1638928, 7351046),
(128, 'Gicohifele', 'Satélite', 6205127, 9967206, 7944507),
(129, 'Gifoju', 'Planeta', 6447716, 8718604, 4434938),
(130, 'Oivi', 'Satélite', 6740414, NULL, 6179),
(131, 'Uetufahita', 'Planeta', 9029021, 1114925, 5824722),
(132, 'Qunala', 'Satélite', 5540247, 6995431, 9916367),
(133, 'Wiqu', 'Planeta', NULL, 3514784, NULL),
(134, 'Kahizubi', 'Planeta', 4536135, 8112926, NULL),
(135, 'Qero', 'Planeta', 9965732, 3576426, 7857201),
(136, 'Sesedaxu', 'Planeta', 470962, 2778707, 8736151),
(137, 'Zawixe', 'Planeta', 5298991, 5327207, 5746887),
(138, 'Yodetozi', 'Planeta', 9188636, 5078352, 3314419),
(139, 'Fexuja', 'Planeta', 355054, 1976050, 4581896),
(140, 'Wuca', 'Planeta', 9545384, 6316460, 496),
(141, 'Aole', 'Planeta', 1875718, 6001796, 6897083),
(142, 'Baripage', 'Planeta', 2395256, 5790346, 6512),
(143, 'Lisipoji', 'Satélite', 4986949, 9226434, 9116439),
(144, 'Gofeno', 'Planeta', 8157247, 1240876, 139878),
(145, 'Begoje', 'Planeta', 5515870, 8426880, 6921982),
(146, 'Titacoti', 'Planeta', 4733074, 4028127, NULL),
(147, 'Mucu', 'Planeta', 4948164, 6451546, 27),
(148, 'Giviri', 'Asteroide', 8908442, 3535426, 5284788),
(149, 'Tuvi', 'Planeta', 9075604, 7191707, 8374253),
(150, 'Podohici', 'Satélite', 5731009, 599106, 6737027),
(151, 'Fodesabeze', 'Satélite', 3601578, 4717990, 5297402),
(152, 'Poqa', 'Planeta', 6936723, 5799940, 3422238),
(153, 'Ceni', 'Satélite', 7071985, 5360120, 8705647),
(154, 'Vozowami', 'Satélite', NULL, 5247527, 1413506),
(155, 'Honipumi', 'Satélite', 4793927, 2125228, NULL),
(156, 'Vapiki', 'Planeta', 1744226, 6344337, 243532),
(157, 'Gepabihi', 'Cometa', 1620293, 5162729, 8406255),
(158, 'Diqoxo', 'Satélite', 3510849, 5051249, 77),
(159, 'Ouqunura', 'Planeta', NULL, 9068480, 5515027),
(160, 'Luqasa', 'Satélite', 8768697, 3488606, 3883896),
(161, 'Valono', 'Planeta', 7808656, 6867145, 2987218),
(162, 'Pi', 'Planeta', 2561790, 4364079, 2722944),
(163, 'Ralepa', 'Cometa', 767576, 2748812, 3699),
(164, 'Iahabefe', 'Satélite', 2443847, 9270092, NULL),
(165, 'Qepotaxe', 'Planeta', 4472955, 124769, 6031328),
(166, 'Roja', 'Asteroide', NULL, 9790324, 0),
(167, 'Uebeha', 'Cometa', 6974693, 8462530, 6313629),
(168, 'Votanipata', 'Satélite', 9588950, 7832700, 7452),
(169, 'Pafikugu', 'Planeta', 6367444, 4538529, 3177345),
(170, 'Qi', 'Planeta', 4314249, 2594598, 6123),
(171, 'Uubi', 'Satélite', 4124773, 2756493, 6171037),
(172, 'Wodila', 'Satélite', 4424386, 2602971, 7995681),
(173, 'Jozuwu', 'Satélite', 3234251, 5474670, 6),
(174, 'Wado', 'Planeta', 9921825, 6696372, 9),
(175, 'Hi', 'Satélite', 3257875, 1091914, 8618839),
(176, 'Miqime', 'Planeta', 758277, 1987354, 105),
(177, 'Xuxofo', 'Cometa', 4774721, 2107900, 27),
(178, 'Yidoxe', 'Planeta', 6750977, 8467179, 9572418),
(179, 'Dumajalo', 'Satélite', 3813900, 3291141, NULL),
(180, 'Zibomuduxa', 'Planeta', 5004510, 5559379, 5540613),
(181, 'Daxo', 'Satélite', 8417972, 9513148, 9660666),
(182, 'Joci', 'Planeta', 8514673, 4245702, 6977049),
(183, 'Sihobone', 'Satélite', 5481541, 1590214, 413602),
(184, 'Oalelame', 'Asteroide', 488793, 7073765, NULL),
(185, 'Reyuruje', 'Planeta', NULL, 2603195, 2020559),
(186, 'Iekawa', 'Asteroide', 6103262, 9041788, 1233184),
(187, 'Lesoza', 'Planeta', 2672760, 3088374, 9636929),
(188, 'Oo', 'Satélite', 4614709, 3995361, NULL),
(189, 'Ouhegi', 'Planeta', 4194024, 920941, 8474600),
(190, 'Gu', 'Satélite', 1384845, 445653, 5595783),
(191, 'Wigeqekemo', 'Planeta', NULL, 4609515, 303),
(192, 'Zunurava', 'Planeta', 9238181, 9882727, 3227512),
(193, 'Pegefo', 'Planeta', 8512703, 414462, NULL),
(194, 'Wuju', 'Planeta', NULL, NULL, 3200225),
(195, 'Mojucoruka', 'Satélite', 4717798, 2402277, 283),
(196, 'Fowadasa', 'Planeta', 9394441, 2890455, NULL),
(197, 'Xacila', 'Planeta', 5768531, 3523927, 9714651),
(198, 'Mepoqe', NULL, 9075452, NULL, 65),
(199, 'Oedesifura', 'Satélite', 8581201, 1197835, 5015227),
(200, 'Qodiwo', 'Planeta', 4476100, 3972266, 2),
(201, 'Jonala', 'Planeta', NULL, 5843093, 8),
(202, 'Lasu', 'Planeta', 7748972, 5793214, NULL),
(203, 'Xefiwu', 'Planeta', 2506207, 6094901, 2378831),
(204, 'Miyecica', 'Satélite', 915218, 6889946, 4730237),
(205, 'Repoxeyu', 'Cometa', 7530633, 9993303, 8440858),
(206, 'Jugawa', 'Planeta', 9669404, 9836300, 2117594),
(207, 'Womoqa', 'Satélite', 3720735, 9376422, 8932218),
(208, 'Goqasoho', 'Cometa', 3017894, 2337195, 9800258),
(209, 'Eazi', 'Planeta', 2066833, 3654981, 24),
(210, 'Puxewohaxi', 'Satélite', 7015293, 8035205, NULL),
(211, 'Gufoku', 'Planeta', 6663446, 3191097, 1037067),
(212, 'Feqavewu', 'Planeta', 459334, NULL, 4),
(213, 'Uuhuguzo', 'Planeta', 9619288, 6798476, 8760094),
(214, 'Iucidiqe', 'Asteroide', 6105768, 1310824, 6449081),
(215, 'Qubiquqa', 'Satélite', 5407324, 5584706, 7504123),
(216, 'Lo', 'Satélite', 9564014, 4178408, NULL),
(217, 'Pedidati', 'Planeta', 2410048, 1016795, 74),
(218, 'Vavagu', 'Planeta', NULL, 4361594, 2),
(219, 'Iesare', 'Planeta', 2493178, NULL, 111083),
(220, 'Xudo', 'Planeta', 3436635, 7665714, 84),
(221, 'Jumupuva', 'Cometa', 9262376, 9368049, 612),
(222, 'Banaji', 'Planeta', 2762217, 343608, 6542475),
(223, 'Xofici', 'Satélite', 342222, 3306178, 3665923),
(224, 'Sule', 'Planeta', 456041, 683542, 910),
(225, 'Juxeza', 'Satélite', NULL, 3139120, NULL),
(226, 'Tafupe', 'Planeta', 7845598, 8207552, 7848394),
(227, 'Yimudaqo', 'Planeta', 7356464, 4206138, NULL),
(228, 'Uiwo', 'Cometa', 5544113, 9049788, 6380388),
(229, 'Waxa', 'Planeta', 1225184, 3212189, 942),
(230, 'Mejekugo', 'Planeta', 2800167, 2156580, 9895299),
(231, 'Gacomi', 'Satélite', 6090349, 7372341, 8027456),
(232, 'Pericusu', 'Planeta', 8766942, 3920600, 4749972),
(233, 'Tepu', 'Satélite', 3492417, 4144716, 2958296),
(234, 'Lu', 'Satélite', 4482309, 5015290, 5187164),
(235, 'Silece', 'Satélite', 7892959, 3405134, 7044780),
(236, 'Uujedodu', 'Satélite', 5663164, 1468983, 2538276),
(237, 'Ridupo', 'Planeta', 7215706, 6687041, 7832388),
(238, 'Raca', 'Satélite', 4644741, 9684956, 3659546),
(239, 'Lepa', 'Satélite', 9821091, 6622652, 8891690),
(240, 'Bemacu', 'Planeta', 8599752, NULL, 4260048),
(241, 'Bogawisu', 'Planeta', 3745605, 3611875, 3619841),
(242, 'Gisuzi', 'Satélite', 137738, 1178619, 785227),
(243, 'Ausegadi', 'Planeta', 3516959, 919284, 4991500),
(244, 'Aeta', 'Satélite', 136722, 2449983, 490),
(245, 'Qizuha', 'Planeta', 8082451, 59045, 261),
(246, 'Nihireli', 'Planeta', 747079, 1599853, 6424182),
(247, 'Bigebe', 'Planeta', 5268802, 5789273, 2684874),
(248, 'Gadeye', 'Satélite', NULL, 8729837, 9259863),
(249, 'Sukoxexohu', 'Satélite', 5492184, 1663560, 6390458),
(250, 'Zo', NULL, 4683902, NULL, 4213),
(251, 'Yixalesi', 'Cometa', 6406046, 7489483, NULL),
(252, 'Keka', 'Asteroide', 3983350, NULL, 170),
(253, 'Nate', 'Planeta', 3723498, 6437848, 4271846),
(254, 'Gamiba', 'Satélite', NULL, 7549731, 1000438),
(255, 'Dunazuji', 'Satélite', 5858347, 4265003, 6182254),
(256, 'Wuvi', 'Planeta', 2098039, 7658473, 2975711),
(257, 'Zekupe', 'Asteroide', 2083891, 546750, 1169540),
(258, 'Iokoke', 'Planeta', 8182612, 5801283, 5130005),
(259, 'Mudugopi', 'Satélite', 2170065, 5271815, 3156249),
(260, 'Ropa', 'Satélite', 1301767, 5239273, 9),
(261, 'Cu', 'Planeta', 848017, NULL, 339),
(262, 'Gubeqo', 'Planeta', 6051147, 7276065, 624),
(263, 'Vufiku', 'Planeta', 6759328, 7441890, 7),
(264, 'Iesuyabo', 'Satélite', 5339863, 4438886, 1),
(265, 'Ba', 'Planeta', 3759020, 5841321, 7983203),
(266, 'Kaxine', 'Asteroide', 311786, 320889, 307),
(267, 'Eowudi', 'Planeta', 1386218, NULL, 4857009),
(268, 'Ziyufo', 'Satélite', 6545461, 5109571, 2382884),
(269, 'Qetoje', 'Planeta', 4922986, 3191184, 2022160),
(270, 'Iibazi', 'Planeta', 3715413, 5846617, 4145160),
(271, 'Qokomimo', 'Planeta', 5260041, NULL, 332552),
(272, 'Mo', 'Satélite', NULL, 1545338, 9),
(273, 'Nunele', 'Planeta', 8341120, 2789949, 1233247),
(274, 'Ietugi', 'Satélite', 6095022, 2110141, 6908341),
(275, 'Hokujaduse', 'Planeta', 381116, 2246488, 9),
(276, 'Godoto', 'Satélite', 8527899, 2399801, 8498117),
(277, 'Xovu', 'Cometa', 4154746, 6059246, NULL),
(278, 'Lafome', 'Planeta', 7389066, 986301, 9332400),
(279, 'Jatezu', 'Cometa', 41460, 8681363, NULL),
(280, 'Waja', 'Planeta', 1198689, NULL, 3584942),
(281, 'Miqemula', 'Satélite', 8772297, 6464477, 3296511),
(282, 'Oebaya', 'Planeta', 3988931, 1934029, 7958979),
(283, 'Oavibisizu', 'Satélite', 2813414, 2331234, 1606467),
(284, 'Ouwe', 'Planeta', 7440145, 5258705, 6488606),
(285, 'Yajisi', 'Planeta', 8630721, 6748002, 7347),
(286, 'Mofoza', 'Planeta', 9117763, 5336580, 9),
(287, 'Powixopi', 'Satélite', 7000959, 5958229, 8247),
(288, 'Nimosuho', 'Satélite', 7326911, 3656353, 1980212),
(289, 'Rumiwu', 'Planeta', 3957641, 4789343, 1224226),
(290, 'Kofovivo', NULL, NULL, NULL, 4936518),
(291, 'Vuceti', 'Planeta', 5975237, 20458, 6299635),
(292, 'Rivavepi', 'Planeta', 733276, 166919, 3673922),
(293, 'Aituho', 'Cometa', 496469, 1323973, 7556),
(294, 'Leseyu', NULL, 5337185, NULL, 2502804),
(295, 'Vozegu', 'Planeta', 5737063, 6373968, 7038807),
(296, 'Kezi', 'Planeta', 7215464, 8352513, 5396288),
(297, 'Wibewe', 'Planeta', 9533884, 5756643, 7358816),
(298, 'Vocure', 'Satélite', 4941782, 2761707, 4610490),
(299, 'Qafa', 'Satélite', 7121378, 1735678, 2329472),
(300, 'Oawe', 'Planeta', 4895204, 3945571, NULL),
(301, 'Henuze', 'Satélite', NULL, 2160376, NULL),
(302, 'Kaqawi', 'Planeta', 1332079, 5726838, 9644806),
(303, 'Zawe', 'Planeta', 8629510, 91259, 6678609),
(304, 'Fidiwiwi', 'Planeta', 3602678, 5208327, 5983516),
(305, 'Wape', 'Planeta', 4745571, 8828987, 4474213),
(306, 'Cuto', 'Planeta', 6943631, 4849766, 9456757),
(307, 'Papiyaki', 'Satélite', 9427780, 2606156, 1518890),
(308, 'Rujijuzu', 'Planeta', 4952891, 494931, 2811324),
(309, 'Gowocazopu', 'Asteroide', 8423278, 5362428, 8579),
(310, 'Ho', 'Asteroide', 4433533, NULL, 9),
(311, 'Meda', 'Satélite', NULL, 1872905, 3033881),
(312, 'Veraxaxi', 'Planeta', 9912969, 8690063, 7238490),
(313, 'Fozuzo', 'Satélite', 4157636, 8147920, 4212147),
(314, 'Eoro', 'Asteroide', 7437474, NULL, 4204507),
(315, 'Xujesugesi', 'Planeta', 6467888, 1915342, 2450616),
(316, 'Eatogi', 'Satélite', 3171582, 3277840, 2942093),
(317, 'Kokomu', 'Asteroide', 2418549, 6608279, 1597041),
(318, 'Eacozu', 'Satélite', NULL, 9794117, 65),
(319, 'Muqurepe', 'Cometa', NULL, 5675439, 1252926),
(320, 'Uiqoseva', 'Planeta', 9662257, 7536855, 7019938),
(321, 'Eovu', 'Satélite', 2434683, 3904018, NULL),
(322, 'Eojora', 'Planeta', 7507685, 2906983, 9),
(323, 'Aepa', 'Satélite', 6113545, 5211601, 1217876),
(324, 'Laca', 'Satélite', 761932, 8210148, 30),
(325, 'Jepi', 'Satélite', 3051635, 8781342, 466718),
(326, 'Huquke', 'Planeta', 7213723, 1444496, 15071),
(327, 'Ruha', 'Planeta', 1616700, 8336720, 3180349),
(328, 'Eocexedopa', 'Planeta', 4533806, 1234778, 1927781),
(329, 'Fuyuze', 'Planeta', 7974671, 8203303, 8079652),
(330, 'Puricemujo', 'Satélite', 5891915, 1379917, 2563042),
(331, 'Viyaneza', 'Satélite', 6688804, 5299444, 8187312),
(332, 'Uakubu', 'Planeta', 5136362, 3725456, 8560083),
(333, 'Nalu', 'Planeta', 4307182, 7559900, 3873340),
(334, 'Duquvomuze', 'Satélite', 2805335, NULL, 4953538),
(335, 'Vihehofo', 'Planeta', 6941234, 153018, 94),
(336, 'Yayiwifato', 'Satélite', 9153708, 1276166, 3647668),
(337, 'Kido', 'Cometa', 4167805, 7323481, 7),
(338, 'Meno', 'Satélite', 3200181, 6079583, 2),
(339, 'Hidiliya', 'Planeta', 6482859, 4826823, 52),
(340, 'Liqoco', 'Planeta', 7005382, 2337863, 3176771),
(341, 'Qope', 'Satélite', 9618462, 7475324, 7166308),
(342, 'Ramo', 'Planeta', 6743431, 7028687, 2),
(343, 'Rofala', 'Planeta', 1495741, 3515845, 155),
(344, 'Ya', 'Planeta', 423717, NULL, 3955155),
(345, 'Uukumefeho', 'Satélite', 1036047, 7504066, 2020274),
(346, 'Na', 'Cometa', 9587013, 4839307, 3094750),
(347, 'Mozanuqo', 'Planeta', 750720, 8734139, 975885),
(348, 'Aotahi', 'Planeta', 3632889, 3329551, 8109627),
(349, 'Hifuzoxo', 'Planeta', 7547472, 4578934, 2367694),
(350, 'Gacuku', 'Satélite', 8792460, 270519, 17),
(351, 'Fipigado', 'Planeta', 7984232, 489174, 8),
(352, 'Bapu', 'Planeta', 1694902, 3374162, 8939),
(353, 'Lojifame', 'Planeta', 389049, 5711510, NULL),
(354, 'Koxupixe', 'Satélite', 9294808, 1054408, 4806451),
(355, 'Ciwozepa', 'Planeta', NULL, 7064001, 5632996),
(356, 'Tanidocu', 'Planeta', 324450, 2788191, 9660747),
(357, 'Bacibaco', 'Planeta', 9348498, 7168147, 528316),
(358, 'Divadici', 'Satélite', 1806696, 4421071, 6483404),
(359, 'Paseyomo', 'Cometa', 2075226, 8134039, NULL),
(360, 'Li', 'Planeta', 5512826, 7841306, 5638522),
(361, 'Zebiqo', 'Planeta', 3334816, 6738781, 1),
(362, 'Turuto', 'Planeta', 8234283, 2421584, 9355530),
(363, 'Temupofo', 'Satélite', 1506687, 4200219, 4278135),
(364, 'Eeyulevo', 'Planeta', NULL, 3167802, 9056791),
(365, 'Xoha', 'Planeta', NULL, 7907632, 971),
(366, 'Hozasisu', 'Planeta', 5068375, 4610247, NULL),
(367, 'Xocoqobivi', 'Planeta', 7659100, 4637920, NULL),
(368, 'Helaxa', 'Asteroide', 7688004, 1052543, 60),
(369, 'Sasisilo', 'Planeta', 5735131, 3714377, 7284047),
(370, 'Aeqe', 'Planeta', 746898, 1211496, NULL),
(371, 'Ri', 'Satélite', 1021940, 2977826, 6275051),
(372, 'Iela', 'Planeta', 1294336, NULL, NULL),
(373, 'Neqonu', 'Planeta', 5907878, 1904299, 8715333),
(374, 'Foxo', 'Cometa', 8863229, 8764523, 6055469),
(375, 'Ruvosuwuge', 'Satélite', 168854, 7892981, NULL),
(376, 'Toquyi', 'Planeta', 247307, 9656592, 5),
(377, 'Qehi', 'Planeta', 1606848, 598568, 16),
(378, 'Qu', 'Satélite', 1182771, 1499623, 1310847),
(379, 'Pewepi', 'Satélite', 7514472, 3750980, 8692122),
(380, 'Eura', NULL, 5180548, NULL, 505998),
(381, 'Mexu', 'Planeta', 7632465, NULL, 2159786),
(382, 'Iabozo', 'Planeta', 3755658, 8716803, 975686),
(383, 'Kavuju', 'Satélite', 1177045, NULL, 6260917),
(384, 'Cibuhone', 'Satélite', NULL, 4762623, 588454),
(385, 'Suzesa', 'Planeta', 9335607, 5929765, 69),
(386, 'Aaduva', 'Satélite', 3845686, 958496, NULL),
(387, 'Hafowi', 'Planeta', 6200362, 7762835, 18),
(388, 'Muzu', 'Planeta', NULL, 8165531, 15),
(389, 'Megose', 'Satélite', 7091877, 7762316, 6839805),
(390, 'Cija', 'Planeta', 857952, NULL, 6),
(391, 'Luti', 'Cometa', 3532302, 4629546, 5324284),
(392, 'Mulutakiza', 'Planeta', 5566814, NULL, 7),
(393, 'Aitonevifi', 'Planeta', 607705, 572456, 3199253),
(394, 'Dahodomi', 'Planeta', 4855902, 391456, 9012653),
(395, 'Mu', 'Planeta', 1003561, NULL, 34),
(396, 'Iaziko', 'Planeta', 2483012, 5183826, 1039797),
(397, 'Fiteme', 'Planeta', NULL, 5138794, 8382851),
(398, 'Tuju', 'Planeta', 9422927, 7171809, 6978648),
(399, 'Ravaralu', 'Planeta', 9117344, 9807159, NULL),
(400, 'Feceba', 'Satélite', 4199772, 8905126, 8),
(401, 'Rizude', 'Planeta', 7245291, 1182507, 2767),
(402, 'Buxenane', 'Planeta', 7292535, 9174967, 3064294),
(403, 'Eutuxemi', 'Planeta', 5631240, 7443934, 2),
(404, 'Juqani', 'Planeta', 5818499, 8695263, 3344503),
(405, 'Beza', 'Planeta', NULL, 5237026, NULL),
(406, 'Kuwiko', 'Planeta', 6431103, 6934522, 6406666),
(407, 'Sidafitigi', 'Satélite', 2896846, NULL, 582282),
(408, 'Sexide', 'Planeta', 8042488, 9381384, NULL),
(409, 'Siqeku', 'Planeta', 9942882, 6307026, 4059045),
(410, 'Guziwu', 'Satélite', 399618, 3644327, 9788768),
(411, 'Luhama', 'Satélite', 6883061, 1136912, 1465688),
(412, 'Qutoxipo', 'Planeta', 576700, 7615118, 2572389),
(413, 'Lufoqu', 'Cometa', 3253129, NULL, 858853),
(414, 'Wokerobino', 'Planeta', 2149498, 6797878, 4998467),
(415, 'Geneqa', 'Planeta', 1131674, 6382992, 8990878),
(416, 'Joqewaqa', 'Planeta', 4937029, 3122311, 6),
(417, 'Qura', 'Satélite', NULL, 2221550, 1202367),
(418, 'Iuledoqe', 'Satélite', 4889478, 2820846, 8929915),
(419, 'Aeyuhanica', 'Satélite', 9620547, NULL, 8699285),
(420, 'Suhucoxo', 'Planeta', 6516059, 2732111, 1065158),
(421, 'Ji', 'Planeta', 1907758, 2254097, 891868),
(422, 'Puci', 'Satélite', NULL, 8052441, NULL),
(423, 'Monuyo', 'Satélite', 8322307, 339657, NULL),
(424, 'Tahijusodu', 'Planeta', 5874536, 9829332, 6355),
(425, 'Aolaqa', 'Planeta', 1513298, 1494997, 4887341),
(426, 'Loze', 'Satélite', 6097219, 8094941, 365),
(427, 'Lireji', 'Satélite', 2171419, 3881515, 7389),
(428, 'Iimu', 'Satélite', 9518136, 3922894, 1553327),
(429, 'Legasino', 'Planeta', 1026059, 9913801, NULL),
(430, 'Tutetevo', 'Satélite', 9443548, NULL, 10),
(431, 'Jiqayawu', 'Planeta', 9923869, 5720691, 8302911),
(432, 'Lebezi', 'Satélite', 7344038, 6710774, 5073024),
(433, 'Momureju', 'Planeta', 9472217, 8034643, 8623121),
(434, 'Iawoga', 'Planeta', 3547749, 308481, 917728),
(435, 'Oeqo', 'Satélite', 9455529, NULL, 4962002),
(436, 'Lezojumone', 'Planeta', 453163, 4233827, 3355016),
(437, 'Oita', 'Satélite', 1892688, 3970534, 1563988),
(438, 'Hucurafifi', 'Planeta', NULL, 1978355, 95),
(439, 'Honoyoyote', 'Planeta', 7831385, 773416, 7292382),
(440, 'Wehiwu', 'Planeta', 6836450, 4402205, 59),
(441, 'Pequ', 'Satélite', 6824555, 5944650, 9009596),
(442, 'Gamupa', 'Planeta', 3625381, 6437896, 9700042),
(443, 'Joyeza', 'Planeta', 5291770, 2854757, 61),
(444, 'Yawubu', 'Planeta', 3847028, 2447604, 8805640),
(445, 'Ieco', 'Planeta', 8667948, 9775478, 816570),
(446, 'Xuci', 'Planeta', 6425341, 6396700, 342144),
(447, 'Gezu', 'Asteroide', NULL, 9273466, 3438590),
(448, 'Jada', 'Planeta', 2125701, NULL, 5670418),
(449, 'Tilu', 'Satélite', NULL, 5085588, 65),
(450, 'Uetuwi', 'Asteroide', 8669501, 1720026, 2000275),
(451, 'Yogumava', 'Satélite', NULL, 7564762, 7385378),
(452, 'Sobi', 'Planeta', 1262804, NULL, 7790602),
(453, 'Gisila', 'Cometa', 9798664, 8707067, 7378216),
(454, 'Zijoyopa', 'Planeta', 8617668, 5443326, 88),
(455, 'Bami', 'Planeta', 1708602, 4187369, 5733827),
(456, 'Wokoxa', 'Planeta', 993427, 5422564, 5394),
(457, 'Baza', 'Satélite', 8306294, 383388, 3),
(458, 'Viku', 'Planeta', 5425527, 1017628, NULL),
(459, 'Wuwusa', 'Planeta', 7974342, NULL, 9),
(460, 'Pamidigi', 'Planeta', 2117183, 8210495, 8784584),
(461, 'Hoyeka', 'Planeta', 8597090, 8469285, 7481835),
(462, 'Oohafi', 'Cometa', 5136837, 1579801, 2737607),
(463, 'Uufozo', 'Satélite', 8162237, 2224752, 922262),
(464, 'Qa', 'Satélite', 155968, NULL, 12),
(465, 'Rebaki', 'Cometa', 6402768, 452087, NULL),
(466, 'Eetecumi', 'Asteroide', 7114894, 990869, 256),
(467, 'Qolaci', 'Planeta', 552817, 439164, 17),
(468, 'Tuwizunifa', 'Cometa', 5515139, 634716, 35880),
(469, 'Lelaqara', 'Satélite', 5975813, 7430068, NULL),
(470, 'Kego', 'Asteroide', 9956999, 6160777, 8928),
(471, 'Savi', 'Planeta', 2204718, 438511, 1898081),
(472, 'Gaduli', 'Satélite', 4467007, 6552428, 1929096),
(473, 'Zederibe', 'Planeta', 5182070, 6183099, NULL),
(474, 'Oikewape', 'Satélite', 6519521, 2089922, 9649762),
(475, 'Kohusaju', 'Satélite', 9207258, 3490058, 4205729),
(476, 'Xisisafe', 'Asteroide', 9687176, 7370884, 27),
(477, 'Zeniro', 'Planeta', 6472148, 7234989, 56),
(478, 'Teroluya', 'Satélite', 9993438, 8461239, NULL),
(479, 'Fevu', 'Satélite', 3673001, 6723640, 6730),
(480, 'Gehido', 'Satélite', 8760209, 6245861, 28),
(481, 'Qaduzu', 'Planeta', 8924458, 4333897, 3754111),
(482, 'Lobize', 'Planeta', NULL, 6933039, 23),
(483, 'Zihiku', 'Planeta', 1000237, 9199860, 19),
(484, 'Eukuko', 'Satélite', 6447485, 334616, 4274905),
(485, 'Nipo', 'Cometa', 3857675, 2105059, 748841),
(486, 'Juquse', 'Planeta', 6293622, 5162749, 9822415),
(487, 'Japu', 'Cometa', NULL, 213459, 833),
(488, 'Mapa', 'Satélite', 5028456, 8100663, 3),
(489, 'Feteku', 'Planeta', 7900359, 4803888, 8086772),
(490, 'Paxaxaneme', 'Planeta', 2181923, 9252676, 0),
(491, 'Domujuli', 'Planeta', 1443823, 940736, 5679035),
(492, 'Zinanoki', 'Cometa', 1805458, 7124759, 6767375),
(493, 'Dake', 'Satélite', 590733, 8660662, 6134102),
(494, 'Eivesitu', 'Planeta', 4014827, 2537248, 9260639),
(495, 'Kexese', 'Cometa', 7339342, 9192470, 6637246),
(496, 'Fatilu', 'Planeta', 6834728, 9592717, NULL),
(497, 'Buxi', 'Satélite', 2097991, 4510149, 658347),
(498, 'Luzonewu', 'Asteroide', 6706266, 1339191, 8324426),
(499, 'Ruqu', 'Planeta', 9603184, 9912692, 1616376),
(500, 'Sipodo', 'Planeta', 3573257, 6849597, 8288097),
(501, 'Luveniwo', 'Planeta', 351414, 5958225, 9894492),
(502, 'Semeniti', 'Cometa', NULL, 4294063, 5012708),
(503, 'Gafovu', 'Planeta', 1082534, 4297243, 6365972),
(504, 'Tujezigode', 'Satélite', 3432629, 4402574, 2668911),
(505, 'Medibura', 'Planeta', 5898937, 5323488, 3167940),
(506, 'Rato', 'Satélite', 3993902, 4609195, 2871400),
(507, 'Yocadimuwi', 'Planeta', NULL, 2372002, 5866491),
(508, 'Hufolakico', 'Planeta', 9137839, 4018320, 3794594),
(509, 'Bufi', 'Asteroide', 5776985, 233488, 2452443),
(510, 'Vehexo', 'Planeta', 6842591, 6890839, 7113730),
(511, 'Migemi', 'Satélite', 1970285, 9916127, NULL),
(512, 'Rido', 'Planeta', 7236628, NULL, 690365),
(513, 'Pazi', 'Satélite', 9073137, 4181529, 3),
(514, 'Sukika', 'Planeta', 3590405, 1239569, 714),
(515, 'Cujagomi', 'Planeta', 7771929, 9942382, 5980159),
(516, 'Jemofebepa', 'Satélite', 6800504, 3118779, 4064),
(517, 'Worexida', 'Planeta', 2777746, 1175243, NULL),
(518, 'Nadoki', 'Planeta', 6522525, 1305199, 1154),
(519, 'Bajesifi', 'Satélite', 8412303, 5268932, 2926668),
(520, 'Zuxivi', 'Planeta', 9233008, 3003847, NULL),
(521, 'Luseha', 'Planeta', 6703748, 3212571, 5643111),
(522, 'Sopumi', 'Planeta', NULL, NULL, 6),
(523, 'Pumimuhe', 'Planeta', 8609167, 1418164, 6690474),
(524, 'Dohiluqu', 'Planeta', 990941, 3983473, NULL),
(525, 'Eaca', 'Satélite', NULL, 8786007, NULL),
(526, 'Wokojixato', 'Satélite', 9087800, 1175918, 37),
(527, 'Fofasi', 'Asteroide', 9405752, 7495852, NULL),
(528, 'Wutifoyo', 'Asteroide', 6739646, 4159710, 8461841),
(529, 'Piquka', 'Planeta', 1045350, 4822086, 6833),
(530, 'Iariku', 'Cometa', 644553, NULL, 4585),
(531, 'Xozu', 'Cometa', 9803004, 6689707, 8986),
(532, 'Mifomi', 'Planeta', 9696397, 1904139, 5017144),
(533, 'Naqu', 'Satélite', 2302966, 659983, 58),
(534, 'Gevokovoza', 'Planeta', 4921937, NULL, 4),
(535, 'Suvudabivo', 'Satélite', 8623800, 1603975, 6359621),
(536, 'Tagu', 'Asteroide', 4851226, 1648014, 2773084),
(537, 'Iipariqa', 'Satélite', 1230600, 4690086, 94),
(538, 'Xofe', 'Cometa', 9072865, 1000219, 9729084),
(539, 'Cepisi', 'Asteroide', 8458914, 4401705, 3270101),
(540, 'Pubenobu', 'Planeta', NULL, 6508491, 4037591),
(541, 'Dasiyivu', 'Satélite', 7477743, 7149306, 6),
(542, 'Gaxanuxulo', 'Planeta', 2764770, 2843603, 5833617),
(543, 'Zevafiju', 'Planeta', 6514532, 5085663, 9106),
(544, 'Lefufu', 'Planeta', 9755559, 174170, 2711628),
(545, 'Varigega', 'Planeta', 8664814, 1248653, 9614191),
(546, 'Qoli', 'Planeta', 4425936, 4414634, 7535218),
(547, 'Pepe', 'Planeta', 9530703, 4839827, 664673),
(548, 'Coxedago', 'Satélite', 9992257, 2256983, 8379182),
(549, 'Zi', 'Planeta', 4763980, NULL, 1880082),
(550, 'Aisecoxa', 'Satélite', 4969184, 2748770, 4521246),
(551, 'Aiwo', 'Planeta', 2318234, 8115761, 47),
(552, 'Iekobe', 'Planeta', 3126570, 1290274, 9530602),
(553, 'Wifive', 'Planeta', 6656183, 2579229, 9),
(554, 'Cumepaqe', 'Planeta', 6466710, 57586, 848),
(555, 'Iejukubu', 'Planeta', 4816618, NULL, 497715),
(556, 'Xudono', 'Planeta', 3496510, 4504942, 129),
(557, 'Taqe', 'Satélite', 5228420, 1661068, 6310725),
(558, 'Borozove', 'Planeta', 9375904, 7332189, 1495638),
(559, 'Jacana', 'Planeta', NULL, 1270696, NULL),
(560, 'Cabiku', 'Planeta', NULL, 3231136, 5598789),
(561, 'Voje', 'Cometa', 9702848, 2913622, 6640606),
(562, 'Boxidaqu', 'Planeta', 1264869, 9117393, 8),
(563, 'Yaqini', 'Cometa', 7420728, 6720034, 55921),
(564, 'Auvu', 'Planeta', 2217042, 2393099, 3464),
(565, 'Gaxa', 'Satélite', 5459055, 4078695, 6617840),
(566, 'Eevo', 'Cometa', 3386031, 6496097, 9667202),
(567, 'Gapola', 'Satélite', 3811602, 786448, 7315312),
(568, 'Xehu', NULL, 6627572, NULL, 4),
(569, 'Kayixu', 'Planeta', 3359380, 8486859, 1690781),
(570, 'Kiyuha', 'Planeta', NULL, 7241823, 7404105),
(571, 'Wicokifili', 'Satélite', 2854884, 2789810, 8443270),
(572, 'Oivo', 'Satélite', NULL, 3085694, 2779470),
(573, 'Nibotewu', 'Satélite', NULL, 8527100, 50),
(574, 'Puseguso', 'Planeta', 6467850, NULL, 8000466),
(575, 'Wazasi', 'Asteroide', 3938080, 3749608, 4558220),
(576, 'Uukufa', 'Satélite', 2756601, 1419171, 223),
(577, 'Iivu', 'Satélite', 5264601, NULL, 1882449),
(578, 'Hosema', 'Cometa', 1265536, 482841, 8),
(579, 'Gusaxedi', 'Planeta', 7228667, 6141000, 9295105),
(580, 'Mene', 'Satélite', 5257611, 7282466, 1304828),
(581, 'Jogozi', 'Planeta', NULL, 6246321, 8038916),
(582, 'Gevobeno', 'Planeta', 6802385, 3450614, 1160202),
(583, 'Aofogo', 'Cometa', 784838, 9682530, 1),
(584, 'Uo', 'Asteroide', 9260306, 8581159, 2042491),
(585, 'Tijoke', 'Planeta', 4607538, NULL, 3364706),
(586, 'Iepeyuho', 'Planeta', 6828562, 2101902, 1613828),
(587, 'Iivisi', 'Planeta', 1819041, 8412864, 5427062),
(588, 'Coragixiza', 'Cometa', NULL, NULL, 3031699),
(589, 'Zibevaho', 'Planeta', 8578963, 5322046, 9168),
(590, 'Foyagi', 'Planeta', 2187498, 5774281, 7951045),
(591, 'Aixoho', 'Planeta', 6628922, 8925271, 1466892),
(592, 'Fi', 'Planeta', 4837293, 6533840, 8847493),
(593, 'Setonani', 'Satélite', 5243995, 1228274, 188),
(594, 'Muwuvu', 'Satélite', 1618194, 7949980, 74373),
(595, 'Toqesuge', 'Satélite', 6826074, 3577925, 2428113),
(596, 'Eeke', 'Asteroide', NULL, 8499560, 4068171),
(597, 'Yime', 'Planeta', 8087463, 8211754, NULL),
(598, 'Cifuto', 'Planeta', 6200808, 6742776, 6770417),
(599, 'Nu', 'Satélite', NULL, 576927, 5101685),
(600, 'Ae', 'Asteroide', 2086770, 6289225, 3273696),
(601, 'Cakatuhu', 'Planeta', 9765603, 5366242, NULL),
(602, 'Vabi', 'Planeta', 9272839, 8341206, 2434765),
(603, 'Seyeme', 'Planeta', 690146, 6786155, 22),
(604, 'Muna', 'Satélite', 5072348, NULL, 596115),
(605, 'Huvogeya', 'Planeta', 2698693, 2077910, 7134940),
(606, 'Oocuya', 'Cometa', 6607622, 5560769, 8389),
(607, 'Rizigayu', 'Satélite', 9287158, 5018871, 3905),
(608, 'Karewepe', 'Planeta', 3937618, 159396, NULL),
(609, 'Aupicoti', 'Satélite', 5480746, 7675302, NULL),
(610, 'Vano', 'Planeta', 900770, 8507584, 444),
(611, 'Kupidi', 'Satélite', 3136097, 4739086, 3),
(612, 'Zino', 'Planeta', 1049751, 5164323, 5224736),
(613, 'Gaqome', 'Satélite', NULL, 3622000, 1216268),
(614, 'Tefocega', 'Satélite', 6899207, 2133753, 1597643),
(615, 'Joxaya', 'Planeta', 2891516, 172488, 1166),
(616, 'Eumijadu', 'Satélite', 1374010, 3086669, 7158703),
(617, 'Vipuqe', 'Planeta', 9391533, 8083011, 5779),
(618, 'Bovige', 'Planeta', 6740476, 6892827, NULL),
(619, 'Masi', 'Planeta', 5309658, NULL, 6586),
(620, 'Wilu', 'Satélite', 4244073, 9942550, 765),
(621, 'Vococoro', 'Satélite', 8897811, 1275262, 5498832),
(622, 'Wewura', 'Asteroide', NULL, 5124453, 9521666),
(623, 'Fotule', 'Planeta', 4851979, NULL, 6747),
(624, 'Kagegafo', 'Planeta', 319575, 9622500, 98),
(625, 'Sabeto', 'Planeta', 1512465, 1835838, 4943642),
(626, 'Oaricojo', 'Satélite', 2414342, 1035577, NULL),
(627, 'Yihebemo', 'Satélite', 1725598, 467597, 1696716),
(628, 'Hoceduje', 'Planeta', 7895907, 9764669, 24),
(629, 'Fonano', 'Planeta', 7161037, 12227, NULL),
(630, 'Hafa', 'Planeta', 9501824, 3930464, 1834931),
(631, 'Hojeqayage', 'Planeta', 523138, 2023667, 9259),
(632, 'Zapeda', 'Planeta', 749220, 6534467, 482),
(633, 'Wuyuhuqa', 'Planeta', 5561366, 7524092, 6031243),
(634, 'Pejewari', 'Satélite', 1922913, 6403255, 4913309),
(635, 'Gimela', 'Planeta', 4975044, 6065245, 91),
(636, 'Zubi', 'Planeta', 4507569, 5595709, 2265904),
(637, 'Rihu', 'Planeta', 704701, 2719641, 4980237),
(638, 'Tovihu', 'Asteroide', 6019257, 3451114, 7241172),
(639, 'Comega', 'Planeta', 7384732, 8127628, 15),
(640, 'Aawocacu', 'Asteroide', 1962885, 9882205, 9987206),
(641, 'Layefi', 'Satélite', 4346265, 6932350, 2414326),
(642, 'Fiha', 'Satélite', 6697483, 9919166, 0),
(643, 'Bumegi', 'Satélite', 674609, 7820463, 237),
(644, 'Uokofuce', 'Satélite', 1634723, 6456843, NULL),
(645, 'Hebaca', 'Planeta', 3478685, NULL, 1817869),
(646, 'Voxucoku', 'Planeta', 1580559, NULL, 2),
(647, 'Earibi', 'Satélite', 9690903, 3671144, 1760393),
(648, 'Yaxaba', 'Planeta', 5956369, 8974688, 648921),
(649, 'Ne', 'Cometa', 5150013, 3153608, 2306249),
(650, 'Qeruhe', 'Satélite', 394180, 8263806, 686180),
(651, 'Ve', 'Asteroide', 1749369, 7647286, 6188213),
(652, 'Xedaqipe', 'Planeta', 1440753, 6295853, 1652801),
(653, 'Payohe', 'Satélite', NULL, 9268042, 440),
(654, 'Fukuza', 'Planeta', 1434728, 1041439, 34),
(655, 'Ranafuju', 'Planeta', 1680747, 2976854, NULL),
(656, 'Mopezuxa', 'Planeta', NULL, 2524761, 333),
(657, 'Ceta', 'Planeta', 5350538, 9972878, NULL),
(658, 'Dizopa', 'Planeta', 3194302, 3438203, 5138216),
(659, 'Pihadicuke', 'Planeta', NULL, 3588795, 4851242),
(660, 'Pupe', 'Planeta', 6588671, 1353120, 7920375),
(661, 'Divo', 'Planeta', 4433969, 6305594, 6050612),
(662, 'Hahino', 'Planeta', 947475, 8620699, 4585106),
(663, 'Vaqoba', 'Planeta', 2480121, 6590902, 46),
(664, 'Aema', 'Asteroide', 3927775, 4576377, 7992175),
(665, 'Rileda', 'Planeta', 7838553, 1288217, 6728249),
(666, 'Nafokira', 'Planeta', 881658, 6225253, 8994803),
(667, 'Ceqi', NULL, 8754392, NULL, 4),
(668, 'Wopetite', 'Satélite', NULL, NULL, NULL),
(669, 'Ye', 'Planeta', 5096294, 4095499, 3826893),
(670, 'Figumefu', 'Planeta', 8304462, 9449795, 600),
(671, 'Oaju', 'Cometa', 1396457, 9368553, 8384045),
(672, 'Ioxonu', 'Planeta', 5958572, 5658690, 8795190),
(673, 'Qiwe', 'Planeta', 7622480, NULL, 5040565),
(674, 'Jesigo', 'Satélite', 1418775, 3053133, 4223170),
(675, 'Dowujavefa', 'Satélite', 494763, 3550523, NULL),
(676, 'Veli', 'Planeta', 5084940, 1356012, 1363319),
(677, 'Rimopi', 'Cometa', 2609816, 7128395, 6867611),
(678, 'Tatonu', 'Planeta', 9133430, 8401083, 4496281),
(679, 'Wotudi', 'Planeta', 266116, 3930550, 4378641),
(680, 'Eego', 'Planeta', NULL, 4735217, 6),
(681, 'Bepaduduje', 'Satélite', NULL, 8757287, 7147582),
(682, 'Qagu', 'Planeta', 182385, 1692991, 596506),
(683, 'Uijuci', 'Planeta', 1981223, 7304608, NULL),
(684, 'Gome', 'Planeta', 5998632, NULL, 9726889),
(685, 'Citogu', 'Asteroide', 6036104, 2559911, 4276837),
(686, 'Yelixuzu', 'Planeta', 3643834, 8030149, NULL),
(687, 'Euzo', 'Planeta', 9591693, 9777675, 1675582),
(688, 'Pari', 'Planeta', 2704044, NULL, 4758600),
(689, 'Eubiko', 'Planeta', 4803942, 6113346, 967515),
(690, 'Ioqedemuvu', 'Satélite', 1470034, 6026619, 8176),
(691, 'Telize', 'Planeta', 8347359, NULL, 2679257),
(692, 'Wugi', 'Cometa', 9637576, 6528370, 35),
(693, 'Mequpi', 'Satélite', 1404991, 5952156, 5112),
(694, 'Au', 'Planeta', 4972906, NULL, 5166458),
(695, 'Wimu', 'Planeta', 4521967, 913238, 9540243),
(696, 'Xuvi', 'Satélite', 6856447, 2554681, 8146417),
(697, 'Yasecagu', 'Asteroide', 855194, NULL, 9129848),
(698, 'Denevuye', 'Planeta', 7996299, 1793447, 3668092),
(699, 'Wedi', 'Planeta', 6345399, 9669888, 753136),
(700, 'Oonaku', 'Planeta', 8375087, 7597494, NULL),
(701, 'Xapebamu', 'Asteroide', 5702390, 5885577, 5758352),
(702, 'Puxoyu', 'Satélite', 943018, 9355642, 4561690),
(703, 'Yene', 'Planeta', 3040111, 5162449, 74),
(704, 'Iipu', 'Planeta', 6666374, 78390, 5779350),
(705, 'Guzo', 'Planeta', NULL, 3048911, 4685440),
(706, 'Aotuyula', 'Satélite', 8113961, 6395241, 663655),
(707, 'Dirurolo', 'Planeta', 6134180, 4577953, 516),
(708, 'Zawivuku', 'Cometa', 3533930, 9450560, 3615677),
(709, 'Vorota', 'Planeta', 9310346, 6670578, NULL),
(710, 'Nudajewavo', 'Planeta', 482815, 3491780, 1841571),
(711, 'Zikequ', 'Satélite', 303352, 9542164, 1654725),
(712, 'Xuraxi', 'Planeta', 5840729, 8311493, 726),
(713, 'Vanajuyo', 'Planeta', 6633293, 9845603, 8958651),
(714, 'Womeyeji', 'Planeta', NULL, 3260522, 9509504),
(715, 'Febi', 'Satélite', 2655457, 5503442, 0),
(716, 'Mecijageta', 'Planeta', 358234, 3841967, 35),
(717, 'So', 'Planeta', 8646374, 9868210, 4410),
(718, 'Zecozobi', 'Asteroide', 6360163, 2424218, 4446173),
(719, 'Kiru', NULL, 3617509, NULL, 1657194),
(720, 'Seziwi', 'Cometa', 3023721, 2817069, 3353727),
(721, 'Ie', 'Planeta', 5150735, 535004, NULL),
(722, 'Wigo', 'Satélite', 5940118, 9231896, 4748958),
(723, 'Dujojeko', 'Cometa', 1683790, 5724333, 8497046),
(724, 'Mohu', 'Planeta', 2948746, 8506194, 1),
(725, 'Jeleqa', 'Asteroide', 4175940, 2606815, 314),
(726, 'Vaxosoja', 'Planeta', 3512829, 9703991, 82),
(727, 'Livibu', 'Planeta', 1468143, 6281276, 28),
(728, 'Nuzusuja', 'Planeta', 6906180, 5541686, 1880863),
(729, 'Oazubawa', 'Satélite', 5672699, 4013248, 6169),
(730, 'Hucebi', 'Cometa', 404197, 3591071, 3731960),
(731, 'Uufarepuga', 'Asteroide', 5047619, 1590812, 3481),
(732, 'Tabego', 'Asteroide', 5449490, 9941802, 4360526),
(733, 'Xiyaqoci', 'Planeta', 8667957, 9861823, 75),
(734, 'Quzuwufa', 'Planeta', 8021131, 7970032, 8679794),
(735, 'Neseba', 'Cometa', 240480, 7275702, 8493720),
(736, 'Kawo', 'Satélite', NULL, 3699377, 5486733),
(737, 'Yaduhohi', 'Planeta', 6883311, 8965628, 1649899),
(738, 'Yojoka', 'Satélite', 6665892, 9583865, 4191100),
(739, 'Gekada', 'Satélite', 8542562, 6808686, 400132),
(740, 'Eujasu', 'Satélite', 7670642, 8916020, 72),
(741, 'Habube', 'Planeta', NULL, 7538077, 86),
(742, 'Hogero', 'Planeta', 7789467, NULL, 3501214),
(743, 'Jufifi', 'Planeta', 2167731, 2789975, NULL),
(744, 'Xuco', 'Planeta', 7418233, 9675169, 2),
(745, 'Xade', 'Satélite', 2332807, 5009239, 580818),
(746, 'Nihe', 'Satélite', 2090358, 2666753, 8886941),
(747, 'Zetihi', 'Planeta', 9982917, 8478282, 8735369),
(748, 'Wufihoci', 'Satélite', 7903992, 8646154, 1688602),
(749, 'Xo', 'Satélite', 3610373, 3783001, NULL),
(750, 'Seso', 'Planeta', 6843029, 3129474, NULL),
(751, 'Yafoco', 'Planeta', 9681674, 9503727, 1110739),
(752, 'Rotasuha', 'Satélite', 8874118, 2231245, 5),
(753, 'Qijato', 'Satélite', 1928198, 1338703, 4471649),
(754, 'Qepefoso', 'Satélite', 1254988, 7220204, 4739975),
(755, 'Qituho', 'Asteroide', 4131417, 854004, 1315768),
(756, 'Wuhe', 'Satélite', 1466097, NULL, 5259849),
(757, 'Lehejamo', 'Satélite', 6660837, 9020954, 4093119),
(758, 'Iuto', 'Satélite', 7938862, 6600031, 9964255),
(759, 'Aa', 'Planeta', 7587904, 4812742, 1466487),
(760, 'Iaxi', 'Planeta', 2175174, 4508318, 3811413),
(761, 'Lowebire', 'Asteroide', 4472837, 9563540, 15),
(762, 'Hofa', 'Planeta', 6339720, 5928745, 4319),
(763, 'Voci', 'Planeta', 9170175, 7516362, NULL),
(764, 'Luwu', 'Satélite', 2755004, 2786624, 4910349),
(765, 'Gurepaye', 'Planeta', NULL, 1956380, 881),
(766, 'Uoko', 'Planeta', 4318401, NULL, 674317),
(767, 'Wizora', 'Satélite', 9467361, 7671581, NULL),
(768, 'Qehiro', 'Planeta', 1383772, 2877021, 7677905),
(769, 'Eixukepu', 'Planeta', 3235350, 4571763, 23),
(770, 'Gimabece', 'Planeta', 4246240, 849027, 3355325),
(771, 'Bokomu', 'Planeta', 1281634, 2362013, 9324799),
(772, 'Jevehihu', 'Satélite', 7326596, NULL, 514),
(773, 'Lawode', 'Satélite', 3016145, 9162008, 539882),
(774, 'Vutejesa', 'Satélite', 7684713, NULL, 4),
(775, 'Qexara', 'Planeta', NULL, NULL, 3973108),
(776, 'Iopadumu', 'Planeta', 2132687, 8811076, 6565),
(777, 'Hepoza', 'Planeta', 1308520, 1801350, 6618),
(778, 'Sa', 'Asteroide', 3226765, 6436302, 7),
(779, 'Gorukezo', 'Satélite', 3464618, 4581019, 5987608),
(780, 'Huvu', 'Planeta', 9373503, 7445949, 8741561),
(781, 'Cegeri', 'Planeta', 988112, 3538721, NULL),
(782, 'Xahi', 'Satélite', 4387568, 7345770, 10),
(783, 'Oejolagota', 'Planeta', 189463, 1692753, 7256001),
(784, 'Puvoxotu', 'Planeta', 9332993, 7860150, 2483042),
(785, 'Iaxuzate', 'Satélite', 2537082, 1405862, 434),
(786, 'Bowulapu', 'Planeta', 7944695, 5433016, 7),
(787, 'Zoruxo', 'Cometa', 5078961, 8937990, 8075452),
(788, 'Hiji', 'Satélite', NULL, 1820972, 2067451),
(789, 'Keyi', 'Planeta', 4997730, 2542366, 8718423),
(790, 'Paceku', 'Satélite', 8585188, 2002621, 5006263),
(791, 'Dogi', 'Planeta', 3973932, 3129746, 86),
(792, 'Wulofomu', 'Satélite', 1706742, 2087526, 891044),
(793, 'Aojuyi', 'Asteroide', 4294952, 5068325, 1024428),
(794, 'Zujekixi', 'Satélite', 7789911, 8949896, 6846620),
(795, 'Lecewuhe', 'Cometa', NULL, 2598943, 2976388),
(796, 'Ueco', 'Satélite', NULL, 7699790, NULL),
(797, 'Wevuxu', 'Asteroide', 8413588, 5943441, 3432087),
(798, 'Hutufiwu', 'Planeta', 3928494, 2676980, 9004),
(799, 'Nagulo', 'Planeta', 6014243, 1210429, 4521223),
(800, 'Zilakefi', 'Planeta', 7427734, 8553584, NULL),
(801, 'Pazoliqo', 'Cometa', 6189286, 3535986, 1),
(802, 'Auwuwase', 'Cometa', 4623029, 7559892, 5287537),
(803, 'Nufele', 'Planeta', 5250694, 5594688, 1589),
(804, 'Bekegube', 'Satélite', 633352, 6522537, 5246127),
(805, 'Oeheqo', 'Satélite', 8482293, 3161026, 9946811),
(806, 'Zutoxaja', 'Cometa', 4187354, 3031862, 3765174),
(807, 'Poqejulu', 'Planeta', 7697240, 7983355, 3),
(808, 'Xeyogo', 'Planeta', 6093175, 2924153, NULL),
(809, 'Yefegu', 'Satélite', 8638786, 4973872, 5),
(810, 'Aawu', 'Asteroide', 7410287, 2624422, 721),
(811, 'Simuqeviyi', 'Satélite', 7886138, 3516481, 2422998),
(812, 'Vidinetu', 'Planeta', 7749898, 9684507, 9209987),
(813, 'Bahuvo', 'Planeta', 1082881, 5685893, 3975136),
(814, 'Fefoka', 'Planeta', 3801460, 7334859, 9322896),
(815, 'Aiduna', 'Cometa', 4791218, 7861909, 4985235),
(816, 'Wibexu', 'Planeta', 2561431, 2834224, NULL),
(817, 'Qifoxe', 'Satélite', 170775, 5718644, 87),
(818, 'Bumo', 'Planeta', 8879747, NULL, NULL),
(819, 'Gutuvaxu', 'Cometa', 773127, 8889855, 7018548),
(820, 'Nuho', 'Planeta', 2407739, 7140987, 6061738),
(821, 'Kixi', 'Satélite', 9652298, 7948304, 5332166),
(822, 'Aikepa', 'Planeta', 3044110, 738593, 4131951),
(823, 'Bapabihe', 'Planeta', NULL, 7851286, 2670055),
(824, 'Goha', 'Planeta', 1462518, 3752179, 3714135),
(825, 'Jaruselofe', 'Planeta', NULL, 5492802, NULL),
(826, 'Henu', 'Planeta', 8482291, 4937074, 3454091),
(827, 'Bakovi', 'Planeta', 1510471, 2536130, 3779),
(828, 'Witoka', 'Planeta', 1089367, 9215654, NULL),
(829, 'Dabizewo', 'Satélite', NULL, 8182895, 92),
(830, 'Negiri', 'Planeta', 2812619, 2795592, 877),
(831, 'Zoko', 'Planeta', NULL, NULL, 14),
(832, 'Babexomu', 'Planeta', 3724711, 1882480, 3),
(833, 'Jiviso', 'Planeta', 4428004, NULL, 149),
(834, 'Felowuxuci', 'Planeta', 3754974, 5163640, 9967845),
(835, 'Laro', 'Planeta', 4180869, 7223210, 5373069),
(836, 'Gonececu', 'Satélite', 3149279, 6347054, 2880727),
(837, 'Hiwiqa', 'Planeta', 2007720, 1034177, 3571535),
(838, 'Yo', 'Planeta', 7711474, 1627347, 9211854),
(839, 'Kesa', 'Planeta', NULL, 5897719, 9),
(840, 'Jipaxi', 'Planeta', NULL, 1665377, NULL),
(841, 'Paqibusi', 'Cometa', NULL, 1898969, 5397897),
(842, 'Fayike', 'Planeta', 2071326, NULL, NULL),
(843, 'Qacopurahe', 'Planeta', 7217037, 7510248, 10483),
(844, 'Wivime', 'Planeta', 5414109, 4655519, 6303509),
(845, 'Cazotafu', 'Planeta', 5879733, NULL, 5479),
(846, 'Niqucewa', 'Cometa', 988296, 3095707, 1721001),
(847, 'Cuheha', 'Planeta', 5924404, 6878134, 3),
(848, 'Uenu', 'Satélite', 6525718, 4230175, 2),
(849, 'Keke', 'Planeta', 534679, 8387875, 2005605),
(850, 'Eeru', 'Satélite', 9035959, 90472, NULL),
(851, 'Rehoqa', 'Planeta', 3129616, 8309780, NULL),
(852, 'Eizigo', 'Planeta', 4871962, 9869231, 6833155),
(853, 'Iafi', 'Planeta', 8587632, 8470131, 5926490),
(854, 'Tigufigopi', 'Satélite', 1058167, 7673758, 5368335),
(855, 'Hokexipo', 'Cometa', 1181764, 4416, 4773389),
(856, 'Da', 'Satélite', 9552168, 3990199, NULL),
(857, 'Soporapo', 'Planeta', 1787271, 1380249, 18863),
(858, 'Qakoqe', 'Planeta', 8458848, 991437, 1677969),
(859, 'Civobo', 'Planeta', NULL, 7815492, 531),
(860, 'Eajebu', 'Satélite', 3916460, 7546112, 5),
(861, 'Vipaju', 'Planeta', 8967930, NULL, 425033),
(862, 'Hirohido', 'Planeta', 3217954, 8974457, 4362),
(863, 'Fiyo', 'Planeta', 2113410, 9727650, 7342282),
(864, 'Kugaje', 'Planeta', 3856503, 1170311, 8391570),
(865, 'Wede', 'Satélite', 3221691, 680947, 2),
(866, 'Xajeniye', 'Planeta', 8051289, 2742838, NULL),
(867, 'Lecuzuwe', 'Cometa', 6409567, 9566875, 5003927),
(868, 'Oadexeqi', 'Asteroide', 202846, 8376353, 72),
(869, 'Eewu', 'Satélite', 8685924, 2045357, 828145),
(870, 'Jito', 'Planeta', NULL, 7284313, 1153789),
(871, 'Zetu', 'Planeta', 585622, 8178322, 7033),
(872, 'Cuqiqobi', 'Planeta', 6534115, 4003234, 95),
(873, 'Sicileke', 'Planeta', 1131651, 3450837, 4008634),
(874, 'Gumepowe', 'Cometa', 1346101, 9567828, 80),
(875, 'Aijamivu', 'Satélite', 9427022, 3196425, 1865955),
(876, 'Muluke', 'Planeta', 6457791, 8934575, 3469698),
(877, 'Xuja', 'Asteroide', 7345442, 2551894, 9856250),
(878, 'Taso', 'Planeta', 9925330, 1446489, 2137778),
(879, 'Iegubojo', 'Planeta', 1586588, 3668263, 599634),
(880, 'Oete', 'Planeta', 5875198, NULL, 3052266),
(881, 'Jeguvu', 'Satélite', 9801617, 7651754, 3523627),
(882, 'Huka', 'Planeta', 9171421, 9244054, 8130021),
(883, 'Ribelose', 'Planeta', NULL, 6626154, 1162767),
(884, 'Quyuva', 'Planeta', 2615832, 8773857, 3630811),
(885, 'Like', 'Planeta', 2493013, 3248381, 3135917),
(886, 'Zahezisa', 'Planeta', 9401788, 6552260, 5535827),
(887, 'Dagakepi', 'Satélite', 4618363, 7211469, 9712360),
(888, 'Yitiyeze', 'Satélite', 53247, 1809317, 2721804),
(889, 'Yagisucema', 'Planeta', 3206679, 2800661, 6582151),
(890, 'Kazoso', 'Planeta', 1069687, 7458529, 32),
(891, 'Qoga', 'Planeta', 4995647, 8612074, 5626940),
(892, 'Tatifi', 'Satélite', 8147904, 500166, 3825650),
(893, 'Qiwuco', 'Planeta', 7918045, 852111, 2646177),
(894, 'Eibaxoko', 'Planeta', 6113895, 4147200, 36),
(895, 'Dabu', 'Planeta', 1890971, 8095150, 92),
(896, 'Xapo', 'Planeta', 1714424, 4420120, 2338445),
(897, 'Ma', 'Cometa', 6055607, 1866863, 314916),
(898, 'Xeto', 'Satélite', 3211941, 6629441, 9029816),
(899, 'Qisujeru', 'Planeta', 4691804, 2278782, 5007731),
(900, 'Wuroceqo', 'Planeta', 1333241, 9907150, 559),
(901, 'Romoxumu', 'Cometa', 4416723, 6702261, 2725965),
(902, 'Sazururi', 'Asteroide', 3299142, 9989296, 20),
(903, 'Zivo', 'Satélite', 1360078, 4967687, 1802037),
(904, 'Jafo', 'Planeta', 8664328, 2557115, 9289),
(905, 'Buri', 'Satélite', 6577738, 5248399, 9784125),
(906, 'Dasinunudu', 'Satélite', 8449149, 5241557, NULL),
(907, 'Yukugafehi', 'Asteroide', 3375380, 1183871, 8012536),
(908, 'Bakoxa', 'Planeta', 9287404, 115976, NULL),
(909, 'Simegu', 'Satélite', 2077847, 6489046, NULL),
(910, 'Mara', 'Satélite', 6137128, 3410238, 2313168),
(911, 'Seqovahi', 'Asteroide', 1010995, 398241, 7468740),
(912, 'Xugoba', 'Planeta', 6057993, 2566802, 2736676),
(913, 'Sawudixe', 'Satélite', 8704116, 448455, 5785078),
(914, 'Betufe', 'Satélite', 5686662, 2689782, 380808),
(915, 'Qokihu', 'Planeta', 8185908, 1473272, 8),
(916, 'Uadoleho', 'Asteroide', 8448887, 9332650, 6),
(917, 'Tepima', NULL, 808753, NULL, 8882093),
(918, 'Nafigi', 'Planeta', 2262910, 8493587, 8239770),
(919, 'He', 'Satélite', 282829, 4073971, 7242326),
(920, 'Ii', 'Cometa', 1491643, 2187304, 3),
(921, 'Eimohe', 'Planeta', 944464, 7635, 9748578),
(922, 'Hovo', 'Planeta', 4462227, 8984605, 6811230),
(923, 'Uoxe', 'Satélite', 9616026, 7375732, 4732512),
(924, 'Zahowa', 'Satélite', 206736, 8410781, 1600527),
(925, 'Co', 'Planeta', 1998680, 4925152, 3),
(926, 'Nogoze', 'Cometa', 8659229, NULL, 493),
(927, 'Qune', 'Planeta', 2880606, 1167602, 8927803),
(928, 'Pekecezi', 'Satélite', 5382482, NULL, 1838269),
(929, 'Aijezuwo', 'Satélite', 7650268, 1035338, 1389),
(930, 'Tihitaba', 'Satélite', 6305823, 1782922, 2933),
(931, 'Xome', 'Cometa', 9624437, 4842445, 1269253),
(932, 'Bikahe', 'Satélite', 5988348, 7484109, 208664),
(933, 'Lovuro', NULL, 1919551, NULL, 5),
(934, 'Cucazizagu', 'Satélite', 6537632, 8481777, 62),
(935, 'Dovidaza', 'Planeta', 1591187, 5664008, 474381),
(936, 'Vogezugi', 'Planeta', 601322, 8772682, 9),
(937, 'Damumo', 'Planeta', 6559961, 1986079, 58),
(938, 'Powanome', 'Cometa', 3603407, 4167618, 260666),
(939, 'Kiwo', 'Planeta', 9246108, 968853, 665019),
(940, 'Yevepebi', 'Satélite', NULL, 7271053, 939),
(941, 'Ianaru', 'Asteroide', NULL, 3472199, NULL),
(942, 'Aohehuce', 'Satélite', 3175894, 3648098, 9998950),
(943, 'Uocato', 'Planeta', 9810650, 9273496, 6450463),
(944, 'Hiwo', 'Planeta', NULL, 1875993, 6361361),
(945, 'Yegaqe', 'Planeta', 2086336, 2865263, 451),
(946, 'Uiwewe', 'Satélite', 9360341, 4338934, 4451256),
(947, 'Uu', 'Planeta', 6336497, 5713112, 8156551),
(948, 'Zuhaqesu', 'Planeta', 4323105, 429577, 8384),
(949, 'Rufa', 'Satélite', NULL, 7303716, 7192624),
(950, 'Geqe', 'Planeta', 2558713, 1824715, 39),
(951, 'Qoxexu', 'Planeta', 6933732, 5896455, 33),
(952, 'Pexuhe', 'Planeta', 4078919, 8916731, 9314322),
(953, 'Fadute', 'Satélite', 1648456, 1821156, 8467714),
(954, 'Yibufoxo', 'Planeta', 6922496, 9536223, 9503130),
(955, 'Joveho', 'Satélite', 3919775, NULL, NULL),
(956, 'Tuneho', 'Planeta', 603141, 5544598, 1678290),
(957, 'Wi', 'Planeta', 5409206, 1023063, 6140),
(958, 'Qozuwojayi', 'Planeta', 1163227, 3856157, 6474718),
(959, 'Nicoyeri', 'Planeta', 5515165, 4791294, 6485568),
(960, 'Ualu', 'Satélite', 5166478, 2792021, 9044880),
(961, 'Euza', 'Planeta', 8694968, 3915971, 7543231),
(962, 'Lepinesi', 'Planeta', 5086442, 9757907, 4987378),
(963, 'Cutoqo', 'Satélite', 1056259, 3671526, 6),
(964, 'Qula', 'Satélite', 5722261, 5413584, 2974413),
(965, 'Kefe', 'Satélite', 1320073, 7370180, 4),
(966, 'Welici', 'Planeta', 7439899, 9278476, 3904848),
(967, 'Uepohu', 'Planeta', 3531736, NULL, 7264238),
(968, 'Paje', 'Planeta', 3359516, 8181593, 624),
(969, 'Dayiqu', 'Cometa', 7762224, 6607629, 2546563),
(970, 'Moyini', 'Planeta', 5108626, 4791033, 553),
(971, 'Audugi', 'Planeta', 6230730, 8813354, 7854026),
(972, 'Yequlogo', 'Satélite', 7207758, NULL, 975341),
(973, 'Eepu', 'Satélite', NULL, 1659546, 7982468),
(974, 'Bujeboyo', 'Planeta', 657253, NULL, 1746505),
(975, 'Jubilo', 'Satélite', 8638541, 6436496, 8606268),
(976, 'Nefi', 'Planeta', 9035174, 6947346, 5319042),
(977, 'Eagezi', 'Satélite', 9993388, NULL, 9621),
(978, 'Wivami', 'Satélite', 1732243, 3607226, 38),
(979, 'Juriwimi', 'Planeta', 5075762, 8149678, 9319811),
(980, 'Heya', 'Satélite', 5486251, 4465305, 5679202),
(981, 'Lowotibe', 'Satélite', 3794060, 4986530, 377),
(982, 'Barega', 'Planeta', 3197270, 5106023, 5775476),
(983, 'Xako', 'Asteroide', 9916674, 2753431, 2452472),
(984, 'Ou', 'Planeta', 1860924, 561389, 5719608),
(985, 'Coqobabusa', 'Satélite', 1055809, NULL, 95),
(986, 'Zefabu', 'Planeta', NULL, 34378, 491142),
(987, 'Uova', 'Asteroide', NULL, 4950120, 9),
(988, 'Bixe', 'Satélite', NULL, 2557323, 8),
(989, 'Nigaxi', 'Satélite', NULL, 5367964, 1950636),
(990, 'Oife', 'Satélite', NULL, 2731684, 575874),
(991, 'Qusewi', 'Satélite', NULL, NULL, 7),
(992, 'Fazizelo', 'Planeta', NULL, NULL, 4069155),
(993, 'Wodobumeto', 'Planeta', NULL, NULL, 7),
(994, 'Qumogefe', 'Planeta', NULL, NULL, 292858),
(995, 'Peho', 'Planeta', NULL, NULL, 4),
(996, 'Ko', 'Planeta', NULL, NULL, 5958364),
(997, 'Uoto', 'Satélite', NULL, NULL, 7014668),
(998, 'Guduqene', 'Planeta', NULL, NULL, 4930435),
(999, 'Febomi', 'Planeta', NULL, NULL, 3606798),
(1000, 'Qotesa', 'Planeta', NULL, NULL, 48);

INSERT INTO cuerpo_celeste_orbita_cuerpo_celeste(id_cuerpo_celeste_orbitador, id_cuerpo_celeste_orbitado) VALUES
(23, 393),
(53, 218),
(424, 225),
(925, 361),
(206, 495),
(348, 61),
(894, 126),
(236, 369),
(116, 475),
(396, 145),
(383, 313),
(937, 210),
(584, 9),
(435, 6),
(840, 42),
(599, 119),
(283, 286),
(3, 233),
(13, 132),
(587, 399),
(965, 5),
(667, 40),
(499, 74),
(520, 327),
(87, 83),
(158, 430),
(946, 11),
(78, 143),
(881, 305),
(484, 352),
(525, 5),
(487, 13),
(828, 157),
(472, 342),
(114, 159),
(780, 360),
(979, 262),
(536, 343),
(58, 103),
(933, 321),
(124, 61),
(588, 193),
(14, 54),
(573, 191),
(142, 50),
(296, 423),
(337, 19),
(227, 20),
(903, 356),
(704, 306),
(488, 212),
(868, 483),
(179, 263),
(154, 7),
(384, 460),
(104, 203),
(938, 344),
(629, 96),
(600, 204),
(604, 17),
(966, 125),
(741, 29),
(16, 421),
(768, 317),
(237, 346),
(42, 105),
(641, 271),
(355, 70),
(473, 9),
(992, 413),
(284, 223),
(266, 19),
(425, 6),
(188, 74),
(338, 305),
(79, 470),
(706, 270),
(70, 140),
(238, 284),
(895, 334),
(159, 9),
(752, 185),
(115, 3),
(730, 185),
(882, 481),
(15, 261),
(841, 427),
(806, 283),
(307, 150),
(367, 477),
(436, 384),
(4, 387),
(745, 188),
(989, 342),
(397, 150),
(589, 8),
(339, 107),
(630, 230),
(793, 101),
(267, 219),
(171, 33),
(328, 9),
(645, 92),
(255, 192),
(88, 176),
(24, 233),
(537, 237),
(489, 392),
(372, 135),
(326, 261),
(574, 16),
(904, 43),
(742, 5),
(117, 375),
(297, 270),
(385, 5),
(869, 466),
(500, 75),
(606, 268),
(939, 383),
(705, 329),
(437, 124),
(474, 69),
(180, 234),
(967, 445),
(549, 62),
(892, 78),
(560, 280),
(926, 329),
(836, 357),
(219, 340),
(601, 353),
(398, 145),
(228, 187),
(226, 116),
(526, 267),
(807, 430),
(189, 87),
(980, 261),
(17, 459),
(449, 3),
(460, 433),
(668, 367),
(327, 81),
(849, 413),
(272, 416),
(561, 360),
(298, 9),
(947, 334),
(426, 349),
(652, 449),
(356, 453),
(59, 347),
(207, 227),
(850, 21),
(501, 58),
(527, 435),
(118, 85),
(80, 8),
(905, 114),
(753, 45),
(575, 241),
(590, 2),
(373, 64),
(54, 331),
(602, 301),
(680, 454),
(285, 323),
(256, 191),
(368, 45),
(550, 376),
(490, 199),
(746, 161),
(808, 375),
(990, 59),
(71, 343),
(105, 67),
(993, 3),
(357, 201),
(842, 8),
(934, 75),
(653, 43),
(160, 8),
(239, 85),
(605, 320),
(475, 88),
(585, 107),
(143, 142),
(308, 137),
(707, 335),
(502, 149),
(329, 431),
(420, 392),
(125, 282),
(320, 263),
(607, 307),
(311, 335),
(754, 194),
(5, 311),
(60, 274),
(683, 349),
(386, 57),
(161, 399),
(257, 343),
(717, 210),
(948, 384),
(106, 373),
(646, 124),
(464, 182),
(642, 6),
(358, 130),
(538, 337),
(693, 240),
(837, 161),
(211, 168),
(896, 3),
(61, 214),
(340, 465),
(220, 330),
(286, 238),
(940, 207),
(438, 435),
(784, 312),
(427, 95),
(731, 2),
(399, 394),
(229, 438),
(781, 2),
(654, 466),
(603, 91),
(794, 487),
(450, 332),
(273, 86),
(684, 5),
(870, 131),
(576, 70),
(155, 43),
(43, 437),
(935, 297),
(755, 440),
(330, 426),
(528, 193),
(655, 382),
(551, 144),
(195, 67),
(89, 7),
(162, 355),
(503, 444),
(144, 471),
(883, 268),
(769, 267),
(972, 396),
(694, 71),
(387, 314),
(521, 59),
(461, 169),
(299, 100),
(591, 147),
(258, 352),
(62, 205),
(190, 336),
(172, 243),
(55, 77),
(785, 191),
(861, 80),
(795, 78),
(44, 79),
(25, 51),
(208, 54),
(491, 437),
(617, 133),
(374, 143),
(18, 24),
(851, 254),
(400, 179),
(240, 403),
(421, 132),
(843, 393),
(312, 17),
(321, 73),
(359, 391),
(743, 300),
(949, 406),
(968, 324),
(181, 254),
(592, 475),
(718, 414),
(829, 165),
(565, 43),
(1000, 141),
(163, 322),
(852, 462),
(927, 7),
(695, 403),
(994, 489),
(871, 391),
(274, 142),
(95, 500),
(722, 392),
(906, 57),
(669, 354),
(72, 7),
(375, 217),
(145, 67),
(230, 280),
(404, 53),
(809, 298),
(287, 375),
(981, 193),
(45, 58),
(309, 418),
(275, 125),
(817, 186),
(950, 137),
(376, 498),
(770, 126),
(897, 463),
(90, 221),
(830, 493),
(670, 415),
(618, 130),
(492, 5),
(388, 439),
(191, 136),
(685, 441),
(884, 60),
(915, 202),
(63, 39),
(771, 330),
(126, 341),
(875, 190),
(173, 234),
(276, 449),
(331, 309),
(631, 168),
(26, 448),
(221, 487),
(756, 225),
(91, 7),
(377, 171),
(818, 303),
(671, 186),
(539, 108),
(212, 357),
(796, 72),
(593, 334),
(259, 469),
(196, 256),
(681, 98),
(300, 471),
(6, 80),
(786, 428),
(192, 407),
(401, 246),
(505, 428),
(92, 64),
(732, 214),
(403, 4),
(164, 100),
(656, 23),
(708, 347),
(476, 386),
(504, 394),
(995, 194),
(428, 56),
(136, 2),
(632, 302),
(439, 446),
(529, 87),
(451, 409),
(96, 237),
(982, 66),
(916, 423),
(719, 239),
(969, 7),
(73, 255),
(465, 421),
(107, 51),
(313, 500),
(885, 456),
(959, 350),
(782, 498),
(213, 451),
(119, 57),
(277, 485),
(127, 484),
(608, 49),
(7, 293),
(973, 62),
(577, 400),
(314, 197),
(27, 210),
(19, 167),
(288, 298),
(552, 182),
(872, 359),
(81, 232),
(209, 273),
(747, 319),
(696, 219),
(619, 28),
(120, 173),
(452, 467),
(412, 143),
(686, 118),
(819, 121),
(797, 7),
(876, 192),
(360, 283),
(322, 163),
(720, 90),
(193, 36),
(248, 370),
(772, 298),
(231, 243),
(970, 381),
(620, 230),
(493, 65),
(197, 412),
(672, 275),
(513, 140),
(174, 95),
(873, 385),
(477, 61),
(787, 126),
(721, 434),
(983, 255),
(687, 92),
(647, 2),
(898, 241),
(128, 191),
(622, 227),
(540, 1),
(146, 296),
(709, 244),
(697, 330),
(723, 476),
(97, 230),
(941, 97),
(928, 106),
(389, 196),
(429, 184),
(798, 483),
(917, 97),
(974, 322),
(440, 334),
(222, 417),
(64, 107),
(553, 390),
(28, 115),
(566, 319),
(698, 265),
(996, 106),
(129, 440),
(562, 465),
(862, 31),
(853, 46),
(332, 359),
(310, 287),
(907, 404),
(182, 379),
(899, 115),
(844, 453),
(260, 208),
(810, 2),
(877, 233),
(820, 312),
(361, 141),
(578, 328),
(918, 453),
(462, 33),
(831, 429),
(466, 314),
(453, 8),
(541, 339),
(886, 51),
(214, 496),
(682, 330),
(594, 95),
(748, 268),
(36, 314),
(951, 69),
(530, 60),
(773, 296),
(757, 57),
(942, 401),
(441, 141),
(563, 24),
(673, 171),
(648, 333),
(289, 125),
(261, 31),
(845, 4),
(657, 59),
(799, 83),
(165, 6),
(137, 277),
(93, 400),
(390, 387),
(29, 266),
(749, 71),
(315, 370),
(478, 477),
(542, 17),
(301, 469),
(194, 462),
(997, 142),
(65, 110),
(960, 2),
(130, 434),
(609, 107),
(341, 265),
(494, 183),
(46, 205),
(621, 488),
(405, 258),
(788, 153),
(710, 18),
(579, 487),
(94, 478),
(82, 397),
(971, 60),
(198, 430),
(290, 53),
(699, 86),
(430, 207),
(30, 215),
(402, 105),
(610, 263),
(147, 2),
(567, 387),
(506, 420),
(929, 336),
(131, 165),
(711, 9),
(463, 115),
(183, 318),
(406, 8),
(31, 31),
(595, 366),
(758, 482),
(832, 495),
(241, 188),
(108, 130),
(378, 424),
(564, 309),
(442, 365),
(37, 331),
(83, 110),
(874, 65),
(975, 165),
(166, 130),
(20, 233),
(984, 318),
(302, 117),
(342, 445),
(362, 104),
(543, 47),
(783, 138),
(821, 114),
(878, 14),
(184, 438),
(210, 299),
(554, 59),
(943, 302),
(495, 16),
(479, 60),
(908, 70),
(443, 133),
(66, 253),
(976, 100),
(660, 466),
(900, 5),
(132, 51),
(658, 5),
(531, 208),
(454, 288),
(611, 494),
(733, 419),
(854, 179),
(507, 425),
(580, 44),
(811, 486),
(431, 284),
(952, 489),
(278, 140),
(759, 2),
(392, 71),
(863, 221),
(232, 23),
(292, 148),
(633, 141),
(467, 257),
(242, 230),
(407, 64),
(998, 407),
(774, 252),
(445, 183),
(167, 27),
(855, 341),
(909, 500),
(649, 331),
(333, 266),
(413, 382),
(343, 418),
(919, 2),
(674, 393),
(712, 63),
(544, 495),
(47, 255),
(546, 404),
(508, 474),
(846, 70),
(444, 469),
(930, 3),
(822, 146),
(84, 116),
(944, 83),
(262, 127),
(32, 107),
(323, 267),
(391, 270),
(856, 492),
(379, 39),
(879, 241),
(775, 342),
(121, 442),
(812, 99),
(800, 431),
(954, 190),
(21, 491),
(349, 378),
(675, 1),
(568, 250),
(761, 337),
(223, 59),
(910, 83),
(122, 320),
(953, 407),
(750, 385),
(813, 446),
(291, 104),
(148, 90),
(279, 1),
(555, 371),
(661, 5),
(22, 182),
(545, 499),
(468, 39),
(249, 362),
(532, 185),
(659, 170),
(847, 305),
(776, 107),
(8, 213),
(762, 320),
(215, 16),
(185, 472),
(760, 198),
(662, 213),
(514, 58),
(961, 35),
(138, 16),
(911, 462),
(432, 120),
(446, 483),
(85, 29),
(700, 386),
(977, 343),
(643, 327),
(380, 311),
(887, 199),
(233, 190),
(133, 155),
(48, 1),
(763, 227),
(408, 378),
(744, 500),
(334, 110),
(650, 60),
(688, 48),
(455, 492),
(363, 136),
(480, 467),
(509, 236),
(74, 87),
(814, 206),
(263, 216),
(350, 466),
(612, 340),
(364, 92),
(268, 134),
(556, 305),
(316, 80),
(920, 14),
(533, 157),
(156, 473),
(414, 249),
(243, 451),
(823, 141),
(734, 305),
(623, 66),
(175, 409),
(202, 1),
(713, 493),
(801, 31),
(280, 147),
(369, 87),
(67, 292),
(515, 327),
(56, 213),
(75, 334),
(676, 215),
(724, 89),
(33, 434),
(98, 353),
(381, 368),
(522, 499),
(581, 106),
(234, 277),
(199, 1),
(433, 176),
(481, 467),
(912, 188),
(269, 96),
(613, 42),
(264, 499),
(534, 258),
(569, 232),
(134, 434),
(921, 415),
(149, 115),
(370, 269),
(596, 15),
(434, 461),
(857, 16),
(344, 127),
(985, 316),
(901, 374),
(864, 17),
(38, 8),
(955, 355),
(815, 43),
(999, 206),
(456, 197),
(663, 139),
(913, 408),
(777, 288),
(714, 101),
(393, 137),
(816, 326),
(614, 1),
(677, 218),
(415, 7),
(176, 475),
(99, 145),
(186, 461),
(701, 436),
(422, 438),
(34, 461),
(547, 255),
(624, 85),
(778, 291),
(764, 413),
(634, 9),
(281, 131),
(523, 81),
(789, 323),
(123, 457),
(962, 226),
(109, 138),
(469, 7),
(76, 124),
(168, 181),
(802, 411),
(250, 23),
(865, 476),
(570, 206),
(447, 167),
(9, 82),
(516, 9),
(470, 461),
(644, 487),
(751, 36),
(914, 44),
(270, 237),
(963, 48),
(725, 302),
(858, 277),
(303, 436),
(715, 401),
(382, 1),
(157, 114),
(135, 4),
(496, 386),
(244, 400),
(335, 285),
(535, 289),
(702, 398),
(49, 471),
(371, 349),
(68, 67),
(200, 386),
(57, 87),
(110, 54),
(169, 466),
(423, 354),
(282, 137),
(838, 259),
(69, 216),
(936, 237),
(216, 202),
(945, 11),
(956, 486),
(345, 2),
(597, 366),
(35, 2),
(271, 3),
(866, 9),
(615, 467),
(245, 93),
(139, 232),
(416, 208),
(848, 311),
(664, 436),
(557, 495),
(839, 395),
(582, 247),
(651, 204),
(235, 9),
(625, 330),
(517, 353),
(346, 290),
(524, 267),
(859, 404),
(497, 313),
(246, 210),
(824, 215),
(100, 442),
(10, 105),
(336, 138),
(170, 190),
(347, 95),
(964, 55),
(833, 491),
(922, 452),
(716, 107),
(247, 297),
(735, 373),
(39, 497),
(689, 479),
(902, 4),
(485, 441),
(548, 4),
(417, 487),
(140, 153),
(678, 94),
(598, 27),
(365, 47),
(893, 382),
(482, 388),
(805, 211),
(293, 172),
(409, 270),
(931, 3),
(201, 90),
(991, 220),
(510, 59),
(834, 12),
(616, 158),
(586, 445),
(888, 5),
(498, 472),
(486, 191),
(457, 211),
(177, 9),
(40, 195),
(150, 82),
(203, 373),
(448, 253),
(790, 247),
(351, 137),
(986, 237),
(558, 369),
(765, 284),
(635, 8),
(726, 82),
(86, 458),
(690, 187),
(665, 384),
(932, 483),
(779, 38),
(324, 469),
(825, 9),
(766, 359),
(304, 11),
(50, 70),
(251, 7),
(666, 80),
(736, 5),
(317, 140),
(583, 487),
(352, 390),
(151, 64),
(410, 452),
(101, 130),
(518, 21),
(889, 2),
(880, 7),
(141, 335),
(418, 414),
(204, 40),
(111, 260),
(394, 152),
(791, 361),
(187, 213),
(77, 74),
(458, 151),
(11, 330),
(691, 96),
(483, 472),
(767, 319),
(511, 241),
(636, 338),
(305, 8),
(252, 262),
(265, 218),
(571, 8),
(353, 3),
(803, 149),
(217, 156),
(112, 1),
(1, 353),
(737, 207),
(987, 439),
(102, 79),
(626, 85),
(294, 290),
(559, 456),
(957, 84),
(224, 69),
(637, 386),
(2, 8),
(205, 32),
(860, 233),
(703, 459),
(306, 294),
(253, 9),
(366, 10),
(318, 42),
(890, 250),
(395, 350),
(459, 57),
(471, 22),
(354, 208),
(51, 389),
(295, 409),
(988, 236),
(218, 184),
(804, 33),
(792, 37),
(727, 274),
(12, 2),
(692, 49),
(679, 19),
(958, 10),
(867, 467),
(178, 88),
(152, 387),
(627, 8),
(113, 46),
(835, 48),
(923, 52),
(103, 5),
(325, 417),
(978, 443),
(891, 121),
(319, 389),
(225, 371),
(572, 3),
(738, 2),
(728, 122),
(519, 254),
(254, 462),
(638, 167),
(411, 442),
(739, 222),
(41, 117),
(639, 27),
(628, 68),
(419, 268),
(512, 193),
(740, 194),
(826, 413),
(52, 259),
(924, 139),
(640, 492),
(729, 229),
(153, 265),
(827, 464);

INSERT INTO direcciones(id, direccion, id_persona) VALUES
(1, 'Cyoyima.link', 1),
(2, 'Bimo.link', 1),
(3, 'Icoba.link', 340),
(4, 'Ecebi.link', 495),
(5, 'Gowidaja.link', 48),
(6, 'Xokifo.link', 445),
(7, 'Lpa.link', 72),
(8, 'Wudage.link', 372),
(9, 'LBK33BKKS.link', 572),
(10, 'Sece.link', 55),
(11, 'Wqa.link', 506),
(12, 'V.link', 630),
(13, 'Cta.link', 270),
(14, 'Zaqa.link', 114),
(15, 'Rje.link', 280),
(16, 'Xobupi.link', 83),
(17, 'Zpuzada.link', 57),
(18, 'Sonojeti.link', 116),
(19, 'Domesu.link', 624),
(20, 'Lugi.link', 4),
(21, 'Gecohami.link', 1),
(22, 'Kusuqe.link', 669),
(23, 'Qeyojoqi.link', 72),
(24, 'Rqimo.link', 620),
(25, 'Oatezi.link', 489),
(26, 'Kvoxi.link', 36),
(27, 'Oho.link', 626),
(28, 'Renopi.link', 464),
(29, 'Dluru.link', 529),
(30, 'Redajeca.link', 586),
(31, 'Ajuyago.link', 473),
(32, 'Tbiti.link', 466),
(33, 'Soke.link', 199),
(34, 'Lma.link', 516),
(35, 'Zpoqizeji.link', 7),
(36, 'Biha.link', 151),
(37, 'Xpiloge.link', 575),
(38, 'Dju.link', 388),
(39, '7M1416AJ.link', 469),
(40, 'Beka.link', 9),
(41, 'Ieyazeku.link', 387),
(42, 'O.link', 245),
(43, 'Eozusaki.link', 48),
(44, 'F42943A58.link', 70),
(45, 'Phuyu.link', 611),
(46, 'Yyerakatu.link', 336),
(47, 'Iguqaqe.link', 582),
(48, 'Zebohi.link', 434),
(49, 'Xyudohida.link', 25),
(50, 'X.link', 709),
(51, 'Gyegifoja.link', 274),
(52, 'Sme.link', 736),
(53, '5LA106XL.link', 517),
(54, 'Ztasa.link', 722),
(55, 'S85J5NUX.link', 300),
(56, 'Lademepi.link', 349),
(57, 'Ucake.link', 363),
(58, 'Rma.link', 370),
(59, 'Uacipa.link', 35),
(60, 'Xedoyewe.link', 397),
(61, 'Kuhavobito.link', 448),
(62, 'Yofacebu.link', 522),
(63, 'Fuxela.link', 342),
(64, 'Kvaku.link', 473),
(65, 'Mdavu.link', 61),
(66, 'Pye.link', 774),
(67, 'Kaka.link', 305),
(68, 'Muli.link', 56),
(69, 'Ohu.link', 328),
(70, 'Gzogoweka.link', 381),
(71, 'Tu.link', 193),
(72, 'Tve.link', 258),
(73, 'Ybi.link', 5),
(74, 'Yite.link', 447),
(75, 'Gidosedilu.link', 436),
(76, 'Lba.link', 97),
(77, 'Tzipa.link', 465),
(78, 'Yzizozi.link', 552),
(79, 'Hoveye.link', 526),
(80, 'Suwotuqu.link', 737),
(81, 'Dado.link', 19),
(82, 'Mijime.link', 52),
(83, 'Vamefeyoci.link', 30),
(84, 'Qvuqevi.link', 9),
(85, 'Wwa.link', 15),
(86, 'Ljunexu.link', 562),
(87, 'Csojekihi.link', 263),
(88, 'Pviyujule.link', 505),
(89, 'Eoqe.link', 140),
(90, 'Daruji.link', 5),
(91, '3E5XZOT5.link', 430),
(92, 'Rlobuli.link', 576),
(93, 'Noxa.link', 648),
(94, 'Yaja.link', 485),
(95, 'Taxigi.link', 590),
(96, 'B92493727.link', 497),
(97, 'Qatadi.link', 60),
(98, 'Hovogime.link', 58),
(99, 'Pnorova.link', 312),
(100, '5FBHH02J.link', 146),
(101, 'Enitiqumi.link', 617),
(102, 'Nocuvage.link', 6),
(103, 'Bulodoha.link', 122),
(104, 'Chuxaci.link', 217),
(105, 'Fdu.link', 130),
(106, 'Zakumaro.link', 305),
(107, 'Tme.link', 689),
(108, 'Iuxale.link', 491),
(109, 'Tkoso.link', 216),
(110, 'Vluleji.link', 72),
(111, 'Mpudegezu.link', 42),
(112, 'Isa.link', 114),
(113, 'Nzoqucu.link', 641),
(114, 'Cpeju.link', 4),
(115, 'Tura.link', 528),
(116, 'Gtoxo.link', 425),
(117, 'Bqawu.link', 574),
(118, '341L.link', 104),
(119, 'Hnesefa.link', 2),
(120, 'Iyipumi.link', 418),
(121, 'Puzi.link', 186),
(122, 'Cagaxo.link', 200),
(123, 'Vavo.link', 253),
(124, 'Xagumi.link', 132),
(125, 'Yce.link', 739),
(126, 'Kyulo.link', 171),
(127, 'Vlado.link', 298),
(128, '1O7YYL1K.link', 429),
(129, 'Raroliki.link', 372),
(130, 'Oato.link', 330),
(131, 'Ude.link', 376),
(132, '782HS94N.link', 60),
(133, 'Nbigoko.link', 452),
(134, 'Esezesuba.link', 88),
(135, 'Bewesu.link', 745),
(136, 'Vuxofo.link', 462),
(137, 'Eulaviqa.link', 521),
(138, 'Bokusaju.link', 465),
(139, 'Gapavafi.link', 589),
(140, '638G3YL9N.link', 43),
(141, 'Yi.link', 377),
(142, 'Knebo.link', 727),
(143, 'Yuwa.link', 165),
(144, 'Xoxu.link', 545),
(145, 'Uya.link', 200),
(146, 'Nexulo.link', 246),
(147, '6E8N6Y.link', 665),
(148, 'Rpuduqo.link', 264),
(149, 'Klodo.link', 723),
(150, 'Xedexu.link', 224),
(151, 'Mikitupo.link', 222),
(152, 'Kacila.link', 146),
(153, 'Veqeme.link', 638),
(154, 'Iulumoli.link', 8),
(155, 'Awofu.link', 55),
(156, 'Khevuga.link', 106),
(157, 'Ziba.link', 275),
(158, 'Gepepehe.link', 9),
(159, 'Kyu.link', 8),
(160, 'IAY000G.link', 581),
(161, 'Xela.link', 377),
(162, 'Kejige.link', 343),
(163, 'Lavulu.link', 554),
(164, 'Bfoku.link', 200),
(165, 'Wliwijobi.link', 89),
(166, 'Zazo.link', 279),
(167, 'Jtisa.link', 8),
(168, 'Poqadifizi.link', 539),
(169, 'Lxipo.link', 690),
(170, 'Gvaguku.link', 767),
(171, 'Morufefu.link', 6),
(172, 'Felute.link', 242),
(173, 'CA05704.link', 408),
(174, 'Easojo.link', 536),
(175, 'Tepe.link', 68),
(176, 'Kvuhe.link', 10),
(177, 'Fexiwo.link', 239),
(178, 'Uewe.link', 8),
(179, 'Agobu.link', 729),
(180, 'Esikuvo.link', 464),
(181, 'Meliwogu.link', 221),
(182, 'Fqora.link', 237),
(183, 'Q43B821Q.link', 776),
(184, 'Dcade.link', 350),
(185, 'Popegodu.link', 163),
(186, 'Fabefimo.link', 367),
(187, 'Frisegadi.link', 550),
(188, 'Stasu.link', 111),
(189, '0IXA3HC.link', 340),
(190, 'Qxoyi.link', 161),
(191, 'Zweze.link', 740),
(192, 'Wpohu.link', 500),
(193, 'S.link', 755),
(194, 'Aru.link', 102),
(195, 'Dijixe.link', 4),
(196, 'Iu.link', 43),
(197, 'HT7KYFL349.link', 39),
(198, 'Eupete.link', 454),
(199, 'Ewuhe.link', 768),
(200, 'Lbusa.link', 3),
(201, 'Jehopa.link', 174),
(202, 'Moveqa.link', 606),
(203, 'Gquyabo.link', 761),
(204, 'Xoxi.link', 333),
(205, 'Eawarixi.link', 20),
(206, 'Vifa.link', 82),
(207, 'Ye.link', 708),
(208, 'Lcodugi.link', 309),
(209, 'Wxuve.link', 541),
(210, 'Mfahipo.link', 713),
(211, 'Sitexare.link', 35),
(212, 'Yowamo.link', 18),
(213, 'Lozimage.link', 533),
(214, 'Buqexu.link', 33),
(215, 'Vzemu.link', 795),
(216, 'Meboyayo.link', 714),
(217, 'Si.link', 51),
(218, 'Ovuro.link', 564),
(219, 'Irabegefu.link', 330),
(220, 'Mxomoro.link', 647),
(221, 'SE8YZ.link', 16),
(222, '4C1S81CHX9.link', 618),
(223, 'Apuyu.link', 391),
(224, 'Wamotuwa.link', 679),
(225, 'Ociqe.link', 745),
(226, 'Mirulefo.link', 600),
(227, 'Euxi.link', 316),
(228, 'Nugu.link', 121),
(229, 'Epixu.link', 606),
(230, 'Ifefa.link', 59),
(231, 'Hpedo.link', 446),
(232, 'Dwuluzawa.link', 224),
(233, 'Wa.link', 482),
(234, 'Fibavu.link', 624),
(235, 'Geqi.link', 15),
(236, 'Sapiyaki.link', 71),
(237, 'Vxaloda.link', 609),
(238, '814246.link', 8),
(239, 'Svefe.link', 618),
(240, 'Kidujigu.link', 386),
(241, 'Gujitumi.link', 38),
(242, 'Tininuvoko.link', 31),
(243, 'Kujerajuqu.link', 197),
(244, 'Cazuxeko.link', 116),
(245, 'Limu.link', 406),
(246, 'Livuriqa.link', 775),
(247, 'Locaqo.link', 485),
(248, 'Aaloyi.link', 618),
(249, 'Eezo.link', 503),
(250, 'Dfudo.link', 36),
(251, 'Xwudu.link', 587),
(252, '228KT.link', 672),
(253, 'Viqedeza.link', 30),
(254, 'Yice.link', 155),
(255, 'Dogi.link', 3),
(256, 'Ldapiru.link', 276),
(257, '941GWLS2C.link', 781),
(258, 'Z.link', 760),
(259, 'Yijitori.link', 145),
(260, 'Uomoqanu.link', 234),
(261, 'Wlukoxi.link', 77),
(262, 'Fceheku.link', 63),
(263, 'Inodoweso.link', 4),
(264, '0M2X7PO.link', 301),
(265, 'Bjoculu.link', 109),
(266, 'Gocukuhu.link', 33),
(267, 'Saha.link', 326),
(268, 'Gohiye.link', 627),
(269, 'Salepibivi.link', 229),
(270, 'Dala.link', 370),
(271, 'Matela.link', 274),
(272, 'Dara.link', 680),
(273, 'Auxase.link', 74),
(274, 'Eosofowo.link', 756),
(275, 'Pmo.link', 468),
(276, 'Vyemo.link', 1),
(277, 'Lzilozafi.link', 702),
(278, 'Dedufo.link', 418),
(279, 'Rozu.link', 370),
(280, 'Jxiya.link', 284),
(281, 'Baxu.link', 684),
(282, 'Lbulosi.link', 50),
(283, 'U.link', 218),
(284, 'Fonofere.link', 403),
(285, 'Auxoya.link', 241),
(286, 'Ujoruwi.link', 100),
(287, 'Ooxowo.link', 707),
(288, 'Hqa.link', 243),
(289, 'Vdidivi.link', 80),
(290, 'Qli.link', 259),
(291, 'Eoku.link', 678),
(292, 'YONO4T4Q.link', 507),
(293, 'Arijona.link', 673),
(294, 'Bbu.link', 443),
(295, 'Mtegasi.link', 7),
(296, 'Nxe.link', 143),
(297, '7SA163.link', 138),
(298, 'Wgo.link', 612),
(299, 'Vajuniqi.link', 451),
(300, 'Fimufane.link', 85),
(301, 'Mle.link', 628),
(302, '50H797014AJ4.link', 598),
(303, 'Bzope.link', 2),
(304, 'Ckuju.link', 260),
(305, 'Xora.link', 323),
(306, 'Syoge.link', 756),
(307, 'Pilalejepa.link', 153),
(308, 'Hiliga.link', 17),
(309, 'Uguqaxe.link', 48),
(310, 'Ffeyasi.link', 125),
(311, 'Mepori.link', 501),
(312, 'Ptigifo.link', 415),
(313, 'Vyeqetu.link', 158),
(314, 'Swigebe.link', 27),
(315, 'Jaduqa.link', 744),
(316, 'Dmo.link', 2),
(317, 'Yapu.link', 770),
(318, 'Lyi.link', 26),
(319, 'Tkilene.link', 620),
(320, 'Pepoye.link', 342),
(321, 'Xqura.link', 138),
(322, 'Bedoqe.link', 13),
(323, 'Gvocu.link', 154),
(324, 'Nusa.link', 642),
(325, 'Uixuku.link', 383),
(326, 'Imowa.link', 489),
(327, '19339X.link', 362),
(328, 'Lcile.link', 200),
(329, 'Cpi.link', 164),
(330, '2M4.link', 3),
(331, 'Lovefeci.link', 127),
(332, 'Novayoka.link', 677),
(333, 'Rvoxu.link', 188),
(334, 'Yugebe.link', 244),
(335, 'Awikote.link', 661),
(336, 'Ilica.link', 249),
(337, 'Royoye.link', 246),
(338, 'Uumone.link', 144),
(339, 'Q.link', 2),
(340, 'Bcurafifi.link', 32),
(341, 'Iikena.link', 332),
(342, 'Vale.link', 63),
(343, 'Okitu.link', 14),
(344, 'EKE8BQ0L0.link', 512),
(345, 'Rviyu.link', 539),
(346, 'Usiku.link', 317),
(347, 'Eda.link', 2),
(348, '97XEN90.link', 755),
(349, 'Rwucaqa.link', 153),
(350, 'Sovumu.link', 713),
(351, 'Veso.link', 468),
(352, 'Bta.link', 665),
(353, '117S21.link', 161),
(354, '59URT.link', 279),
(355, 'Jusefi.link', 363),
(356, 'Obijujigu.link', 92),
(357, 'Mufase.link', 56),
(358, 'Rekime.link', 128),
(359, 'Lca.link', 520),
(360, 'Bivanu.link', 106),
(361, 'Caqegudo.link', 217),
(362, 'Sixivoyu.link', 25),
(363, 'B.link', 104),
(364, 'Hurava.link', 626),
(365, 'Pni.link', 474),
(366, 'Dzeheqi.link', 514),
(367, 'Hwinuge.link', 406),
(368, 'Kevoyoxo.link', 4),
(369, 'Ageniro.link', 483),
(370, 'Zloluya.link', 359),
(371, 'Eu.link', 139),
(372, 'Npa.link', 641),
(373, 'J23FT6D.link', 6),
(374, 'VX704W09.link', 754),
(375, 'Xajo.link', 400),
(376, 'Afepuci.link', 435),
(377, 'Jateku.link', 195),
(378, 'Pavo.link', 653),
(379, 'Bomoxe.link', 502),
(380, 'Yomilepi.link', 174),
(381, 'Howecedi.link', 476),
(382, 'Vpi.link', 51),
(383, 'Jlozaza.link', 379),
(384, 'Qmuha.link', 743),
(385, 'Qporo.link', 421),
(386, 'Luqu.link', 3),
(387, 'Hsibibu.link', 497),
(388, 'Leca.link', 110),
(389, 'DXNRCC0MM.link', 609),
(390, '2S8WBW2.link', 36),
(391, 'Wezerahe.link', 36),
(392, 'Sojujo.link', 168),
(393, 'Wkutihu.link', 164),
(394, 'Nopucibi.link', 433),
(395, 'Ooziteku.link', 462),
(396, 'Zzijo.link', 16),
(397, 'Zkikale.link', 252),
(398, '57N3J19WD.link', 480),
(399, '7EP7F5F5.link', 161),
(400, 'Hmivudo.link', 113),
(401, '827M7O3.link', 91),
(402, 'Pmije.link', 691),
(403, 'Jfo.link', 235),
(404, 'Uixahi.link', 546),
(405, 'Gra.link', 604),
(406, 'Fjo.link', 575),
(407, 'Viyolu.link', 504),
(408, 'Ootele.link', 704),
(409, 'Ofoya.link', 210),
(410, 'Equla.link', 637),
(411, 'Dtibi.link', 363),
(412, 'Iwene.link', 145),
(413, 'Yqevoko.link', 141),
(414, 'Gubavuda.link', 592),
(415, 'Hlo.link', 356),
(416, 'Swome.link', 264),
(417, 'Jqa.link', 773),
(418, 'Cmekibo.link', 19),
(419, 'Pbopejiji.link', 419),
(420, 'Yyubu.link', 305),
(421, 'Lihu.link', 85),
(422, 'Fmeli.link', 684),
(423, 'Boje.link', 497),
(424, 'Gugako.link', 463),
(425, 'Rzotuwa.link', 436),
(426, 'Bpayeyi.link', 3),
(427, 'Zeho.link', 163),
(428, 'Peloruvi.link', 762),
(429, 'Hyaqo.link', 554),
(430, 'S2L9YO12.link', 140),
(431, 'Poboco.link', 586),
(432, 'Tgaki.link', 725),
(433, 'Uozo.link', 372),
(434, 'Hu.link', 75),
(435, 'Myeke.link', 10),
(436, 'We.link', 239),
(437, 'Mmekuma.link', 240),
(438, 'Joxidaqu.link', 738),
(439, 'Bxalera.link', 576),
(440, 'Ljafejucu.link', 656),
(441, 'Tfetu.link', 334),
(442, 'Furubu.link', 418),
(443, 'Ouqimuko.link', 17),
(444, 'Gbami.link', 556),
(445, 'Nazu.link', 56),
(446, 'Fbotewu.link', 206),
(447, 'Mdibo.link', 219),
(448, 'Hova.link', 631),
(449, 'Gle.link', 30),
(450, '0NTXD7.link', 776),
(451, 'Biroto.link', 90),
(452, 'Oeca.link', 28),
(453, 'Iefuhuha.link', 645),
(454, 'Qjafuzi.link', 800),
(455, 'Ixu.link', 252),
(456, 'Moduciku.link', 130),
(457, 'Vqego.link', 73),
(458, 'Cowevu.link', 558),
(459, 'Xuwi.link', 464),
(460, 'Wrati.link', 712),
(461, 'Cteyaxo.link', 42),
(462, 'Yelisuyo.link', 75),
(463, 'Hriju.link', 684),
(464, 'Zahuma.link', 5),
(465, 'Qedu.link', 54),
(466, 'Szore.link', 368),
(467, 'Lfe.link', 205),
(468, 'Jdiba.link', 745),
(469, 'Fo.link', 60),
(470, 'Lzu.link', 797),
(471, 'Motecino.link', 68),
(472, 'Moyalu.link', 56),
(473, 'Uafecu.link', 793),
(474, 'Cipu.link', 190),
(475, 'Canire.link', 9),
(476, 'Rqe.link', 399),
(477, 'Lese.link', 442),
(478, 'Qumufu.link', 302),
(479, 'Vvuxo.link', 798),
(480, 'Iabemeki.link', 93),
(481, 'Hhoma.link', 7),
(482, 'Mayazi.link', 148),
(483, 'Upaheqoqu.link', 223),
(484, 'Zoyeke.link', 737),
(485, 'Xuni.link', 599),
(486, 'Zjo.link', 477),
(487, 'Uexili.link', 698),
(488, 'Gtecotu.link', 326),
(489, '06UU79.link', 4),
(490, 'Ctohu.link', 577),
(491, 'Popabito.link', 785),
(492, 'Eriha.link', 257),
(493, 'Guxuwijeri.link', 236),
(494, 'Aikino.link', 479),
(495, 'Zila.link', 583),
(496, 'Banimi.link', 237),
(497, 'Qsoca.link', 704),
(498, 'Xa.link', 364),
(499, 'Tomoki.link', 691),
(500, 'Gokima.link', 400),
(501, 'Qdojeneru.link', 774),
(502, 'Ofuga.link', 20),
(503, 'Uhu.link', 88),
(504, 'TG976S.link', 798),
(505, 'Rucegi.link', 75),
(506, 'Nheca.link', 532),
(507, 'Qma.link', 394),
(508, 'Rkoxuco.link', 448),
(509, 'Htolo.link', 485),
(510, 'Khi.link', 4),
(511, 'Xiko.link', 795),
(512, 'Cyu.link', 739),
(513, 'J5CX45.link', 3),
(514, 'Oo.link', 422),
(515, 'Setena.link', 683),
(516, 'Henu.link', 770),
(517, 'Icoci.link', 1),
(518, 'Sa.link', 6),
(519, 'Sexazopa.link', 549),
(520, 'Jofo.link', 261),
(521, 'Yehozuca.link', 99),
(522, 'Hofe.link', 18),
(523, 'Ize.link', 104),
(524, 'Ieyaru.link', 244),
(525, 'Zeyajomi.link', 206),
(526, 'Wwira.link', 421),
(527, 'Nufopeti.link', 57),
(528, 'Fe.link', 264),
(529, 'Mujune.link', 596),
(530, 'Dqepi.link', 487),
(531, 'Cniza.link', 36),
(532, 'Jididojini.link', 59),
(533, '8MR194G5.link', 561),
(534, 'Aohuyoli.link', 261),
(535, 'Nidomiva.link', 322),
(536, 'Cuduje.link', 710),
(537, 'Gipoda.link', 16),
(538, 'Pwadu.link', 382),
(539, 'Fogu.link', 6),
(540, 'Bolego.link', 741),
(541, 'Fupo.link', 42),
(542, 'Gutuzeba.link', 71),
(543, 'G50YR698.link', 96),
(544, 'Morokesu.link', 536),
(545, 'Mvumi.link', 128),
(546, 'Ikopo.link', 252),
(547, 'Ua.link', 399),
(548, 'Rpoke.link', 75),
(549, 'Dye.link', 19),
(550, 'Zpi.link', 13),
(551, 'Pvu.link', 440),
(552, 'Gkamu.link', 202),
(553, '8011VIVW.link', 566),
(554, 'Zakiyawe.link', 545),
(555, 'Ufe.link', 85),
(556, 'Pucusuxu.link', 586),
(557, 'Fixi.link', 85),
(558, 'Ci.link', 468),
(559, 'Eiruso.link', 75),
(560, 'Qloyo.link', 412),
(561, 'Aepiwe.link', 594),
(562, 'Enuyo.link', 172),
(563, 'Uledo.link', 225),
(564, 'Aaba.link', 454),
(565, 'Migaheqi.link', 287),
(566, 'Ndicozobi.link', 127),
(567, 'Mtidu.link', 272),
(568, 'Rbivo.link', 659),
(569, 'Jenebisu.link', 2),
(570, 'Diweti.link', 331),
(571, 'Eazito.link', 577),
(572, 'Zbomaqaxo.link', 535),
(573, 'Ui.link', 455),
(574, 'Rzi.link', 269),
(575, 'Koloce.link', 78),
(576, 'Wawoka.link', 230),
(577, 'Tuqabapavi.link', 609),
(578, 'Xiru.link', 14),
(579, 'Oipifo.link', 277),
(580, '6R02AP0VM.link', 132),
(581, 'Cnosa.link', 97),
(582, 'Nimupu.link', 1),
(583, 'Nefija.link', 68),
(584, 'Nta.link', 67),
(585, 'Wneje.link', 196),
(586, 'Jnu.link', 388),
(587, 'Ckexa.link', 534),
(588, 'Vti.link', 161),
(589, 'Tlazo.link', 68),
(590, '72R4257Q.link', 267),
(591, 'Jiluyi.link', 370),
(592, 'Pbitu.link', 45),
(593, 'Sasa.link', 468),
(594, 'Iuqupoxe.link', 383),
(595, 'Uojixe.link', 8),
(596, 'Vtezihe.link', 303),
(597, 'Esato.link', 536),
(598, 'Hdufeci.link', 759),
(599, 'Tyudu.link', 788),
(600, 'Y48NR5I14CP.link', 141),
(601, 'Male.link', 274),
(602, 'Roxoju.link', 550),
(603, 'Gehukepu.link', 54),
(604, 'Nzu.link', 191),
(605, 'Ttegoyi.link', 252),
(606, 'Ju.link', 331),
(607, 'Lerelonu.link', 350),
(608, 'Loledahe.link', 9),
(609, 'Xoguzujo.link', 243),
(610, 'Dwojo.link', 11),
(611, 'Xyodahi.link', 171),
(612, 'E4OZY1.link', 363),
(613, 'Fhicu.link', 1),
(614, 'Xkizesa.link', 219),
(615, 'Tezi.link', 647),
(616, 'Aevi.link', 674),
(617, 'Zpubi.link', 268),
(618, 'Lapusuqe.link', 430),
(619, 'A121XB.link', 459),
(620, 'Tga.link', 259),
(621, 'Qwoyo.link', 58),
(622, 'Misebi.link', 710),
(623, 'N5F5T.link', 728),
(624, 'Ycewuhe.link', 699),
(625, 'Govu.link', 792),
(626, 'Rxuni.link', 235),
(627, 'Jdosoruta.link', 356),
(628, 'Miqucu.link', 76),
(629, 'EC0518CL.link', 549),
(630, 'Nike.link', 646),
(631, 'Tujaba.link', 117),
(632, 'Lemeyuqo.link', 303),
(633, 'Uuxuva.link', 26),
(634, 'Dke.link', 696),
(635, 'Todoru.link', 576),
(636, 'Jdazeze.link', 759),
(637, 'Xhimuqevi.link', 157),
(638, 'Jjiqequ.link', 751),
(639, 'Kixaqiyuni.link', 707),
(640, 'Dqiluzi.link', 4),
(641, 'Yawuqa.link', 229),
(642, 'Bemo.link', 726),
(643, 'Yajehaweni.link', 711),
(644, 'Jxijino.link', 732),
(645, 'Dlewa.link', 34),
(646, 'Ielesuqi.link', 485),
(647, 'Aqetawa.link', 457),
(648, 'Bcu.link', 767),
(649, 'Mweda.link', 774),
(650, 'Wselo.link', 195),
(651, 'Gwo.link', 9),
(652, 'Vexebako.link', 591),
(653, 'Eere.link', 649),
(654, 'Waqeha.link', 17),
(655, 'Eegi.link', 22),
(656, 'Yjeha.link', 302),
(657, 'Gi.link', 190),
(658, 'Clugo.link', 462),
(659, 'Iya.link', 772),
(660, 'Gone.link', 739),
(661, 'Niha.link', 344),
(662, 'Jacayuboxa.link', 524),
(663, 'Oiparaho.link', 659),
(664, 'Jeguqu.link', 554),
(665, 'Tatena.link', 453),
(666, 'Tobohupi.link', 566),
(667, 'Dki.link', 408),
(668, 'Buxote.link', 6),
(669, 'Fqukeyari.link', 82),
(670, 'Bujobu.link', 729),
(671, 'Zafi.link', 212),
(672, 'Javike.link', 435),
(673, 'Za.link', 43),
(674, 'Cxipohi.link', 567),
(675, 'Caxune.link', 80),
(676, 'Uxefi.link', 214),
(677, 'Q2IDODD.link', 22),
(678, 'Fjodema.link', 274),
(679, 'Nagoci.link', 618),
(680, 'Zsanapofo.link', 137),
(681, 'Gijoku.link', 387),
(682, 'Cuga.link', 111),
(683, 'Uicudaso.link', 447),
(684, 'Evaha.link', 449),
(685, 'Npi.link', 507),
(686, 'Pxifadohi.link', 55),
(687, 'Kqegopa.link', 227),
(688, 'Zzusoxece.link', 51),
(689, 'Zeqeko.link', 194),
(690, 'Yominaso.link', 32),
(691, 'Wgubojo.link', 665),
(692, 'Xboqi.link', 94),
(693, 'Uexuka.link', 277),
(694, 'Snuto.link', 440),
(695, 'Ktifobu.link', 765),
(696, 'Zusari.link', 590),
(697, 'Xki.link', 134),
(698, 'Kmutoto.link', 2),
(699, 'Omucuzu.link', 70),
(700, 'Puwononi.link', 656),
(701, 'Ldura.link', 492),
(702, 'Cewu.link', 641),
(703, 'Rwuco.link', 4),
(704, '3M08N937W79.link', 256),
(705, 'Oarogi.link', 264),
(706, 'Dgibacu.link', 755),
(707, 'Ibomoxu.link', 370),
(708, 'Zlupigali.link', 45),
(709, 'Dofuwe.link', 261),
(710, 'Yrabu.link', 37),
(711, 'Gudi.link', 49),
(712, 'Dkebi.link', 386),
(713, 'Uhiweko.link', 606),
(714, 'Eiyiqa.link', 46),
(715, 'Risa.link', 176),
(716, 'Akoze.link', 693),
(717, 'Ployu.link', 24),
(718, 'Qujaqenezo.link', 151),
(719, 'Gavohomu.link', 4),
(720, 'Ntegi.link', 3),
(721, 'Amewo.link', 480),
(722, 'Y1WSJ.link', 124),
(723, 'Fbofiha.link', 452),
(724, 'Lkore.link', 694),
(725, 'Kruli.link', 345),
(726, 'Ugoge.link', 315),
(727, 'Wukavepu.link', 81),
(728, 'Vifizuwo.link', 86),
(729, 'Ype.link', 693),
(730, 'Sxuqide.link', 343),
(731, 'Sebunepu.link', 355),
(732, 'Myucehi.link', 643),
(733, 'Qoyoze.link', 344),
(734, 'Balotuki.link', 172),
(735, 'Damumo.link', 148),
(736, 'Ogu.link', 555),
(737, 'Vuli.link', 660),
(738, 'Kgo.link', 60),
(739, 'Hoxewa.link', 81),
(740, 'Wohehuce.link', 6),
(741, 'Unifobe.link', 152),
(742, 'Arabu.link', 582),
(743, 'Ypewe.link', 581),
(744, 'Bonaqe.link', 41),
(745, 'Oizumokemi.link', 362),
(746, 'Yxu.link', 470),
(747, 'Ie.link', 201),
(748, 'Ckoxira.link', 453),
(749, 'Jisuku.link', 562),
(750, 'Iesefope.link', 59),
(751, 'Lime.link', 783),
(752, 'ZF36C0V76.link', 514),
(753, 'Zxeza.link', 79),
(754, 'Pari.link', 439),
(755, 'NINV6N.link', 8),
(756, 'Xetaqava.link', 185),
(757, 'Vicoboko.link', 430),
(758, 'Hra.link', 741),
(759, 'Vuqi.link', 623),
(760, 'Uje.link', 4),
(761, 'Wiparu.link', 23),
(762, 'Aawaxu.link', 534),
(763, 'Wi.link', 394),
(764, 'Redufuna.link', 2),
(765, 'E.link', 633),
(766, 'Cyeqa.link', 632),
(767, 'Wovami.link', 714),
(768, 'T2NH20.link', 437),
(769, 'Matibe.link', 9),
(770, 'Pcozobo.link', 800),
(771, 'Gilaci.link', 197),
(772, 'Chane.link', 3),
(773, 'Ximi.link', 7),
(774, 'Cna.link', 157),
(775, 'Tevurema.link', 332),
(776, 'Yusewi.link', 742),
(777, 'Oya.link', 765),
(778, 'Olido.link', 272),
(779, 'Jfezu.link', 781),
(780, 'Upe.link', 405),
(781, 'Vyaxu.link', 513),
(782, 'Oewuluduqe.link', 352),
(783, 'Ima.link', 573),
(784, 'Vvoni.link', 532),
(785, 'Uganowe.link', 215),
(786, 'Jiyi.link', 9),
(787, 'Cazi.link', 61),
(788, 'Kixebu.link', 672),
(789, 'Xowuzewi.link', 592),
(790, 'Hukeho.link', 144),
(791, 'Hqu.link', 213),
(792, 'Gtezu.link', 698),
(793, 'Qodegijadi.link', 39),
(794, 'Rmu.link', 366),
(795, 'Cojika.link', 246),
(796, 'Loticeguhu.link', 1),
(797, 'Nalakube.link', 15),
(798, 'Keto.link', 445),
(799, 'Eequcogo.link', 462),
(800, 'Mazolopi.link', 443),
(801, 'Keme.link', 211),
(802, 'FZ.link', 231),
(803, 'Nigopa.link', 440),
(804, 'Odazo.link', 21),
(805, 'W.link', 780),
(806, 'Iuhirida.link', 108),
(807, 'LSHS90UV.link', 25),
(808, '08751WHFM.link', 11),
(809, '03614586K.link', 327),
(810, 'Papimo.link', 613),
(811, 'Xte.link', 557),
(812, 'FT470.link', 262),
(813, 'Jcecekeca.link', 550),
(814, 'Oe.link', 104),
(815, 'Pjuhu.link', 797),
(816, 'Yuqa.link', 441),
(817, 'Bze.link', 65),
(818, 'Vlu.link', 69),
(819, 'Vwate.link', 9),
(820, 'Sogemizoke.link', 71),
(821, 'Nkujugi.link', 124),
(822, 'Axexewu.link', 277),
(823, 'Pugehase.link', 117),
(824, 'Hokeri.link', 3),
(825, 'Eka.link', 524),
(826, '0YP9D5G.link', 163),
(827, 'Fiworu.link', 34),
(828, 'Oli.link', 1),
(829, 'Kdotile.link', 195),
(830, 'Gluyu.link', 753),
(831, 'Zloru.link', 407),
(832, 'Hasibetime.link', 376),
(833, 'Lkekone.link', 255),
(834, 'Iobive.link', 5),
(835, 'Xlajo.link', 2),
(836, '4EJH79S18.link', 538),
(837, 'Qguca.link', 3),
(838, 'Asupura.link', 761),
(839, 'Pqi.link', 213),
(840, 'Uora.link', 156),
(841, 'Xufilujose.link', 209),
(842, 'Rra.link', 719),
(843, 'Cadayoma.link', 396),
(844, '0MDI6L68.link', 96),
(845, 'Dto.link', 742),
(846, 'Uloceja.link', 105),
(847, 'Nfoqu.link', 687),
(848, 'Vmiwe.link', 406),
(849, 'Zze.link', 76),
(850, 'Qohovi.link', 657),
(851, 'Lhi.link', 9),
(852, 'Squ.link', 598),
(853, 'Lgiruvu.link', 130),
(854, 'Speje.link', 356),
(855, 'Mzaqo.link', 675),
(856, 'Gitegipa.link', 364),
(857, 'Neroziju.link', 180),
(858, '4YG911013621.link', 42),
(859, 'Iasebafamu.link', 418),
(860, 'Jgase.link', 590),
(861, 'Tro.link', 41),
(862, 'Aqo.link', 461),
(863, 'Zolisu.link', 770),
(864, 'Rko.link', 217),
(865, 'Nesocici.link', 388),
(866, 'Ru.link', 154),
(867, 'Byehi.link', 455),
(868, 'Giyudo.link', 771),
(869, 'Wadirime.link', 92),
(870, 'Xuro.link', 9),
(871, 'Rzafade.link', 629),
(872, 'Iapofeca.link', 150),
(873, 'Aonatoro.link', 62),
(874, 'Zqabajaye.link', 492),
(875, 'Hheri.link', 297),
(876, 'Zodi.link', 633),
(877, 'Iti.link', 775),
(878, 'Fhi.link', 9),
(879, 'Ycumume.link', 490),
(880, 'Xenavotofi.link', 13),
(881, 'Otizeno.link', 677),
(882, 'Te.link', 517),
(883, 'Vpepe.link', 150),
(884, 'Oqidi.link', 75),
(885, 'Zbeca.link', 270),
(886, 'Lta.link', 320),
(887, 'ZI506UA7A1.link', 150),
(888, 'Henebovi.link', 352),
(889, 'Yxi.link', 359),
(890, 'Poliva.link', 219),
(891, 'Skeyetu.link', 80),
(892, 'Juvo.link', 376),
(893, 'Trifi.link', 39),
(894, 'Jxigi.link', 732),
(895, 'Flezarone.link', 316),
(896, 'Tunomono.link', 626),
(897, 'Hsu.link', 575),
(898, 'Ebo.link', 738),
(899, 'Txejo.link', 251),
(900, 'Pyeri.link', 44),
(901, 'S4VKK124.link', 373),
(902, 'Ro.link', 510),
(903, 'Yobuloca.link', 48),
(904, 'Yazutudu.link', 779),
(905, 'Sdopemi.link', 182),
(906, 'Oaba.link', 532),
(907, 'Rteco.link', 72),
(908, 'Xahuzu.link', 2),
(909, 'Eika.link', 157),
(910, 'Wxu.link', 60),
(911, 'G.link', 431),
(912, 'Uxuzu.link', 214),
(913, 'Lrudexu.link', 7),
(914, 'F.link', 224),
(915, 'Tohokaya.link', 125),
(916, 'Jbo.link', 198),
(917, 'Cji.link', 717),
(918, 'Pu.link', 345),
(919, 'Suluqa.link', 120),
(920, 'Zugufe.link', 564),
(921, 'Kduzowu.link', 151),
(922, 'Vetu.link', 63),
(923, '106X5T13BW.link', 787),
(924, 'Mnuga.link', 526),
(925, 'Oyabo.link', 601),
(926, 'Hrojoxo.link', 194),
(927, 'Gaquza.link', 88),
(928, 'Ce.link', 9),
(929, 'Savi.link', 92),
(930, 'Goxedu.link', 189),
(931, 'Dizaso.link', 396),
(932, 'Eewogu.link', 178),
(933, 'Dlobejo.link', 308),
(934, '0.link', 351),
(935, 'Ikaxaji.link', 622),
(936, 'Ucotu.link', 592),
(937, 'Zotodu.link', 469),
(938, 'Uume.link', 429),
(939, 'Gnu.link', 557),
(940, 'Cru.link', 236),
(941, 'Nbidabo.link', 216),
(942, 'Xawu.link', 101),
(943, '6O3R.link', 371),
(944, 'Vnasa.link', 143),
(945, 'JD7V95UM5.link', 237),
(946, 'Yasebo.link', 705),
(947, 'Lolave.link', 83),
(948, 'Depeheri.link', 761),
(949, 'Tufaya.link', 111),
(950, 'E268C56.link', 220),
(951, 'Wpiju.link', 119),
(952, 'Tobunu.link', 79),
(953, 'Radozo.link', 416),
(954, 'Ncoca.link', 112),
(955, 'Rabeki.link', 762),
(956, 'Gpije.link', 416),
(957, 'Xiruvimo.link', 45),
(958, 'Juvizagazo.link', 627),
(959, 'Pyo.link', 570),
(960, 'Uuwizo.link', 164),
(961, 'Ruhuco.link', 800),
(962, 'Einebo.link', 68),
(963, 'Tevagi.link', 648),
(964, 'Wtiba.link', 647),
(965, 'Pojo.link', 308),
(966, 'L2F98UK8.link', 628),
(967, 'Phe.link', 86),
(968, 'Lerika.link', 180),
(969, 'Pkutu.link', 595),
(970, 'Nifanaqa.link', 414),
(971, 'Ameze.link', 542),
(972, 'Codegucu.link', 210),
(973, 'Yafilu.link', 227),
(974, 'Kyifi.link', 327),
(975, 'Pixomiho.link', 518),
(976, 'Rosa.link', 5),
(977, 'Cemukola.link', 369),
(978, 'Rhuyife.link', 160),
(979, 'Qgaqa.link', 562),
(980, 'Kagoru.link', 22),
(981, 'Yyiga.link', 459),
(982, 'Hafibe.link', 745),
(983, 'Zaki.link', 231),
(984, 'Oasipu.link', 655),
(985, 'R.link', 725),
(986, 'D502626.link', 660),
(987, 'Uohovu.link', 7),
(988, 'Cbuti.link', 425),
(989, 'Jpobi.link', 619),
(990, 'Ybasi.link', 516),
(991, 'Ddi.link', 28),
(992, 'Oike.link', 469),
(993, 'Da.link', 286),
(994, 'Kiziwa.link', 778),
(995, 'Aada.link', 532),
(996, 'Aine.link', 63),
(997, 'Rqepedu.link', 193),
(998, 'Yhutaduru.link', 672),
(999, 'Netije.link', 2),
(1000, 'Mabulako.link', 418),
(1001, 'Sfoka.link', 357),
(1002, 'Hjasixo.link', 668),
(1003, 'Gsoha.link', 378),
(1004, 'Cwazupu.link', 771),
(1005, 'Rpira.link', 34),
(1006, 'Gcugivo.link', 103),
(1007, 'Nileku.link', 431),
(1008, 'Pfulo.link', 185),
(1009, 'Ylifu.link', 524),
(1010, 'Aogowada.link', 58),
(1011, 'Cguzo.link', 446),
(1012, 'Ghejeda.link', 268),
(1013, 'Fveyu.link', 600),
(1014, 'Bbopo.link', 543),
(1015, 'Bamavu.link', 164),
(1016, '1Q0F062.link', 9),
(1017, 'Ahiqu.link', 327),
(1018, 'Bbucuxi.link', 74),
(1019, 'Voxe.link', 615),
(1020, 'Xhili.link', 642),
(1021, '8994.link', 723),
(1022, 'Tafofoha.link', 34),
(1023, 'Airi.link', 38),
(1024, 'Meheye.link', 23),
(1025, 'Genatayopo.link', 612),
(1026, 'Hezitimuni.link', 206),
(1027, 'Yiyafuci.link', 335),
(1028, 'Pxiziro.link', 314),
(1029, 'PQV611A3NYC5.link', 717),
(1030, 'Lehiwijiqa.link', 780),
(1031, 'Bfoma.link', 466),
(1032, 'Royaka.link', 324),
(1033, 'Nesoga.link', 125),
(1034, '253IX42.link', 571),
(1035, 'Zyomefibe.link', 772),
(1036, 'Ecu.link', 536),
(1037, '0U59846.link', 595),
(1038, 'Yralu.link', 751),
(1039, 'Kiqaka.link', 17),
(1040, 'Avabeyana.link', 354),
(1041, 'Saweko.link', 288),
(1042, 'Zovema.link', 214),
(1043, 'Io.link', 351),
(1044, 'Tqi.link', 664),
(1045, 'Lxegoyofi.link', 583),
(1046, 'Qzu.link', 410),
(1047, 'Cada.link', 633),
(1048, 'Soloya.link', 515),
(1049, 'Jwu.link', 424),
(1050, 'Ytudu.link', 603),
(1051, 'Tisocafefo.link', 333),
(1052, 'Oceso.link', 800),
(1053, 'Qboba.link', 6),
(1054, 'Wuqiduco.link', 434),
(1055, 'Y93J480.link', 383),
(1056, 'Cnanini.link', 351),
(1057, 'Pbefibe.link', 760),
(1058, 'Eomo.link', 309),
(1059, 'Etafe.link', 196),
(1060, 'Uacije.link', 311),
(1061, 'Qusoda.link', 642),
(1062, 'Hudu.link', 675),
(1063, 'Luqavu.link', 4),
(1064, 'E4V1940MJ.link', 307),
(1065, 'Tizobo.link', 480),
(1066, 'Eja.link', 44),
(1067, 'Kukaga.link', 411),
(1068, 'Cumaxo.link', 85),
(1069, 'Yjibohiva.link', 328),
(1070, 'Lumoma.link', 391),
(1071, 'Revi.link', 394),
(1072, 'Vu.link', 5),
(1073, 'Ixapi.link', 99),
(1074, 'Icoti.link', 389),
(1075, 'Oi.link', 70),
(1076, '1D8QQ560.link', 134),
(1077, 'Fke.link', 441),
(1078, 'Soqoji.link', 655),
(1079, 'Bkojehi.link', 41),
(1080, 'Bgerepu.link', 284),
(1081, '5D3690VM.link', 788),
(1082, 'Nze.link', 767),
(1083, 'Arozule.link', 505),
(1084, 'Ukupa.link', 771),
(1085, 'Obejojo.link', 524),
(1086, 'Woqaliza.link', 57),
(1087, 'Vimo.link', 280),
(1088, 'Hecoriga.link', 597),
(1089, 'Malahesu.link', 585),
(1090, 'Gigeti.link', 503),
(1091, 'Wu.link', 262),
(1092, 'Vjolabu.link', 275),
(1093, 'Eicudeyora.link', 361),
(1094, 'Zke.link', 781),
(1095, 'Cipayori.link', 245),
(1096, 'Wwenu.link', 6),
(1097, 'Cupixiji.link', 470),
(1098, 'Fkuye.link', 632),
(1099, 'Avukaxo.link', 559),
(1100, 'Iajasofe.link', 715),
(1101, 'Cari.link', 669),
(1102, 'Aodefesoxa.link', 62),
(1103, 'Zucuyapo.link', 788),
(1104, 'Gowoso.link', 279),
(1105, 'C720LJ30.link', 440),
(1106, 'J1OEE2.link', 390),
(1107, 'Rekevasa.link', 37),
(1108, 'Qba.link', 199),
(1109, 'W63P447.link', 58),
(1110, 'Wenaqipa.link', 237),
(1111, 'Aiguca.link', 526),
(1112, 'Lsinoco.link', 379),
(1113, 'Iane.link', 360),
(1114, 'Zcabime.link', 490),
(1115, 'Khu.link', 6),
(1116, 'Uezoxoru.link', 777),
(1117, 'Fife.link', 539),
(1118, 'Zubo.link', 46),
(1119, 'Xu.link', 86),
(1120, 'Dvavolo.link', 255),
(1121, 'Dsupe.link', 462),
(1122, 'Vihode.link', 5),
(1123, 'Wdusu.link', 84),
(1124, 'Oqoginu.link', 585),
(1125, 'Regami.link', 601),
(1126, 'P02SMT51.link', 428),
(1127, 'Lho.link', 593),
(1128, 'Sisewa.link', 602),
(1129, 'Vocokixe.link', 780),
(1130, 'Sli.link', 546),
(1131, '676V81.link', 208),
(1132, 'Jiyiso.link', 505),
(1133, 'Ouvowivo.link', 511),
(1134, 'Xroyeku.link', 449),
(1135, 'Bmoco.link', 560),
(1136, 'Nni.link', 547),
(1137, 'Esewa.link', 223),
(1138, 'Shosigapo.link', 1),
(1139, 'VD0DQ.link', 421),
(1140, 'Afibo.link', 364),
(1141, 'Gno.link', 710),
(1142, 'E06J7686.link', 3),
(1143, 'Eobefihidu.link', 567),
(1144, 'Ximoza.link', 496),
(1145, 'Seyega.link', 505),
(1146, 'Kakumubu.link', 173),
(1147, 'Aeqenude.link', 307),
(1148, 'Videhu.link', 790),
(1149, 'Gjoxu.link', 337),
(1150, 'Rtucova.link', 2),
(1151, 'Fvo.link', 395),
(1152, 'Hutifupa.link', 2),
(1153, 'Vguzewo.link', 524),
(1154, 'Qlumulo.link', 20),
(1155, 'Xacelobo.link', 382),
(1156, 'Pagekaqa.link', 8),
(1157, 'Ttepa.link', 755),
(1158, 'Nxu.link', 321),
(1159, 'Viyuba.link', 11),
(1160, 'Vega.link', 87),
(1161, 'Ugu.link', 107),
(1162, 'Vpaqu.link', 341),
(1163, 'Yuboji.link', 77),
(1164, 'Tva.link', 3),
(1165, 'Oilase.link', 571),
(1166, 'Qhude.link', 94),
(1167, 'Xijiyuqu.link', 5),
(1168, 'Bzi.link', 554),
(1169, 'Abe.link', 24),
(1170, 'Ei.link', 96),
(1171, 'Uoyuqaveme.link', 199),
(1172, 'Kmesa.link', 547),
(1173, 'Fudanihi.link', 377),
(1174, 'Cwuwebo.link', 261),
(1175, 'Piqisosu.link', 638),
(1176, 'Ratusequ.link', 214),
(1177, '4G5QX2B8AN1.link', 32),
(1178, 'Hxu.link', 689),
(1179, 'Whosapi.link', 247),
(1180, 'Ywe.link', 524),
(1181, 'Aeta.link', 224),
(1182, 'Hcobo.link', 181),
(1183, 'JSXTC0.link', 318),
(1184, 'Eobilaya.link', 694),
(1185, 'Faye.link', 141),
(1186, 'Yyo.link', 438),
(1187, 'Njikequ.link', 256),
(1188, 'Xoranu.link', 8),
(1189, '5T0727IB.link', 710),
(1190, 'BM7Y6LD43L4.link', 712),
(1191, 'Safimicipe.link', 253),
(1192, 'Siji.link', 150),
(1193, 'Suye.link', 700),
(1194, 'Zquri.link', 775),
(1195, 'Cdufe.link', 587),
(1196, 'Uvono.link', 489),
(1197, 'G2U432.link', 353),
(1198, 'Wade.link', 69),
(1199, 'Ejohi.link', 390),
(1200, 'Qiwada.link', 712);

INSERT INTO especie(id, nombre, reino, tipo_alimentacion, n_estimado) VALUES
(1, 'dogokude', 'Minerali', 'geovoro', 1339733510),
(2, 'jega', 'Animalia', 'hervíboro', 1795055902),
(3, 'sije', 'Protista', 'hervíboro', 4350341),
(4, 'ipa'' kife', 'Plantae', 'hervíboro', 2),
(5, 'ahe badu', 'Conceptia', 'omnívoro', 1319003892),
(6, 'doreve', 'Protista', 'hervíboro', 855052294),
(7, 'efeju bulazo', 'Minerali', 'hervíboro', 778344343),
(8, 'zisubele', 'Animalia', 'carnívoro', 732121471),
(9, 'wuvaneqa', 'Plantae', 'carnívoro', 814716132),
(10, 'e'' opemi', 'Archaea', 'omnívoro', 1531646711),
(11, 'ilirine', 'Synaisthemia', 'hervíboro', 495926294),
(12, 'ozufija', 'Protista', 'omnívoro', 1770952274),
(13, 'kopehi', 'Protista', 'vampirismo', 407954175),
(14, 'lo', 'Synaisthemia', 'omnívoro', 2097300945),
(15, 'vubi', 'Bacteria', 'hervíboro', 1776260678),
(16, 'o nopecu', 'Minerali', 'carnívoro', 1479876453),
(17, 'ejo'' ', NULL, 'vampirismo', 404718101),
(18, 'gofe', NULL, 'carnívoro', 1934793967),
(19, 'ecani'' coxoke', 'Plantae', 'hervíboro', 1472918018),
(20, 'wu', 'Protista', 'geovoro', 5834),
(21, 'api'' ubo', 'Bacteria', 'hervíboro', 1075561369),
(22, 'citu', 'Animalia', 'omnívoro', 1692582844),
(23, 'carumiju', 'Synaisthemia', 'hervíboro', 1988950358),
(24, 'ha', 'Fungi', 'hervíboro', 3),
(25, 'boqi', 'Synaisthemia', 'vampirismo', 347),
(26, 'witi', 'Conceptia', 'hervíboro', NULL),
(27, 'bobi', 'Minerali', 'hervíboro', 175822372),
(28, 'oqi iwiqita', 'Minerali', 'hervíboro', 1190406283),
(29, 'fepedu', 'Synaisthemia', 'vampirismo', NULL),
(30, 'ce', 'Animalia', 'omnívoro', 71),
(31, 'liba', 'Synaisthemia', 'omnívoro', 705663981),
(32, 'liha', 'Protista', 'omnívoro', 1546346675),
(33, 'u wo', 'Bacteria', 'hervíboro', 10),
(34, 'ime'' la', 'Bacteria', 'hervíboro', 2099880573),
(35, 'jahaki', NULL, 'omnívoro', 1846380256),
(36, 'cize', 'Plantae', 'hervíboro', 1852349395),
(37, 'a u', 'Synaisthemia', 'geovoro', 647),
(38, 'seba', 'Synaisthemia', 'carnívoro', 4),
(39, 'cuhapupisa', 'Plantae', 'hervíboro', 1585911262),
(40, 'axuki', 'Archaea', 'omnívoro', 1572448441),
(41, 'ajalo', 'Minerali', 'omnívoro', 2085270889),
(42, 'xo efo', 'Minerali', 'hervíboro', 25),
(43, 'fogobu', 'Conceptia', 'geovoro', 2070766921),
(44, 'dipu', 'Animalia', 'omnívoro', 1481),
(45, 'asu towo', NULL, 'hervíboro', 153798464),
(46, 'uxeqe', 'Synaisthemia', 'hervíboro', 87),
(47, 'izo'' pogo', 'Archaea', 'hervíboro', 2075982364),
(48, 'okina', 'Archaea', 'omnívoro', 777124422),
(49, 'icumu', 'Archaea', 'hervíboro', 834599996),
(50, 'ukinete', 'Protista', 'omnívoro', 1692257918),
(51, 'coli', 'Conceptia', 'omnívoro', 157643901),
(52, 'pa', 'Bacteria', 'hervíboro', 183824749),
(53, 'tanocina', 'Conceptia', 'hervíboro', 1005611911),
(54, 'xoza', NULL, 'geovoro', NULL),
(55, 'gixi', 'Archaea', 'omnívoro', 1843989829),
(56, 'efu'' ca', 'Protista', 'hervíboro', 584198169),
(57, 'olarafa', 'Plantae', 'hervíboro', 1102405420),
(58, 'oxe oguto', 'Synaisthemia', 'geovoro', 2094967634),
(59, 'inoli'' axo', 'Bacteria', 'hervíboro', 1325397988),
(60, 'ivoti xeha', 'Synaisthemia', 'hervíboro', 82953666),
(61, 'jiqu', 'Protista', 'omnívoro', 6),
(62, 'foze', 'Archaea', 'hervíboro', 479),
(63, 'tuqa', 'Fungi', 'omnívoro', 450623004),
(64, 'rari', 'Conceptia', 'omnívoro', 1844562086),
(65, 'hewotu', 'Synaisthemia', 'hervíboro', 4),
(66, 'keho', 'Animalia', 'carnívoro', 2019736352),
(67, 'owurijaka', 'Conceptia', 'omnívoro', 364),
(68, 'eto', 'Plantae', 'carnívoro', 2088207901),
(69, 'safudi', 'Animalia', 'vampirismo', NULL),
(70, 'eka', 'Archaea', 'hervíboro', 1102723477),
(71, 'ruveji', 'Synaisthemia', 'carnívoro', 378296132),
(72, 'ifelo kikomiqo', 'Archaea', 'hervíboro', 977521292),
(73, 'uso'' ufakifi', 'Plantae', 'hervíboro', 1097900286),
(74, 'a'' aboxa', 'Bacteria', 'hervíboro', 135979232),
(75, 'e rejaxada', 'Protista', 'hervíboro', 330),
(76, 'kumo', NULL, 'hervíboro', 927),
(77, 'jidozavo', 'Minerali', 'omnívoro', 2105502229),
(78, 'idutuve', NULL, 'hervíboro', 621439037),
(79, 'a', 'Synaisthemia', 'geovoro', 1316667067),
(80, 'ubu jo', 'Fungi', 'carnívoro', 1068056648),
(81, 'imiza'' iwuquta', 'Synaisthemia', 'omnívoro', 58),
(82, 'ejakitabe', 'Synaisthemia', 'omnívoro', 170008127),
(83, 'a xefi', 'Protista', 'omnívoro', 1229242796),
(84, 'uzu bewodu', NULL, 'hervíboro', NULL),
(85, 'omege', NULL, 'geovoro', 576885941),
(86, 'uce'' re', NULL, 'carnívoro', 1037445581),
(87, 'jofigacu', 'Plantae', 'hervíboro', 2006832533),
(88, 'ufe'' araso', 'Minerali', 'hervíboro', 1442535140),
(89, 'lufa', 'Protista', 'omnívoro', 1463656459),
(90, 'legu', NULL, 'omnívoro', 1550362985),
(91, 'qegafuvi', 'Plantae', 'geovoro', 281114901),
(92, 'pole', 'Bacteria', 'hervíboro', 853216101),
(93, 'uvogo ecevikazu', 'Archaea', 'hervíboro', 996763973),
(94, 'e'' ukutaza', 'Synaisthemia', 'hervíboro', 5),
(95, 'ga'' emo', 'Protista', 'geovoro', 456469548),
(96, 'anidodi', 'Minerali', 'carnívoro', 954),
(97, 'ize'' ugehejege', 'Conceptia', 'carnívoro', 95780565),
(98, 'notuxo', 'Bacteria', 'hervíboro', 1906152786),
(99, 'cixife', 'Synaisthemia', 'carnívoro', 1706257071),
(100, 'iquva', NULL, 'omnívoro', 66),
(101, 'uxi'' hema', 'Plantae', 'omnívoro', 89940048),
(102, 'azo', 'Plantae', 'omnívoro', 517),
(103, 'a'' pe', 'Conceptia', 'omnívoro', 1227337006),
(104, 'ni', 'Fungi', 'hervíboro', 1026022887),
(105, 'zesote', 'Protista', 'hervíboro', 1790071342),
(106, 'qa', 'Synaisthemia', 'carnívoro', 677625014),
(107, 'qu', 'Synaisthemia', 'hervíboro', NULL),
(108, 'uli'' gubo', 'Minerali', 'hervíboro', 1477142019),
(109, 'ulufaca', 'Animalia', 'omnívoro', 1099838101),
(110, 'ula hecu', 'Fungi', 'hervíboro', 4),
(111, 'ki', 'Fungi', 'hervíboro', NULL),
(112, 'ilidaxase', 'Protista', 'geovoro', 151889526),
(113, 'azotehe', 'Minerali', 'geovoro', 549711992),
(114, 'ehasi erajuwepo', 'Archaea', 'omnívoro', 1696364515),
(115, 'iqu'' oqocu', 'Bacteria', 'carnívoro', 690233241),
(116, 'ba', 'Synaisthemia', 'hervíboro', 430067032),
(117, 'eqabi vanaxu', 'Minerali', 'hervíboro', 1480665552),
(118, 'uziza', 'Bacteria', 'carnívoro', 206652286),
(119, 'u'' akilo', 'Protista', 'omnívoro', 1000600576),
(120, 'dolomi', 'Protista', 'carnívoro', 6077),
(121, 'axeno'' imi', 'Bacteria', 'hervíboro', 119644960),
(122, 'obutute', 'Bacteria', 'carnívoro', 215698963),
(123, 'mida', 'Archaea', 'vampirismo', NULL),
(124, 'do', 'Minerali', 'hervíboro', 8),
(125, 'wufoviza', NULL, 'hervíboro', 1069978284),
(126, 'otalica', 'Bacteria', 'carnívoro', 1561321974),
(127, 'edoqa', 'Minerali', 'hervíboro', 356452688),
(128, 'ina kavipo', NULL, 'hervíboro', 1978),
(129, 'da', 'Minerali', 'hervíboro', 1523408258),
(130, 'burixofi', NULL, 'omnívoro', 150404067),
(131, 'ga', 'Animalia', 'vampirismo', 610028556),
(132, 'u'' pewu', 'Synaisthemia', 'carnívoro', 205),
(133, '', 'Plantae', 'omnívoro', 551415092),
(134, 'ucuti obewuki', 'Fungi', 'hervíboro', NULL),
(135, 'goruwa', 'Conceptia', 'vampirismo', 202),
(136, 'hu', 'Animalia', 'geovoro', 313343900),
(137, 'asivo'' ho', 'Animalia', 'omnívoro', 335463794),
(138, 'mehotu', 'Conceptia', 'carnívoro', 373398774),
(139, 'makekive', 'Synaisthemia', 'omnívoro', 407964391),
(140, 'kexi', 'Conceptia', 'carnívoro', 652798135),
(141, 'uhomo aloqegi', 'Plantae', 'hervíboro', 1125916817),
(142, 'golega', 'Minerali', 'hervíboro', 1651760616),
(143, 'famumo', 'Synaisthemia', 'carnívoro', 883),
(144, 'ciki', 'Animalia', 'carnívoro', 2052863156),
(145, 'xirozate', NULL, 'hervíboro', 1830149306),
(146, 'moroqama', 'Archaea', 'hervíboro', 263),
(147, 'tiqaki', 'Minerali', 'hervíboro', 160379011),
(148, 'u'' tudozi', 'Fungi', 'carnívoro', NULL),
(149, 'ulafu', 'Synaisthemia', 'carnívoro', 1898963032),
(150, 'adopa pi', 'Plantae', 'omnívoro', 64),
(151, 'xule', 'Archaea', 'hervíboro', 408545056),
(152, 'merakeba', 'Plantae', 'vampirismo', 0),
(153, 'i'' iricoke', 'Plantae', 'carnívoro', 532907270),
(154, 'koculu', 'Animalia', 'geovoro', 1001000821),
(155, 'guqi', 'Fungi', 'carnívoro', 381437085),
(156, 'te', 'Plantae', 'hervíboro', 4594),
(157, 'du', 'Minerali', 'geovoro', NULL),
(158, 'wonevi', 'Animalia', 'carnívoro', 1562984852),
(159, 'veqo', 'Conceptia', 'hervíboro', 5161),
(160, 'a he', NULL, 'omnívoro', 1569826561),
(161, 'waqa', 'Minerali', 'carnívoro', 1930583274),
(162, 'elehula', 'Conceptia', 'hervíboro', 1439709326),
(163, 'kupu', NULL, 'vampirismo', 1604820242),
(164, 'wota', 'Animalia', 'hervíboro', 532789073),
(165, 'minuzu', 'Archaea', 'hervíboro', 246420051),
(166, 'ze', 'Conceptia', 'vampirismo', 429219804),
(167, 'zecu', 'Bacteria', 'hervíboro', 937524450),
(168, 'pifi', 'Plantae', 'omnívoro', NULL),
(169, 'buce', NULL, 'vampirismo', 512),
(170, 'divo', 'Conceptia', 'carnívoro', 1397794201),
(171, 'ewu jeho', 'Synaisthemia', 'hervíboro', NULL),
(172, 'a'' odevigiqe', 'Bacteria', 'omnívoro', 1193289275),
(173, 'uveze'' awe', 'Conceptia', 'omnívoro', 1175600438),
(174, 'lewo', NULL, 'hervíboro', 816),
(175, 'ubibinami', 'Conceptia', 'hervíboro', 1455079144),
(176, 'izi', 'Bacteria', NULL, NULL),
(177, 'qedena', 'Conceptia', 'hervíboro', 1124065579),
(178, 'adofilatuxa', 'Plantae', 'hervíboro', 370),
(179, 'uzu'' odowulara', 'Minerali', 'carnívoro', 1981273619),
(180, 'odope', 'Bacteria', 'hervíboro', 1150322420),
(181, 'lofe', 'Synaisthemia', 'hervíboro', 1787469107),
(182, 'ugeze', NULL, 'hervíboro', 1391420525),
(183, 'lazi', NULL, 'carnívoro', 44),
(184, 'uhe', 'Bacteria', 'carnívoro', 1371403089),
(185, 'zere', NULL, 'carnívoro', 62848619),
(186, ''' izalowu', NULL, 'carnívoro', 315157501),
(187, 'ho'' edivewavuwe', 'Bacteria', 'hervíboro', 589853094),
(188, 'cada', 'Minerali', 'hervíboro', 562603952),
(189, 'a arica', 'Conceptia', 'vampirismo', 150),
(190, 'ojohipe', 'Archaea', 'omnívoro', 9),
(191, 'wihawe', 'Protista', 'omnívoro', 815),
(192, 'fi'' esucivexa', 'Bacteria', 'hervíboro', 511637220),
(193, 'rewa', 'Bacteria', NULL, NULL),
(194, 'exu buju', 'Archaea', 'hervíboro', 1190910170),
(195, 'ijo kaba', 'Fungi', 'carnívoro', 1124869725),
(196, 'uqu', 'Minerali', 'hervíboro', 4010),
(197, 'suxa', 'Plantae', 'hervíboro', 810),
(198, 'inubu', NULL, 'hervíboro', 1870604201),
(199, 'erofe', NULL, 'hervíboro', 474787378),
(200, 'bujuniqoqi', 'Conceptia', 'carnívoro', 294375578),
(201, 'fukurage', NULL, 'hervíboro', NULL),
(202, 'imipo', 'Protista', 'hervíboro', 4),
(203, 'akosa gumoce', 'Fungi', 'geovoro', NULL),
(204, 'hicatotu', 'Protista', 'carnívoro', 897420579),
(205, 'axoviga', 'Protista', 'omnívoro', 1931605050),
(206, 'u talelu', 'Synaisthemia', 'vampirismo', 1675693977),
(207, 'po', 'Conceptia', 'carnívoro', 1664880387),
(208, 'jumi', 'Plantae', 'carnívoro', 1657877960),
(209, 'u'' bero', 'Animalia', 'hervíboro', 586),
(210, 'fovo', 'Animalia', 'hervíboro', 25),
(211, 'bafa', 'Archaea', 'omnívoro', 1274253496),
(212, 'kediciri', 'Bacteria', 'hervíboro', 1498794879),
(213, 'xoxiki', 'Animalia', 'hervíboro', 1),
(214, 'wumi', 'Fungi', 'carnívoro', 285),
(215, 'xazelifo', 'Minerali', NULL, NULL),
(216, 'aqici', 'Conceptia', 'carnívoro', NULL),
(217, 'ukuka', NULL, 'geovoro', 277946510),
(218, 'nizu', 'Synaisthemia', 'hervíboro', 7),
(219, 'megu', 'Synaisthemia', 'geovoro', 307946375),
(220, 'uci'' nufu', 'Synaisthemia', 'carnívoro', 1713756613),
(221, 'topeto', 'Plantae', 'hervíboro', 863869395),
(222, 'unumi'' bacekira', 'Conceptia', 'carnívoro', 624209269),
(223, 'awozokevupu', 'Plantae', 'hervíboro', 233708719),
(224, 'ema', 'Animalia', 'omnívoro', 409140017),
(225, 'wefu', NULL, 'hervíboro', 1005472618),
(226, 'kope', 'Bacteria', 'vampirismo', 1553926885),
(227, 'kabele', 'Synaisthemia', 'hervíboro', 59),
(228, 'uxamo'' cawi', 'Protista', 'carnívoro', 1480047894),
(229, 'fovesi', 'Bacteria', 'hervíboro', 454729378),
(230, 'erere', 'Synaisthemia', 'hervíboro', 7378),
(231, 'qina', 'Archaea', 'omnívoro', 449285035),
(232, ''' gixuqi', 'Bacteria', 'hervíboro', 1019730668),
(233, 'ci dafeno', 'Fungi', 'vampirismo', 910),
(234, 'ije', 'Conceptia', 'omnívoro', NULL),
(235, 'bovuba', NULL, 'carnívoro', 586630470),
(236, 'uhemi'' ucefu', 'Fungi', 'hervíboro', 30),
(237, 'adeduha', 'Animalia', NULL, NULL),
(238, 'ecojudage', 'Animalia', 'omnívoro', 110125742),
(239, 'huro', 'Minerali', 'hervíboro', 432774797),
(240, 'nifuna', 'Protista', 'geovoro', 493691426),
(241, 'deliruja', NULL, 'omnívoro', 8),
(242, 'go'' odizi', 'Protista', 'omnívoro', 506415598),
(243, ' olazi', 'Protista', 'hervíboro', NULL),
(244, 'kaji', 'Archaea', 'hervíboro', 1415257222),
(245, 'cufodahu', 'Animalia', 'vampirismo', 994105861),
(246, 'firuza', 'Bacteria', 'omnívoro', 1136831218),
(247, 'pujirama', 'Bacteria', 'hervíboro', 1548911644),
(248, 'ihozixumi', 'Archaea', 'hervíboro', 186751736),
(249, 'ivacu iti', NULL, 'omnívoro', 406601583),
(250, 'puje', 'Conceptia', 'carnívoro', 1560308275),
(251, 'ka'' tekopo', 'Plantae', 'omnívoro', 325),
(252, 'apu', 'Synaisthemia', 'carnívoro', NULL),
(253, 'otu', 'Protista', 'omnívoro', 2392),
(254, 'hudajefu', 'Plantae', 'hervíboro', 814024560),
(255, 'mimuxera', 'Animalia', 'omnívoro', 340),
(256, 'opugi'' ', 'Plantae', 'geovoro', 2491),
(257, 'e ome', 'Archaea', 'geovoro', 2062767933),
(258, 'bare', 'Bacteria', 'omnívoro', 15),
(259, 'i'' xiki', 'Conceptia', 'carnívoro', 255826651),
(260, 'hijinuce', 'Protista', 'omnívoro', 1448),
(261, 'dari', 'Fungi', 'carnívoro', 403089393),
(262, ' xemipomi', 'Animalia', 'carnívoro', 1),
(263, 'femusewu', 'Protista', 'hervíboro', 541966809),
(264, 'ejice', 'Minerali', 'hervíboro', 37110062),
(265, 'icujiri', 'Conceptia', 'hervíboro', NULL),
(266, 'opiwami', 'Fungi', 'carnívoro', 1413839963),
(267, 'ihi otohe', 'Protista', 'geovoro', 9204),
(268, 'upexali', NULL, 'vampirismo', 807498583),
(269, 'u', 'Synaisthemia', 'omnívoro', 6818),
(270, 'utegu eneholo', 'Archaea', 'carnívoro', 74),
(271, 'kira', 'Minerali', 'hervíboro', 637084785),
(272, 'ovewe'' ige', NULL, 'vampirismo', 671),
(273, 'hori', 'Conceptia', 'omnívoro', 355498770),
(274, 'iqeva'' mu', 'Protista', 'hervíboro', 454761170),
(275, 'apuwesa', 'Protista', 'hervíboro', 182117567),
(276, 'ko'' ebumo', NULL, 'vampirismo', 382),
(277, 'obo'' ocole', 'Synaisthemia', 'hervíboro', 554593510),
(278, 'ata egoxutifori', 'Archaea', 'carnívoro', 1777618180),
(279, 'wo', 'Fungi', 'carnívoro', 587674848),
(280, 'zusarudojo', 'Minerali', 'geovoro', NULL),
(281, 'ifo', 'Archaea', 'hervíboro', 1729635414),
(282, 'owiwo loto', 'Fungi', 'carnívoro', 1384515267),
(283, 'gakuqe', 'Plantae', 'carnívoro', 1819676652),
(284, 'igige zete', 'Protista', 'vampirismo', 79),
(285, 'gisosu', 'Animalia', 'hervíboro', 1448127313),
(286, 'ona', 'Conceptia', 'omnívoro', 972441743),
(287, 'i caxa', 'Archaea', 'geovoro', 393102913),
(288, 'hare', 'Plantae', NULL, NULL),
(289, 'ohu ucuhiwo', 'Protista', 'hervíboro', 915481843),
(290, 'mino', 'Plantae', 'hervíboro', 25),
(291, 'ifovo', 'Archaea', 'vampirismo', 1152883615),
(292, 'oce'' kahehi', 'Plantae', 'carnívoro', 1782287345),
(293, 'uhedina', 'Bacteria', 'carnívoro', 1130045411),
(294, 'oxu', 'Protista', 'hervíboro', 532645470),
(295, 'hota', 'Bacteria', 'hervíboro', 126201516),
(296, 'fabidude', 'Synaisthemia', 'hervíboro', 1158702402),
(297, 'gepeharo', 'Conceptia', 'hervíboro', 1916069763),
(298, 'oji', 'Conceptia', 'hervíboro', 1580146769),
(299, 'naxo', 'Bacteria', 'omnívoro', 1252211522),
(300, 'qusa', 'Plantae', 'vampirismo', 46),
(301, 'oti fifala', 'Synaisthemia', 'hervíboro', 2118826656),
(302, 'ho'' ugi', 'Animalia', 'vampirismo', 764059354),
(303, 'tu', 'Animalia', 'hervíboro', 693538394),
(304, 'coxa', NULL, 'omnívoro', 2053974527),
(305, 'wucuza', 'Plantae', 'hervíboro', 897081883),
(306, 'xawe', 'Animalia', 'hervíboro', 1679359302),
(307, 'uruhefi', 'Bacteria', 'geovoro', 7),
(308, 'xiva', 'Animalia', 'omnívoro', 962547435),
(309, 'ivija', 'Animalia', 'hervíboro', 64852129),
(310, 'e'' gutosako', 'Animalia', 'omnívoro', 2766),
(311, 'riwoqu', 'Animalia', 'geovoro', 1684573685),
(312, 'keruqu', 'Protista', 'carnívoro', 908842192),
(313, 'a ixusajusa', 'Plantae', NULL, NULL),
(314, 'olo'' wa', 'Plantae', 'carnívoro', 21952957),
(315, 'eko'' mifo', 'Archaea', 'hervíboro', 55),
(316, 'u efumahefana', 'Fungi', 'omnívoro', 1165085080),
(317, 'lopifapa', 'Fungi', 'omnívoro', NULL),
(318, 'oxu zipoka', 'Plantae', 'hervíboro', 1932378242),
(319, 'anevotaroga', 'Protista', 'hervíboro', 566586427),
(320, 'sosemuci', 'Protista', 'carnívoro', 1804780489),
(321, 'aqe', 'Synaisthemia', 'hervíboro', 926948435),
(322, 'badero', 'Protista', 'hervíboro', 919640872),
(323, 'acadi', 'Archaea', 'carnívoro', 221068261),
(324, 'u miraqe', NULL, 'omnívoro', 286058725),
(325, 'fezuxaro', 'Protista', 'vampirismo', NULL),
(326, 'seceha', NULL, 'omnívoro', 35),
(327, 'huzu', 'Synaisthemia', 'hervíboro', 92),
(328, 'iqopo', 'Animalia', 'omnívoro', 8355),
(329, 'wujejuru', 'Synaisthemia', 'omnívoro', NULL),
(330, 'koco', 'Archaea', 'hervíboro', 1288631408),
(331, 'somu', NULL, 'geovoro', 1443021514),
(332, 'ufagonu', 'Archaea', 'hervíboro', 959),
(333, 'uno sume', 'Plantae', 'omnívoro', 276178279),
(334, 'veho', 'Fungi', 'omnívoro', 362040708),
(335, 'ubane', 'Plantae', 'carnívoro', 8252),
(336, 'ago'' nabi', 'Protista', 'hervíboro', 1773013114),
(337, 'rulilo', NULL, 'hervíboro', 934432949),
(338, 'teda', 'Animalia', 'vampirismo', 8),
(339, 'umute', 'Bacteria', 'omnívoro', 2083966704),
(340, 'qobavogu', 'Bacteria', 'carnívoro', 904739394),
(341, 'una'' qahebi', 'Fungi', 'carnívoro', 4793),
(342, 'ahagimapoho', 'Protista', 'hervíboro', 1553956913),
(343, 'vaca', 'Protista', 'hervíboro', 1670933655),
(344, 'hulagu', NULL, 'carnívoro', 1336567093),
(345, 'muri', 'Archaea', 'hervíboro', 94507509),
(346, 'meka', 'Synaisthemia', 'hervíboro', 323015861),
(347, 'puzuqe', 'Protista', 'hervíboro', 9090),
(348, 'sube', 'Synaisthemia', 'hervíboro', 532644169),
(349, 'nu', 'Archaea', 'hervíboro', 417530716),
(350, 'elabi', 'Animalia', 'carnívoro', 646),
(351, 'eretu', 'Bacteria', 'omnívoro', 6276),
(352, 've egehiju', 'Synaisthemia', 'hervíboro', 770),
(353, 'nozusiju', 'Animalia', 'hervíboro', 1644685885),
(354, 'fe', 'Animalia', 'omnívoro', 568770019),
(355, 'inugo'' za', 'Minerali', 'hervíboro', NULL),
(356, 'o', 'Animalia', 'carnívoro', 2011861058),
(357, 'ugegi', 'Protista', 'vampirismo', 407933497),
(358, 'caboge', 'Plantae', 'hervíboro', 2),
(359, 'gipoji', 'Bacteria', 'hervíboro', NULL),
(360, 'dojewunu', 'Minerali', 'hervíboro', 587425095),
(361, 'su', 'Conceptia', 'hervíboro', 816596992),
(362, 'zimobu', 'Plantae', 'omnívoro', 1784235407),
(363, 'juke', 'Animalia', 'hervíboro', 1236752388),
(364, 'oducube', 'Synaisthemia', 'hervíboro', NULL),
(365, 'bituku', 'Archaea', 'carnívoro', 343133485),
(366, 'ramidu', 'Synaisthemia', 'omnívoro', 1638216458),
(367, 'so', 'Protista', 'hervíboro', 1),
(368, 'ibigexu', 'Bacteria', 'omnívoro', 2127666916),
(369, 'efihatado', 'Animalia', 'geovoro', 1498156354),
(370, 'eroqu', 'Archaea', 'hervíboro', NULL),
(371, 'iki'' kiboza', NULL, 'carnívoro', 473463507),
(372, 'fibamakuko', 'Protista', 'omnívoro', 146018949),
(373, 'u'' vamumo', 'Animalia', 'carnívoro', NULL),
(374, 'pumo', 'Fungi', 'omnívoro', 980732958),
(375, 'to exe', 'Protista', 'hervíboro', 1000049714),
(376, 'mive', 'Bacteria', 'geovoro', 661489913),
(377, 'jacobowi', 'Plantae', 'hervíboro', 1087223154),
(378, 'ubude', NULL, 'geovoro', 1),
(379, 'faki', 'Plantae', 'carnívoro', 517423396),
(380, 'xive', NULL, 'omnívoro', 8228),
(381, 'jukunide', 'Synaisthemia', 'carnívoro', 7599),
(382, 'sahu', 'Minerali', 'hervíboro', 752),
(383, 'puqapu', 'Archaea', 'carnívoro', 600904201),
(384, 'ihi'' abubide', 'Minerali', 'hervíboro', 335245117),
(385, 'ece'' duwadu', NULL, 'omnívoro', 1582915301),
(386, 'bifegu', 'Minerali', NULL, NULL),
(387, 'gehu', NULL, 'omnívoro', 1147480781),
(388, 'ironi', 'Plantae', 'hervíboro', 231233372),
(389, 'ecagi', 'Minerali', 'geovoro', 633689190),
(390, 'xejoga', 'Protista', 'hervíboro', 694),
(391, 'cadivi', 'Protista', 'hervíboro', 214994907),
(392, 'rokagumo', 'Minerali', 'hervíboro', 609),
(393, 'jo', 'Plantae', 'hervíboro', 95084892),
(394, 'ocimo'' igu', 'Conceptia', 'carnívoro', 209346216),
(395, 'ke', 'Fungi', 'omnívoro', 1438848427),
(396, 'cicovu', 'Fungi', NULL, NULL),
(397, 'gu', 'Fungi', 'hervíboro', 8),
(398, 'xa', 'Plantae', 'omnívoro', 1303536461),
(399, 'awamobu', 'Minerali', 'hervíboro', 1193643106),
(400, 'ora', NULL, 'omnívoro', 65),
(401, 'lanehiro', 'Animalia', 'hervíboro', 1558887930),
(402, 'o'' tiqesa', 'Minerali', 'omnívoro', 850256650),
(403, 'busixi', 'Protista', 'omnívoro', 63),
(404, 'eneki'' uzowu', 'Animalia', 'carnívoro', 1213781918),
(405, 'luse', 'Conceptia', 'hervíboro', 992467735),
(406, 'ivole', 'Plantae', 'omnívoro', 2087259558),
(407, 'avo'' ewonufori', 'Synaisthemia', 'geovoro', 9),
(408, 'wori', 'Fungi', 'hervíboro', 3),
(409, 'fidujadago', 'Fungi', 'omnívoro', 1615730416),
(410, 'haru', 'Protista', 'hervíboro', 4),
(411, 'tewecozo', NULL, 'omnívoro', 1449655576),
(412, 'uje raliku', NULL, 'hervíboro', 1790914709),
(413, 'ucigufu', 'Protista', 'hervíboro', 88149182),
(414, 'i'' guvena', 'Conceptia', 'vampirismo', 1081266436),
(415, 'eqisenikice', 'Plantae', 'carnívoro', 935),
(416, 'o ebeso', NULL, 'omnívoro', 288165695),
(417, 'orola', 'Synaisthemia', 'carnívoro', NULL),
(418, 'qisihi', 'Synaisthemia', 'hervíboro', 1637369593),
(419, 'ize', 'Archaea', 'hervíboro', 1703801724),
(420, 'a'' esaliriso', 'Conceptia', NULL, NULL),
(421, 'rohi', 'Fungi', 'vampirismo', 368389140),
(422, 'lu'' vosoci', 'Plantae', 'omnívoro', 427921740),
(423, 'qadulidi', 'Archaea', 'omnívoro', 5936),
(424, 'obunada', 'Protista', 'omnívoro', NULL),
(425, 'eticaveti', 'Archaea', 'hervíboro', 1405583370),
(426, 'pesu', 'Conceptia', 'carnívoro', 406275693),
(427, 'ece', 'Animalia', 'vampirismo', 2067260202),
(428, 'larima', 'Plantae', 'hervíboro', 1209447853),
(429, 'uqacage', 'Conceptia', 'carnívoro', 1985880014),
(430, 'ravinu', 'Bacteria', 'hervíboro', 823980998),
(431, 'zuve', 'Protista', 'vampirismo', 753),
(432, 'ujilezu', 'Archaea', 'hervíboro', 1972449128),
(433, 'ro', 'Protista', 'hervíboro', 196135517),
(434, 'efiwi', 'Bacteria', 'geovoro', 45),
(435, 'le jixo', 'Animalia', 'carnívoro', 1249805291),
(436, 'udo'' vu', 'Protista', 'vampirismo', 912594026),
(437, 'hula', 'Bacteria', 'vampirismo', 2),
(438, 'ge'' ataci', 'Plantae', 'geovoro', 1625328168),
(439, 'wovi', 'Animalia', 'geovoro', 1261872006),
(440, 'usuvo ebezo', 'Archaea', 'geovoro', 1591648645),
(441, 'woqelade', 'Conceptia', 'omnívoro', 1537423629),
(442, 'nobo', 'Bacteria', 'hervíboro', 1044970352),
(443, 'fera', 'Synaisthemia', 'carnívoro', 336588080),
(444, 'menajo', 'Minerali', 'vampirismo', 1620234246),
(445, 'ecohuqi', 'Minerali', 'omnívoro', 141150896),
(446, 'oto'' jawuno', 'Minerali', 'hervíboro', 2026011872),
(447, 'roxe', 'Conceptia', 'geovoro', 915499020),
(448, 'qe', 'Synaisthemia', 'omnívoro', 2084359655),
(449, ''' ohitu', 'Protista', 'hervíboro', 27),
(450, 'hicegi', 'Synaisthemia', 'carnívoro', 903819456),
(451, 'ejo', 'Protista', 'geovoro', 458059855),
(452, 'be', 'Minerali', 'hervíboro', 42),
(453, 'alu ebofe', 'Protista', 'hervíboro', NULL),
(454, 'ixaloci', 'Conceptia', 'carnívoro', 914800123),
(455, 'pahica', 'Plantae', 'hervíboro', NULL),
(456, 'cutasolu', 'Minerali', 'hervíboro', NULL),
(457, 'oki'' ifaliza', 'Bacteria', 'hervíboro', NULL),
(458, 'udice taxiro', 'Animalia', 'geovoro', 5),
(459, 'li we', 'Minerali', 'carnívoro', 2079250759),
(460, 'uzela'' ugafa', 'Archaea', 'hervíboro', 1105660523),
(461, 'puromido', 'Animalia', 'hervíboro', NULL),
(462, 'acuwizawo', 'Animalia', 'omnívoro', 1029824680),
(463, 'uride'' ewoma', 'Animalia', 'carnívoro', NULL),
(464, 'tufa', 'Plantae', 'omnívoro', NULL),
(465, 'zefohinu', 'Synaisthemia', 'vampirismo', 1664521584),
(466, 'xenizi', 'Bacteria', 'hervíboro', 64),
(467, 'zakexelo', 'Protista', 'hervíboro', NULL),
(468, 'aca', 'Synaisthemia', 'carnívoro', 1224520174),
(469, 'opi'' lihemi', 'Bacteria', 'omnívoro', 1260616820),
(470, 'oziji', 'Protista', 'geovoro', 787341398),
(471, 'exisa', 'Archaea', 'omnívoro', 3),
(472, 'e evaqa', 'Conceptia', 'omnívoro', 220),
(473, 'axi'' luwina', 'Plantae', 'omnívoro', NULL),
(474, 'tiqedo', 'Archaea', 'hervíboro', 2026042052),
(475, 'co ridowo', 'Protista', 'carnívoro', 2037846228),
(476, 'udi', 'Protista', 'carnívoro', 543),
(477, 'o'' pani', 'Minerali', 'hervíboro', 6109),
(478, 'dubatu', 'Protista', 'geovoro', 315693893),
(479, 'oje', 'Plantae', 'vampirismo', 1278371712),
(480, 'xolaketu', 'Bacteria', 'hervíboro', 330774978),
(481, 'efevubesa', 'Fungi', 'carnívoro', NULL),
(482, 'zofa', 'Minerali', 'hervíboro', 10),
(483, 'eku', 'Conceptia', 'omnívoro', 1680965726),
(484, 'padiro', 'Minerali', 'geovoro', 260),
(485, 'di', 'Fungi', 'hervíboro', 1101748296),
(486, 'bivu', 'Synaisthemia', 'vampirismo', 672),
(487, 'pipu', 'Protista', 'vampirismo', 553),
(488, 'i azudeki', 'Protista', 'omnívoro', 725),
(489, 'mejegadono', 'Fungi', 'omnívoro', 1677241450),
(490, 'cukoqazupo', 'Synaisthemia', 'hervíboro', 176156813),
(491, 'gelemu', 'Conceptia', 'omnívoro', 654678603),
(492, 'zedesajeru', 'Animalia', 'geovoro', 874800579),
(493, 'nixa', 'Archaea', 'carnívoro', 4518),
(494, 'loho', 'Synaisthemia', 'vampirismo', 194),
(495, 'erifivu', 'Protista', 'omnívoro', 1321038792),
(496, 'awaqoba', 'Conceptia', 'geovoro', 6879),
(497, 'eba caqiku', 'Archaea', 'vampirismo', 208360776),
(498, 'getu', 'Animalia', 'omnívoro', 1612793128),
(499, 'ugoka'' ehiwa', 'Conceptia', 'geovoro', 526823692),
(500, 'weva', 'Archaea', NULL, 2042964176);

INSERT INTO especie_cuerpo_celeste(id_especie, id_cuerpo_celeste) VALUES
(80, 663),
(334, 950),
(323, 129),
(326, 111),
(134, 7),
(296, 591),
(469, 472),
(4, 33),
(12, 37),
(4, 991),
(191, 640),
(255, 40),
(214, 47),
(214, 653),
(6, 501),
(198, 597),
(473, 828),
(82, 732),
(364, 539),
(140, 159),
(434, 384),
(9, 298),
(147, 7),
(176, 836),
(237, 956),
(468, 573),
(69, 707),
(8, 318),
(342, 915),
(391, 665),
(93, 323),
(406, 665),
(169, 738),
(6, 255),
(167, 485),
(233, 46),
(45, 41),
(94, 545),
(167, 85),
(418, 211),
(39, 334),
(275, 272),
(3, 599),
(336, 700),
(228, 153),
(34, 475),
(188, 969),
(277, 713),
(188, 131),
(224, 860),
(378, 554),
(260, 454),
(186, 883),
(9, 493),
(211, 111),
(98, 594),
(74, 793),
(347, 620),
(443, 430),
(1, 7),
(9, 8),
(182, 450),
(17, 476),
(5, 796),
(456, 287),
(443, 224),
(186, 5),
(88, 92),
(3, 919),
(202, 732),
(402, 801),
(37, 891),
(306, 287),
(202, 840),
(51, 715),
(141, 423),
(425, 254),
(272, 97),
(489, 954),
(122, 156),
(2, 211),
(209, 924),
(472, 129),
(113, 163),
(423, 376),
(135, 345),
(413, 691),
(5, 292),
(418, 92),
(11, 882),
(48, 875),
(317, 390),
(96, 801),
(420, 752),
(130, 5),
(78, 585),
(142, 192),
(279, 818),
(17, 335),
(481, 94),
(82, 20),
(328, 610),
(439, 3),
(142, 5),
(7, 846),
(65, 5),
(205, 374),
(350, 98),
(36, 109),
(386, 45),
(191, 577),
(80, 154),
(47, 218),
(337, 351),
(345, 356),
(459, 184),
(241, 174),
(83, 128),
(16, 553),
(29, 31),
(4, 795),
(52, 9),
(24, 44),
(330, 261),
(46, 445),
(296, 232),
(440, 780),
(257, 99),
(479, 524),
(435, 8),
(137, 514),
(60, 348),
(463, 107),
(89, 3),
(173, 449),
(264, 817),
(268, 608),
(75, 281),
(258, 512),
(459, 844),
(159, 547),
(379, 21),
(498, 519),
(160, 153),
(252, 63),
(26, 736),
(332, 81),
(103, 260),
(57, 462),
(81, 770),
(135, 13),
(462, 296),
(312, 42),
(436, 825),
(87, 834),
(222, 79),
(234, 4),
(2, 405),
(50, 294),
(428, 3),
(285, 872),
(69, 98),
(441, 386),
(5, 95),
(125, 96),
(115, 47),
(227, 576),
(189, 737),
(85, 621),
(129, 9),
(274, 622),
(52, 833),
(352, 114),
(385, 122),
(348, 66),
(134, 130),
(3, 598),
(44, 9),
(300, 618),
(29, 187),
(211, 21),
(416, 847),
(93, 524),
(284, 128),
(174, 9),
(234, 372),
(240, 911),
(415, 988),
(470, 426),
(223, 434),
(374, 928),
(469, 66),
(264, 698),
(301, 93),
(39, 806),
(133, 189),
(447, 547),
(439, 602),
(134, 603),
(417, 889),
(159, 981),
(430, 528),
(4, 460),
(304, 935),
(327, 35),
(346, 982),
(53, 445),
(213, 7),
(370, 456),
(60, 98),
(7, 253),
(9, 7),
(5, 18),
(64, 778),
(237, 626),
(105, 647),
(247, 920),
(61, 619),
(429, 962),
(14, 378),
(492, 759),
(274, 9),
(219, 427),
(251, 207),
(391, 439),
(323, 499),
(286, 597),
(190, 8),
(244, 418),
(299, 626),
(51, 689),
(80, 58),
(35, 937),
(388, 715),
(152, 9),
(198, 860),
(266, 51),
(274, 606),
(437, 39),
(43, 431),
(133, 955),
(244, 648),
(5, 332),
(466, 865),
(80, 8),
(37, 21),
(96, 92),
(55, 379),
(16, 779),
(470, 292),
(152, 567),
(184, 346),
(337, 962),
(486, 954),
(17, 844),
(462, 598),
(347, 154),
(153, 389),
(14, 940),
(43, 612),
(332, 955),
(93, 956),
(114, 411),
(89, 480),
(35, 95),
(456, 352),
(324, 361),
(120, 744),
(93, 990),
(7, 603),
(415, 16),
(246, 87),
(94, 192),
(151, 868),
(29, 621),
(310, 846),
(39, 54),
(356, 709),
(161, 425),
(95, 109),
(11, 832),
(21, 660),
(24, 748),
(32, 2),
(1, 394),
(27, 506),
(39, 269),
(35, 691),
(281, 126),
(281, 590),
(249, 94),
(224, 348),
(386, 75),
(44, 708),
(463, 204),
(448, 824),
(488, 369),
(3, 111),
(154, 525),
(155, 212),
(458, 401),
(64, 55),
(301, 481),
(413, 5),
(439, 478),
(483, 632),
(2, 815),
(102, 485),
(5, 216),
(334, 4),
(234, 720),
(29, 224),
(341, 66),
(25, 842),
(336, 49),
(376, 2),
(22, 695),
(160, 440),
(419, 319),
(436, 2),
(302, 9),
(477, 325),
(422, 808),
(137, 977),
(20, 481),
(304, 3),
(79, 636),
(74, 9),
(202, 889),
(115, 5),
(358, 896),
(133, 18),
(456, 33),
(314, 442),
(4, 478),
(330, 961),
(272, 503),
(80, 551),
(245, 430),
(298, 542),
(299, 849),
(440, 13),
(311, 79),
(465, 639),
(466, 9),
(137, 815),
(6, 619),
(214, 741),
(230, 15),
(145, 968),
(135, 405),
(367, 611),
(342, 587),
(10, 800),
(6, 282),
(260, 294),
(249, 955),
(165, 5),
(79, 676),
(250, 158),
(210, 495),
(381, 45),
(10, 504),
(10, 8),
(151, 8),
(285, 51),
(141, 216),
(257, 90),
(245, 432),
(129, 248),
(262, 805),
(416, 166),
(278, 1),
(251, 361),
(157, 381),
(309, 418),
(312, 694),
(6, 782),
(99, 565),
(315, 996),
(5, 50),
(413, 260),
(137, 265),
(244, 939),
(433, 701),
(274, 973),
(6, 456),
(78, 898),
(96, 876),
(301, 85),
(9, 231),
(1, 873),
(217, 151),
(9, 519),
(374, 952),
(364, 947),
(187, 576),
(117, 427),
(476, 546),
(28, 593),
(65, 877),
(354, 157),
(47, 513),
(54, 5),
(6, 102),
(49, 275),
(378, 500),
(387, 503),
(122, 968),
(7, 184),
(490, 871),
(431, 473),
(326, 769),
(11, 668),
(72, 178),
(348, 48),
(41, 4),
(313, 100),
(70, 41),
(98, 601),
(185, 480),
(120, 238),
(462, 580),
(430, 275),
(271, 34),
(167, 937),
(133, 937),
(350, 3),
(29, 407),
(493, 33),
(372, 533),
(185, 16),
(416, 147),
(112, 378),
(491, 289),
(125, 539),
(21, 23),
(48, 781),
(362, 456),
(450, 9),
(406, 893),
(6, 39),
(115, 170),
(446, 249),
(397, 83),
(56, 586),
(363, 16),
(430, 268),
(178, 261),
(237, 289),
(31, 995),
(300, 198),
(353, 642),
(248, 30),
(344, 24),
(168, 272),
(306, 721),
(220, 386),
(295, 709),
(17, 372),
(417, 106),
(350, 581),
(61, 367),
(393, 757),
(4, 700),
(397, 897),
(5, 515),
(109, 506),
(133, 689),
(1, 670),
(476, 451),
(68, 708),
(24, 193),
(120, 145),
(29, 327),
(201, 735),
(367, 3),
(292, 244),
(38, 532),
(336, 150),
(416, 122),
(42, 768),
(240, 952),
(460, 7),
(360, 887),
(339, 735),
(92, 33),
(463, 154),
(70, 74),
(20, 766),
(78, 146),
(39, 505),
(73, 726),
(356, 118),
(30, 345),
(93, 763),
(10, 984),
(138, 380),
(499, 301),
(32, 565),
(307, 682),
(77, 763),
(331, 39),
(49, 651),
(133, 639),
(67, 68),
(30, 739),
(3, 506),
(271, 632),
(290, 8),
(494, 4),
(430, 866),
(2, 50),
(48, 273),
(19, 255),
(363, 873),
(197, 235),
(173, 229),
(344, 457),
(365, 876),
(5, 22),
(357, 309),
(205, 696),
(222, 804),
(382, 112),
(87, 461),
(187, 564),
(214, 548),
(21, 787),
(91, 853),
(5, 767),
(313, 832),
(278, 918),
(10, 589),
(22, 114),
(445, 211),
(45, 874),
(496, 473),
(19, 89),
(81, 845),
(388, 653),
(27, 599),
(381, 690),
(316, 5),
(4, 68),
(2, 205),
(5, 143),
(268, 81),
(394, 999),
(252, 82),
(270, 132),
(247, 590),
(104, 25),
(51, 712),
(9, 835),
(79, 89),
(175, 712),
(218, 446),
(1, 730),
(306, 169),
(71, 677),
(363, 443),
(35, 924),
(82, 118),
(62, 553),
(426, 903),
(4, 657),
(171, 939),
(260, 7),
(135, 696),
(206, 274),
(210, 6),
(330, 166),
(439, 646),
(24, 8),
(4, 414),
(77, 120),
(6, 468),
(257, 979),
(215, 495),
(274, 5),
(409, 302),
(492, 428),
(107, 1),
(229, 326),
(317, 122),
(9, 833),
(469, 1),
(28, 420),
(323, 359),
(209, 105),
(117, 191),
(374, 530),
(74, 583),
(125, 276),
(474, 54),
(488, 25),
(173, 156),
(9, 106),
(148, 2),
(187, 890),
(116, 217),
(323, 354),
(36, 369),
(478, 222),
(8, 65),
(283, 276),
(397, 96),
(68, 132),
(160, 551),
(335, 639),
(5, 612),
(347, 7),
(482, 471),
(183, 942),
(212, 443),
(34, 623),
(162, 762),
(86, 145),
(246, 848),
(49, 476),
(140, 6),
(179, 385),
(83, 400),
(154, 833),
(63, 168),
(9, 86),
(165, 682),
(234, 335),
(235, 3),
(451, 691),
(426, 862),
(67, 494),
(119, 255),
(2, 428),
(281, 287),
(402, 756),
(479, 213),
(499, 756),
(84, 1),
(401, 84),
(3, 650),
(318, 547),
(94, 71),
(439, 600),
(120, 11),
(489, 254),
(257, 859),
(9, 245),
(175, 215),
(148, 727),
(3, 105),
(108, 73),
(269, 138),
(300, 4),
(418, 898),
(375, 569),
(90, 589),
(391, 490),
(208, 291),
(260, 401),
(442, 570),
(221, 783),
(93, 29),
(3, 809),
(154, 6),
(5, 970),
(43, 921),
(409, 377),
(336, 542),
(462, 133),
(264, 120),
(5, 840),
(383, 160),
(51, 23),
(454, 279),
(372, 141),
(62, 3),
(113, 460),
(160, 642),
(378, 363),
(256, 240),
(7, 100),
(5, 338),
(54, 872),
(139, 222),
(44, 686),
(305, 842),
(249, 174),
(238, 100),
(434, 174),
(222, 993),
(240, 370),
(332, 5),
(1, 950),
(372, 672),
(243, 117),
(6, 38),
(2, 648),
(353, 3),
(25, 964),
(199, 631),
(422, 669),
(363, 679),
(186, 806),
(316, 553),
(47, 19),
(280, 60),
(195, 8),
(336, 25),
(363, 731),
(9, 432),
(60, 853),
(24, 688),
(160, 68),
(393, 316),
(37, 778),
(336, 506),
(388, 470),
(262, 218),
(409, 7),
(428, 155),
(78, 4),
(8, 991),
(113, 450),
(179, 152),
(197, 205),
(479, 353),
(401, 483),
(481, 268),
(192, 186),
(282, 268),
(180, 109),
(170, 8),
(104, 285),
(48, 963),
(287, 721),
(284, 565),
(191, 172),
(83, 757),
(446, 426),
(336, 207),
(152, 522),
(366, 943),
(197, 453),
(41, 348),
(4, 499),
(202, 206),
(13, 288),
(300, 384),
(445, 169),
(332, 281),
(96, 122),
(312, 661),
(70, 526),
(33, 2),
(290, 759),
(81, 8),
(9, 72),
(181, 501),
(230, 615),
(461, 365),
(62, 855),
(46, 943),
(219, 778),
(423, 656),
(471, 495),
(195, 45),
(438, 758),
(276, 570),
(164, 587),
(154, 261),
(7, 870),
(440, 5),
(69, 758),
(345, 233),
(138, 793),
(405, 1),
(94, 717),
(16, 957),
(28, 81),
(360, 378),
(121, 76),
(2, 752),
(145, 263),
(446, 690),
(239, 893),
(384, 2),
(479, 584),
(9, 149),
(465, 12),
(51, 971),
(404, 65),
(409, 272),
(23, 30),
(306, 776),
(92, 771),
(235, 1),
(382, 315),
(497, 19),
(444, 652),
(5, 872),
(166, 854),
(189, 860),
(161, 483),
(392, 874),
(12, 666),
(23, 158),
(255, 679),
(225, 552),
(257, 967),
(8, 802),
(324, 96),
(32, 238),
(438, 88),
(320, 767),
(327, 915),
(436, 6),
(461, 557),
(461, 134),
(351, 697),
(357, 329),
(20, 50),
(391, 41),
(228, 207),
(264, 5),
(88, 192),
(65, 819),
(165, 21),
(116, 910),
(445, 96),
(47, 204),
(43, 59),
(44, 682),
(160, 977),
(117, 7),
(63, 531),
(15, 161),
(67, 200),
(421, 118),
(1, 880),
(347, 982),
(81, 915),
(159, 381),
(293, 532),
(56, 472),
(241, 208),
(195, 707),
(392, 525),
(324, 986),
(499, 79),
(493, 402),
(476, 674),
(454, 831),
(153, 336),
(139, 989),
(38, 749),
(55, 213),
(198, 227),
(151, 6),
(58, 229),
(193, 508),
(460, 575),
(205, 899),
(133, 908),
(295, 424),
(208, 723),
(44, 69),
(442, 780),
(196, 720),
(61, 536),
(52, 302),
(127, 593),
(6, 890),
(421, 346),
(399, 98),
(411, 941),
(40, 330),
(88, 383),
(309, 34),
(146, 493),
(275, 474),
(124, 9),
(418, 441),
(157, 502),
(349, 588),
(279, 9),
(438, 658),
(247, 981),
(233, 66),
(3, 397),
(409, 371),
(174, 537),
(420, 982),
(151, 179),
(238, 7),
(475, 119),
(289, 3),
(270, 749),
(194, 540),
(94, 102),
(225, 5),
(157, 5),
(72, 844),
(269, 869),
(116, 672),
(213, 401),
(302, 2),
(356, 13),
(327, 612),
(173, 535),
(487, 173),
(418, 237),
(11, 224),
(496, 964),
(226, 885),
(483, 968),
(8, 211),
(5, 630),
(314, 413),
(71, 502),
(8, 478),
(373, 200),
(230, 610),
(1, 794),
(52, 807),
(278, 607),
(362, 310),
(7, 860),
(492, 554),
(179, 38),
(94, 46),
(406, 672),
(244, 3),
(219, 8),
(23, 53),
(92, 701),
(1, 538),
(486, 250),
(8, 311),
(4, 51),
(435, 418),
(46, 535),
(250, 389),
(75, 2),
(320, 84),
(352, 7),
(224, 9),
(116, 662),
(429, 64),
(152, 704),
(148, 212),
(142, 769),
(302, 796),
(462, 803),
(5, 215),
(215, 77),
(24, 124),
(72, 621),
(340, 1),
(451, 988),
(50, 429),
(347, 49),
(16, 410),
(28, 163),
(52, 5),
(70, 384),
(287, 813),
(224, 375),
(246, 3),
(289, 397),
(86, 816),
(12, 660),
(24, 184),
(39, 394),
(48, 250),
(6, 863),
(428, 814),
(24, 945),
(98, 38),
(445, 278),
(482, 840),
(126, 609),
(120, 34),
(455, 634),
(414, 131),
(15, 137),
(287, 472),
(80, 120),
(401, 343),
(96, 524),
(123, 87),
(3, 847),
(462, 546),
(317, 99),
(47, 973),
(451, 700),
(208, 991),
(341, 561),
(249, 262),
(498, 439),
(329, 131),
(189, 150),
(388, 601),
(78, 30),
(376, 924),
(17, 320),
(469, 892),
(445, 846),
(2, 144),
(430, 549),
(395, 3),
(375, 64),
(480, 791),
(9, 3),
(495, 373),
(360, 685),
(125, 829),
(440, 528),
(42, 9),
(22, 831),
(409, 183),
(434, 142),
(193, 1),
(253, 62),
(123, 522),
(120, 691),
(70, 327),
(12, 139),
(479, 79),
(96, 584),
(331, 688),
(448, 508),
(87, 428),
(226, 40),
(394, 13),
(120, 905),
(246, 57),
(18, 746),
(28, 97),
(395, 21),
(299, 49),
(11, 914),
(106, 228),
(93, 10),
(436, 651),
(384, 633),
(9, 115),
(403, 712),
(199, 478),
(490, 93),
(473, 668),
(4, 855),
(472, 95),
(75, 677),
(419, 345),
(353, 20),
(474, 25),
(344, 198),
(466, 676),
(35, 123),
(215, 455),
(196, 488),
(17, 155),
(435, 521),
(115, 406),
(122, 779),
(485, 747),
(190, 746),
(70, 505),
(376, 607),
(219, 504),
(465, 383),
(320, 996),
(225, 579),
(357, 985),
(346, 885),
(432, 339),
(476, 626),
(76, 807),
(5, 419),
(180, 886),
(7, 3),
(159, 802),
(460, 415),
(13, 300),
(160, 725),
(155, 849),
(62, 932),
(32, 946),
(385, 1000),
(439, 816),
(495, 78),
(78, 941),
(7, 605),
(337, 277),
(307, 502),
(7, 44),
(209, 29),
(88, 511),
(493, 856),
(391, 3),
(95, 842),
(202, 743),
(17, 322),
(285, 472),
(388, 41),
(81, 236),
(303, 5),
(220, 764),
(241, 1),
(5, 68),
(8, 275),
(8, 513),
(52, 698),
(175, 884),
(21, 500),
(379, 122),
(75, 335),
(13, 399),
(284, 569),
(258, 92),
(437, 8),
(124, 6),
(8, 909),
(83, 985),
(394, 628),
(238, 11),
(7, 7),
(484, 911),
(38, 964),
(7, 29),
(186, 994),
(172, 8),
(261, 117),
(485, 16),
(33, 232),
(45, 782),
(5, 654),
(164, 60),
(245, 338),
(420, 109),
(348, 637),
(454, 783),
(34, 91),
(443, 664),
(141, 472),
(92, 8),
(289, 913),
(81, 559),
(127, 45),
(88, 58),
(316, 356),
(52, 484),
(246, 89),
(163, 183),
(51, 635),
(133, 1),
(322, 468),
(177, 786),
(149, 5),
(482, 687),
(204, 921),
(67, 545),
(377, 160),
(356, 219),
(482, 636),
(229, 644),
(211, 91),
(414, 270),
(140, 452),
(280, 159),
(153, 411),
(74, 614),
(485, 47),
(5, 176),
(155, 789),
(69, 536),
(455, 699),
(8, 627),
(161, 119),
(247, 824),
(322, 4),
(29, 178),
(361, 799),
(81, 152),
(51, 893),
(256, 55),
(138, 888),
(424, 6),
(471, 6),
(237, 761),
(334, 747),
(408, 705),
(181, 951),
(320, 769),
(464, 22),
(154, 40),
(180, 666),
(135, 189),
(369, 437),
(9, 911),
(103, 823),
(39, 921),
(31, 619),
(494, 295),
(159, 44),
(226, 387),
(281, 683),
(64, 927),
(411, 367),
(153, 920),
(203, 723),
(66, 619),
(28, 324),
(181, 922),
(376, 447),
(418, 719),
(325, 936),
(143, 424),
(306, 485),
(339, 396),
(220, 372),
(418, 50),
(489, 595),
(244, 167),
(174, 288),
(198, 350),
(159, 33),
(23, 31),
(105, 604),
(185, 492),
(352, 881),
(4, 205),
(6, 968),
(253, 835),
(314, 172),
(301, 536),
(131, 75),
(325, 256),
(288, 841),
(326, 58),
(108, 370),
(22, 699),
(292, 704),
(6, 55),
(239, 995),
(309, 74),
(314, 265),
(96, 938),
(112, 460),
(324, 845),
(7, 991),
(7, 747),
(403, 76),
(60, 554),
(302, 957),
(137, 5),
(303, 35),
(97, 704),
(368, 398),
(426, 9),
(476, 8),
(31, 593),
(78, 668),
(22, 556),
(201, 544),
(283, 59),
(86, 239),
(76, 523),
(345, 308),
(3, 208),
(313, 99),
(245, 259),
(263, 84),
(316, 568),
(148, 6),
(488, 6),
(401, 945),
(60, 269),
(436, 464),
(334, 141),
(23, 411),
(283, 364),
(195, 273),
(106, 209),
(472, 565),
(296, 834),
(188, 62),
(357, 61),
(313, 75),
(69, 113),
(474, 832),
(316, 56),
(306, 410),
(121, 332),
(121, 459),
(497, 152),
(34, 440),
(326, 83),
(240, 739),
(383, 110),
(462, 108),
(328, 192),
(138, 665),
(331, 305),
(442, 845),
(466, 7),
(383, 4),
(67, 978),
(244, 152),
(408, 480),
(324, 402),
(30, 561),
(331, 784),
(487, 81),
(7, 265),
(147, 266),
(44, 291),
(78, 559),
(63, 7),
(79, 253),
(236, 954),
(207, 168),
(7, 548),
(279, 104),
(241, 699),
(440, 305),
(485, 113),
(328, 867),
(423, 1),
(254, 926),
(488, 2),
(416, 74),
(236, 745),
(7, 325),
(104, 191),
(13, 675),
(9, 186),
(113, 154),
(266, 588),
(183, 579),
(482, 590),
(432, 570),
(12, 994),
(307, 927),
(18, 354),
(1, 81),
(21, 663),
(391, 76),
(229, 196),
(219, 502),
(177, 654),
(2, 916),
(316, 233),
(35, 915),
(327, 990),
(162, 2),
(154, 580),
(274, 652),
(161, 5),
(4, 602),
(179, 627),
(334, 251),
(179, 76),
(105, 34),
(247, 619),
(16, 676),
(47, 637),
(362, 582),
(158, 486),
(308, 17),
(4, 887),
(116, 564),
(267, 17),
(249, 694),
(274, 351),
(449, 225),
(183, 809),
(494, 138),
(136, 617),
(154, 870),
(376, 318),
(71, 2),
(467, 368),
(217, 497),
(96, 121),
(360, 5),
(1, 102),
(94, 276),
(127, 454),
(438, 448),
(29, 636),
(430, 833),
(134, 164),
(68, 675),
(155, 925),
(49, 371),
(304, 1),
(214, 950),
(446, 375),
(352, 524),
(219, 257),
(301, 452),
(403, 326),
(71, 473),
(254, 32),
(33, 988),
(11, 753),
(480, 580),
(336, 899),
(240, 389),
(2, 329),
(1, 115),
(452, 462),
(423, 136),
(322, 222),
(470, 284),
(33, 888),
(149, 740),
(201, 541),
(43, 435),
(406, 431),
(302, 363),
(485, 34),
(55, 9),
(73, 6),
(443, 959),
(39, 242),
(47, 678),
(419, 34),
(319, 60),
(206, 120),
(76, 71),
(219, 561),
(99, 539),
(218, 719),
(455, 1),
(439, 482),
(386, 76),
(345, 158),
(13, 93),
(486, 327),
(73, 734),
(30, 720),
(424, 49),
(92, 989),
(308, 88),
(89, 338),
(14, 289),
(271, 469),
(479, 811),
(391, 106),
(461, 23),
(341, 195),
(196, 894),
(424, 34),
(267, 595),
(348, 4),
(292, 866),
(308, 1),
(22, 58),
(106, 764),
(274, 74),
(312, 372),
(102, 150),
(260, 57),
(490, 6),
(400, 450),
(147, 409),
(238, 106),
(385, 522),
(156, 876),
(396, 990),
(40, 740),
(376, 53),
(311, 422),
(56, 796),
(437, 320),
(306, 95),
(64, 609),
(76, 962),
(45, 11),
(353, 763),
(82, 836),
(183, 256),
(79, 902),
(15, 946),
(474, 99),
(398, 302),
(380, 8),
(421, 972),
(228, 7),
(7, 447),
(140, 334),
(249, 7),
(276, 411),
(5, 621),
(255, 760),
(317, 475),
(450, 765),
(440, 257),
(351, 740),
(77, 54),
(9, 293),
(183, 945),
(286, 514),
(492, 688),
(317, 61),
(262, 42),
(312, 17),
(162, 476),
(199, 120),
(200, 178),
(65, 591),
(415, 2),
(37, 205),
(3, 865),
(471, 100),
(175, 217),
(94, 351),
(210, 3),
(115, 785),
(206, 79),
(145, 444),
(103, 392),
(172, 898),
(143, 439),
(79, 53),
(299, 462),
(216, 341),
(3, 89),
(125, 9),
(6, 15),
(8, 443),
(381, 840),
(435, 435),
(35, 584),
(447, 601),
(170, 794),
(301, 27),
(420, 514),
(211, 304),
(400, 166),
(406, 305),
(26, 971),
(193, 9),
(222, 360),
(163, 2),
(145, 269),
(94, 872),
(461, 275),
(435, 743),
(3, 367),
(20, 16),
(434, 693),
(283, 850),
(344, 970),
(153, 504),
(456, 830),
(125, 975),
(28, 676),
(304, 47),
(53, 904),
(172, 756),
(259, 388),
(278, 530),
(96, 4),
(329, 76),
(107, 459),
(70, 607),
(425, 615),
(370, 927),
(357, 148),
(54, 652),
(344, 666),
(342, 289),
(315, 569),
(344, 353),
(17, 633),
(214, 686),
(377, 597),
(27, 348),
(128, 743),
(252, 345),
(63, 214),
(76, 909),
(1, 582),
(168, 451),
(485, 144),
(466, 611),
(53, 750),
(272, 544),
(150, 220),
(454, 216),
(287, 849),
(13, 160),
(22, 75),
(378, 17),
(362, 465),
(54, 60),
(391, 530),
(446, 62),
(330, 54),
(53, 293),
(489, 888),
(298, 3),
(23, 833),
(157, 705),
(162, 914),
(96, 91),
(343, 818),
(490, 64),
(368, 3),
(350, 249),
(221, 923),
(205, 912),
(438, 916),
(86, 920),
(281, 6),
(303, 703),
(5, 377),
(437, 78),
(295, 210),
(500, 751),
(166, 45),
(88, 945),
(154, 490),
(93, 119),
(282, 256),
(88, 8),
(68, 2),
(3, 46),
(108, 716),
(145, 243),
(153, 888),
(3, 272),
(418, 340),
(410, 42),
(391, 971),
(76, 40),
(49, 656),
(154, 752),
(314, 610),
(11, 919),
(170, 198),
(31, 1),
(10, 576),
(201, 824),
(146, 8),
(96, 943),
(56, 660),
(301, 880),
(414, 967),
(94, 627),
(6, 311),
(80, 30),
(429, 339),
(107, 308),
(68, 150),
(200, 1),
(214, 953),
(115, 833),
(19, 375),
(175, 245),
(1, 39),
(155, 75),
(129, 842),
(204, 845),
(430, 18),
(159, 559),
(161, 990),
(87, 70),
(22, 354),
(444, 335),
(214, 864),
(431, 154),
(456, 838),
(276, 192),
(300, 586),
(21, 669),
(77, 864),
(491, 772),
(236, 5),
(170, 94),
(231, 227),
(208, 776),
(15, 29),
(99, 979),
(449, 607),
(224, 209),
(480, 401),
(224, 884),
(188, 519),
(300, 454),
(295, 959),
(289, 441),
(76, 775),
(47, 313),
(133, 945),
(204, 165),
(439, 991),
(478, 68),
(114, 73),
(2, 358),
(244, 761),
(146, 97),
(220, 315),
(330, 421),
(290, 968),
(6, 514),
(285, 28),
(131, 417),
(330, 617),
(245, 479),
(43, 903),
(322, 756),
(321, 10),
(234, 6),
(49, 172),
(491, 90),
(72, 348),
(58, 356),
(236, 92),
(206, 955),
(58, 27),
(419, 435),
(151, 906),
(447, 424),
(412, 1),
(36, 411),
(99, 638),
(271, 725),
(424, 485),
(236, 286),
(476, 9),
(348, 914),
(289, 344),
(300, 511),
(407, 278),
(361, 637),
(7, 946),
(28, 487),
(451, 280),
(294, 87),
(383, 168),
(128, 589),
(448, 753),
(388, 359),
(328, 122),
(44, 748),
(302, 47),
(403, 426),
(9, 197),
(391, 11),
(4, 272),
(4, 4),
(270, 219),
(2, 65),
(175, 569),
(35, 517),
(226, 935),
(284, 500),
(220, 422),
(441, 609),
(425, 806),
(15, 582),
(488, 136),
(37, 134),
(152, 447),
(225, 872),
(145, 6),
(465, 22),
(8, 980),
(368, 23),
(191, 139),
(16, 741),
(393, 8),
(369, 4),
(183, 118),
(78, 939),
(185, 6),
(282, 858),
(8, 643),
(295, 271),
(273, 450),
(54, 698),
(405, 611),
(7, 105),
(469, 913),
(93, 181),
(356, 690),
(129, 180),
(56, 5),
(393, 45),
(237, 476),
(262, 425),
(111, 47),
(342, 9),
(35, 675),
(450, 893),
(64, 13),
(161, 567),
(476, 93),
(477, 87),
(100, 528),
(3, 541),
(4, 436),
(421, 416),
(382, 210),
(321, 704),
(231, 867),
(227, 250),
(295, 160),
(4, 546),
(393, 182),
(2, 643),
(64, 758),
(32, 121),
(21, 388),
(77, 225),
(174, 700),
(44, 11),
(377, 289),
(150, 30),
(416, 523),
(378, 642),
(142, 66),
(160, 374),
(254, 348),
(445, 64),
(119, 954),
(199, 283),
(201, 57),
(415, 876),
(137, 204),
(139, 3),
(282, 816),
(295, 850),
(378, 164),
(79, 124),
(461, 159),
(344, 952),
(400, 156),
(5, 731),
(84, 609),
(160, 28),
(190, 248),
(432, 597),
(26, 525),
(302, 611),
(382, 342),
(258, 480),
(55, 529),
(20, 4),
(3, 221),
(421, 791),
(40, 33),
(489, 93),
(194, 631),
(39, 614),
(86, 446),
(18, 817),
(141, 2),
(460, 939),
(310, 214),
(24, 862),
(31, 177),
(58, 6),
(445, 494),
(120, 3),
(302, 958),
(148, 516),
(272, 216),
(42, 261),
(247, 804),
(9, 534),
(285, 367),
(323, 136),
(472, 587),
(317, 553),
(149, 900),
(282, 9),
(444, 252),
(462, 189),
(442, 629),
(212, 30),
(196, 266),
(61, 371),
(488, 787),
(442, 583),
(72, 120),
(2, 763),
(340, 98),
(86, 197),
(213, 2),
(237, 337),
(209, 778),
(399, 873),
(359, 761),
(7, 11),
(409, 236),
(172, 9),
(66, 258),
(8, 334),
(3, 288),
(392, 733),
(235, 309),
(351, 939),
(309, 760),
(473, 287),
(134, 927),
(385, 30),
(468, 725),
(5, 245),
(420, 973),
(237, 302),
(126, 664),
(54, 818),
(108, 628),
(344, 431),
(436, 27),
(168, 164),
(355, 2),
(309, 757),
(315, 106),
(72, 158),
(250, 266),
(128, 507),
(97, 78),
(342, 32),
(175, 29),
(13, 677),
(150, 41),
(24, 567),
(439, 54),
(107, 931),
(142, 573),
(115, 14),
(28, 887),
(177, 48),
(324, 452),
(322, 865),
(202, 449),
(430, 262),
(272, 455),
(341, 418),
(386, 890),
(50, 574),
(2, 740),
(304, 104),
(276, 477),
(271, 712),
(226, 839),
(489, 967),
(220, 948),
(316, 31),
(69, 378),
(235, 277),
(370, 435),
(376, 392),
(221, 168),
(221, 715),
(168, 954),
(158, 411),
(162, 35),
(74, 874),
(116, 43),
(61, 214),
(438, 31),
(200, 73),
(243, 956),
(491, 495),
(86, 32),
(53, 669),
(466, 527),
(13, 429),
(89, 470),
(346, 484),
(305, 808),
(414, 4),
(219, 1),
(5, 585),
(434, 854),
(84, 8),
(451, 206),
(289, 127),
(222, 233);

INSERT INTO especie_persona(id_especie, id_persona) VALUES
(19, 667),
(2, 73),
(24, 181),
(38, 154),
(20, 398),
(46, 800),
(39, 745),
(6, 668),
(39, 746),
(33, 479),
(9, 262),
(20, 182),
(18, 642),
(20, 263),
(3, 183),
(39, 669),
(2, 264),
(29, 562),
(49, 643),
(29, 747),
(8, 399),
(1, 480),
(42, 670),
(8, 74),
(12, 400),
(31, 184),
(4, 265),
(2, 481),
(5, 563),
(45, 644),
(9, 185),
(36, 748),
(21, 155),
(27, 564),
(29, 484),
(5, 401),
(8, 565),
(30, 266),
(35, 186),
(45, 75),
(44, 671),
(14, 749),
(16, 485),
(2, 566),
(27, 156),
(8, 482),
(1, 672),
(2, 750),
(10, 673),
(26, 486),
(7, 751),
(44, 402),
(46, 483),
(34, 76),
(26, 267),
(35, 567),
(34, 187),
(16, 157),
(13, 674),
(39, 487),
(3, 403),
(37, 77),
(34, 752),
(28, 323),
(34, 675),
(22, 158),
(14, 78),
(5, 159),
(3, 568),
(36, 753),
(7, 268),
(35, 79),
(13, 188),
(1, 404),
(19, 676),
(24, 324),
(36, 754),
(26, 269),
(35, 677),
(20, 755),
(48, 189),
(46, 270),
(49, 488),
(36, 160),
(2, 569),
(32, 489),
(8, 190),
(6, 678),
(30, 405),
(15, 80),
(3, 271),
(20, 570),
(2, 191),
(20, 490),
(4, 325),
(37, 756),
(20, 679),
(18, 161),
(24, 571),
(49, 81),
(24, 272),
(22, 757),
(18, 192),
(47, 1),
(46, 406),
(10, 680),
(29, 273),
(46, 758),
(48, 193),
(33, 491),
(43, 572),
(43, 681),
(1, 82),
(8, 759),
(2, 326),
(2, 274),
(27, 407),
(36, 682),
(6, 760),
(7, 194),
(29, 492),
(34, 275),
(11, 573),
(40, 327),
(16, 408),
(31, 328),
(47, 493),
(12, 409),
(38, 2),
(31, 83),
(48, 574),
(47, 683),
(5, 329),
(36, 761),
(24, 494),
(46, 195),
(19, 684),
(50, 410),
(16, 575),
(23, 762),
(23, 330),
(33, 411),
(26, 331),
(14, 495),
(24, 276),
(33, 196),
(34, 412),
(30, 332),
(29, 277),
(8, 197),
(42, 278),
(10, 3),
(29, 198),
(40, 413),
(34, 279),
(48, 685),
(34, 199),
(32, 763),
(44, 333),
(9, 686),
(37, 280),
(36, 576),
(25, 764),
(39, 200),
(45, 84),
(26, 687),
(44, 414),
(49, 281),
(9, 4),
(3, 85),
(23, 334),
(41, 765),
(29, 201),
(1, 688),
(46, 496),
(22, 282),
(40, 577),
(12, 766),
(10, 5),
(37, 202),
(30, 86),
(7, 283),
(43, 203),
(2, 689),
(6, 497),
(38, 578),
(40, 498),
(2, 6),
(2, 415),
(11, 767),
(17, 690),
(11, 768),
(31, 87),
(9, 691),
(33, 579),
(27, 769),
(39, 499),
(36, 284),
(20, 580),
(28, 204),
(5, 500),
(42, 285),
(34, 205),
(3, 7),
(45, 692),
(29, 286),
(2, 581),
(3, 206),
(26, 501),
(42, 88),
(35, 8),
(30, 287),
(27, 582),
(39, 89),
(48, 502),
(45, 770),
(47, 207),
(17, 693),
(15, 583),
(28, 288),
(25, 208),
(20, 289),
(49, 503),
(1, 209),
(34, 9),
(45, 335),
(23, 771),
(48, 416),
(8, 290),
(12, 694),
(5, 584),
(8, 336),
(31, 210),
(39, 504),
(8, 417),
(29, 585),
(6, 90),
(6, 10),
(10, 91),
(14, 291),
(32, 772),
(14, 211),
(27, 292),
(4, 337),
(45, 505),
(13, 418),
(44, 212),
(19, 695),
(22, 11),
(49, 586),
(33, 338),
(10, 506),
(3, 587),
(28, 293),
(5, 92),
(46, 419),
(37, 339),
(38, 773),
(6, 12),
(32, 213),
(46, 420),
(41, 294),
(25, 93),
(33, 507),
(4, 340),
(42, 588),
(12, 13),
(30, 696),
(45, 421),
(26, 774),
(26, 697),
(42, 214),
(50, 775),
(8, 295),
(2, 341),
(5, 698),
(17, 94),
(33, 215),
(12, 508),
(16, 589),
(28, 14),
(26, 95),
(26, 296),
(49, 422),
(44, 342),
(50, 776),
(32, 699),
(43, 15),
(5, 509),
(7, 96),
(35, 216),
(48, 297),
(43, 16),
(8, 590),
(48, 777),
(9, 423),
(22, 217),
(1, 510),
(50, 97),
(3, 700),
(23, 343),
(19, 298),
(12, 218),
(50, 17),
(9, 778),
(4, 98),
(46, 701),
(47, 299),
(24, 591),
(45, 18),
(16, 424),
(16, 219),
(43, 99),
(3, 300),
(25, 220),
(46, 344),
(10, 779),
(27, 425),
(45, 19),
(3, 345),
(3, 702),
(2, 780),
(50, 301),
(11, 426),
(26, 511),
(25, 592),
(29, 100),
(32, 221),
(27, 346),
(13, 703),
(41, 512),
(48, 302),
(29, 222),
(23, 781),
(8, 20),
(37, 704),
(10, 593),
(19, 303),
(7, 427),
(6, 223),
(18, 101),
(17, 347),
(36, 304),
(3, 513),
(27, 594),
(19, 782),
(9, 21),
(35, 514),
(13, 428),
(1, 348),
(33, 595),
(41, 515),
(29, 429),
(5, 349),
(7, 102),
(19, 430),
(48, 22),
(40, 705),
(6, 224),
(3, 305),
(37, 783),
(43, 596),
(36, 706),
(7, 784),
(49, 225),
(26, 103),
(11, 23),
(22, 306),
(4, 226),
(39, 350),
(8, 516),
(2, 597),
(16, 104),
(10, 707),
(32, 431),
(1, 307),
(1, 517),
(42, 598),
(6, 518),
(36, 599),
(39, 351),
(25, 432),
(4, 519),
(1, 785),
(39, 227),
(47, 708),
(37, 786),
(34, 600),
(27, 520),
(31, 601),
(32, 521),
(24, 709),
(12, 787),
(1, 308),
(41, 352),
(28, 433),
(11, 353),
(39, 434),
(38, 228),
(9, 602),
(35, 710),
(44, 788),
(27, 354),
(24, 24),
(9, 522),
(15, 105),
(34, 603),
(41, 523),
(2, 25),
(36, 604),
(34, 711),
(11, 435),
(8, 106),
(18, 355),
(43, 789),
(27, 436),
(33, 712),
(26, 790),
(36, 524),
(33, 356),
(43, 26),
(21, 309),
(6, 437),
(19, 605),
(26, 525),
(10, 713),
(9, 606),
(31, 526),
(2, 229),
(12, 791),
(8, 714),
(5, 107),
(37, 310),
(11, 27),
(12, 792),
(29, 607),
(6, 108),
(4, 527),
(29, 230),
(49, 28),
(9, 311),
(41, 231),
(5, 608),
(26, 109),
(41, 528),
(9, 312),
(27, 609),
(34, 232),
(7, 357),
(42, 715),
(10, 529),
(39, 610),
(5, 793),
(45, 716),
(19, 438),
(45, 358),
(33, 313),
(27, 794),
(5, 439),
(1, 717),
(9, 359),
(18, 795),
(11, 233),
(38, 29),
(5, 718),
(39, 530),
(11, 110),
(3, 30),
(8, 611),
(19, 111),
(39, 440),
(26, 31),
(28, 531),
(26, 360),
(22, 314),
(36, 612),
(7, 532),
(37, 441),
(3, 796),
(16, 234),
(7, 112),
(1, 315),
(9, 235),
(49, 361),
(18, 316),
(50, 236),
(20, 317),
(8, 442),
(48, 362),
(16, 237),
(38, 318),
(27, 32),
(30, 238),
(4, 319),
(37, 613),
(8, 239),
(13, 113),
(7, 443),
(6, 320),
(38, 719),
(4, 240),
(42, 533),
(2, 614),
(28, 321),
(17, 363),
(40, 444),
(3, 797),
(30, 241),
(5, 364),
(38, 720),
(47, 798),
(34, 721),
(41, 799),
(50, 33),
(50, 722),
(44, 114),
(16, 534),
(26, 645),
(37, 615),
(44, 445),
(30, 365),
(9, 446),
(32, 535),
(12, 322),
(31, 616),
(10, 242),
(40, 723),
(32, 366),
(2, 646),
(23, 34),
(1, 536),
(45, 115),
(47, 35),
(50, 724),
(44, 647),
(9, 447),
(47, 367),
(5, 116),
(3, 725),
(10, 648),
(6, 162),
(22, 36),
(4, 726),
(6, 617),
(39, 243),
(4, 448),
(9, 163),
(20, 117),
(49, 368),
(47, 449),
(3, 537),
(12, 244),
(34, 649),
(16, 618),
(33, 369),
(16, 727),
(8, 37),
(42, 164),
(41, 450),
(6, 118),
(49, 538),
(49, 370),
(47, 451),
(38, 371),
(41, 245),
(34, 650),
(10, 619),
(3, 728),
(41, 165),
(24, 246),
(16, 539),
(11, 452),
(46, 651),
(31, 729),
(7, 166),
(8, 247),
(27, 372),
(27, 652),
(12, 38),
(2, 167),
(20, 119),
(8, 620),
(7, 730),
(48, 248),
(36, 168),
(41, 249),
(41, 169),
(30, 453),
(28, 373),
(6, 653),
(12, 454),
(15, 39),
(26, 540),
(6, 731),
(23, 120),
(27, 654),
(19, 374),
(28, 455),
(15, 250),
(39, 170),
(1, 732),
(2, 251),
(6, 655),
(9, 40),
(5, 733),
(1, 121),
(32, 375),
(38, 656),
(35, 171),
(33, 41),
(49, 456),
(20, 122),
(4, 252),
(37, 172),
(29, 42),
(30, 123),
(34, 376),
(2, 253),
(12, 43),
(43, 734),
(16, 621),
(11, 173),
(13, 457),
(8, 254),
(16, 541),
(27, 377),
(39, 657),
(24, 735),
(20, 622),
(43, 458),
(17, 658),
(40, 124),
(49, 378),
(50, 542),
(39, 459),
(15, 623),
(17, 736),
(13, 659),
(23, 174),
(4, 255),
(36, 737),
(46, 175),
(37, 44),
(45, 256),
(4, 379),
(1, 460),
(32, 660),
(36, 176),
(16, 543),
(9, 125),
(30, 257),
(49, 177),
(42, 258),
(8, 380),
(44, 624),
(3, 461),
(13, 544),
(39, 381),
(43, 178),
(29, 462),
(26, 45),
(3, 382),
(18, 126),
(12, 738),
(43, 259),
(8, 463),
(12, 383),
(5, 625),
(2, 545),
(9, 179),
(19, 260),
(43, 626),
(9, 661),
(24, 739),
(33, 46),
(8, 464),
(29, 127),
(4, 180),
(24, 662),
(21, 261),
(31, 546),
(36, 384),
(22, 47),
(37, 627),
(44, 128),
(15, 465),
(32, 740),
(30, 48),
(33, 129),
(50, 663),
(15, 49),
(29, 547),
(7, 628),
(4, 130),
(14, 385),
(38, 466),
(11, 50),
(44, 741),
(47, 131),
(8, 51),
(8, 132),
(25, 548),
(14, 629),
(6, 664),
(18, 549),
(10, 386),
(12, 467),
(38, 387),
(26, 52),
(11, 468),
(46, 630),
(46, 550),
(16, 133),
(44, 742),
(20, 631),
(9, 388),
(32, 469),
(8, 551),
(42, 665),
(2, 632),
(43, 389),
(28, 552),
(3, 743),
(4, 53),
(3, 666),
(7, 134),
(6, 54),
(9, 744),
(9, 135),
(50, 55),
(44, 136),
(15, 633),
(10, 56),
(40, 470),
(49, 553),
(3, 634),
(3, 554),
(25, 390),
(7, 137),
(4, 471),
(48, 635),
(16, 555),
(28, 391),
(40, 472),
(25, 636),
(11, 392),
(47, 556),
(1, 473),
(26, 637),
(12, 557),
(10, 393),
(12, 57),
(37, 474),
(38, 638),
(24, 394),
(5, 558),
(20, 138),
(14, 639),
(33, 475),
(9, 58),
(19, 395),
(20, 476),
(16, 139),
(20, 396),
(50, 59),
(26, 477),
(25, 559),
(3, 397),
(35, 640),
(3, 560),
(1, 478),
(27, 140),
(1, 641),
(41, 60),
(28, 561),
(2, 141),
(19, 61),
(15, 142),
(15, 62),
(7, 143),
(48, 63),
(43, 144),
(31, 64),
(3, 145),
(7, 65),
(35, 146),
(23, 66),
(20, 147),
(25, 67),
(38, 148),
(12, 68),
(3, 149),
(1, 69),
(13, 150),
(3, 70),
(32, 151),
(42, 71),
(38, 152),
(10, 72),
(27, 153);

INSERT INTO estrella(id, tipo, temperatura, luminosidad, id_cuerpo_celeste, id_galaxia) VALUES
(1, 'Gigante luminosa violeta', 3751881, 1546344, 87, 6),
(2, 'Gigante luminosa azul', 1697417, 5297978, 259, 6),
(3, 'Gigante blanca', 2571183, 16035, 37, 14),
(4, NULL, NULL, 5496747, 190, 22),
(5, 'Gigante violeta', 2906477, 4222723, 140, 2),
(6, 'Sub-enana blanca', 2168913, 9237299, 468, 13),
(7, 'Supergigante violeta', 9589381, 3639172, 393, 14),
(8, 'Supergigante Luminosa roja', 1445346, 9676143, 191, 12),
(9, 'Enana negra', 3656988, 4451122, 343, 18),
(10, 'Gigante azul', 4944566, 3360349, 421, 5),
(11, 'Gigante violeta', 106153, 9897141, 394, 15),
(12, 'Enana amarilla', 6149022, 7675081, 469, 6),
(13, 'Sub-gigante amarilla', 70828, 7303702, 344, 7),
(14, 'Supergigante violeta', 3495630, 5660762, 500, 4),
(15, 'Sub-gigante roja', 8872134, 7696382, 209, 9),
(16, 'Sub-gigante negra', 89684, 7869068, 141, 4),
(17, 'Supergigante violeta', 2947996, 6670758, 260, 15),
(18, 'Supergigante Luminosa violeta', 7149264, 1509942, 88, 20),
(19, 'Supergigante Luminosa blanca', 50213, 1055203, 210, 2),
(20, 'Gigante luminosa roja', NULL, 8231469, 422, 8),
(21, 'Hipergigante azul', 2497299, NULL, 395, 11),
(22, 'Enana blanca', 3433947, 7156017, 470, 4),
(23, 'Gigante luminosa roja', 44021, 4534508, 423, 20),
(24, 'Gigante luminosa blanca', 662948, 1996842, 345, 14),
(25, 'Enana azul', 9249231, NULL, 38, 9),
(26, 'Supergigante Luminosa negra', 2482499, 8898255, 396, 18),
(27, 'Hipergigante azul', 7974456, 9943784, 471, 8),
(28, 'Enana azul', 2787642, 6753057, 424, 21),
(29, 'Gigante amarilla', 2780512, 9553539, 89, 18),
(30, 'Gigante luminosa blanca', 7253886, 593779, 192, 16),
(31, 'Gigante luminosa blanca', 8890572, 9233066, 39, 5),
(32, 'Sub-enana azul', 2706224, 443667, 90, 17),
(33, 'Gigante blanca', 2197208, 7498804, 472, 22),
(34, 'Sub-enana negra', 7997964, 7496107, 346, 8),
(35, 'Gigante luminosa roja', 9197861, 6228273, 261, 18),
(36, 'Supergigante Luminosa blanca', 6438564, 945575, 40, 19),
(37, 'Enana amarilla', 7965822, 3181620, 142, 9),
(38, 'Hipergigante amarilla', 5841547, NULL, 91, 23),
(39, 'Supergigante Luminosa roja', 3108739, 589790, 425, 22),
(40, 'Gigante luminosa violeta', 4642171, 9034316, 193, 7),
(41, NULL, NULL, 9046898, 397, 18),
(42, 'Sub-enana roja', 5584487, 7174861, 347, 6),
(43, 'Gigante luminosa violeta', 8866546, 6192162, 398, 11),
(44, 'Hipergigante amarilla', 9682047, 3212336, 143, 5),
(45, 'Gigante negra', 2665552, 6501243, 41, 14),
(46, 'Supergigante Luminosa negra', 4260992, NULL, 92, 7),
(47, 'Supergigante Luminosa negra', 3297530, 6530381, 348, 2),
(48, 'Sub-enana negra', NULL, 5211496, 399, 25),
(49, 'Gigante azul', 8295147, NULL, 194, 1),
(50, 'Hipergigante violeta', 9537103, 2703250, 473, 20),
(51, 'Gigante luminosa negra', 797010, 5856020, 211, 5),
(52, 'Supergigante Luminosa azul', 4450695, 3714435, 144, 1),
(53, 'Sub-enana azul', 9261119, 5659295, 426, 6),
(54, 'Hipergigante roja', 1750655, 4120179, 349, 6),
(55, NULL, NULL, 2186999, 474, 17),
(56, 'Gigante luminosa azul', 7115931, 7092152, 427, 7),
(57, 'Gigante negra', 6301626, 5577259, 400, 14),
(58, 'Gigante roja', 1988378, 876160, 195, 25),
(59, 'Sub-enana blanca', 7973754, 8636504, 145, 16),
(60, 'Gigante amarilla', 2858701, 4977123, 196, 16),
(61, 'Gigante luminosa roja', 835703, 909893, 42, 23),
(62, 'Supergigante roja', 4388761, 4139561, 93, 22),
(63, 'Gigante amarilla', 5457401, 1868586, 43, 10),
(64, 'Sub-gigante negra', 8364148, 2999993, 350, 9),
(65, 'Sub-gigante azul', 982284, 604776, 401, 7),
(66, 'Sub-gigante violeta', 4835103, 7368608, 262, 19),
(67, 'Supergigante negra', 3573268, 2776012, 351, 16),
(68, 'Supergigante Luminosa violeta', NULL, 8668767, 146, 6),
(69, 'Enana azul', 9190112, 4676966, 402, 12),
(70, 'Hipergigante roja', 3378486, 6029135, 475, 7),
(71, 'Hipergigante azul', 7794203, 3230982, 352, 18),
(72, 'Sub-enana amarilla', 3312797, 1667678, 428, 19),
(73, 'Supergigante blanca', 8630164, 219900, 476, 18),
(74, 'Hipergigante blanca', 3517708, 8286541, 403, 20),
(75, 'Hipergigante azul', 6240478, 7153575, 212, 19),
(76, 'Gigante luminosa negra', 9937715, NULL, 353, 8),
(77, 'Sub-gigante blanca', 6121037, 7975746, 404, 20),
(78, 'Sub-enana violeta', 7087685, 429945, 94, 11),
(79, 'Supergigante Luminosa amarilla', 2041986, 5750763, 263, 2),
(80, 'Gigante luminosa roja', 9658963, 1115188, 197, 14),
(81, 'Hipergigante negra', 4748590, 8905710, 147, 5),
(82, 'Supergigante roja', 8580365, 6706260, 429, 10),
(83, 'Supergigante blanca', 4824069, 8441189, 198, 3),
(84, 'Supergigante Luminosa violeta', 4361790, 2627081, 354, 16),
(85, 'Enana roja', 9063048, 9389549, 477, 20),
(86, 'Enana roja', 3692499, 5836181, 430, 3),
(87, 'Supergigante Luminosa roja', 5215816, NULL, 304, 17),
(88, 'Hipergigante blanca', 5603032, 4059152, 478, 10),
(89, 'Supergigante violeta', 6384415, 1439135, 355, 24),
(90, 'Sub-gigante negra', 2112651, 355619, 213, 21),
(91, 'Supergigante Luminosa azul', 8538427, 729636, 431, 13),
(92, 'Supergigante Luminosa roja', 4642073, 8840994, 305, 9),
(93, 'Gigante blanca', 8769733, 2119824, 356, 10),
(94, 'Hipergigante amarilla', 3491868, 3568040, 148, 19),
(95, 'Supergigante negra', 6670487, 7853127, 44, 25),
(96, 'Gigante luminosa amarilla', 2682134, 9733206, 264, 17),
(97, 'Supergigante Luminosa violeta', 7039686, 5856951, 306, 9),
(98, 'Hipergigante amarilla', 2614000, NULL, 199, 8),
(99, 'Sub-enana roja', 7971447, 173298, 357, 18),
(100, 'Supergigante Luminosa azul', 6715682, 6377111, 307, 14),
(101, 'Enana violeta', 6190778, 9395003, 358, 8),
(102, 'Sub-enana violeta', 4005799, NULL, 214, 1),
(103, 'Supergigante Luminosa negra', 2570125, 7111609, 265, 6),
(104, 'Sub-gigante blanca', 4564924, 8929406, 149, 6),
(105, 'Sub-gigante azul', 1203411, 3116092, 200, 18),
(106, 'Supergigante roja', 6630023, 7324051, 95, 2),
(107, 'Gigante luminosa amarilla', 4993979, 3970480, 150, 17),
(108, 'Sub-enana violeta', 3174872, 8857590, 308, 17),
(109, 'Sub-enana violeta', 7064562, NULL, 359, 21),
(110, 'Enana azul', 631560, NULL, 45, 22),
(111, 'Sub-gigante amarilla', NULL, 8606486, 309, 23),
(112, 'Gigante luminosa roja', 482865, 1542722, 215, 24),
(113, 'Enana amarilla', 403694, 5221591, 201, 15),
(114, 'Gigante luminosa blanca', 2007187, NULL, 96, 20),
(115, 'Sub-enana violeta', 6425184, 7465917, 46, 8),
(116, 'Supergigante Luminosa blanca', 8113790, 3662618, 151, 12),
(117, 'Gigante luminosa violeta', 8448158, 4751761, 266, 18),
(118, 'Sub-gigante amarilla', 8088153, 3341305, 216, 1),
(119, 'Gigante negra', 5203145, 6309316, 360, 24),
(120, 'Enana blanca', 9108310, 8759048, 267, 3),
(121, 'Gigante negra', NULL, 3616006, 202, 9),
(122, 'Gigante luminosa negra', 555257, 713301, 152, 20),
(123, 'Enana amarilla', 289521, 3415398, 479, 4),
(124, 'Sub-enana negra', 6859683, 439093, 310, 18),
(125, 'Supergigante violeta', 7941494, NULL, 217, 14),
(126, 'Gigante luminosa amarilla', 7393362, 2597470, 97, 11),
(127, 'Enana violeta', 192834, 7168109, 47, 21),
(128, 'Supergigante Luminosa blanca', 9391366, 4263796, 432, 24),
(129, 'Sub-gigante negra', 5441208, 8863047, 480, 19),
(130, 'Enana blanca', 7592950, 8200700, 433, 2),
(131, 'Gigante luminosa violeta', 3675219, 8662809, 361, 11),
(132, 'Gigante luminosa azul', 5382062, 8125596, 311, 18),
(133, 'Supergigante blanca', 881628, 3780018, 362, 2),
(134, 'Hipergigante roja', 8034074, 2831946, 481, 22),
(135, 'Enana roja', 2522755, 2362817, 268, 14),
(136, 'Sub-gigante blanca', 312161, 4892541, 102, 8),
(137, 'Enana roja', 6506155, 4980956, 312, 7),
(138, 'Gigante luminosa azul', 9844201, 4851275, 363, 3),
(139, 'Supergigante blanca', 3269202, 6451754, 218, 9),
(140, 'Supergigante blanca', 3169701, 5764960, 269, 7),
(141, 'Gigante luminosa violeta', 7121961, 5277430, 313, 9),
(142, 'Sub-enana roja', 3916322, 3314377, 153, 25),
(143, 'Sub-gigante azul', 6381482, 8248522, 434, 7),
(144, 'Sub-enana blanca', 7654217, 7175203, 98, 7),
(145, 'Enana amarilla', 9944716, 9772485, 364, 16),
(146, 'Gigante violeta', 9596136, 4987994, 219, 15),
(147, 'Gigante violeta', 7641611, 8582504, 482, 21),
(148, 'Supergigante blanca', 8838566, 4345269, 270, 24),
(149, 'Supergigante amarilla', 6909400, 5255606, 103, 18),
(150, 'Gigante luminosa roja', 7155105, 2461332, 48, 18),
(151, 'Sub-enana violeta', 1159578, 3891726, 314, 20),
(152, 'Enana roja', 3097958, 6844143, 99, 11),
(153, NULL, NULL, 9760594, 365, 21),
(154, 'Enana blanca', NULL, 947696, 435, 4),
(155, 'Enana negra', 2001322, NULL, 220, 6),
(156, 'Sub-gigante azul', 7479831, 3792858, 49, 21),
(157, 'Enana azul', 1644608, 3719836, 483, 25),
(158, 'Sub-gigante azul', 9475203, 8899381, 100, 16),
(159, 'Hipergigante azul', 6828068, 1324172, 315, 6),
(160, 'Sub-gigante azul', 1496756, 1485866, 366, 19),
(161, 'Gigante violeta', NULL, 9713898, 436, 8),
(162, 'Enana violeta', 690355, 6224270, 484, 19),
(163, 'Sub-gigante azul', 9385130, 7552298, 271, 23),
(164, 'Enana violeta', NULL, 1848224, 221, 16),
(165, 'Sub-gigante amarilla', 231542, 5108556, 316, 22),
(166, 'Enana violeta', NULL, 1753003, 154, 21),
(167, 'Gigante roja', 2034219, 957689, 272, 3),
(168, 'Enana violeta', 7160763, 2016023, 222, 18),
(169, 'Sub-enana negra', 6225994, 2245964, 104, 25),
(170, 'Gigante azul', 740488, 3631150, 273, 6),
(171, 'Gigante violeta', 6304353, 7515087, 223, 6),
(172, 'Gigante negra', 1540475, 3166529, 274, 12),
(173, 'Sub-enana azul', 5013849, 7954763, 367, 7),
(174, 'Supergigante Luminosa roja', 6851007, 6414843, 155, 22),
(175, 'Enana violeta', 8240090, 3092117, 224, 5),
(176, 'Sub-enana roja', 8855390, 7928957, 275, 15),
(177, 'Supergigante Luminosa azul', 8939061, 5473735, 50, 4),
(178, 'Supergigante blanca', 7973279, 778020, 105, 17),
(179, 'Supergigante violeta', 6104751, 6025335, 317, 18),
(180, 'Enana violeta', 117148, 8422225, 156, 12),
(181, 'Gigante blanca', 5511763, 3578113, 106, 19),
(182, 'Sub-gigante blanca', 3336597, 2801630, 101, 16),
(183, 'Sub-gigante roja', 1687559, 8428075, 225, 14),
(184, 'Supergigante Luminosa roja', 4340117, NULL, 437, 22),
(185, 'Sub-gigante violeta', 1805552, 7605054, 276, 8),
(186, 'Enana amarilla', 4651204, 5111701, 157, 1),
(187, 'Gigante luminosa amarilla', 2964184, 5182142, 51, 15),
(188, 'Gigante luminosa azul', 6392396, 2073519, 226, 22),
(189, 'Enana blanca', 6266240, 6780252, 485, 23),
(190, 'Sub-enana violeta', 7721505, 926788, 438, 3),
(191, 'Supergigante Luminosa roja', 6714434, 5670251, 368, 2),
(192, 'Gigante luminosa amarilla', 2767727, 5464806, 277, 17),
(193, 'Enana roja', 2854023, 675426, 227, 16),
(194, 'Sub-enana violeta', NULL, 5387209, 1, 21),
(195, 'Sub-enana roja', NULL, 4144386, 486, 3),
(196, 'Enana violeta', NULL, NULL, 107, 23),
(197, 'Hipergigante azul', NULL, NULL, 52, 4),
(198, 'Enana negra', NULL, NULL, 278, 22),
(199, 'Gigante luminosa violeta', NULL, NULL, 158, 22),
(200, 'Hipergigante blanca', NULL, NULL, 318, 13);

INSERT INTO estrella_galaxia(id_estrella, id_galaxia) VALUES
(192, 10),
(33, 17),
(59, 26),
(13, 17),
(107, 41),
(200, 6),
(175, 15),
(193, 35),
(176, 14),
(87, 25),
(80, 48),
(60, 5),
(125, 6),
(81, 8),
(61, 18),
(194, 8),
(82, 47),
(146, 10),
(126, 6),
(177, 12),
(108, 48),
(88, 27),
(195, 41),
(34, 26),
(109, 1),
(62, 18),
(42, 23),
(89, 2),
(147, 2),
(127, 2),
(63, 37),
(178, 1),
(14, 11),
(148, 43),
(128, 38),
(110, 26),
(149, 11),
(43, 43),
(64, 39),
(35, 26),
(196, 30),
(179, 26),
(129, 21),
(150, 28),
(15, 13),
(90, 44),
(197, 39),
(180, 14),
(198, 12),
(130, 2),
(181, 24),
(111, 3),
(91, 12),
(36, 50),
(44, 38),
(151, 7),
(65, 10),
(16, 40),
(199, 20),
(131, 40),
(112, 21),
(37, 39),
(182, 45),
(92, 3),
(165, 29),
(17, 46),
(38, 1),
(18, 16),
(152, 17),
(183, 49),
(45, 6),
(39, 35),
(66, 4),
(113, 18),
(166, 43),
(93, 34),
(184, 18),
(46, 19),
(167, 49),
(185, 3),
(67, 12),
(47, 39),
(132, 34),
(19, 13),
(153, 47),
(133, 9),
(68, 45),
(168, 16),
(114, 22),
(40, 14),
(48, 18),
(154, 47),
(69, 38),
(134, 34),
(94, 7),
(186, 18),
(169, 37),
(20, 26),
(155, 2),
(41, 32),
(49, 3),
(187, 9),
(70, 33),
(21, 42),
(115, 10),
(170, 5),
(50, 48),
(188, 13),
(71, 25),
(135, 25),
(156, 11),
(171, 15),
(1, 8),
(189, 42),
(95, 46),
(51, 22),
(116, 50),
(172, 32),
(190, 22),
(72, 15),
(136, 48),
(52, 3),
(157, 18),
(96, 5),
(117, 17),
(97, 30),
(137, 29),
(118, 42),
(22, 24),
(2, 9),
(158, 40),
(173, 32),
(98, 32),
(191, 45),
(138, 26),
(73, 28),
(174, 5),
(119, 44),
(159, 1),
(53, 21),
(74, 44),
(99, 50),
(120, 14),
(54, 30),
(23, 38),
(100, 44),
(75, 20),
(55, 10),
(3, 38),
(76, 2),
(24, 16),
(4, 41),
(56, 50),
(77, 50),
(139, 26),
(57, 6),
(160, 42),
(121, 48),
(140, 24),
(25, 6),
(101, 34),
(161, 38),
(78, 47),
(5, 36),
(141, 12),
(58, 18),
(26, 3),
(6, 31),
(27, 39),
(79, 1),
(162, 49),
(142, 50),
(163, 35),
(7, 12),
(143, 47),
(164, 18),
(28, 16),
(122, 2),
(8, 6),
(29, 17),
(9, 47),
(144, 18),
(124, 8),
(145, 30),
(102, 7),
(30, 28),
(123, 43),
(103, 22),
(83, 49),
(10, 31),
(104, 1),
(84, 17),
(105, 7),
(85, 49),
(31, 17),
(106, 25),
(11, 25),
(86, 25),
(32, 1),
(12, 32);

INSERT INTO galaxia(id, numero, id_cuerpo_celeste) VALUES
(1, '524', 999),
(2, '77572', 972),
(3, '96783381', 996),
(4, '244576', 953),
(5, '552890', 959),
(6, '5444106', 954),
(7, '831550', 1000),
(8, '36211', 978),
(9, '8468318', 997),
(10, '9667', 973),
(11, '1221', 960),
(12, '954700', 955),
(13, '83044', 979),
(14, '1194356', 950),
(15, '4634656', 974),
(16, '41850', 986),
(17, '424926', 963),
(18, '48902', 994),
(19, '524', 969),
(20, '76805', 964),
(21, '620231', 992),
(22, '35072', 970),
(23, '5270', 980),
(24, '1794', 975),
(25, '9200065', 981),
(26, '2959254', 956),
(27, '557764', 976),
(28, '431', 987),
(29, '366', 998),
(30, '355529', 993),
(31, '4134', 951),
(32, '12824', 995),
(33, '89569', 988),
(34, '7870533', 983),
(35, '190665', 982),
(36, '2595', 965),
(37, '638530', 971),
(38, '968787', 989),
(39, '3324540', 984),
(40, '10980', 966),
(41, '2157155', 977),
(42, '928694', 957),
(43, '40868', 952),
(44, '348675', 990),
(45, '38656526', 958),
(46, '317170', 985),
(47, '635679', 991),
(48, '437', 961),
(49, '428', 967),
(50, '30459498', 962);

INSERT INTO nave(id, nombre, identificador, tipo, capacidad_carga, n_tripulantes, id_cuerpo_celeste, id_coalicion) VALUES
(1, 'Butterfly', '9T9S91DYH33H5SH', 'pasajeros', 4063, 0, 31, 63),
(2, 'Lehi', '11JB718X762HN5P', 'carga', NULL, 8, 44, NULL),
(3, 'Lofudisu', 'F9T5T2ME38R42I9', 'carga', -7169831, 3, 24, 87),
(4, 'Cloudy Zeppeling', '778V3KJ50Y6H8A3', 'pasajeros', -4157329, 3, NULL, 76),
(5, 'Shiny Butterfly', '36J89WL063P75EQ', 'carga', 60, 1, NULL, 81),
(6, 'USS Condor', 'BU83P1OX6490891', 'carga', 7977060, 3, 40, 70),
(7, 'USS Luhamuvo', '6S045B6F29H5WY7', 'carga', 6244, 14, NULL, 9),
(8, 'USS Butterfly', '7QR4Y66OK6QPQ1S', 'exploración', -6743141, 5, 1, 71),
(9, 'Ejuso', 'V16C6HC38ISAGB6', 'combate', -3784936, 339, NULL, 80),
(10, 'USS Uxojola', 'L9SC55LL40PNWG1', 'carga', 7441, 0, 10, 7),
(11, 'Muganobo', '5SR5H0O627O9L3B', 'pasajeros', -8447736, 106, NULL, 99),
(12, 'Kuniwute', 'YQ621RY3RV28DG8', 'exploración', -2963077, 0, NULL, 83),
(13, 'Shiny Eagle', '3G104G7ZV8344MY', 'pasajeros', 8829307, 0, 26, 95),
(14, 'Grand Zopadumovo', '2QGRJ8B7TI2P9FE', 'carga', -4303, 408, 16, 58),
(15, 'Lil'' Macacazeje', '00M3A8B540PI33J', 'carga', 1299238, 15, 11, NULL),
(16, 'Kicu', 'Z3K4G883168HBUN', 'pasajeros', -3346541, 1, 49, 15),
(17, 'Faxozu', 'BQYP532ZD7E9K0Q', 'carga', -3, 60, NULL, 36),
(18, 'Poqonemo', 'V5S0C13L7C5I00Z', 'carga', 82, 145, NULL, 1),
(19, 'Big Idade', '260415AZ4U1IZ1X', 'carga', -187948, 1, 48, 23),
(20, 'Big Condor', 'TGQO5Q8C4J7E2F3', 'exploración', -7, 6, 18, 61),
(21, 'Cloudy Enibuli', 'M941Y9V86B83D2T', 'carga', 2384056, 1, 8, 72),
(22, 'USS Naqote', '8O06B133851HU5J', NULL, NULL, 2, 16, 14),
(23, 'Big Huxaki', 'F80578K7DLQNI50', 'exploración', NULL, 0, 8, 51),
(24, 'Golden Bedihuroru', '50RKJ6K7NVRPF08', 'carga', -3611445, 2, 44, 13),
(25, 'Lil'' Condor', 'A2EQL1348C3U184', 'pasajeros', -3776664, 1, NULL, 77),
(26, 'Condor', '7FTAOO8P6W8142S', 'carga', 5238, 85, NULL, NULL),
(27, 'Silver Disecuxi', 'Q97H80X247F7108', 'carga', 4851876, 14, 26, 44),
(28, 'Cloudy Rezu', 'N4AO1E3N1TOOONC', 'carga', 3438516, 12, 1, 28),
(29, 'Mojavocaga', 'B6R7EU3JK01EGZ5', 'carga', 3017829, 1, 9, 25),
(30, 'USS I', '879V8Q10KD215JP', 'carga', 1971129, 6, NULL, 14),
(31, 'Grand Eagle', 'L77K9FP9JT1BYIK', 'carga', -7256146, 0, NULL, 37),
(32, 'Vuhihusa', '095RUXYN7778UW8', 'carga', 7889348, 5, NULL, 15),
(33, 'Lil'' Hirine', 'NZ108DWK60T2866', 'combate', 65, 284, 1, 70),
(34, 'Fuzejo', 'LDXYAWU5X57H424', 'carga', 1995701, 3, 12, 64),
(35, 'Shiny Dicoro', 'M49D5FOMDM2D6RN', 'pasajeros', -991, 0, 49, 32),
(36, 'Fifanuxi', 'QXAD5564TKKA31Q', 'carga', -5177594, 15, 42, NULL),
(37, 'Urecasiji', '722Z997A2KZH6Q9', 'pasajeros', 8417937, 192, NULL, 96),
(38, 'Cloudy Uloxe', '91FI08HZ24ET2N2', 'pasajeros', -8152770, 11, NULL, 19),
(39, 'Xorazisu', 'E2K6QTP9K6MJTG8', 'carga', 3, 10, 37, 4),
(40, 'Butterfly', 'U0KOJ51L58Y5X5O', 'pasajeros', 5394768, 15, 30, 82),
(41, 'Berete', '72CT94H5CAUXU2A', 'carga', -78, 321, 48, 7),
(42, 'Cloudy De', 'PLIIW2CYL7MX16K', 'pasajeros', -5701674, 15, NULL, 67),
(43, 'Tixazo', '6H8D9ZV3CO4UGU6', 'pasajeros', 9154661, 5, NULL, 42),
(44, 'Ripazale', '6A76QZ0K6EJMS66', 'carga', -566614, 359181, 26, 46),
(45, 'Golden Imagukikapu', 'PV44B0017HC97C5', 'carga', NULL, 2, 7, 77),
(46, 'Nunomohu', 'X29RCO7D5J0JRI8', 'combate', 887541, 208, 13, 24),
(47, 'Wahasape', 'BL6878TGPBB123D', 'pasajeros', -1059476, 5, NULL, 98),
(48, 'Uxaci', '6Z20E3KD5Y8E3R0', 'pasajeros', -1730017, 2, 22, 36),
(49, 'Cloudy Wapigi', '83O2698VE8UJ85Y', 'pasajeros', 7204874, 5, 21, NULL),
(50, 'Nelito', '7TB7EKVKQ9528AK', 'carga', 4254174, 7, NULL, 14),
(51, 'Golden Sipeho', '24Y199LSKQ72ZAL', 'carga', -6936030, 1, NULL, 62),
(52, 'Golden Qaxime', '1856S494IB9V67E', 'carga', -95, 8, NULL, 93),
(53, 'Kegokinago', 'QDW205251OOL039', 'exploración', -4, 1, NULL, 94),
(54, 'Fecuvacoma', 'B02189F7GUN3O4S', 'pasajeros', -819, 13, NULL, 63),
(55, 'Megelu', '01A9HJJ77D67SDY', 'carga', 1510519, 1, 35, 92),
(56, 'USS Zeto', '11634N88H7CCZC1', 'carga', 16, 7, NULL, 68),
(57, 'Silver Ja', 'G215N8E6UMCG9W0', 'pasajeros', 3104134, 2, 7, NULL),
(58, 'Grand Oqadebe', 'OI92YW2231DFQ0Q', 'exploración', NULL, 1, 48, 78),
(59, 'Silver Ahupubate', '197249RM36Z12QO', 'carga', NULL, 7, NULL, 47),
(60, 'Serodo', 'Y9K2EUS44519325', 'pasajeros', -7131300, 1, 8, 36),
(61, 'Big Zeppeling', '8N604D13W1DUA1O', 'pasajeros', 64, 220, 7, 16),
(62, 'Grand Alifu', 'Z1LAXDJWE779CHR', 'exploración', 367, 1, 17, 31),
(63, 'Little Damevofala', 'L2U6241FE137N2S', 'exploración', 3748, 0, 30, 41),
(64, 'Big Fox', '8731VO79317G535', 'carga', -2704264, 11, 15, 65),
(65, 'Ilove', '248L04BV0375E95', 'pasajeros', 1157268, 1, 29, 46),
(66, 'Stormy Emuno', 'PCMA9VA37DDH0T6', 'combate', -7708773, 1, NULL, 25),
(67, 'Judanaziriku', 'DYCQH7F5597R87H', 'pasajeros', -9387849, 0, 2, 48),
(68, 'Pofuho', '6QCD1R25FY1HMH9', 'pasajeros', -7, 14, 25, 90),
(69, 'Stormy Butterfly', 'R47H5669N780T9Z', 'carga', -5455565, 89, NULL, 41),
(70, 'Cloudy Nevo', 'CW759E4088IWXT7', 'carga', -61, 159, NULL, 92),
(71, 'Cloudy Kuza', '560IQ713287D538', 'pasajeros', -7172311, 0, 3, 26),
(72, 'A', 'M404SC0JUEGB3L2', 'pasajeros', 165, 0, 47, 65),
(73, 'Golden Cuvirutodone', '0GB57GIIG93I7YO', 'exploración', 3072307, 3, 21, 97),
(74, 'Bifelefa', '53RO459K5CO02I1', 'pasajeros', -9879289, 8, 48, 39),
(75, 'Stormy Azeve', 'I0756I43D119LYD', 'carga', 8527214, 9, 38, 1),
(76, 'Shiny Gejowisi', 'EAZJZRQ6HT9B1K4', 'carga', -5406356, 7, 8, 95),
(77, 'Uqokupo', '5A4P0UUE57GE5FL', 'carga', -637, 452, NULL, 57),
(78, 'Zeppeling', '2V02G28XDZP3R96', 'carga', -7, 0, 9, 4),
(79, 'Little Kafese', '0YL2HRBVMJG7261', 'carga', -8, 7, NULL, 88),
(80, 'Little Eagle', '1I9G2527911SS00', 'pasajeros', 444, 0, 36, 29),
(81, 'Eagle', 'NY52MLM8H4WHLE4', 'carga', -3192776, 3, 43, 2),
(82, 'Stormy Luqasa', '92TT92FY59RGM17', 'pasajeros', 636, 3, 14, 54),
(83, 'Big Butterfly', '9F6T024683Y4I38', 'carga', -1924973, 0, 10, 9),
(84, 'Stormy Susefa', 'S3X070WSRY875PG', 'carga', -2957897, 12, NULL, NULL),
(85, 'USS Enefoso', 'YQLW8657OX280CW', 'exploración', 4155518, 1, NULL, 88),
(86, 'USS Butterfly', 'Q2T7K4G7QV29EMJ', 'pasajeros', -4, 14, NULL, 60),
(87, 'Eagle', 'ZFCB32GVTK7VBEB', 'carga', 1288490, 3, 39, 22),
(88, 'Jojajo', '8873PPD9BJ630DL', 'carga', 2387472, 12, 36, 7),
(89, 'Bebu', '3C9F1X651V089KK', 'pasajeros', 2826526, 7, NULL, 74),
(90, 'Jekejaleke', 'Y60V68U74UN9KWD', 'carga', -77, 8, NULL, 42),
(91, 'USS Daqetubo', 'V89M7093PBW3JBK', 'carga', -9958533, 187409, NULL, 97),
(92, 'Shiny Desazanoqoqu', 'JJH3J938P96NH8P', 'pasajeros', 8098325, 9, 4, 51),
(93, 'Taju', 'FE947Y4H7837L70', 'carga', -5720, 0, 5, NULL),
(94, 'Stormy Cozoju', '515Z2AY6OQR4OHB', 'pasajeros', -3834, 9, 40, 18),
(95, 'USS Dumavefa', '2X8LYIFKT4JRR7V', 'pasajeros', -7441525, 11, 2, 36),
(96, 'Cloudy Donikena', '052P944OJPHFT85', 'carga', -3640508, 4, 18, 72),
(97, 'Likaji', '6Q5G87LQW0I0IOC', 'pasajeros', -4777047, 1, 27, 35),
(98, 'Bibakuhute', '6WXNVXTPLE95B7H', 'carga', 8, 0, 19, 85),
(99, 'Silver Rajiko', '68Y6D16K20QSKPX', 'carga', -4141136, 354, 9, 85),
(100, 'Qaxeke', '4PM587WCEBNR027', 'combate', -7217167, 7, 16, 21),
(101, 'Big Condor', 'H8R3WL2DRBWZD92', 'carga', 861, 2, 9, 50),
(102, 'Opizo', '4NPU58A13V4ND63', 'carga', -1624458, 132, 35, 46),
(103, 'Silver Ma', 'PYCP4K98Y5R1Z61', 'pasajeros', -8448733, 468, NULL, 63),
(104, 'Zeppeling', '921C4QUQD8955T1', 'pasajeros', 53, 9, 23, 56),
(105, 'Silver Vugeqoguda', 'AK0EW8J159HF9R6', 'exploración', 224, 0, 6, 37),
(106, 'Ewafitu', '7G626L31476Z27I', 'pasajeros', 5896018, 184, 50, 7),
(107, 'Cloudy Cuju', 'RT0OA02G5VJYR5V', 'carga', 9421917, 1, NULL, 77),
(108, 'Lagi', '76G4O63J86O86Y2', NULL, NULL, 0, 5, 50),
(109, 'Fish', '44LY2X98W63MQI2', 'carga', -4, 12, 40, 31),
(110, 'Little Velupohi', '82D83601D6AWJM0', 'carga', -7273346, 10, NULL, 16),
(111, 'Condor', '4C4AA34J6V7M9ZI', 'carga', -1252290, 4, NULL, 83),
(112, 'Little Ejoce', 'B1N7K33679YGCL1', NULL, NULL, 11, 39, 43),
(113, 'Aba', '7YUIWDNA4DU9QUS', 'pasajeros', 7431344, 0, NULL, 35),
(114, 'Becajalidi', 'X83WT527S3W6644', 'carga', 2734026, 15, 41, 81),
(115, 'Hagu', '05AP9F1OS0CU76I', 'pasajeros', 3702835, 13, NULL, 17),
(116, 'Ehisucifibi', '0LU177VF7KGMG7B', 'pasajeros', -1060501, 0, 32, 48),
(117, 'Rikuzoje', 'T9RLL1289X03YW6', NULL, NULL, 1, 27, 79),
(118, 'Cloudy Fox', '0C34HRZ4A35239X', 'carga', -7002076, 13, NULL, 95),
(119, 'Grand Vujuze', 'RJV71M2F345UAI7', 'carga', 3966159, 1, NULL, 27),
(120, 'Sopumi', '8C0OWB3L93N8IK9', 'carga', -759472, 12, NULL, 48),
(121, 'Focelu', '733AYG61I4C610T', 'carga', -709, 9, 15, 15),
(122, 'Wasasiqe', 'DCJ3JSI2YX7V1HO', 'carga', 7683779, 15, NULL, 70),
(123, 'Little Meregure', 'N84UL65BLSB057T', 'exploración', 9877480, 128, NULL, 41),
(124, 'Cloudy Jivecijo', '64MP0Y89S325ITI', 'pasajeros', 74, 9, 1, 50),
(125, 'Jode', 'DLLG6S8CFZ639VO', 'carga', -2937658, 421, 42, 7),
(126, 'A', '1CZD087I9U3N7QE', NULL, NULL, 0, 38, 66),
(127, 'Fovuwofu', 'N5P621E872ILUP8', 'pasajeros', 191, 0, NULL, 63),
(128, 'Conaqawi', '41GWKH53THPC7WN', 'pasajeros', NULL, 0, NULL, 7),
(129, 'Grand Ucegu', '65559PN0N351ZP5', 'carga', 9512, 1, 46, NULL),
(130, 'Efebu', '89G0LXDDXE6E147', 'pasajeros', NULL, 11, NULL, 47),
(131, 'Big Loguha', '0V01PMJYB6Y21WW', 'pasajeros', 7192242, 13, NULL, 63),
(132, 'Little Tapogi', 'U41I8M9HNJ77431', 'carga', -7983472, 12, NULL, 49),
(133, 'Silver Dasobevehugo', '0B02KYAR3FZ242C', 'carga', -9, 1, 19, 53),
(134, 'Cikukako', '654400YQ9L2O3L9', 'combate', 5250129, 3, 28, 94),
(135, 'Nekoci', 'Q57420748S3BY6W', 'carga', -4506522, 13, 34, NULL),
(136, 'Little E', 'R1EOMW65DG39865', 'carga', 2199700, 5, NULL, 61),
(137, 'Grand Fanudofu', '19C04KZ8JPL1QQV', 'exploración', -9801900, 10, NULL, 4),
(138, 'Jopuneluwaba', '42CM67DLF7517W4', 'combate', 993000, 9, 46, 85),
(139, 'Big Genolaqosu', '56S0AOA7M2Q6TDG', 'carga', NULL, 13, 9, 62),
(140, 'Fish', 'AHPQLMSQGWNK1EY', 'carga', 7942242, 1, 44, 58),
(141, 'Xixororuna', '9NY5P86U35W9LOL', 'carga', -7452, 15, NULL, 74),
(142, 'Jucujo', '6Z319071C03RJQ7', 'pasajeros', NULL, 6, NULL, 9),
(143, 'Sosaquvuvo', '19223018YD0P2HQ', 'pasajeros', -230, 97, NULL, 62),
(144, 'Stormy Tajowo', '694JW2X7R940SI2', 'carga', 9308271, 1, NULL, 47),
(145, 'Noka', 'XE27ZP83YU62LCL', 'carga', 3596449, 12, NULL, 1),
(146, 'Livugubuzi', '3B8N8327IU7NL51', 'carga', -9478, 0, NULL, 8),
(147, 'Ozado', 'A74M81PS2SIP0C6', 'pasajeros', -926624, 9, NULL, 31),
(148, 'Silver Seme', '5JDI0U7JE488MQV', 'carga', 4462868, 12, 15, 67),
(149, 'Little Abazofovi', 'R1471A44F7OE43K', 'pasajeros', -2684, 15, NULL, 7),
(150, 'Makacoparu', '551C9T7TU911A30', 'carga', NULL, 6, 6, 1),
(151, 'Uhegeviwi', '0Z9VZS30TVRA1IS', 'combate', 71, 10, NULL, 80),
(152, 'Pepiguhi', '1V33L3LV9WCE72O', 'carga', 6144639, 7, NULL, 50),
(153, 'Condor', '973GE0S8RV33O46', 'carga', 3143310, 323757, NULL, NULL),
(154, 'Butterfly', 'WRKUJGM13741A06', 'pasajeros', NULL, 10, 48, 78),
(155, 'Mehujo', '8PN10DTE810U40I', 'pasajeros', -9545650, 428, NULL, NULL),
(156, 'Condor', '512OYNT58574330', 'carga', -2449681, 136308, 23, 27),
(157, 'Big Icoqegaji', '9Q9HS8Z032K3W9W', 'carga', -8572810, 1, 37, 46),
(158, 'Golden Fepiwemu', 'UTN630CP56I5LV8', 'pasajeros', 7593, 12, NULL, 81),
(159, 'Grand Dehe', '40C8PEFXXV3SCHL', 'carga', 1810340, 3, 7, 43),
(160, 'Condor', '7EGADN9Y42JZGR2', 'exploración', 8757401, 124, 41, 92),
(161, 'Fox', 'T1V82W194G4XJZH', 'carga', 8, 398, NULL, 98),
(162, 'Big Mefofobu', '16GCWHR5TP3AC1U', 'pasajeros', 9128763, 1, NULL, 83),
(163, 'USS Fox', 'X17Z4O1O3HBGQH9', 'carga', -8154333, 0, 1, 48),
(164, 'Wa', 'JOZZ8JN2DQ8W35L', 'carga', -9204457, 9, NULL, NULL),
(165, 'Nihuba', 'GG924Z5ZJ39H01E', NULL, NULL, 4, 47, 96),
(166, 'Silver Mubahi', 'R0Y7W0VK93GZU3Y', 'exploración', 56, 0, 6, 14),
(167, 'Golden Eagle', 'NL5DY81B6FZNURT', 'combate', -166236, 14, NULL, 89),
(168, 'Fodeqocupi', 'JYS7C635S80JPWA', 'exploración', -4581751, 2, NULL, 92),
(169, 'Izejo', 'WRK0UI2X62HZ6LG', 'carga', -9266407, 0, 9, 38),
(170, 'Grand Avoxiweki', 'WKZOE2AEH3Y69PM', 'pasajeros', 225444, 0, NULL, 81),
(171, 'Stormy Sogeraca', 'GMJF9BY1QCIOKH3', 'carga', -3827652, 2, 20, 26),
(172, 'Golden Ecetu', 'Q2HS9VM3G73H08G', 'carga', 5169709, 11, NULL, 21),
(173, 'Lil'' Ofovo', 'C29IKEN2O130F5S', 'pasajeros', 7567720, 1, 20, 35),
(174, 'Condor', '8N0FTG986PX4D2W', 'carga', -88, 1, 2, 3),
(175, 'Sicugaje', 'PI2U2R3523QI17I', 'carga', -1199746, 0, NULL, 18),
(176, 'USS Hozawife', '45JEW27E4EJQ01A', NULL, NULL, 1, NULL, 88),
(177, 'Stormy Lacori', '3PIOP5TO0LV1H43', 'combate', 6871033, 8, 15, 9),
(178, 'Derabe', '6MK9X7I57IXZKA9', 'carga', 3997082, 14, NULL, 59),
(179, 'Grand Kiqexitemo', '6RQ1Y6AW08W41XE', 'pasajeros', -8909077, 9, 2, 42),
(180, 'Grand Condor', 'PAC44230RO61GJC', 'carga', -6384616, 4, NULL, 35),
(181, 'Golden U', '23803LZ65F68046', 'carga', 5911735, 11, NULL, 22),
(182, 'Majutuba', 'O5O048XEAMXX8R2', 'carga', 5973170, 8, 11, 55),
(183, 'Firunafo', 'WU7KO6915SIY86T', 'pasajeros', -3009642, 1, NULL, 88),
(184, 'Kucuhu', '5NUYFX27B1MGVRX', 'carga', 672192, 7, 44, 90),
(185, 'Grand Zurihaso', 'ZC5E6W2805KEY54', 'combate', 7487182, 1, 27, 20),
(186, 'USS Ka', 'D2J7Z1998N8X283', 'carga', -3605659, 279157, NULL, 29),
(187, 'Duhaha', 'T2O5DUFV7289L48', 'pasajeros', 7026122, 12, NULL, 64),
(188, 'Cloudy Vedelugimo', '13U60QAJ8OEJXQN', NULL, NULL, 8, 39, 36),
(189, 'Dabaxo', 'FDZU6K6651HURHS', 'carga', 9829173, 5, NULL, 70),
(190, 'Shiny Zudejogaja', '757E1A5253K4MG4', 'combate', -6529247, 5, NULL, 8),
(191, 'Zemozowuti', '93EP77NZY62Z14O', 'carga', -3283619, 10, NULL, 75),
(192, 'Little Ci', '17G272UDA6I689J', NULL, NULL, 9, 28, 67),
(193, 'Xuximoce', '10U23D5TMVW7XWF', 'carga', -3001023, 1, NULL, 21),
(194, 'Big Ehetituka', '17U9Z4QC3230L5K', 'carga', -1, 2, NULL, 68),
(195, 'Fish', '5EPI928FP250CUI', 'pasajeros', 0, 9, 34, 72),
(196, 'Upoto', '0C191Z629605XQ1', 'carga', 3604539, 12, 14, 60),
(197, 'Eagle', '45L8RZMVMDMZLH5', 'pasajeros', 5064963, 1, 16, 65),
(198, 'Fish', 'S71DFL05V520J3C', 'carga', -724, 0, 26, 48),
(199, 'Golden Covudala', '4J2FXCB4V8AW914', 'pasajeros', 3055238, 8, 21, 15),
(200, 'Lil'' Condor', '73N68DXV1ET32L8', 'carga', 3348512, 2, NULL, 65),
(201, 'Big Opixi', '2MLZL1OC21UZ2B8', 'pasajeros', 726383, 10, 46, 5),
(202, 'USS Sabagukewa', '810Z5B86ZF1P2E3', 'carga', -2711, 11, 7, 35),
(203, 'Lil'' Poqegigovugi', 'FS0Y50VTG7ZZ1GU', 'carga', 4577953, 13, 8, 23),
(204, 'Eagle', '9845S92X7L0W4NF', 'carga', 6249, 4, 19, 40),
(205, 'Niribu', 'LP9WY86189JNTMN', 'carga', 552, 518206, NULL, 35),
(206, 'Lil'' Zeppeling', '21EJZ7V060MB6DF', 'carga', 5103283, 1, 24, 6),
(207, 'Eagle', 'YYJ3X0YHYH37PB0', 'pasajeros', 6588627, 5, NULL, 28),
(208, 'Shiny Sojokudo', 'L6Z8MMK0SM3A6F3', 'carga', -6589, 286, NULL, 4),
(209, 'Wuvoriju', 'CN566E51J8AS65T', 'combate', 1772876, 1, 17, 36),
(210, 'Ravurevo', '170T1656439Q682', 'carga', 7889951, 4, NULL, 59),
(211, 'Fazafaja', '1T4U62C6J0F7HR1', 'exploración', -5681, 1, 30, 6),
(212, 'Pogika', '026KMG0D2CVI6J9', 'combate', 1276249, 0, 45, 23),
(213, 'Ucico', '1G69IL9BR2NXZZ9', 'pasajeros', -5033367, 446, NULL, NULL),
(214, 'Big Uzucoxake', 'AAU13KRIFK9L47J', 'carga', -3566586, 7, 27, 55),
(215, 'Foxewosezo', 'VN5EY7GCXJA5569', 'pasajeros', 625124, 1, 37, 99),
(216, 'Lil'' Soqelaqi', 'V5H085M960VCG2D', 'carga', -8821488, 8, 27, 51),
(217, 'Silver Famofoko', 'SY945642M2VNY88', 'carga', 2657435, 3, NULL, 15),
(218, 'Fox', 'E57MB94M31C1356', 'combate', 6397513, 12, 10, 68),
(219, 'Silver Deqejeno', '0Y1V1844J6I5737', 'carga', 3850804, 3, 37, 94),
(220, 'Golden Fish', '72511MQPX32P042', 'exploración', -1102073, 12, 19, 77),
(221, 'Silver Wihupadi', 'GO6XHU4ZG543HZH', 'pasajeros', 6296310, 9, NULL, 100),
(222, 'Little Lezumulu', 'Z938BXA601J4K9B', 'exploración', 7773147, 4, NULL, 66),
(223, 'USS Bicirogumo', '5DM18X1C631T830', 'carga', -3738495, 1, NULL, 89),
(224, NULL, 'S3AV930SWQ59NGY', NULL, NULL, 4, NULL, 60),
(225, 'Omudumu', '6GT7P6H295M03TE', NULL, NULL, 13, NULL, 93),
(226, 'Kawepopiga', '56B45Z2CV9M3XXH', NULL, NULL, 1, NULL, 5),
(227, 'Stormy Xinuxa', 'E52DQBSI163HD4R', NULL, NULL, 12, NULL, 41),
(228, 'Azoza', '51Y0D86R3Q0L997', 'pasajeros', 5383399, 9, 23, 31),
(229, 'Lesibabo', 'Y295097L1L178A8', 'combate', -463150, 2, NULL, 65),
(230, 'Stormy Usimo', 'R193814ID7BBF66', 'carga', -6411976, 9, 11, 83),
(231, 'Guxilelura', '449WY71NPKIIW4P', 'carga', -334, 202, 10, 67),
(232, 'Cloudy Fish', '53245IA4LO7G57W', 'pasajeros', NULL, 14, NULL, 6),
(233, 'Agexefoka', '9N7ZB666N2Y64R0', 'carga', 2777800, 6, NULL, 22),
(234, 'Ahihepu', 'P3FWKL3VHGBFPBY', 'pasajeros', -653890, 3, NULL, 5),
(235, 'Xupodufi', 'F6Y5F436J4T5N6Z', 'combate', NULL, 0, NULL, 45),
(236, 'Lil'' Nuraqo', 'JRQ16N3HIWH1QQ5', 'carga', -5846749, 0, 47, 61),
(237, 'Fici', 'BF9U377D1CA37CQ', 'carga', 157236, 75, 47, 59),
(238, 'Grand Fox', '35F0DIWNE638616', 'pasajeros', 4364546, 4, 7, 26),
(239, 'Shiny Pi', '4WQ4K1Q8J8C2U04', 'exploración', 4569452, 12, 21, 84),
(240, 'Zo', 'GZK7V7TT4TP59M5', 'carga', -4277040, 2, NULL, 18),
(241, 'Meceduko', '37F4S02M4TPHV79', 'exploración', 9585, 14, NULL, 29),
(242, 'Cloudy Ki', '622695K1K73X902', 'exploración', -7379435, 9, 2, 31),
(243, 'Rubumusu', 'FHE79554UP3AT5Q', 'exploración', -5418, 14, 29, 69),
(244, 'Lil'' Biduxe', '18SU23NYZIPD659', 'pasajeros', -5189662, 15, NULL, 25),
(245, 'Grand Muzu', 'N120XMVD3V5Y825', 'pasajeros', -2545638, 1, NULL, 89),
(246, 'Hanoregu', '4Q47G965V47TURL', 'pasajeros', 8672, 0, NULL, 62),
(247, 'Grand Hiri', '171WFKWJT2O4962', 'carga', -317, 2, 50, NULL),
(248, 'Big Quro', '344XUO0L2L826D8', NULL, NULL, 1, NULL, 18),
(249, 'Shiny Kokozi', '0F0H5TQ6023919Z', 'carga', NULL, 5, 42, 16),
(250, 'Little Hohetufewu', 'SN9U2Z3W9DUD585', 'carga', -8905716, 430, NULL, 30),
(251, 'Fubene', 'G8S45J1W754TL1F', 'exploración', 0, 8, NULL, 28),
(252, 'Silver Butterfly', '36O5T784NC6T6MM', 'pasajeros', 8892977, 5, 35, 32),
(253, 'Firacomi', '273T4N7074D8087', 'combate', -3, 0, 19, 41),
(254, 'Lil'' Fish', 'H8WS2RS3PN5P6FB', NULL, NULL, 15, 8, 93),
(255, 'Runo', '1SZX17P8J56Y891', 'carga', 4171429, 0, NULL, 6),
(256, 'Golden Butterfly', 'TC08L358O748YAO', 'carga', NULL, 4, 22, 34),
(257, 'Isahimu', 'B2GMWTK63I30UVV', 'carga', -2873417, 10, NULL, 91),
(258, 'Lil'' Honeka', 'UWIKI72Q62CLD37', 'pasajeros', -7195701, 412, NULL, 22),
(259, 'Bivigaji', 'R0X0UM3MB746V7M', 'combate', -7808711, 1, NULL, 98),
(260, 'Stormy Atuduni', 'Z6G7M80E1NTT7SX', 'exploración', NULL, 80, NULL, 51),
(261, 'Big Dike', '1009VGCNO29011D', 'carga', -4181254, 3, NULL, 42),
(262, 'Cloudy Ekiradibaki', 'MFX863X903W1048', 'pasajeros', 8225366, 0, NULL, 2),
(263, 'Big Loriliki', 'X4S66R0TWQ7I1S7', 'pasajeros', 200, 0, NULL, 4),
(264, 'Big Condor', '9618R37UV41560K', 'carga', 3964541, 12, NULL, 18),
(265, 'USS Ebu', 'YY0145F60987409', 'carga', -7878481, 438, NULL, 9),
(266, 'Dadohe', 'KN38X86MMQP109A', 'pasajeros', -5, 13, 32, 40),
(267, 'Big Ifudidehu', 'X8P6II8SHIN5323', 'pasajeros', -6827341, 349, 18, 17),
(268, 'Shiny Di', 'I52K981ADDRMOOH', 'combate', -445419, 1, 5, 9),
(269, 'USS Fox', 'JW7F2660RPQ5CP9', 'pasajeros', 3568967, 7, 50, 19),
(270, 'Lil'' Ugipura', '2XD3Q21VM991ZKF', 'carga', -6419961, 1, 7, 57),
(271, 'Silver Bituhu', 'LOHNT4S6S1UM3L1', 'carga', -6645991, 3, 50, 95),
(272, 'Silver Lijikuhi', 'UAQZMB1X1731W28', 'pasajeros', 784, 0, NULL, 5),
(273, 'Gomocaka', '6H9TWSFK2TSGATD', 'pasajeros', 289289, 5, 21, 55),
(274, 'Grand Ekozexo', 'WF37CJKS39D69NQ', 'pasajeros', -87, 0, NULL, 86),
(275, 'Little Zedehemube', 'X5WI5HMZDR89332', 'carga', 6049623, 6, NULL, 29),
(276, 'Big Fatado', 'U3KP0L6U689F7YE', 'carga', 877845, 3, NULL, 62),
(277, 'Stormy Axi', '6MSN2L0108G53E3', 'carga', 6449329, 0, NULL, 62),
(278, 'Stormy Dinajicehe', '6D7332YWM40E1C8', 'carga', -9540, 0, 1, 51),
(279, 'Big Popageto', 'QZB1U3AGTK225OP', 'combate', -4391374, 1, 35, 54),
(280, 'USS Fiwuci', '88AX25932JCL28Q', 'carga', NULL, 9, 1, 26),
(281, 'Fifabusu', 'WQ8N5C30YTQEI8I', 'carga', 4316406, 9, 3, 8),
(282, 'Silver Esarojo', '6IYQ7VBT003ZZWZ', 'exploración', 7825779, 0, NULL, 22),
(283, 'Lil'' Condor', '1JU5ALEA74MQ51B', 'pasajeros', 7808886, 0, NULL, 92),
(284, 'Cevalefebo', 'H801402SI008666', 'carga', 1, 9, 39, 32),
(285, 'Ewete', 'IWL1H6G6DQ941H1', NULL, NULL, 1, 8, 100),
(286, 'Shiny Giku', 'W07Q0T06EUH36J7', NULL, NULL, 0, 16, 32),
(287, 'Jusoxa', '1T54NZ07GLZQ475', 'carga', -306956, 3, 27, 60),
(288, 'Big Mojaralasa', 'H39B21IX39DBM18', 'combate', NULL, 5, NULL, 3),
(289, 'Bigidojahe', 'HE1H0FYR86BN2M9', 'carga', NULL, 15, 47, 44),
(290, 'Big Gudalunu', '4XIFN4WBL8YVWET', 'carga', -7, 1, NULL, 21),
(291, 'Little Vegaxixa', 'DAQ168RS8CONR38', 'carga', 613874, 6, 48, 6),
(292, 'Jomona', 'XATYOJOQP1YSM19', 'exploración', 2410301, 0, 45, 68),
(293, 'Volavi', '3P8MA8824H3P59W', 'pasajeros', 695, 14, 37, 5),
(294, 'Ovi', 'OT90P3BG844300X', 'carga', -970, 14, 9, 14),
(295, 'Golden Poqosace', '9P8X2JO4Z14X38Y', 'carga', -6862541, 404, NULL, 31),
(296, 'Big Socilejixa', '4487SD6ASC9O4X9', 'carga', 4107556, 4, NULL, 54),
(297, 'Eagle', 'N7V75N80926CFM2', 'carga', 732911, 14, 1, 5),
(298, 'Cloudy Fuzu', 'IV12R29FS7T8X2V', 'carga', -4250630, 1, 47, 6),
(299, 'USS Qubepejena', '21A35UI63593O3F', 'carga', 222686, 134, NULL, 99),
(300, 'Otinatami', 'S9381R489ZIPQD3', 'carga', -226670, 19, 44, 34),
(301, 'Lupi', '03RDMG63O93TPFR', 'carga', -7676870, 0, NULL, 68),
(302, 'Vopewovicu', 'UL1KF70B4MO5457', 'carga', -666, 3, 43, 53),
(303, 'Golden I', 'RQ4190A54460839', 'pasajeros', -4178712, 12, NULL, 26),
(304, 'Wobagi', 'QI407OEJ5ZQKM9I', 'carga', 2318069, 0, 19, 54),
(305, 'Cloudy Jirezaheso', '4G488JS08OJK8RS', 'combate', 151515, 7, 44, 82),
(306, 'Butterfly', 'ZLO5098O3I1W6FI', 'exploración', 9343193, 3, 7, 7),
(307, 'Shiny Fish', 'S4Z477091Y2PKB5', 'exploración', -3420376, 165610, NULL, 65),
(308, 'Tutuweka', '11PVSU9WSS65HN5', 'carga', 176, 1, NULL, 20),
(309, 'Lil'' Bixeqoxa', '2757Y2RA74U15V1', 'carga', -9848575, 1, 1, 62),
(310, 'Sebepaxoruso', '9HHHSG51ASDV51X', 'combate', -2472091, 10, 5, 3),
(311, 'Fox', 'Y4P36XE8JUHPMXY', 'pasajeros', -5896773, 15, 43, 3),
(312, 'Pixufirabo', '2EG92BT4Y3YOGI0', 'exploración', -4074, 0, 10, 49),
(313, 'Little Talilode', 'XDJ3Y1TN7M4NDTA', 'carga', -8251713, 13, 36, 12),
(314, 'USS Fox', 'W511VRR6VC2V7II', 'exploración', -6, 6, NULL, 66),
(315, 'Shiny Condor', 'X8J46K3FT5FN77B', 'carga', -5091682, 8, NULL, 11),
(316, 'Grand Warila', '9MHM9240QT9D8B5', 'carga', 8705922, 10, 20, 87),
(317, 'Stormy Amifa', '4O4M40RHBECS184', 'pasajeros', 2389, 258, 16, 91),
(318, 'Fox', 'Z9O1I9991KV3J85', 'carga', 7, 14, NULL, 8),
(319, 'Ojijaga', '8GI1UCZYCM6GH5X', 'pasajeros', -758818, 1, 49, 82),
(320, 'Apibiqi', 'FFMJ1L979C309S8', 'carga', 5, 14, NULL, 43),
(321, 'Big Teseti', 'WZW3ZY221JYH99Q', 'exploración', -5621817, 7, 28, 44),
(322, 'Golden Rozo', '34FR82M8611JRH0', 'carga', NULL, 1, NULL, 4),
(323, 'Big Bamojohu', 'D6T3200IWQRLC19', 'carga', -15, 10, 6, NULL),
(324, 'Fish', 'GY0R6RK0Y627A5D', 'carga', 72, 5, 41, 76),
(325, 'Big Condor', 'ZD59HXPW2MW3D08', 'pasajeros', -4978559, 6, 13, 9),
(326, 'Rufa', 'NS3IQ3311C977IB', 'pasajeros', 3, 4, 21, 31),
(327, 'Little Egedeva', '7YEL26KJY6A78Z8', 'carga', -8608958, 7, 21, 44),
(328, 'Little Vorufija', '81W91333BC3715W', 'exploración', -286, 17, 15, 45),
(329, 'USS Wezu', 'CCZ44X62JLEC363', 'carga', 6, 0, NULL, 57),
(330, 'Big Padunocu', 'M32NEL42KF6830J', 'carga', -59, 242, NULL, 73),
(331, 'Stormy Cogehica', '7SD0H8PV740LRGI', 'pasajeros', -6909871, 1, NULL, 56),
(332, 'Stormy Levilu', '08JCD6R16HDOE3B', 'exploración', 67, 400, NULL, 3),
(333, 'Grand Ciwuniso', 'ALRI2FR6Q8F991Y', 'exploración', 2732082, 12, NULL, 15),
(334, 'Big Butterfly', 'N57O738R6I62YK7', 'pasajeros', 4174718, 7, 7, 55),
(335, 'Lil'' Omi', '78A80N26QRF16M3', 'pasajeros', NULL, 1, NULL, 47),
(336, 'Jita', 'RZ018750P469SF1', 'exploración', 8877294, 0, NULL, 39),
(337, 'Lil'' Alusahu', 'R3K1ZC015Q64776', 'pasajeros', 4297003, 3, NULL, 9),
(338, 'Shiny Kopawudiwe', 'C84P07XJIB67VUF', 'pasajeros', -7454364, 9, 17, 4),
(339, 'Butunapu', '04NDA3OW44R2ACO', 'exploración', -2316353, 1, NULL, 54),
(340, 'Lil'' Qotuga', '6074POMMXQ1BI1E', 'pasajeros', 4317794, 5, 14, 57),
(341, 'USS Qosodexuhera', '04GQIO97CMR0LW3', 'carga', 1385549, 0, 29, 58),
(342, 'Eagle', 'Q45UP06900OTFPP', 'exploración', 7133566, 5, NULL, 39),
(343, 'Little Kihi', 'T68F06W4Z11Y8HZ', 'pasajeros', NULL, 5, NULL, NULL),
(344, 'Unulaha', '45IZH2G8CMNP83J', 'carga', -867557, 0, 47, 21),
(345, 'Gugikedi', '8HM0EK08UR5OXX4', 'carga', -4012158, 9, 32, 78),
(346, 'Rigonari', 'ZE4T8I6077M7ZSH', 'carga', 8013753, 1, NULL, 29),
(347, 'Silver Legojuho', '2M561P6ACOF143C', 'carga', 1031379, 10, 15, 9),
(348, 'Shiny Ximohupo', '4ENB1E326O0CLLW', 'pasajeros', 659221, 0, 50, 90),
(349, 'USS Kopogo', '6959YJ3Y55DW666', 'pasajeros', -512478, 0, NULL, 49),
(350, 'Havawute', '7463A5V7BZEUO3P', 'pasajeros', 8647071, 0, NULL, NULL),
(351, 'Lujebi', '1ZK6974G58LFF1R', 'pasajeros', -3008128, 7, NULL, 46),
(352, 'Cloudy Eja', '9G286X5GJ2912F7', 'pasajeros', -9709064, 1, NULL, 62),
(353, 'Cloudy Deluco', '0V7864WA354Y662', 'carga', 939, 1, NULL, 53),
(354, 'Cova', '79DW4X9QN46RV55', 'exploración', 6009986, 0, 7, 63),
(355, 'Hutuga', '55VJW46296B9453', 'carga', 9440, 0, 7, 17),
(356, 'Cloudy Cicudasamijo', '4P7MUESV61TIO5R', 'carga', 96, 1, 10, 55),
(357, 'USS Zeqiwimu', '78TAGD80HV423XR', 'pasajeros', -5290580, 5, 13, 82),
(358, 'Little Fish', 'VAIVE82W6031I30', 'carga', NULL, 0, 16, 17),
(359, 'Cloudy Itakeno', '33HZYERF43191LR', 'pasajeros', -9789535, 5, 11, 62),
(360, 'Bojuhiri', '4W9JPPL673ADQFD', 'carga', 876337, 0, NULL, 6),
(361, 'Lil'' Kafobo', 'XY5GA1Z7095R70Y', 'carga', -4283243, 329, NULL, 16),
(362, 'Marohuhe', 'FXCC5K01G4D6U84', NULL, NULL, 1, 35, 58),
(363, 'Grand Dafuduse', 'RUU45L575IA569W', 'exploración', -9146794, 294622, 3, 43),
(364, 'Zejupuletaxi', 'FIBG30EDER9YI4I', 'carga', -3186600, 0, NULL, 50),
(365, 'Shiny Fumo', '581P477QP4671R9', 'carga', -9746, 1, 4, 94),
(366, 'Ewa', '412NSD0F10Q00R3', 'carga', NULL, 11, 25, 96),
(367, 'Nehuju', '1TG8WB4K045JSNM', 'pasajeros', 5521440, 279, NULL, 8),
(368, 'Grand Henujekoju', '1V13PCOQ384I1GL', 'combate', -3523582, 0, NULL, 55),
(369, 'Eagle', 'I3RG02IU5B03804', 'carga', -3158986, 14, NULL, 51),
(370, 'Jumuza', 'PMZ26YI4H09399A', 'carga', -5937062, 11, 5, 72),
(371, 'USS Izisepi', 'HZX456A605F666N', 'pasajeros', -2584, 0, 17, 9),
(372, 'Qizocugu', 'Q43L01JZ84P281H', NULL, NULL, 1, NULL, 51),
(373, 'Stormy Niwuxisi', 'G999EOR88S5AEM1', 'pasajeros', NULL, 1, NULL, 95),
(374, 'Mugiquqa', 'GVSU7062L6LX67R', 'exploración', NULL, 0, 24, 76),
(375, 'Big Galotewuge', '8FS78Q2OMN1B98U', 'carga', 7375322, 6, NULL, 2),
(376, 'Fibegoso', 'P795D22D9P8TW4E', 'pasajeros', -2975620, 10, 14, NULL),
(377, 'Xabevi', '898T76P110O98X0', 'carga', -8555079, 4, 25, 50),
(378, 'Big Vuwoti', '97T39A1MR7CLVO4', 'combate', 3166682, 12, 22, 4),
(379, 'Tiqufini', 'VYAF56OAYL6J411', 'carga', 91, 8, 1, 33),
(380, 'Otogasu', 'O45CAD0R0UG57A3', NULL, NULL, 0, 20, 71),
(381, 'Lil'' Eagle', '7EYA0ZG4L1S70X5', 'pasajeros', 6308828, 0, 11, 23),
(382, 'Butterfly', '70YO085F2C403B0', 'combate', 6678921, 12, NULL, 55),
(383, 'Zubexi', 'TW4XIEB2SD5DUIT', 'carga', 84650, 5, NULL, 85),
(384, 'Vodoqa', 'EX4FIU0Q1H8V5VT', 'carga', 4350018, 315, 11, 22),
(385, 'Igoce', '884G3LHR1W3B02R', 'pasajeros', -1705000, 12, 45, 29),
(386, 'Eboloro', '28N613Z3919TBY5', 'carga', -9691365, 1, 4, 38),
(387, 'Umaqa', 'GK25F0PFF49Q8NU', 'pasajeros', -6, 11, NULL, 64),
(388, 'Mena', '4AR25I52B4FM65W', 'carga', -5584341, 1, 42, NULL),
(389, 'Fox', 'PA1K4D3QPRZZ1WH', 'combate', 2100188, 0, NULL, 26),
(390, 'Dotikoka', 'Y2Z4B064AQ1B25K', 'carga', -41, 168, 12, 49),
(391, 'Lil'' Fish', 'K88RM1II52OA29X', 'exploración', -6, 1, 29, 39),
(392, 'Shiny Fox', 'XYQY8XU1T3C5O78', 'carga', -1849922, 10, 20, 46),
(393, 'Big Xequxu', '7B3IJLK99S41012', 'carga', 8623903, 1, NULL, 97),
(394, 'Nodahuzi', 'AT355G4319771L7', NULL, NULL, 0, NULL, 25),
(395, 'Eagle', 'SJMH30QW967NXY6', 'carga', -1835371, 10, NULL, 1),
(396, 'Grand Zakafuvuco', 'B6SNVT0AY34793N', 'carga', -8365514, 0, NULL, 8),
(397, 'Obajitema', 'XH6PYRE7RJ6Q1KX', NULL, NULL, 13, 28, 21),
(398, 'Fuha', 'UM7XU41BNFLCF00', 'exploración', 5424247, 11, 1, 61),
(399, 'Gewicege', 'V2FDX418SJZ234T', 'pasajeros', 9709199, 6, 7, 87),
(400, 'Omusoni', '02HW45515VMKN30', 'carga', 7613184, 40, 8, 84),
(401, 'Fox', '282PAHUCG9F1165', 'carga', 2170399, 15, NULL, 18),
(402, 'Shiny Agikomo', '45B7VHY8VKWS555', NULL, NULL, 0, 15, 46),
(403, 'Bebeju', 'C9LHB4MO7EPT5WG', 'pasajeros', -5807, 8, 46, 40),
(404, 'USS Diliqubaje', '7O33XX8OH3SY8HK', 'carga', 2391590, 367, NULL, 7),
(405, 'Tecoxo', '1U0KO01SG3R6V26', NULL, NULL, 0, NULL, 1),
(406, 'Jebiroti', '2KUV85BUUR9BX15', 'carga', NULL, 9, 46, NULL),
(407, 'USS Butterfly', '1QXXRC0ZBPLU0W7', 'pasajeros', 5939184, 0, 28, 30),
(408, 'Qijasu', '35SK1C6IV318XL2', 'carga', 4162679, 168, 3, 1),
(409, 'Fish', 'B1E17DI23UW38IK', 'combate', 3395226, 7, NULL, 95),
(410, 'Stormy Okana', '2D797EF84J0Z33T', 'carga', NULL, 15, 41, 85),
(411, 'Awudoco', '4KSAU3VT610G755', 'combate', 6090215, 12, 32, 94),
(412, 'Colizuwoca', '3IJ6A1FT4855PR8', 'combate', 1440778, 1, NULL, 82),
(413, 'Gebikato', 'K90F8P6L8X88S81', 'pasajeros', 6, 8, NULL, 43),
(414, 'Pufu', 'IQF0LSE2O581F0H', 'combate', -2679577, 7, NULL, 47),
(415, 'Stormy Mifoti', '08D4G0Y854U8HIH', 'carga', -30, 1, NULL, 5),
(416, 'Grand Use', 'U74HTZE8RZJG3QN', 'pasajeros', 1831837, 15, 30, 2),
(417, 'Cloudy Nolecodu', '1QSL13309NJ1VB9', 'carga', -5940827, 14, 17, 2),
(418, 'Shiny Vexesa', 'W7V2I17ZGK9K92W', 'pasajeros', -2427363, 1, NULL, 18),
(419, 'Zavoki', 'HXVG94A6TICU59N', 'combate', 9953, 12, 48, 28),
(420, 'Ivupacu', 'R85G602NX319W31', 'carga', -8886, 0, NULL, 56),
(421, 'Qudafiriri', 'P5DWJ62971WW285', 'carga', -5394810, 99, 11, 1),
(422, 'Cloudy Quzesesa', 'H612X48MPZ2V31B', 'exploración', 2455574, 15, 4, 74),
(423, 'Fukuhe', 'MHX8F986IJGDM8C', 'pasajeros', -774, 212, 46, 78),
(424, 'Golden Ugele', '3D7TP6EV35XHJA7', 'pasajeros', 2733953, 13, NULL, 49),
(425, 'Stormy Mehime', '93C450P0O339RNR', 'carga', -1093042, 1, NULL, 1),
(426, 'Dozinu', 'L7J10RVUX5LR9J7', 'pasajeros', -9209, 6, NULL, 68),
(427, 'Golden Femofemi', 'E30UT363A2M11UJ', 'carga', 694801, 0, 33, 41),
(428, 'Epo', 'ZK81J411N82PK6Z', 'carga', -779988, 1, 36, 29),
(429, 'Nihazo', '67T4150TIF1K79U', 'carga', -1, 8, NULL, 25),
(430, 'Esenala', '4V9141PC8MEEIJ0', 'carga', -4645966, 13, NULL, 73),
(431, 'Hijobo', 'O8827K302ZX7L5X', 'exploración', 45345, 1, NULL, 44),
(432, 'Ijepugaki', 'KLJ4TJ5J8Z3THE3', 'carga', 1773019, 403, 30, 67),
(433, 'Lil'' Butterfly', '046M6F448B9UMQ2', 'carga', -9581869, 12, NULL, 38),
(434, 'Lil'' Demumi', '3RE4I054C1JQ37Q', 'exploración', 3716523, 7, NULL, 15),
(435, 'Zonixiti', '7ZA2KZ4I6XE1RA9', 'pasajeros', -3116322, 366, NULL, 14),
(436, 'Rujeka', '18ZX481JU643Y1N', 'carga', 8949, 4, NULL, 23),
(437, 'Unepivi', 'T28ANY9HHJK9S43', 'pasajeros', 3025873, 2, 20, 22),
(438, 'USS Cegaxu', 'QCCJF8F88X113O5', 'carga', -3355917, 6, NULL, 24),
(439, 'Silver Jopi', '8Z7Q320PB9V53Z9', 'exploración', 6328822, 14, 50, 97),
(440, 'Kaqadu', '4379HO779F3S722', 'carga', 0, 0, NULL, 100),
(441, 'Big Fish', 'S163QUDA4D2OTI9', 'carga', 7142, 548555, NULL, 57),
(442, 'USS Diruluma', 'PU9G762X51P1H01', 'carga', 9812994, 2, NULL, 71),
(443, 'Butterfly', '7QLB2D39L8NV799', 'carga', 8928084, 7, 32, 72),
(444, 'USS Qifirupo', '9UA345KX956U705', NULL, NULL, 7, NULL, 87),
(445, 'Shiny Jekoqo', 'R2MNW85AFKZRS72', 'carga', 41, 1, NULL, 4),
(446, 'Shiny Zafonu', '835HE26675W16A5', 'combate', -66, 471, 19, 87),
(447, 'Xedemine', 'QTOT499RR30X35O', 'carga', -8558881, 195, NULL, 74),
(448, 'Little Tegeko', 'Q7831QC5ZC9YG9F', 'carga', 3342347, 13, 6, 100),
(449, 'Big U', 'X4305Q00Y4G1Z98', 'exploración', 7305115, 15, 6, 23),
(450, 'Zuxajeqa', 'U8110XOU65NLUX4', 'pasajeros', -4190785, 0, 43, 67),
(451, 'Fowaki', '4A720R1G537I06C', 'combate', -765, 2, 27, 38),
(452, 'Xijo', 'V105VLV1226068L', 'pasajeros', 8687747, 8, NULL, 78),
(453, 'Pupuvuhixo', 'HT714X4O99A9W3J', 'pasajeros', -4576997, 5, 6, 8),
(454, 'Fijadoci', 'MPQEV1557775Y8O', 'carga', 1066520, 3, 28, NULL),
(455, 'Stormy Rihifu', 'Y25W0700A999160', 'combate', 10, 1, NULL, 28),
(456, 'Fazewu', '74KU090N0T22550', 'pasajeros', -5116269, 12, NULL, 4),
(457, 'Zeppeling', 'Q07UPUO7NED1VG1', 'pasajeros', -8511, 1, NULL, NULL),
(458, 'Mosokinuvu', 'TQ0CM87EKJ0MQD0', 'pasajeros', -6345024, 338, 27, 48),
(459, 'Omuguguga', 'Y771VUY02199497', 'carga', 0, 5, NULL, 82),
(460, 'Lil'' Iniqu', 'X5NI5ZI5E7VJ07D', NULL, NULL, 5, NULL, 75),
(461, 'Opejusu', 'GYZ768ASB0XYJIH', 'carga', 4479, 1, 2, 1),
(462, 'Condor', '4F7F71O25T28163', 'pasajeros', NULL, 68, NULL, 3),
(463, 'Silver Condor', 'JRGSP5J97OI5YH2', 'pasajeros', 1757449, 10, NULL, 5),
(464, 'Grand Oqezoju', '4STQ7G99GCY1K7B', 'carga', -25404, 0, 28, 43),
(465, 'Stormy Kere', '1NT0X5PFP2RE51P', 'carga', -4711426, 15, 5, 42),
(466, 'Ziki', '47986CE63J327C7', 'pasajeros', 1701, 5, NULL, 93),
(467, 'Esicibupiku', '02W38197UQ8X56A', 'carga', -3787746, 8, NULL, 88),
(468, 'Silver Dijezabicilu', 'O9GL3W9N7335I30', 'carga', 6, 4, 1, 79),
(469, 'Ikirujupida', '4RJRQ8GM7O8725U', 'pasajeros', -69, 15, NULL, 95),
(470, 'Gedogo', 'P6I3644L65V69BO', 'pasajeros', -3042194, 0, NULL, 3),
(471, 'Vira', 'DA8OQ0E60D0502F', 'carga', 4876, 4, NULL, 61),
(472, 'Tepusa', '5WH6NYJK8951RO7', 'combate', 9087862, 2, 7, 52),
(473, 'Qazuquvuto', '2L245ZE8X25Y6CK', 'carga', -6270495, 0, 12, 79),
(474, 'Taluko', '4AS1N0687606IUM', 'carga', 3768104, 9, NULL, 76),
(475, 'Condor', '9Q0RDF238C9TU2V', 'pasajeros', -2, 0, NULL, 39),
(476, 'Silver Bojeza', '2JNMC5U2695N6A3', 'carga', -2914, 1, 25, 85),
(477, 'Golden Nofiqipexe', 'ORU1U0W99G83U7N', 'exploración', 3947861, 1, 15, 11),
(478, 'Elahamiki', '8WQ2264X97LRT5X', 'combate', -5219175, 1, 47, 73),
(479, 'Vovirive', '85U3IO6QF1P4QEP', 'pasajeros', -7069951, 10, 13, 18),
(480, 'Vuxafezeqa', 'B767BZHWUV48H7Y', 'carga', 734, 0, 8, 82),
(481, 'Little Jedevozuru', '4TS0633015896AJ', 'pasajeros', -339, 3, 10, 77),
(482, 'Shiny Beguxu', '1D11LMK6ZAQS546', NULL, NULL, 10, 12, 20),
(483, 'Kiracufuhe', 'Y37M6G6H2307XV9', 'pasajeros', 6369985, 1, NULL, 26),
(484, 'Stormy Vekopo', '08UF4X4FC799AN4', 'carga', -1479709, 1, 40, 8),
(485, 'Oluzo', 'M68X4ZI6ADP5QP2', 'carga', 90, 3, NULL, 2),
(486, 'Oqequ', '6YW279LGUS08WYT', 'carga', -3, 12, 36, 59),
(487, 'Zeppeling', 'LPV4ZR9BGM177R9', 'combate', 439349, 0, 14, 81),
(488, 'Stormy Isoqeza', 'U9W8MMR62XKA50V', 'carga', 83, 1, NULL, 75),
(489, 'Alofixi', 'W69NM5CWXR450X2', 'carga', 3265, 3, 31, 97),
(490, 'Pexivubu', '390S51JH72OTYX0', 'carga', 4847564, 1, 27, 91),
(491, 'Gimecave', 'G4G01N9F0XFSO34', 'carga', -2146393, 3, NULL, 5),
(492, 'Wofeju', '3184427I46KI8U6', 'carga', -4972277, 136, NULL, 21),
(493, 'Lil'' Fefisa', 'Z74C19148M930RY', 'carga', -4915086, 5, NULL, 96),
(494, 'USS Xesodo', '607HKUOHHM3MC02', 'pasajeros', -6, 0, 15, 68),
(495, 'Silver Fish', '2TOB8N73PX7QN3X', 'carga', -4778274, 13, 1, 31),
(496, 'Saqisuce', '54604F73RO87F0P', 'exploración', -862407, 0, NULL, 96),
(497, 'Grand Soxogicuja', 'A08AK6HJK923A86', 'carga', 8722862, 0, NULL, 63),
(498, 'Big Gu', '95QPF624F67U38M', 'pasajeros', 8195849, 0, 49, 92),
(499, 'Cloudy Votoho', '9U96W71188UD0JS', 'exploración', -47, 297, 37, 24),
(500, 'Eagle', '8X417O2H4EBBXC2', 'combate', 13, 0, NULL, 23),
(501, 'Bofaroxeva', 'H4P464LY2M2GX39', 'carga', NULL, 14, 32, 34),
(502, 'Silobi', '3009G8RTY4VF6FR', 'pasajeros', -1692369, 1, NULL, 69),
(503, 'Little Minalezila', '3G5Q0940328219V', 'carga', 9176428, 0, NULL, 39),
(504, 'Silver Deholerunu', 'RQ2CQ67R12MV0KP', 'exploración', NULL, 15, 12, 97),
(505, 'Grand Jivuja', 'K366WFX538ZD2WS', 'carga', -4320957, 12, NULL, 14),
(506, 'Grand Fox', 'A703D268M00J2KY', 'pasajeros', 7019125, 0, NULL, 15),
(507, 'Lil'' Dipafa', 'NGT19RF391F4945', 'pasajeros', 7, 0, NULL, 79),
(508, 'Big Omune', '3CZ7N80XD40199Q', 'exploración', 8640448, 329, 41, 5),
(509, 'Tiheta', 'Y60H5070OPT5902', 'carga', -31421, 0, NULL, 37),
(510, 'Lil'' Naxo', '5F3R08C9Z2V7BRU', 'pasajeros', -959, 122, NULL, 3),
(511, 'Lil'' Qajipa', '102VLTVD8GWFY37', 'pasajeros', -2, 4, 47, 84),
(512, 'Sopodi', 'N0N99JX88X415W3', 'combate', 6814, 268, 20, 71),
(513, 'Lil'' Navulixu', '19YLG7NX2Y000BE', 'pasajeros', -7950547, 13, NULL, 16),
(514, 'Wewazu', 'WZ0JQ10637H733Q', 'pasajeros', 420396, 10, NULL, 81),
(515, 'Eagle', '2KH3K9AR2S9FU64', 'carga', 349965, 15, NULL, 86),
(516, 'Cloudy Sokurigu', '4I5BOPAWH167BO2', 'pasajeros', -5096140, 347, NULL, 54),
(517, 'Zeppeling', '05LV020DOC59FNI', 'carga', -495, 10, NULL, 61),
(518, 'Grand Eagle', 'X9HT11CSZDJDKR1', 'carga', NULL, 15, NULL, 58),
(519, 'Stormy Qivuje', 'SF6N7D761E79M31', 'carga', -9782187, 8, NULL, 22),
(520, NULL, 'H8H258O4B84WFP7', NULL, NULL, 0, 32, 74),
(521, 'Lil'' Vocaxa', 'IMQ51KP4D1365YH', 'pasajeros', 5154417, 5, 48, 88),
(522, 'USS Cirizi', 'Z55F63K101J3M69', 'carga', -9700, 1, 13, 5),
(523, 'Fox', 'IU1403964KX0CYK', 'carga', 55, 0, 23, 40),
(524, 'Bolo', 'B280X7Q2G91152O', 'carga', -7668852, 1, 48, 97),
(525, 'Lil'' Dozifozuru', '8R5RQIQ9W0OO1X2', 'combate', 1, 12, NULL, 1),
(526, 'Golden Lujafu', '50812D907A0C0M1', 'carga', -7301623, 7, 46, 99),
(527, 'Cloudy Qurumecedo', 'K9V9XQ8777Z2IZ8', 'carga', -6884914, 11, NULL, 58),
(528, 'Stormy Fox', '6FYAS20TX8X1362', 'combate', -1127010, 0, NULL, 42),
(529, 'Udirarusuxu', 'TOKXO9RDA2A6Y4Y', 'carga', -1346053, 305, 36, 9),
(530, 'Lil'' Oqosa', '12N5CLNX8AFKX7X', 'exploración', 646, 0, 45, 70),
(531, 'Gimodico', '431KNK8MFX46G2A', 'carga', 2, 294, 39, 15),
(532, 'Bucoku', 'SO8XR084K52RU0G', 'pasajeros', 83, 1, 3, NULL),
(533, 'Grand Vorube', 'N6N3KH74733T991', 'pasajeros', 4940459, 6, 28, 38),
(534, 'Gemuwiku', '3VD726CAXIJOM5N', 'combate', 3478924, 2, 38, 13),
(535, 'Big Nubipe', '9O5E3Z56191RUHD', 'exploración', 1990243, 9, NULL, 88),
(536, 'Cewubegodi', '73ME4LTJWZ6RH64', 'carga', 9560739, 13, 31, 35),
(537, 'Stormy Butterfly', '9500D243860236J', 'pasajeros', -5932063, 0, 3, 100),
(538, 'Waxetoke', '621AT89ZO13Y8CC', 'carga', -3504380, 14, NULL, 56),
(539, 'Stormy Ewasivuxi', 'L4OL5Y846X52293', 'exploración', -9129237, 13, NULL, 68),
(540, 'Colezeju', 'ZN5Z2V571ECL82N', 'pasajeros', -536, 0, NULL, 87),
(541, 'Dokugo', 'YI14JOC1TC8Y8R5', 'carga', 6, 3, 26, 8),
(542, 'Daloni', 'JFGIO12OQJPLFWR', 'pasajeros', 17, 0, NULL, 100),
(543, 'Little Ulabeleqe', '53M4WKU9NM0EN8V', 'combate', -8554115, 0, 20, 100),
(544, 'Jafefera', 'Q7O5U4P295GDVIC', 'pasajeros', 2248921, 4, 12, 39),
(545, 'Lil'' Une', 'NR8XT4WK23T78T9', 'carga', -8055650, 11, 33, 98),
(546, 'Bezimuziha', 'AHHAAV1U6636KM1', 'pasajeros', 3216304, 14, NULL, 10),
(547, 'Pulasepe', 'D653590504837UP', 'carga', -9, 5, NULL, 65),
(548, 'Qukana', 'S028D3AKZ3EGAR9', 'pasajeros', 6226755, 0, NULL, 12),
(549, 'Big Elodi', 'HFCMY13BP3SB1W2', 'carga', -71, 6, NULL, NULL),
(550, 'Morefime', '9X7K779N82R2NTA', 'carga', -3862348, 40, NULL, 68),
(551, 'Silver Gutogi', 'JAF1D27Z7661FN0', 'carga', -6939488, 0, NULL, 25),
(552, 'Kimewoma', 'V5Q057200J47743', 'carga', -7314323, 3, 33, 47),
(553, 'Golden Duda', 'T8Z7V33JV533TD8', 'pasajeros', 9, 2, NULL, 18),
(554, 'Sesiwase', 'G883FFKEG9R54B0', 'carga', 3175, 106, 6, 43),
(555, 'Golden Cobukiqo', 'YO5UE55HBO1F17F', 'combate', -1, 11, 27, 93),
(556, 'Vutufegu', 'RW0XW3R5M6L8D23', 'exploración', -593537, 1, NULL, 94),
(557, 'Lil'' Feju', '8YSIYA98HD272HB', 'exploración', -8692780, 1, 12, NULL),
(558, 'Cloudy Xukuzo', 'V8318067IA44R60', 'carga', 7542825, 362, 37, 86),
(559, 'Giza', 'N8NO02936JIU5LJ', 'carga', -949, 197, NULL, 69),
(560, 'Shiny Fomi', 'WFC2V0K2471D9S7', NULL, NULL, 15, NULL, 79),
(561, 'Ranatuxane', 'AP115471AT35E3X', 'carga', 4185869, 6, NULL, 45),
(562, 'Jovivoze', 'L3D19PP1034K1U5', 'combate', 1100299, 200, NULL, 89),
(563, 'USS Danadovo', '1C43OI1ES5I7381', 'pasajeros', 657, 1, NULL, NULL),
(564, 'Negocope', '1F5D0C0K35U9AE1', 'carga', 8511715, 0, NULL, 90),
(565, 'Bezica', 'D18N2149720N2WT', 'combate', 7290547, 69, NULL, 62),
(566, 'Unitoku', '3B60A2WVY306Y9C', 'carga', 2382289, 13, 39, NULL),
(567, 'Silver Vicaxicome', 'J459UZ4R037Q4X0', 'carga', NULL, 14, NULL, 86),
(568, 'Golden Eagle', '26E7NZ88BN86I05', 'exploración', 8917152, 0, 5, NULL),
(569, 'Little Newacu', '3A93S1L5942HT22', 'combate', -6015528, 301248, 10, 31),
(570, 'Deqewo', 'KWLLA1A85958V42', 'pasajeros', -481555, 1, 5, 97),
(571, 'Lil'' Gehacege', '6JS7BGUW8LMG455', 'carga', 6103878, 4, 14, 45),
(572, 'Efesexugi', 'TEU1IW362IOZL29', 'carga', -767, 1, NULL, 8),
(573, 'Eagle', '7I5Q9B6V1D87ZM4', 'pasajeros', -1213503, 5, NULL, NULL),
(574, 'Golden Lapapabisu', '4VE22O3WNZG0792', 'carga', 5014255, 8, NULL, 16),
(575, 'Ufowije', '2GT1HDOFA68T77G', 'pasajeros', 1297043, 6, 7, 45),
(576, 'Ito', 'Z6J6NKWL78NK4BD', 'combate', NULL, 0, NULL, 6),
(577, 'Silver Sako', 'X660E8N7W619SNL', 'carga', 1246473, 0, NULL, 8),
(578, 'Ofobo', 'S55L4K9Y70195NP', 'combate', 4706549, 0, NULL, 22),
(579, 'Lil'' Konoho', 'K0J7QM405DXV544', 'carga', -1052547, 3, NULL, 67),
(580, 'Big Qede', 'TP6PZ195188XKSX', 'pasajeros', -8421909, 1, NULL, 49),
(581, 'Zeppeling', 'GJ69B1YU228QC22', 'carga', -1905508, 1, NULL, 37),
(582, 'Fish', 'PX0C791IKG332S3', 'carga', 721761, 5, 22, 39),
(583, 'Stormy Condor', '2DDAGS073WK0X47', 'pasajeros', -5532941, 14, 5, 97),
(584, 'Fox', 'Q8H8424I727Y3S2', 'pasajeros', 3936575, 1, 41, 3),
(585, 'Lil'' Nune', '3RBBBR0FJ4828K6', 'pasajeros', -8848768, 222, 48, 4),
(586, 'Stormy Wuvuxi', 'L3GT1B046UP4226', 'pasajeros', 3653846, 0, 32, 26),
(587, 'Stormy Butterfly', '2191C325OE305K6', 'pasajeros', 9035689, 7, 43, 66),
(588, 'Mesalumo', 'M3CRBWOYB8XA315', 'pasajeros', 5754743, 2, 14, 13),
(589, 'Silver Zeppeling', '71CTRRYX8BY4I2S', 'carga', NULL, 4, 28, 93),
(590, 'Shiny Eagle', '650T6JWCK8N90Z2', 'pasajeros', -923, 12, 34, 47),
(591, 'Sobezo', '2G4E5LR7C68V252', 'combate', 1278709, 7, NULL, 71),
(592, 'Worako', 'O5P894D0X9CDKH9', 'carga', -9045409, 1, 23, 26),
(593, 'Little Vidixihe', '6WSAB5CWV73MYE9', 'carga', -4957736, 3, NULL, 80),
(594, 'Shiny Asole', 'KF791I9DEN0VSFJ', 'pasajeros', -4603511, 47, 3, 24),
(595, 'Grand Zepucilava', 'JBV45MDFHE6P8PM', 'carga', -8207230, 415, 28, 39),
(596, 'Xurabelipu', '03P17379E81KV6X', 'pasajeros', 8331304, 9, 5, 16),
(597, 'Dowudonukuhu', '3MESZD38760G305', 'pasajeros', 5141, 0, 24, 100),
(598, 'Big Bupegedu', 'KT9CI0WA777N310', 'carga', 158, 171, NULL, 63),
(599, 'Lenexukiva', 'CYK118IK2X6GK4J', 'combate', NULL, 4, NULL, 76),
(600, 'Silver Ijimabo', 'V7424HLZQT127I3', 'pasajeros', 8714998, 7, NULL, 67),
(601, 'Xefiludewo', '38SVC6C0935JW3W', 'carga', 0, 0, NULL, 36),
(602, 'Cloudy Guwepa', '2LX5UO0FY0215W2', 'pasajeros', -5477233, 9, NULL, 22),
(603, 'Grand Eagle', '2J116Q3XW596L1P', 'carga', 4142, 1, 25, 82),
(604, 'Duvoro', 'Y6D96J33468202H', 'exploración', -286, 1, NULL, NULL),
(605, 'Buqaquvu', 'ICC15Q19H83D1EQ', 'pasajeros', -2150962, 1, NULL, 22),
(606, 'Stormy No', 'T7TE09SI667PF24', 'exploración', -5724251, 0, 10, 11),
(607, 'Little Eagle', 'KTZK68783E0QJH0', 'carga', 544753, 0, 50, 44),
(608, 'Zeppeling', 'VL9BTN6N663298A', NULL, NULL, 9, 15, 95),
(609, 'Golden Dege', 'E3452A6151KOS4H', 'carga', 7888118, 3, 2, 97),
(610, 'Shiny Ibuluze', '2764VZUDW71R2PY', 'combate', NULL, 2, NULL, 9),
(611, 'USS Fox', '0QD1GEZ85534N26', 'carga', -3759459, 1, NULL, 16),
(612, 'Qorugituza', '84JVXU37PDJ06KJ', 'pasajeros', 7025079, 11, 47, 78),
(613, 'Cafarikaso', '95IZR3QTW6Q358L', 'exploración', 2667448, 3, NULL, 31),
(614, 'Golden Condor', '1NS2YDQ810AL8E3', 'carga', -8395983, 282, NULL, 37),
(615, 'Fufeda', 'R757STII41J8NV2', 'pasajeros', -12, 11, 29, 2),
(616, 'Zagucede', 'RKA19U7S875QJVD', 'carga', 1565, 15, NULL, 91),
(617, 'Zeppeling', '9HVWSA516IA741G', 'carga', 986, 1, 22, 35),
(618, 'Little Pehoviwa', 'VO3S4K2NRBO5WY7', 'carga', 653, 0, NULL, 54),
(619, 'Emile', '19K711VI513O47N', 'pasajeros', 4549078, 0, NULL, 74),
(620, 'Stormy Ezugocuju', 'V4R053KV2131K4R', 'pasajeros', -545, 308, 20, 67),
(621, 'Cadexusoki', '8N72XGC6U54GS7R', 'carga', 8, 14, 13, 59),
(622, 'Fox', 'HYMYD9G783K9YFZ', 'carga', -6417689, 1, NULL, 26),
(623, 'Silver Omoluha', '1T21GZN9XJ6GC6L', 'carga', 2955, 14, 11, 39),
(624, 'Golden Xuzano', 'TRO77RAWK3942A9', 'carga', 240, 3, NULL, 8),
(625, 'Hebamuji', '195S9482L6Q4Z3I', 'carga', 390, 6, 34, 4),
(626, 'USS Zeppeling', '1J13A670HA3102X', 'pasajeros', 75, 15, NULL, 53),
(627, 'Shiny Icuguco', 'IC3CR35S5C0UAX4', 'pasajeros', -2704511, 4, NULL, 12),
(628, 'Lil'' Pericenupa', '6KN67780QF9O765', NULL, NULL, 39, 5, 66),
(629, 'USS Zuvomuqi', 'DJ7T61G8YL5DP18', 'carga', 7848271, 7, 5, 89),
(630, 'Lacuwiha', 'CKAU96E1I0G1X4H', 'combate', -6197453, 2, NULL, 78),
(631, 'Hubizina', '63063AO1278075Z', NULL, NULL, 100, 33, 72),
(632, 'Lil'' Condor', 'R515NE237GR82N8', 'exploración', 6691839, 1, 33, 45),
(633, 'Uruna', '3260EC087I0XAM3', 'exploración', 8618087, 6, 15, 23),
(634, 'Gasaqa', 'J4X13X8009HFLZ0', 'carga', 4754, 427, NULL, 6),
(635, 'Grand Rinexo', 'AK027P089E0QRII', 'exploración', 139880, 435, NULL, 57),
(636, 'Cloudy Ehogi', 'B69K62DIE47Y0U7', 'exploración', 23, 11, NULL, 63),
(637, 'Big Eagle', 'DH2WBEZ8619V759', 'exploración', -7, 10, NULL, 72),
(638, 'Runele', '9YCQQ350G0T3U51', 'carga', 4503, 8, NULL, 55),
(639, 'Zuhija', 'U8DL317DZZ9S0OS', 'carga', 4618596, 2, 23, 83),
(640, 'Lil'' Viwimebu', '70286OK453EK96W', 'exploración', NULL, 15, NULL, 53),
(641, 'Cloudy Olera', '4S2P9201FA8AD43', 'pasajeros', -9002179, 324754, 11, 60),
(642, 'Shiny Talora', '116F0GD5021LYWB', 'combate', 3607030, 140, 42, 40),
(643, 'Golden Bofefucodu', 'V6J89NE325PL35B', 'pasajeros', 2628213, 244, 18, 2),
(644, 'Cirakojewo', '90425ZU6S8F0K27', 'combate', -5924886, 0, 3, 45),
(645, 'Shiny Dunolo', 'PM659151E88J3UK', 'carga', 0, 0, 9, 18),
(646, 'Little Kakeha', '3E4GU4S063KWHG3', 'pasajeros', -1173, 5, NULL, 90),
(647, 'Golden Tuvebihe', '19B6WD31I9SM9JN', 'carga', 4947379, 15, NULL, 81),
(648, 'Condor', 'WU2MJB6EQT1YBX7', 'combate', 3583118, 5, NULL, 6),
(649, 'Cloudy Tuduwu', 'W0LIH73R2T6T20X', 'carga', 2, 3, NULL, 70),
(650, 'Arecaka', 'XZ085Z0BQP258GT', 'carga', 7373668, 1, 26, 11),
(651, 'Uxuce', 'M8N6168MS052085', 'carga', -371, 13, 14, 77),
(652, 'Big Mifacuxe', 'Y8C1193ITVO2OX2', 'carga', -887, 0, NULL, 17),
(653, 'Agusawaru', 'U7W8KU41JETSR0D', NULL, NULL, 3, 15, NULL),
(654, 'Stormy Fox', '6M57475T259F9WO', 'exploración', -50, 255, 19, NULL),
(655, 'Jufubawo', '67XP866GK3O2SYV', 'pasajeros', -6727801, 45, 4, 93),
(656, 'Paxucihi', '5MG49594DT97M55', 'exploración', -2974678, 81, 3, 84),
(657, 'Siqanodi', '3IC7O2V88O4D3Y8', 'carga', 3977720, 0, 6, 3),
(658, 'Lil'' Nopesi', '0344HCVJ9198M0G', 'pasajeros', -193, 15, NULL, 41),
(659, 'Silver Cawo', '6JRUS3KP2OQ6TID', 'carga', 4, 15, NULL, 1),
(660, 'Toha', '4253NME50089F4V', 'combate', -9375060, 14, 38, 83),
(661, 'Stormy U', '8C9IR0ZB609FWD8', NULL, NULL, 14, NULL, 41),
(662, 'Silver Butterfly', 'O8H7KOGK140WJ96', 'carga', -7891596, 0, 50, 82),
(663, 'Buwisere', 'L5HH8E022665S23', 'exploración', 1534764, 0, 45, 7),
(664, 'Muhafu', '7YJ6M67960249FH', 'carga', -129, 12, NULL, 2),
(665, 'Subude', 'VUUVQ3Q65M1KZU5', 'pasajeros', -6108680, 8, NULL, 98),
(666, 'Big Pupoxa', 'HFRNBM592FFLRDO', 'carga', 3430050, 0, 1, 44),
(667, 'Lil'' Muxuvo', '9I766CQU4184L1C', 'carga', -1, 9, NULL, NULL),
(668, 'Jurezi', 'Z7BUK47BX6YKY84', 'carga', 2788004, 7, 33, 46),
(669, 'Wuluhege', 'UPB4XF2N8T3M3W8', 'combate', -4948045, 127, 42, 73),
(670, 'Lil'' Overe', 'B0D3O7PBH96XWQ4', 'exploración', -5715796, 8, NULL, 8),
(671, 'Kuqanaje', 'C6B5Z200U9I612M', 'exploración', 6005982, 11, NULL, 76),
(672, 'Beheresa', 'J5IE36JIGGJ3UT3', 'exploración', 5003982, 9, 24, 71),
(673, 'Big Qagebitoce', 'CWA08CX8445L7G0', 'carga', -3837336, 1, NULL, 74),
(674, 'Eagle', '9PI79E3IXS399L7', 'carga', 3986, 11, NULL, NULL),
(675, 'Siziqu', 'N7135VHT643220A', 'carga', 8716575, 428, 14, 69),
(676, 'Fish', '2I27V453721VDGA', 'carga', -4026044, 10, 3, 35),
(677, 'Cuqahu', 'M74YBFT32RIEWDG', 'carga', -9810649, 0, 49, 73),
(678, 'Nate', 'L36KNK6G4M5402N', 'pasajeros', 64, 1, NULL, 52),
(679, 'Eti', 'FUP625EY481T51Y', 'exploración', 4555672, 13, 49, 81),
(680, 'Big Odaro', '37G7IA52XL6G79F', 'carga', 2738614, 10, NULL, 14),
(681, 'Epa', 'Y3D2V3S4I6KP17T', NULL, NULL, 4, NULL, 30),
(682, 'Big Izekimi', '2Z8EU7Y7PJSALH1', 'pasajeros', -5621990, 10, 32, 70),
(683, 'Silver Fedaci', '5051JEE9TA76P6Y', 'carga', -9622333, 9, NULL, 67),
(684, 'Shiny Dutewogavo', '10E6FSE8J3K079H', 'exploración', -7696785, 15, 2, 55),
(685, 'Shiny Rapuwo', 'G300Q6S5HY30KU0', 'carga', 1847819, 13, 45, 20),
(686, 'Fox', 'F604BL70RL350GB', 'carga', 7974247, 7, NULL, 60),
(687, 'Lil'' Fapaviko', '02LV94B6J00CJA8', 'pasajeros', -3, 9, 10, 46),
(688, 'Silver Fuzawo', '228LL1RL7BG189P', 'carga', 4178006, 8, NULL, 72),
(689, 'Ede', 'GN1SMX67FQ9US57', 'carga', -216, 0, NULL, 70),
(690, 'Cloudy Adofuzineca', 'I893G4F6T4SUKY7', 'exploración', 0, 186, NULL, 77),
(691, 'Emehaguzi', 'G2QU1IRU16WMC0A', 'carga', 771, 4, NULL, 83),
(692, 'Jevugi', 'J0Z7626CQB4T452', 'carga', -6557721, 427, 27, 86),
(693, 'Grand Fox', 'M76N3FN2KJ5CVC1', 'carga', 95, 2, NULL, 24),
(694, 'USS Cisogogotu', 'MQ0T718Y7Z7QA27', 'carga', -85555, 115, NULL, 98),
(695, 'Lil'' Uhimupapu', 'M833BO5L90417S8', 'pasajeros', -7692, 0, 13, 99),
(696, 'Little Condor', '8KSCFJ4WO28RI74', 'carga', -82, 217, 36, 2),
(697, 'Ajelebuta', '4W58ZI77X74B316', 'carga', -8777566, 4, 30, 97),
(698, 'Piwiquge', '6M8QS2ZG47M3336', 'exploración', 5269, 0, NULL, 21),
(699, 'Little Letacoha', '62M22UUH456PRD8', 'carga', 5791881, 9, 18, 36),
(700, 'Little Eagle', '66TAB0FX20W5LHJ', 'carga', -15, 1, NULL, 28),
(701, 'Little Hanacofo', '0GV7FXA6A465WW5', 'carga', -586, 9, 31, 8),
(702, 'Tede', 'VCAC7001YNQXF8V', 'carga', -6878030, 0, 47, 66),
(703, 'Memabo', 'H5205F00L5V5909', 'carga', -4139031, 32, 36, NULL),
(704, 'Negedacezewe', '5K9I11RPFH0OKT7', 'pasajeros', -9272532, 45, 15, 3),
(705, 'Lil'' Vifiwova', 'M90BL7B5824411T', 'carga', -1934662, 5, NULL, 90),
(706, 'Silver Puxaze', 'PWL3CAZXNT02V68', 'combate', 7352070, 10, NULL, 16),
(707, 'Isuto', 'IUL07D097YWZSDM', 'carga', 2914374, 149, 43, 18),
(708, 'Gu', '048C7M707WUM69R', 'pasajeros', NULL, 1, 18, 81),
(709, 'Lokivoha', '28RW68W0I901KU9', 'exploración', -1224408, 50, 17, 20),
(710, 'Fox', 'GCB0ZI4ESNURXL0', 'exploración', 4895971, 1, 11, 96),
(711, 'Condor', 'C416V240BL5EAGG', 'carga', 7227316, 8, 22, NULL),
(712, 'Ixato', 'E951F0E221C5628', 'carga', -1551313, 277, 25, 77),
(713, 'Qu', '36PO644679F207Z', 'carga', -7624004, 1, 21, 60),
(714, 'Febumuke', 'CLLXYQE0FIDKGRL', 'carga', -8427453, 30, NULL, 8),
(715, 'Vafiride', 'U0IH9P98F2T99M2', 'carga', 50, 0, 7, 32),
(716, 'Qukikeko', '67X29JJBC0M53O9', 'carga', NULL, 0, NULL, 53),
(717, 'Big Nutadezi', 'WFH8XBFSN2KFUD1', NULL, NULL, 10, NULL, 68),
(718, 'Cloudy Eagle', 'CNUVDU7O8M525K0', 'pasajeros', -4066, 4, 20, 61),
(719, 'Grand Luhiqohu', 'W856H0N12T76CJX', 'carga', -5428788, 1, NULL, 37),
(720, 'Silver Remane', '7OC14LG9IX71HF5', 'pasajeros', -17, 7, 47, 8),
(721, 'Stormy Cepunemo', 'GJX9O0I1OJLJC2P', 'pasajeros', 48505, 15, 41, 15),
(722, 'Lil'' Kide', 'YAYB4G5BOWJS0M4', 'combate', -5825772, 23, 6, 17),
(723, 'Mulebesugi', '4RV15T973QA3N1I', 'carga', -1830817, 2, NULL, 3),
(724, 'Condor', '373U6W000T62Y92', 'combate', -8173179, 97, 5, 28),
(725, 'Fixafeluce', 'A5T216666UH35GI', 'carga', -9895800, 10, NULL, 9),
(726, 'Stormy Eagle', 'AXIHN5V8M4V5E5I', 'pasajeros', 5633799, 3, 6, 81),
(727, 'Big Ra', '69MP0411N5SZBJQ', 'pasajeros', -9773408, 220, NULL, 36),
(728, 'Zeppeling', '57WTYMZR0DE18T1', 'carga', 9999349, 10, NULL, 44),
(729, 'Xexuhufe', 'H2T66ZRX9ATW65M', 'pasajeros', -3, 4, NULL, 27),
(730, 'Nijirohu', '901T6CA8T690P5A', 'pasajeros', -8292, 1, 19, 9),
(731, 'USS Eagle', 'TP376PSGI0HIF88', 'combate', -351, 360, NULL, 9),
(732, 'Lil'' Purita', '8QPCW930J05P853', 'carga', 80, 8, NULL, 7),
(733, 'Rawa', 'NSS0K30QZT62AM0', 'carga', NULL, 8, NULL, 54),
(734, 'Shiny Iromugi', '38Z0K419W8494LC', 'pasajeros', 1629526, 0, 5, 44),
(735, 'Grand Juqagopu', 'W5L2WZ09F9W53ML', 'carga', 7286035, 1, 32, 99),
(736, 'Golden Condor', '7G799L4Q82Q180B', 'pasajeros', -9772288, 13, NULL, 84),
(737, 'Xexihedu', 'I8O1J5DD0OP35PL', 'pasajeros', 1630828, 4, NULL, 36),
(738, 'Qupoxo', 'GRJT879CPE1POT5', 'carga', 1890, 6, NULL, 62),
(739, 'Cloudy Butterfly', '328Q899J3W77Y71', 'carga', -1587472, 15, NULL, 82),
(740, 'Lil'' Sivipefa', 'WF47E888D86D7C0', 'carga', 1080794, 13, 3, 87),
(741, 'USS Oje', 'O24Q59G8W91XB1A', 'combate', -756, 427, 4, 18),
(742, 'Fexomakalu', '2B2CJUR308RLXW3', 'carga', 46, 1, NULL, 41),
(743, 'Tahe', '1CD08700AN7Q3S2', 'combate', -8411846, 11, NULL, 10),
(744, 'Ona', 'FR9TFLV1UYPC7SF', 'carga', 7484471, 11, NULL, 41),
(745, 'Ofimega', 'L888U3NOI89U154', 'carga', 6, 0, 30, 5),
(746, 'Muqaho', 'R3S0S0R6H6HN358', 'carga', -222, 3, 23, 57),
(747, 'Silver Zutuhaxo', 'M915620G64I15QI', 'pasajeros', 2463, 10, NULL, 54),
(748, 'Hi', '0H2OK190E2T109C', 'exploración', 9249684, 280, 23, NULL),
(749, 'Ubebo', 'PH8NL19S9A37G65', 'carga', 7713977, 414, 41, 25),
(750, 'Jodi', '231021SB2TA09U0', 'pasajeros', 6386435, 153, NULL, 15),
(751, 'Xekice', 'T46LGHECVE5O6P2', 'carga', 3334973, 1, NULL, 25),
(752, 'Big Kifiji', '0307O97F133X1J8', 'pasajeros', 46, 238, 2, 3),
(753, 'Stormy Cidugu', 'XXGU78XLRUXZ00I', 'pasajeros', -8669525, 0, NULL, 7),
(754, 'Little Gogozenira', '603WO5459F11I95', 'carga', -9975823, 0, NULL, 27),
(755, 'Condor', '76A767JQ96N3TMB', 'pasajeros', -3697557, 14, NULL, 37),
(756, 'USS Xazeha', 'M86GP49W0SM72N1', 'carga', -6460156, 8, 48, 90),
(757, 'Big Condor', '2MCN2A7BXDD9V0Y', 'exploración', 0, 4, NULL, 90),
(758, 'Big Niterice', 'D4KVT79T045QF34', 'carga', -4, 100, NULL, 54),
(759, 'Ifazaxo', '16QRTP76YLV9BN5', 'combate', 8756160, 1, 2, 52),
(760, 'Gi', 'MBR1297QKCENXGW', 'combate', -3008701, 0, NULL, 15),
(761, 'Grand Remaxina', '41271DK47382L45', 'pasajeros', -51, 6, 18, 71),
(762, 'Xirupeke', '0H811AK125BM5B1', 'pasajeros', 6977594, 14, NULL, 76),
(763, 'Big Vuvuzi', '8IXC1O2H54T05WO', 'carga', -140452, 77, NULL, 98),
(764, 'Little Afi', '66F43XE12WX29U8', 'combate', -2913644, 3, NULL, NULL),
(765, 'Ijesiju', '1V81T2DRL0DL7Y2', 'pasajeros', 9226991, 0, NULL, 39),
(766, 'Avu', 'B1C331BU636IWTI', 'carga', -2310492, 431, NULL, 56),
(767, 'Golden Ruqugobali', '3SN9T97P3Y66YT0', 'carga', -6928871, 15, 18, 77),
(768, 'Roxo', '27FU0H57GM5N7A4', 'pasajeros', 9269, 394, 32, 41),
(769, 'Homu', '9A82L6C7XWQMZ9U', 'pasajeros', -5144341, 7, NULL, 89),
(770, 'Cloudy Condor', '6EIH0C75LAUHRU6', 'pasajeros', 5375735, 14, NULL, 23),
(771, 'Pilapihutulu', '419C207Q96T9GT5', 'pasajeros', 2311418, 2, NULL, 14),
(772, 'Sebulu', '6D5K0XCJV5V3OX4', 'pasajeros', 1498982, 0, 22, 67),
(773, 'Stormy Vage', '36P1128INY49W4W', 'carga', 6701216, 448, NULL, 68),
(774, 'Shiny Butterfly', 'KS6I0UDY85W15N5', 'exploración', 5528643, 15, 44, 82),
(775, 'Waruboxaba', '8O932ELCADHME3Q', 'pasajeros', -9563368, 10, 38, 90),
(776, 'Grand Qanuleja', 'V704JS7B0G1MM82', 'carga', 6173998, 4, NULL, 86),
(777, 'Wojewa', '4FAX00JTQ7RG2B4', 'combate', 15, 2, 15, 17),
(778, 'Stormy Zeppeling', '08GX9J96KGQ3439', 'carga', -9617301, 9, NULL, 8),
(779, 'Grand Totevanocu', 'JSL96ZHX6M687R3', 'carga', -5733470, 4, 35, 87),
(780, 'Little Nesunewa', '5L013SKWKDOQAC2', 'pasajeros', -5, 21, NULL, 33),
(781, 'Qeci', '46N38D6FX7RC96V', 'pasajeros', 8269299, 7, NULL, 57),
(782, 'Cloudy Ginova', 'KQ26I0HT42HG7Y9', 'pasajeros', -9401707, 1, NULL, 24),
(783, 'Big Condor', '1H9O647J979B6WM', NULL, NULL, 12, 38, 55),
(784, 'Eagle', 'BG47CQW0J87FU25', 'carga', -6800762, 9, 37, 71),
(785, 'Golden Butterfly', 'L11Y5H5I0QS9AZO', 'exploración', -8438201, 396, NULL, 68),
(786, 'Maqidi', 'HY0IDC32NGPM844', 'carga', 8211279, 1, NULL, 4),
(787, 'Cetenoqo', 'AJ5W4585S73356M', 'carga', 6422, 13, 3, 61),
(788, 'Little Savo', '99IQ0E95459K8W4', 'pasajeros', NULL, 12, NULL, 7),
(789, 'Condor', '5D6X21P5D4DTZ31', 'carga', 672759, 8, NULL, 29),
(790, 'Gubinife', 'QQSP3H9HR9XB96S', 'pasajeros', -2907838, 9, 28, 84),
(791, 'Cloudy Ecowo', '4HPJNMSYA71GFPS', 'carga', -3151121, 1, 17, 96),
(792, 'Grand Butterfly', 'U0HVQI310HP4QA3', 'pasajeros', 85, 4, 22, 9),
(793, 'Big Leku', 'M3FOI3CNNIMI9XU', NULL, NULL, 0, 33, 84),
(794, 'Butterfly', 'EN5WXZ6TD99YMIR', 'carga', -8558104, 10, 13, 82),
(795, 'Lilixi', 'G97WL17Y147HRYO', 'carga', 8103982, 0, 9, 56),
(796, 'Acagu', 'FYXSJGPLO932Z15', 'carga', -370268, 10, 48, 59),
(797, 'Big Wumudazu', '216869NR52G72O3', 'pasajeros', -5, 1, NULL, 100),
(798, 'Lil'' Dapo', 'CCYA35WR0OA6997', 'carga', 990, 3, 50, 40),
(799, 'Qosenevi', 'CT9Z6JJH9ZBOFI4', 'combate', -5295850, 3, 9, 31),
(800, 'Big Zupepopo', '1B86U0861I0O767', 'combate', -4758067, 0, NULL, 11),
(801, 'Cloudy Litubexu', '227X4OAS26Z3X75', 'carga', -2328668, 14, NULL, 15),
(802, 'USS Condor', '4K1409P8EP7898V', 'pasajeros', -7339553, 10, 34, 45),
(803, 'U', '6W2HK571V6YG5D8', 'carga', -5861451, 0, 20, 97),
(804, 'Mijufo', '77O9W53873051YQ', 'combate', 9213465, 11, 37, NULL),
(805, 'Big Cigezi', 'XZM46WY212OO7L3', 'carga', 8626, 9, 42, 36),
(806, 'USS Cowocawapa', 'G5GBHXDFY91K620', 'carga', 6942882, 12, NULL, 53),
(807, 'Stormy Butterfly', 'J2Q373JBB790Y7C', 'carga', 2185081, 1, NULL, 86),
(808, 'Little Ledehusi', 'E0NFFP27AJDUBF8', 'pasajeros', -15, 6, NULL, 66),
(809, 'Zifuzehuhe', 'NQDE60W5DGF3870', 'carga', 5097947, 0, NULL, 21),
(810, 'Golden Butterfly', '2IU27YVT3W70K4M', 'pasajeros', NULL, 358, 42, 34),
(811, 'Shiny Niverewu', '0A129SLBV8XE9OO', 'carga', 8991462, 1, 45, NULL),
(812, 'Silver Xucefasu', 'R0OPMS90WP6NUK5', 'carga', 3575462, 4, NULL, 67),
(813, 'Wuvivu', '1L98A2V7615779Y', 'carga', 6969920, 0, 32, 2),
(814, 'Cloudy Giqicaweka', 'PB910Y584M1VSS7', 'pasajeros', -7667628, 1, 42, 37),
(815, 'Little Umakadihi', '0P29WW0Q40795Z6', 'exploración', -8998738, 4, NULL, 50),
(816, 'Wewazu', 'F2D04L5ZH4C16D9', 'carga', -244, 14, NULL, 64),
(817, 'Golden Mufevehe', '0B058NL9DTFEFA6', 'carga', -5515456, 0, 5, 87),
(818, 'Xupetinocu', 'YT731Y84G6V5U38', 'combate', -1, 1, NULL, 21),
(819, 'Fipofigu', '4XI176YBV4Y7E3Y', 'carga', -647, 137, 1, 68),
(820, 'Zocafodeso', '5N2TL67L9246NVU', 'carga', 9247184, 0, NULL, 45),
(821, 'Lil'' Katicabe', 'Q2Z3I3ZY232972N', 'pasajeros', 6865143, 1, 27, 31),
(822, 'Rojewu', '46P7R9KZ144V6QQ', 'carga', 7336506, 1, NULL, 92),
(823, 'USS Ola', 'OXM4L64B5K69MIX', 'exploración', -8149152, 0, 12, 27),
(824, 'USS Butterfly', '60ACW18TS2B0NH3', 'pasajeros', 6806684, 3, 28, 12),
(825, 'Badefaxe', 'HH7QMFL7A335ADF', NULL, NULL, 0, NULL, 84),
(826, 'Shiny Eagle', 'GQ38SX4NYIK70E4', 'exploración', -47, 12, NULL, 1),
(827, 'Grand Obapogicobi', 'WZ5H67KHTCAQE29', 'carga', 9569746, 1, 15, 33),
(828, 'Little Nisihice', '61WAGBQ44I11JC9', 'carga', NULL, 14, 2, 57),
(829, 'Qojima', '68NW4F0CPL5GHG7', 'carga', 3668748, 12, NULL, 86),
(830, 'Silver Fish', '4G9XDB1EGLP6460', 'carga', -7040, 5, 9, 85),
(831, 'Texicu', '25311KZ11MBN135', 'pasajeros', -8188875, 14, NULL, 37),
(832, 'Ojixige', '60QV318503J2U8W', 'carga', -4687137, 14, 19, 54),
(833, 'Silver Liceqewu', 'IR2O235516NKP26', 'carga', -8, 0, NULL, 95),
(834, 'Warokami', '2M623QJM6Y16FO9', 'carga', 2314280, 4, 45, 34),
(835, 'Vawasu', '7BUHO25UT8R80RU', 'combate', -9803982, 12, 34, 24),
(836, 'Va', 'I77426256MJLP1A', 'pasajeros', 2768052, 149, 44, 14),
(837, 'Little Fish', '1208A41P6U96Z5I', 'pasajeros', -6644957, 7, NULL, 40),
(838, 'Stormy Aqo', 'D0W7O5GI1CY3KE8', 'carga', 3467204, 241, 15, 89),
(839, 'Zeppeling', '3X3U82UP8H8718X', 'pasajeros', 57, 0, 12, 50),
(840, 'Grand Tizu', '8U4FN697191LZ85', 'carga', 19, 1, 6, 59),
(841, 'Wonihoki', 'F735J84P94II48R', 'exploración', 7185873, 29, NULL, 62),
(842, 'Lil'' Feci', '9H67T1NV2H0863N', 'pasajeros', -5862665, 1, NULL, 89),
(843, 'Ebukoru', '37N4H90CREY1VAZ', 'carga', 4712719, 0, 20, NULL),
(844, 'Grand Zeppeling', '5D61X39M80KTBZ8', 'exploración', -32, 8, 16, 52),
(845, 'O', '1PQZZSUH3E3GW8M', 'pasajeros', 1825360, 12, NULL, 77),
(846, 'Stormy Gixufobuxi', '86S0S057080UV20', 'pasajeros', 9871432, 15, NULL, 3),
(847, 'Grand Aqexo', 'OQW51A08300L51Y', 'carga', -47, 7, 28, 96),
(848, 'Stormy Zufe', '781GOYQ55A28BFE', 'carga', 3815485, 65, NULL, 93),
(849, 'Condor', '1G6Y0QQDB394BYH', 'pasajeros', 2, 111, 45, 91),
(850, 'Cewevaxa', 'M20A0H2I3O7G76W', 'carga', -9028096, 8, NULL, 43),
(851, 'USS Webakubu', '35NFR3R2EC47FHJ', 'carga', -6021002, 14, NULL, 73),
(852, 'Big Libi', 'X0ICA7WM0VR2HMV', 'carga', 3, 158, NULL, 49),
(853, 'Big Fish', '5GX370DB4X1GG83', 'carga', -3046489, 6, 19, 3),
(854, 'Fox', 'A3L2KBH69520Q0S', 'pasajeros', -3244031, 1, 37, NULL),
(855, 'Dapofe', '1X6X29W1I7Q65L0', 'pasajeros', -533113, 359, 8, 43),
(856, 'Mafi', 'UP58PB77L5LT99P', 'carga', 0, 13, 19, 28),
(857, 'Uxihi', '1T0KHT0U346ZB55', 'pasajeros', -7886369, 5, 28, 8),
(858, 'Uki', 'C4OKI9GTH9USTE9', 'exploración', -5287887, 6, 43, 51),
(859, 'Little Kogogececi', 'N4Y90NLR2A6N4FW', 'carga', -6, 5, NULL, 59),
(860, 'Shiny Ite', '106Z2O0MP8MKWG3', 'carga', 4406124, 6, 8, 55),
(861, 'Elika', '4R69DKXCBRW51NN', 'pasajeros', 7127162, 14, 21, 5),
(862, 'Zolilikavu', 'HW91KYFUOYQ5V0T', 'carga', -9970378, 12, 27, 78),
(863, 'Golden Palikuxu', 'H3865RIY57LOGD2', 'pasajeros', 5, 0, 49, 46),
(864, 'USS Holado', 'OQT6QUIC1XKLG6O', 'carga', -3248, 445, NULL, 50),
(865, 'Vuterumo', '963YK89095EUXS7', 'pasajeros', 3845476, 10, NULL, 70),
(866, 'Gipujizafiru', '13TYA0EL54FPI5S', 'carga', 3668991, 0, 13, 31),
(867, 'Nejumata', '37ZF02NB26JW7PE', 'exploración', -905, 5, NULL, 71),
(868, 'Lil'' Adunujocugi', 'EALQ93EJE74JYI4', 'combate', 785, 11, NULL, 43),
(869, 'Buhigi', '6E08V3SIMM0C3E2', 'combate', 814847, 9, NULL, 55),
(870, 'Iruva', 'M97VK98LO2VDPT8', NULL, NULL, 8, NULL, 9),
(871, 'Unopiho', '1E3KDXA6CY951CQ', 'pasajeros', -5, 6, NULL, 3),
(872, 'Igomi', '957S670F14X7HL4', 'carga', NULL, 1, 14, NULL),
(873, 'Bacube', '1PX38O59W024HPS', 'pasajeros', 11, 0, NULL, 92),
(874, 'Novefi', 'YP309240I8V87OZ', 'carga', -9117753, 7, NULL, 27),
(875, 'Little Wini', '4YOHWZ8A496J37W', NULL, NULL, 1, 50, 24),
(876, 'Unozana', '9WS322D7E07S2O7', 'pasajeros', 3206581, 1, 1, 75),
(877, 'Stormy Uvobi', 'FHHIJ056DZ4L77I', 'carga', -94, 434, NULL, 28),
(878, 'Ekidodi', '62IO182B4B22GP7', 'pasajeros', 9268263, 4, NULL, 88),
(879, 'Asajuda', 'UA983MQ24W88282', 'carga', 4, 1, NULL, 94),
(880, 'Eagle', '29F8163IYS2HR1Q', 'carga', 9081039, 8, 36, 95),
(881, 'Little Lahucaxu', 'K18FRDESWPFEK6A', 'carga', 105, 1, 48, 2),
(882, 'Zumuga', 'TW1E0NRSD1IG0C1', 'pasajeros', -4726, 0, NULL, 7),
(883, 'Cloudy Cozuca', '1APE14YZ03I6323', 'carga', 6730353, 3, NULL, 61),
(884, 'Kavexirohi', 'UPQ8VH4DGR0RK87', 'carga', 7743116, 241, NULL, 81),
(885, 'USS Akegu', '5984WS0QUN1FGS8', 'carga', NULL, 39, NULL, 55),
(886, 'Quxikikafu', 'QZR12I3R34F6683', 'exploración', 8661881, 8, NULL, 81),
(887, 'Little Wazawadini', '260U587T13NWX11', 'carga', -3971515, 0, 14, 33),
(888, 'Shiny Kohuzo', '2Q7GF11FW2D5262', 'carga', 50, 481, NULL, 8),
(889, 'Nufitiha', '839429IXRBKXC4N', 'pasajeros', -768, 11, NULL, 94),
(890, 'Little Ohogati', 'Y2X96I1667Q3EX3', 'carga', -4656, 1, 39, NULL),
(891, 'Usu', '0V9963NX1I5ZUFW', 'pasajeros', -9225184, 0, 2, 96),
(892, 'Esikaxo', 'T6H41C1VP8U85ZI', 'pasajeros', -7766829, 7, NULL, 40),
(893, 'Eagle', 'DB3498T1DE8D569', 'exploración', 7861776, 15, NULL, 6),
(894, 'USS Vaxoqohepu', 'CJAZ7W1PAZ4E148', 'pasajeros', -1871592, 6, NULL, 100),
(895, 'Little Izepuri', '1X36L63VZ3GI7U6', 'combate', -1509205, 0, NULL, 28),
(896, 'Cehoqadi', '0BW0483E986DP7Q', 'pasajeros', -9275511, 1, NULL, 44),
(897, 'Umosi', '374544UT2MI8TF6', 'carga', 7, 402, NULL, 12),
(898, 'Ugoma', '29L6N0D80F89Q2F', 'pasajeros', -8, 1, 35, 52),
(899, 'Xapixolusa', 'F5Y5QP10S58B1GX', 'pasajeros', -7004153, 13, NULL, 33),
(900, 'Silver Du', 'C23BC531O6909P5', 'carga', -3066782, 11, NULL, 85),
(901, 'Jovitile', 'F8243YD91S4B66T', 'combate', -1121215, 1, 4, 26),
(902, 'Silver Qori', 'BX476704662I463', 'carga', -1097399, 1, NULL, 30),
(903, 'Silver Qunejo', '76554M0N9V7JW4O', 'exploración', -3757537, 1, 6, 16),
(904, 'Igajemine', '2UA8CO2A7EX953C', 'carga', -9291235, 0, 10, 47),
(905, 'Lil'' Mirilitu', 'J99NK4KR455YQ5U', 'carga', -3787880, 5, NULL, 28),
(906, 'Gizaki', 'AP7CS8SB73209A5', NULL, NULL, 15, 21, 92),
(907, 'Xidivoxo', 'N2XRROIZ3CR0BDQ', 'exploración', -7886000, 11, 26, 1),
(908, 'Eagle', 'AL7N824DBDMPH9W', 'carga', -97, 123, NULL, 99),
(909, 'Little Fox', '11EPY6T5C2X7R4X', 'carga', -876046, 71, NULL, 39),
(910, 'Wigihufa', '047N1DSWIA4H19S', 'pasajeros', 7361954, 366, NULL, 53),
(911, 'Big Jusihosa', 'JM2J1G28Z10E140', 'exploración', 630, 3, NULL, 77),
(912, 'Fish', 'RPUSDWY855UC483', 'carga', -9, 1, NULL, 82),
(913, 'Dovibu', 'DM3BNQ35I0P9EW9', 'exploración', 192028, 0, 48, 81),
(914, 'Grand Suvirida', '5S368I3ZY950XR6', 'pasajeros', 84, 0, 36, 20),
(915, 'Silver Pibo', '372F4TKGP492U5B', 'carga', -6263601, 8, NULL, 30),
(916, 'Little Roko', '9KJ3H2LW648H4JL', 'pasajeros', 852485, 10, NULL, 84),
(917, 'Lemekubawa', 'F24L636C7G610AC', 'carga', -1, 7, 32, 91),
(918, 'Cloudy Butterfly', '4QFJ0W37BJRIJ7H', 'pasajeros', 5313825, 1, NULL, 28),
(919, 'Cloudy Tegeme', 'HXX5O3RZ11T72M0', 'pasajeros', -529, 0, 31, 91),
(920, 'Uvabodu', 'T0O507GWB4S0634', 'pasajeros', 3494000, 491, NULL, 84),
(921, 'Zeppeling', 'G010GA61540FDXF', 'exploración', NULL, 1, NULL, 93),
(922, 'Gixaheqo', '44XR4N03040VH48', 'combate', -2252559, 12, 50, 81),
(923, 'Little Pekagogidi', '6251OW70QLBN19A', 'carga', -1413902, 263, NULL, 26),
(924, 'Little Hoxizace', 'TK9LAW1MT9X6442', 'pasajeros', -78, 8, NULL, 37),
(925, 'Cloudy Oriqewi', '68C77C85SKJSD9Q', 'carga', -4223663, 4, NULL, 63),
(926, 'Golden Onicomo', 'E2K7U634030MA50', 'carga', 7574, 10, 4, 64),
(927, 'Jetanenexo', 'PQ4T7OS7OPOQW89', 'carga', -6564892, 6, 13, 19),
(928, 'Wajaca', '0J5CHDPH4A6KN67', 'exploración', 345520, 4, NULL, 8),
(929, 'Nepuqo', '579VJN4ZUR37UHR', 'carga', 1722146, 6, 9, NULL),
(930, 'Grand Xirenili', '5AS8A0L704N5MFR', 'pasajeros', 2065363, 1, NULL, 33),
(931, 'Fox', '3P6JM2W032W3IH2', 'pasajeros', -3207507, 0, 9, 75),
(932, 'Imo', 'NJ7D954B58MBRNU', 'carga', -4520983, 3, NULL, 81),
(933, 'Lulali', '3VA7O7FP46XXYPA', 'pasajeros', 5547696, 481, 49, 11),
(934, 'Gisudu', '88CPM3VGT949UVR', 'pasajeros', 9844753, 11, NULL, 19),
(935, 'Shiny Vuveja', 'C7208T828422W39', 'carga', 9, 1, 26, 73),
(936, 'Grand Omegecavo', '8TDZW5A080N1L41', 'carga', -4738793, 189, NULL, 7),
(937, 'Big Naqikawiwa', 'IKKBI6YJ948K0DD', 'pasajeros', 5435063, 6, 46, 5),
(938, 'Debica', 'FUVX5BW5W64S3ID', 'exploración', -241, 1, NULL, 80),
(939, 'Little Condor', 'UF0J5EXQ2CS877F', 'exploración', -5768078, 15, 10, 29),
(940, 'Cloudy Tahiqido', 'UYS7M60132473VA', 'exploración', 7833057, 7, NULL, 87),
(941, 'Caxisuvi', 'B7200Z65X4G0HSW', 'carga', NULL, 7, NULL, 87),
(942, 'Zeppeling', 'HF6AUK09U1NYTHK', 'pasajeros', -7762524, 0, 16, 67),
(943, 'USS Utezegisa', '351S66BS741EF3G', 'pasajeros', 1762, 166, NULL, 98),
(944, 'Wumaje', 'X2QIZAAI78I023U', 'carga', 8946, 7, 38, 20),
(945, 'Golden Tohalu', 'WS53Y0BCAJF1C3N', 'pasajeros', 690, 7, NULL, 17),
(946, 'Big Duvexuho', '6K8WMVQQNKO3CH4', 'carga', 8835875, 1, NULL, 2),
(947, 'Kuburupa', 'H952KU130O9CTMN', 'pasajeros', 1786109, 1, NULL, 53),
(948, 'USS Fish', 'JI5VGV9UO5VUX1M', 'carga', -321, 7, NULL, 93),
(949, 'Gozowinucoxe', 'ULXX2078E31Z957', 'carga', 7722, 4, 2, 88),
(950, 'Cloudy Koxigenaha', 'MF1L4E3634ENIDQ', 'exploración', 15, 2, NULL, 21),
(951, 'Stormy Xumalu', 'NI0JH4S0H6NAHU4', 'carga', -8504008, 5, 4, 88),
(952, 'Lil'' Cexovosaleci', 'QOF8EVG82VNQ955', 'pasajeros', 34, 2, NULL, 31),
(953, 'Baliqani', '96OID8S4Q5CD0BU', 'pasajeros', 1063956, 1, NULL, 7),
(954, 'Shiny Lave', '548F31LY8REGPRR', 'exploración', -8540026, 8, NULL, 64),
(955, 'Razalojere', '8C12KQ9RB9ELX2Q', 'pasajeros', 7072344, 0, 20, 5),
(956, 'Qekogobe', 'K8C5677KF821BP4', 'carga', -2779787, 6, NULL, 56),
(957, 'Fish', '03B5Z33824N0886', 'carga', -6585771, 0, 36, 21),
(958, 'Lesisidina', 'VA88548U895N383', 'carga', -1548361, 12, 15, 40),
(959, 'Lil'' Nigare', 'M895204223HSG73', 'carga', 1982880, 497, NULL, 68),
(960, 'Big Fox', '8NZUZQ6U2GD10SB', 'carga', 1950742, 1, NULL, 40),
(961, 'Cloudy Gixohi', '53R81GZ17VZ524Y', 'combate', NULL, 12, 9, 57),
(962, 'Ukemifi', 'DTU1IRYJ5AENQR8', 'combate', 750452, 499, NULL, 12),
(963, 'Cufiwe', '9EBC8U21F94B878', 'pasajeros', 4745422, 14, NULL, 25),
(964, 'Grand Qejanupala', '79C3XN54760G8VW', 'pasajeros', 6304118, 4, 9, NULL),
(965, 'Gajohevi', '06L17SZEDGM23NY', 'carga', -792, 9, 23, 66),
(966, 'Little Labitaru', 'UY06S3E8P71D862', 'pasajeros', -9344579, 3, 11, 7),
(967, 'Golden Bicebaxo', '4C8OM8Y85TJ052V', 'pasajeros', 3618140, 0, 13, 41),
(968, 'Sa', '3U4RBS4JBGFMPXQ', 'carga', NULL, 5, 42, 58),
(969, 'Condor', 'WE8GT1T5IN3181R', 'pasajeros', -4329343, 5, NULL, 54),
(970, 'Little Fox', '8TF4QHX3N785V28', 'exploración', -667, 236, 36, 23),
(971, 'Grand Pizeha', 'E0R12701AN36ER0', 'exploración', 314590, 322, 25, 86),
(972, 'Big Cutigubi', 'R2JZ588910CP9FX', 'pasajeros', 21, 0, NULL, 12),
(973, 'Bixolu', 'KDLPR5M5358U1EX', 'pasajeros', 486927, 183, 19, 77),
(974, 'Grand Condor', 'L8BNCN1G72W6K3Z', 'pasajeros', 513, 9, 43, 85),
(975, 'Shiny Dotiseratuve', '4TU188B82486JS7', 'pasajeros', 1, 0, 21, 69),
(976, 'Shiny Dazaxaha', 'Z59YF63YCQOYOBF', NULL, NULL, 0, 48, 59),
(977, 'USS Nuwedeqoci', 'N7GYB659DR4W5FH', 'carga', 6150, 5, NULL, 57),
(978, 'Lil'' Eze', 'T4I9B13457U911M', 'carga', -9645552, 0, 1, 3),
(979, 'Eagle', 'BX6744669BT11GT', 'carga', 42671, 15, NULL, 41),
(980, 'Cloudy Isujomi', '37HVG4PF5K9JI6N', 'combate', -7653416, 6, NULL, 56),
(981, 'Awaji', '62J80UVSV395185', 'carga', NULL, 0, 50, 85),
(982, 'Eagle', '34AQ49D30HD11YS', 'pasajeros', 5479762, 1, 47, 6),
(983, 'Golden Abuwidipe', '3415529312257M7', 'combate', -297214, 1, NULL, 4),
(984, 'Cude', '5W9Z7S76Z9B412X', 'carga', -2651542, 168, 41, 47),
(985, 'Condor', '8AVFZ42Z1MO46RP', 'carga', 3580, 0, NULL, 50),
(986, 'Tonusa', 'MUUA9N9J0SHL1O5', 'carga', 8548465, 8, 7, 86),
(987, 'Zerowace', 'IK300LXA9J6P9FF', 'pasajeros', 4066619, 5, NULL, 36),
(988, 'Shiny Peromo', 'IN4IW21KVRFG447', 'carga', 481263, 7, 12, 29),
(989, 'Stormy Efaguve', 'SF26O2FE357I699', 'pasajeros', 2623258, 14, NULL, 30),
(990, 'Utakuzi', 'KSO0RBJO3RCS6JF', 'exploración', 6649074, 11, NULL, 40),
(991, 'Lil'' Gosajoja', '0830A5I3AQEN546', 'exploración', 1069924, 15, NULL, 2),
(992, 'Decewetu', 'OBVU6ZDC08B02F5', 'pasajeros', 634841, 351, NULL, 88),
(993, 'Juriwoge', '0H3D4ERWAV79Q22', 'carga', -5208141, 0, NULL, 56),
(994, 'Lil'' Gico', 'LNDTN5YC332NF00', 'carga', 6660, 1, 41, 3),
(995, 'Lil'' Exojadi', 'FAG5X5KSA5275JB', 'pasajeros', -2441077, 12, 5, 56),
(996, 'Gikawigaxetu', 'Z79PA3M066CVEIQ', 'pasajeros', 5328292, 2, NULL, 39),
(997, 'Silver Fuveke', '7011C2QW57BJZU8', 'carga', NULL, 6, NULL, 42),
(998, 'Qututoze', 'JYZTNYH8C0X1JV2', NULL, NULL, 1, 44, 37),
(999, 'Ejohuse', 'Q15X49WT8C78EZ4', 'carga', -57, 281, 8, 66),
(1000, 'Cizipacumala', 'HP6644P5SHHII6T', 'combate', 3, 1, 28, 6),
(1001, 'Silver E', '9FOOFR2C242I598', 'carga', -1906, 3, 27, 33),
(1002, 'Lil'' Tobixefo', 'Y31SUAQZ7725WQM', 'exploración', -6940609, 3, NULL, 86),
(1003, 'Big Azineverumu', 'A2W63Q7D38M5NL5', 'carga', -7, 15, NULL, 12),
(1004, 'Kiluxu', '06R93MI48616A8Z', 'pasajeros', -4578728, 12, NULL, 91),
(1005, 'Wafofu', 'D4K93U5FLPOB1GM', 'carga', 8519599, 5, 29, 29),
(1006, 'Big Cohazosa', '05I0KT5P2BTN573', 'pasajeros', 2, 2, NULL, 10),
(1007, 'Silver Zuxaguxa', 'HM7SNA44W7O59DA', 'exploración', -79, 13, 38, 28),
(1008, 'Oqeba', 'XL07NL807N718X9', 'pasajeros', NULL, 5, 6, 4),
(1009, 'Linu', '5WT5HJ7TRYZK6Q5', 'combate', -2757372, 0, 22, 3),
(1010, 'Silver Sadeqo', 'YYFSR8VI7D70ESQ', 'pasajeros', -164, 1, NULL, 8),
(1011, 'Lil'' Udejobojula', 'S546Q9E1NH9MMGN', 'carga', -6107290, 1, NULL, 2),
(1012, 'Shiny Zeppeling', 'R74R3A99QG24496', 'pasajeros', 7568941, 1, 16, 27),
(1013, 'Ozuje', '5OVCZ831JOC44VH', 'pasajeros', -1933795, 1, 36, 4),
(1014, 'Xukini', 'Y5T1WD87V4T1S9J', 'carga', 440786, 10, NULL, 31),
(1015, 'Fish', 'LD8W56E942328G0', 'carga', 8361197, 404, 44, 83),
(1016, 'Fox', 'W814141B3RW0TKC', 'carga', 722, 9, 3, 79),
(1017, 'Wamu', '58RKS551HWBH5L6', 'carga', -5480, 9, 44, 24),
(1018, 'Xobeberironu', '06U477CY51258DT', 'exploración', 3, 6, NULL, 21),
(1019, 'USS Melebuxuse', '1Z19YTUULS7YRW9', 'pasajeros', 5977674, 12, 42, 22),
(1020, 'Ekize', '6SK77ST5WY59U7A', 'combate', -513, 12, NULL, 74),
(1021, 'Hahunanesu', 'N4G4FO10FU003TK', 'carga', 547, 0, NULL, 42),
(1022, 'Big Lepuwaju', 'XL7HMGES4SOA7M1', 'carga', 8888963, 13, NULL, 53),
(1023, 'Jajuhi', 'V7962LRR29QL2T2', 'carga', -9721038, 1, NULL, 69),
(1024, 'Golden Nobada', '93MM8PN18TI177K', 'pasajeros', 7, 0, NULL, 37),
(1025, 'Cloudy Zusega', 'GLZ0B7YBOCMBCWQ', 'carga', -980900, 0, NULL, NULL),
(1026, 'Silver Pasu', '1P981DE2ES8K9X6', 'pasajeros', -7400542, 49, 32, 27),
(1027, 'Grand Filiruliga', 'GO9RAHLZ0XPQ8U3', 'combate', -5163630, 0, 9, 47),
(1028, 'Esu', 'L05YI927RG66U74', 'carga', 9329075, 10, 42, 51),
(1029, 'Little Patohimamu', 'HPFAYURDAMWBGX0', 'carga', 7396008, 8, 3, 43),
(1030, 'Kijowefise', '24Y9YTU9PB38H1Y', 'combate', 244621, 3, 8, 99),
(1031, 'Nusuqi', '4Y6N4VU0FEXQ6DE', 'exploración', 6, 6, 39, 23),
(1032, 'Big Vanaqi', 'GV74CUE4039BLA0', 'carga', -205960, 5, NULL, 13),
(1033, 'Silver Secagoce', '1Y4XE37P93J0Y9N', 'exploración', 457, 0, 13, 44),
(1034, 'Little Zeppeling', 'OMN0NGJQD8HEZ24', 'carga', -5157373, 5, 29, 43),
(1035, NULL, '0YBC4ZZ0S14TP5Q', NULL, NULL, 6, 29, 90),
(1036, 'Shiny Rozuqu', '5734U4C6E2S0135', 'pasajeros', -9, 145, NULL, 55),
(1037, 'USS Citu', '9B7S8D2T86W36HG', 'carga', 3028076, 0, NULL, 14),
(1038, 'Xurite', '78R4D1JGAV9033V', 'carga', 6617745, 12, NULL, 91),
(1039, 'Etuvute', '884241PE19T802U', 'combate', 211, 0, NULL, 86),
(1040, 'Lil'' Furu', '4S0C2Q3D15Y4Q45', 'carga', 6361, 15, NULL, NULL),
(1041, 'Grand Ilo', '4DFWG52I788VV41', NULL, NULL, 12, 24, 89),
(1042, 'Tijexebi', '866S88LK6GBW349', 'pasajeros', -3216263, 2, NULL, 93),
(1043, 'Grand Baqekoxa', '429H4RZL9487472', 'carga', 93, 1, 47, 63),
(1044, 'Grand Fox', '5S2C81X31464F3M', 'carga', -74, 5, NULL, 80),
(1045, 'Muvuhi', 'EJY314UG4295846', 'pasajeros', -2410500, 5, 39, 49),
(1046, 'Ovato', 'XY4456DY97AF590', NULL, NULL, 13, 8, NULL),
(1047, 'Amavi', 'VYIJN2PV96IDK5Y', 'carga', -5925372, 4, NULL, 26),
(1048, 'Johicu', 'ZYA1BTQ5M1U25NF', 'carga', NULL, 2, NULL, 17),
(1049, 'Moravu', '62VC753M8U04952', 'carga', -6615367, 14, NULL, 19),
(1050, 'Huja', 'ZQ4C1I20482P898', 'combate', -3318172, 246, 9, 8),
(1051, 'Wokitu', '9QCDS7U9W81717I', 'carga', NULL, 1, 13, 41),
(1052, 'Haqono', 'J855MU08NA08537', 'carga', 98, 1, 13, 6),
(1053, 'Cloudy Nojoxa', 'L9DGGCB92C43R5Z', 'pasajeros', 154867, 10, NULL, 26),
(1054, 'Qatuhi', 'DBO9B495W387550', 'carga', 9965266, 8, NULL, 87),
(1055, 'Inujiza', 'NK18515501UL046', 'exploración', 280020, 1, 43, 64),
(1056, 'Velule', '44P555225957YU9', 'carga', 4329, 154, NULL, 1),
(1057, 'Ireno', '082X3I3U4MY46YZ', 'combate', NULL, 0, 23, 84),
(1058, 'Shiny Wiwogi', 'DT87M2E98Z8GG1F', 'carga', -1854713, 3, NULL, 55),
(1059, 'Jatorapa', 'WGP3Q2R2IB1JA4K', 'exploración', -318, 7, 50, 42),
(1060, 'Fish', '489T3Z0XQY5Y85K', 'carga', NULL, 2, NULL, 87),
(1061, 'Shiny Butterfly', 'I752W5U8Y24ZP5N', 'pasajeros', 7512135, 9, 35, 69),
(1062, 'Segine', 'AN8B0KE91EURN2N', 'carga', 3743328, 0, 16, 9),
(1063, 'Eagle', '5G3FF8IQBO08385', 'pasajeros', 809, 1, NULL, 41),
(1064, 'Zeppeling', '6X48U2U61NVTU6X', 'carga', -7080533, 4, 26, 36),
(1065, 'Lil'' Egoxuce', '75O9P7ET28MZ2SN', 'carga', NULL, 4, 16, 86),
(1066, 'Butterfly', '9T8Z64N7N9V6Y16', 'carga', 2, 13, 24, 10),
(1067, 'Zova', '11T3S05I3G9Z1P0', 'combate', 3538850, 191, NULL, 3),
(1068, 'Vufifume', '5AQ5YN0U9SR5710', 'pasajeros', 7651820, 5, NULL, 47),
(1069, 'Golden Qifo', 'X1MV48P1H1TL646', 'pasajeros', 6213, 439, NULL, 33),
(1070, 'Golden Vagofu', '6Z95DE104BH5DS8', 'pasajeros', 0, 268, 8, 34),
(1071, 'USS Zabicomezi', 'MOPC066N87820Z9', 'pasajeros', -7054743, 3, 1, 100),
(1072, 'Fox', 'I0L7VHRES6E0A85', 'carga', -5508096, 1, NULL, 65),
(1073, 'Silver Eagle', 'QIX8TLJMCN4030F', 'carga', NULL, 0, NULL, 45),
(1074, 'Anevo', 'EWR59581H2Q3UBX', 'pasajeros', -8622530, 15, 29, 35),
(1075, 'Guliladu', 'P0VV9R2LFK5J0IA', 'carga', 2032432, 14, NULL, 90),
(1076, 'Iwoseqizu', '8H34X78897DASK6', 'carga', -2814848, 1, NULL, 38),
(1077, 'Firuli', '005IT2KJG09WSAL', 'combate', 8406830, 7, 17, 12),
(1078, 'Golden Condor', '6BYWGUG7D80SF1W', 'carga', -9325, 62, NULL, 91),
(1079, 'Big Isutepami', '4UV02LFOB9317SK', 'carga', -3166194, 3, 44, 1),
(1080, 'Golden Aji', 'QMA1SL74W1091W8', 'carga', -8945797, 7, 6, 87),
(1081, 'Cidajoti', 'F3XDH0PF985TZ40', 'pasajeros', -2551870, 1, 6, 17),
(1082, 'Shiny Hawo', '5H7E32N7NZE20P2', 'carga', 454394, 9, NULL, 56),
(1083, 'Silver Wiwebe', 'B2O5P7E8J148087', 'pasajeros', 6481337, 0, NULL, 8),
(1084, 'Fish', 'T4K930MOGV5Q741', 'pasajeros', 6515232, 2, 8, 58),
(1085, 'Shiny Butterfly', 'O755Q2602HB3831', 'carga', -730434, 3, 47, 73),
(1086, 'Grand Womusi', 'L0V1W08UL9YQI5L', 'carga', -5888909, 1, NULL, 87),
(1087, 'Lil'' Jojela', 'L06P4D7KKHS59Y2', 'carga', -2612407, 39, NULL, 87),
(1088, 'Big Nolifeto', '99Y73312013544G', 'pasajeros', -5241119, 15, NULL, 37),
(1089, 'Evecu', '75367TB768UNR4A', 'combate', 3, 6, NULL, 70),
(1090, 'Xurufu', '375IU6DL9RG8CY4', 'exploración', 1326206, 12, 29, 43),
(1091, 'Ocifo', '058L9LE1E32366C', 'pasajeros', 118, 8, NULL, 23),
(1092, 'Lil'' Zeqadubi', 'YRKUYBDX0H0GY60', 'pasajeros', 8, 12, NULL, 11),
(1093, 'Cloudy Doguva', '4JCV07Y04X1W27H', 'exploración', -2191369, 0, NULL, 24),
(1094, 'Usu', '614PWCXP9A9595D', 'pasajeros', -4820661, 8, NULL, 24),
(1095, 'Daxaxina', 'A0YXL06ZLJTJG78', 'pasajeros', -7967753, 14, 10, 50),
(1096, 'Cloudy Wibigije', 'DKV0GJ824061LB7', 'carga', 6705670, 3, 4, 66),
(1097, 'Huzevu', '2E068V98D2Q6BE1', 'pasajeros', -868, 11, NULL, NULL),
(1098, 'Shiny Isisuvibe', '54LC9P80YHNU407', 'carga', -6667846, 14, NULL, 73),
(1099, 'Cloudy Sukataxo', 'O1PD8JG1C7ZBIXQ', 'carga', -9786801, 3, NULL, 51),
(1100, 'Grand Fox', 'G7XBSDD9SLWIS7J', 'pasajeros', 31, 11, 5, 99),
(1101, 'Condor', 'X33AD8X936853D4', 'pasajeros', 4998495, 10, 50, 41),
(1102, 'Degigodacu', 'JV4296UE3UV5081', 'pasajeros', 151, 0, NULL, 1),
(1103, 'Xadifezo', 'BLPMH628VK933W1', 'carga', 4369336, 5, NULL, 33),
(1104, 'Bulaca', 'WYV8M0NOAWLP8P5', 'carga', 753, 13, NULL, 7),
(1105, 'Shiny Olavezufa', '65ZEHR7SN30FF1N', 'carga', -6882558, 11, 17, 38),
(1106, 'Conupicuxi', 'L8P16O0H11MFS7M', 'combate', 4, 225, 17, 4),
(1107, 'Little Qukexo', '73GF12CM4472D88', 'exploración', NULL, 132, 10, 80),
(1108, 'Zomova', '08BUI51UZ4C6HQ6', 'exploración', -807, 15, 26, 65),
(1109, 'Coruwolobure', 'L37N36OEMDU558E', NULL, NULL, 3, NULL, 9),
(1110, 'Cloudy Cubirivu', 'WF8Q63O8QM75999', 'pasajeros', 92, 3, 10, 8),
(1111, 'Silver Sovicaqu', 'Y82SD17GSUX035K', 'carga', -1499, 3, 39, 28),
(1112, 'Big Tiboti', 'ODRHV99YYAAA1E1', 'carga', -97, 0, 17, 9),
(1113, 'Fox', '8C49XGT4ZXAO5T4', NULL, NULL, 241, NULL, 95),
(1114, 'Nabuqaru', '3GB82QEL4746M0I', 'carga', -81, 9, NULL, 77),
(1115, 'Zeppeling', '17PCX98W071T5AM', 'carga', -2470, 11, NULL, 60),
(1116, 'USS Zeppeling', '4622L994039411V', NULL, NULL, 15, NULL, 50),
(1117, 'Hugisogi', 'Y7TS2RR5AEOWE61', 'carga', NULL, 351, 27, 27),
(1118, 'Stormy Xemu', '0LPAU1D294OQ518', 'pasajeros', 4748613, 5, NULL, 17),
(1119, 'Shiny Winabixe', '5932RW92G988G80', 'carga', -5730148, 10, NULL, 6),
(1120, 'Silver Fox', 'Y5G0U667R2B3I70', 'carga', -775149, 0, 8, 72),
(1121, 'Grand Idawa', 'SZ113635N8RYTX7', 'carga', -9, 12, NULL, 96),
(1122, 'Stormy Xoqu', '991TI9HAG40MBJ4', 'exploración', -5, 1, NULL, 10),
(1123, 'USS Ibinajoxiqu', 'SSIZ3VO7FVHQ4G9', 'combate', 5119158, 21, NULL, 3),
(1124, 'Shiny Hijilecomo', 'HA3CIUX8J799KGK', 'carga', -1065025, 0, 23, 14),
(1125, 'Shiny Julu', '002W9G8AK2075DR', 'carga', 1, 0, 26, 47),
(1126, 'Duvocila', 'I7FK5BYH4I04141', 'pasajeros', -3, 0, NULL, 81),
(1127, 'Cajomubuwi', '49DR5839KS24UU0', 'exploración', -6009160, 0, NULL, 74),
(1128, 'Kazofagidu', '9ADE637Y94357Z4', 'pasajeros', NULL, 7, NULL, 22),
(1129, 'Gakaqi', 'L1X9H94B6J8YXQ4', 'exploración', -7652730, 5, 26, 91),
(1130, 'Boriraqe', 'LI67O6IS6KDEI34', 'carga', 5954775, 1, 36, 83),
(1131, 'Cevo', '32YM1U0448D25I2', 'carga', -6035, 15, 13, 56),
(1132, 'Lil'' Cohipoto', 'C1W086T9052B1RE', 'combate', 2376281, 0, 4, 46),
(1133, 'Bifekabi', 'IR5361CT155G46S', 'pasajeros', 9891585, 0, NULL, 71),
(1134, 'Debeqoxe', '3B5JTAY1L4IVICY', 'pasajeros', 9324533, 490, 23, 69),
(1135, 'Lil'' Butterfly', '6AFMLF1C45UDND7', 'pasajeros', -5134935, 1, 5, 46),
(1136, 'Raquva', '40S413UKR8V81L0', NULL, NULL, 165, 44, 24),
(1137, 'Stormy Tonevu', 'UO54M65195Z67TD', 'carga', 143004, 5, 1, 32),
(1138, 'Grand Hitokefira', 'PP7E7ISPYE3FVK3', 'carga', NULL, 187, 14, 91),
(1139, 'Little Rimoso', 'O2FGAN1Y77SKOS8', 'pasajeros', 1779327, 13, NULL, 3),
(1140, 'Silver Butterfly', 'C2288V30R0926T7', 'carga', 7789, 14, NULL, 9),
(1141, 'Little Cekugi', '2IM2317IFRI8455', 'pasajeros', 64, 11, NULL, 53),
(1142, 'Lil'' Xovemepavofu', 'TZG615SDVGU7IFW', 'carga', -9742185, 1, NULL, 6),
(1143, 'Vokuxesa', '0J7PVI79D8Y08ON', 'carga', 1909277, 14, 2, 78),
(1144, 'Dotagitihu', '6Z9F9E2YGWAIG9V', 'carga', -4, 12, NULL, 36),
(1145, 'Dukusi', '1SJX988Z86ZHUXA', 'carga', NULL, 0, 20, 23),
(1146, 'Unavone', 'Q9HS31ES911LAMO', 'carga', 9699704, 10, NULL, 31),
(1147, 'Jifi', '8I934B04D386MX1', 'pasajeros', 41, 13, NULL, 28),
(1148, 'Iwuhame', 'YX15HE6B60H25C7', 'carga', 7502686, 3, NULL, 93),
(1149, 'Utowido', '7T27WAWYL6X9613', 'carga', -2437551, 111, 6, 3),
(1150, 'Sohizebixo', 'K6J3934MOK6S9O4', 'carga', -4, 12, 22, NULL),
(1151, 'Golden Eagle', '7NC2WALVEYE6RP3', 'carga', 1399771, 7, 26, 8),
(1152, 'Stormy Eagle', 'FQL2URY6KILA5JQ', 'carga', 9695403, 0, NULL, 72),
(1153, 'Kasegecagi', '2CPLJPSM50J788N', 'exploración', -9710375, 490, NULL, 79),
(1154, 'Duqovi', '7306RCJ00F1561K', 'pasajeros', 927276, 9, NULL, 6),
(1155, 'Butterfly', '94L4GBJ16V1DHTA', 'exploración', -2686303, 6, 1, 23),
(1156, 'Silver Ohomarihanu', 'AF8K5KH32QS9B5V', 'pasajeros', -4198648, 1, NULL, 70),
(1157, 'Grand Zado', 'SJLB3X8X6828529', 'carga', -8275100, 0, NULL, 83),
(1158, 'Stormy Womodeqa', '11I9ZYA8H2309WU', 'combate', -870, 14, 29, 22),
(1159, 'Hocama', '35689POO7W79S0P', 'pasajeros', -1094306, 0, NULL, 43),
(1160, 'Xuturu', 'AV99Q9V4QE13Z2Z', 'carga', -7476915, 1, NULL, 97),
(1161, 'Silver Fox', 'KKK6WS78VY29X15', 'pasajeros', 6196452, 10, 37, 39),
(1162, 'Little Nuzowofu', '57H3879E43PBZNM', 'carga', -6824, 0, NULL, 36),
(1163, 'Butterfly', 'W8V4357KX57CBDQ', 'carga', -5556915, 0, 11, 10),
(1164, 'Silver Purebowule', '2ESO5S1YS7YIKJ2', 'carga', -3144876, 5, NULL, 5),
(1165, 'Hadi', '6E80X0OOSM2KFP6', 'carga', -1, 1, 46, 60),
(1166, 'Eagle', '2AGR0WKE24H4A9U', 'carga', -5589350, 13, NULL, 2),
(1167, 'Silver Qixowoteko', 'SW30I49T132V7HG', 'exploración', 8520357, 1, 22, 19),
(1168, 'Silver Mohifemexe', '92WTYX668S81BTI', 'exploración', NULL, 321404, 37, NULL),
(1169, 'Grand Tasiriju', '1RG7Y13VTC75O1Z', 'pasajeros', -7570373, 6, 16, 20),
(1170, 'Condor', 'KZPHLNRWE03BD5X', 'carga', 2900052, 7, 9, 12),
(1171, 'Zeppeling', '14X4W2X82Q81TM6', 'carga', 7727, 145, 3, 55),
(1172, 'Roravotu', 'W5RL0157M805AL8', 'pasajeros', NULL, 1, 44, 45),
(1173, 'Ere', '1PD684A91SX4H1Q', 'carga', -6986094, 0, NULL, 82),
(1174, 'Condor', '6D8L02Z43962FJ2', 'carga', 56, 0, 29, 5),
(1175, 'Doxiwe', '1YL4L1RAX1PEZRE', 'carga', 5235980, 300, NULL, NULL),
(1176, 'Cami', 'RL961SQ39DFI653', 'combate', -9890370, 15, 13, 36),
(1177, 'Grand Gojaxa', '79937X37V02689V', 'pasajeros', 1272, 4, NULL, 67),
(1178, 'Big Butterfly', '5FMOI87698EOMD9', 'carga', -4911454, 0, NULL, 62),
(1179, 'Golden Jebowoma', '07X32A52WH30Y6C', 'pasajeros', 0, 150, 5, 10),
(1180, 'Tume', 'S3B5A9HMFX6A3B7', 'pasajeros', 7557758, 4, 6, 88),
(1181, 'Condor', '9Q0GT5K8V61P1C4', 'carga', 7331386, 3, NULL, 53),
(1182, 'Ibegi', 'V0PFX9K49V1131M', 'carga', NULL, 10, 17, 4),
(1183, 'Xaqefa', '42FY469HHJTVBWU', 'carga', 8513139, 431, 44, 3),
(1184, 'Condor', 'A8C0YYFHFHW55BD', 'carga', -9517891, 14, NULL, 100),
(1185, 'Big Qugixelebi', 'Z5XY440X5EMBK26', 'carga', -506966, 4, NULL, 93),
(1186, 'Jawudebanu', 'XY9498A7354V5BR', 'exploración', 174, 1, NULL, 4),
(1187, 'Qibuce', '48PP2UYRE4AFL13', 'carga', -4183939, 0, 19, 93),
(1188, 'Little Fox', '9HS24QA57ZLV4NA', 'carga', -6524794, 7, NULL, 34),
(1189, 'Fish', 'AS7K76U42SWI365', 'exploración', 8783829, 0, NULL, 14),
(1190, 'Cloudy Ohuhe', '7XMRR0R71899N23', 'exploración', 6271551, 184, NULL, 96),
(1191, 'Qiquwufu', '5REUV89TC0J9Z32', 'pasajeros', 152888, 11, NULL, 91),
(1192, 'Turugigo', 'C8401B7D700OY53', 'carga', -9815, 0, NULL, 5),
(1193, 'Lil'' Okasekeja', '1YC6757MFTG3BKR', 'pasajeros', 8670790, 12, 3, 97),
(1194, 'Rezidihu', '4Z2ZTU8RH9M022B', 'carga', 7407724, 0, 21, 31),
(1195, 'Lil'' Duwuga', 'F6C3Z33PDEVJVQR', 'carga', -2830358, 10, 21, 7),
(1196, 'Little Zeppeling', '47PULD750J3ODAX', 'carga', -7485748, 1, 36, 15),
(1197, 'Cloudy Utobozino', '8VG25S1D8ZRISNC', 'pasajeros', 2021020, 3, NULL, 13),
(1198, 'Grand Liloreraso', 'IXJ15KY2Z14YIL6', 'pasajeros', -6852542, 13, 37, 49),
(1199, 'Povimeci', 'U52735T2P8PPD69', 'pasajeros', -8, 13, 10, 6),
(1200, 'Ute', 'YQV1504NSHC38PB', 'exploración', -7566, 440, 37, 35),
(1201, 'Shiny Tafisu', 'X480TZSI4O194KM', 'carga', -3904395, 10, NULL, 64),
(1202, 'Usoha', 'HG8HS87N9QU4BDQ', 'pasajeros', 3886911, 10, NULL, 73),
(1203, 'Golden Soke', '7RP3P2R0RG1FT83', 'pasajeros', 5081781, 0, 42, 87),
(1204, 'Silver Pihowuhi', 'Q72BNOB823KQQ09', 'pasajeros', -3359314, 1, NULL, 75),
(1205, 'Lil'' Wizisa', 'RXDWX9II1U440CE', 'carga', 9268858, 8, NULL, 100),
(1206, 'Golden Begamoti', 'PE83T3KQ5TJ1ZCG', 'carga', -461, 8, 34, 91),
(1207, 'Golden Uhi', 'ZE183LQGZ8LB4UG', 'exploración', -19, 0, 7, 24),
(1208, 'Big Cetula', 'W6J2F3BIMQYRG05', 'carga', -7586627, 327, NULL, 69),
(1209, 'Shiny Lumowote', '8DOOK176DB8Y177', 'carga', -8429445, 7, NULL, 43),
(1210, 'Venusibu', '4X21341Y53DDK55', 'pasajeros', 7335977, 0, 29, 16),
(1211, 'Silver Biqezanu', '0HF48Q8AMV2P09R', 'pasajeros', -1121707, 391, 37, 68),
(1212, 'Dujevumuve', 'EE1DU2MNXZ7M5FY', 'pasajeros', 5458683, 0, 25, 63),
(1213, 'Lil'' Opawejege', 'YV9YT2A5H8K9GR1', 'carga', 1270547, 9, 36, 42),
(1214, 'Lil'' Ko', '6C7QOZ95D00Z13H', 'combate', -474, 10, NULL, 13),
(1215, 'Hoju', 'B2MJ51H76V97ROU', 'pasajeros', 3839719, 10, NULL, 40),
(1216, 'Shiny Juvifefa', 'OJ1H0372G77RZ6U', 'carga', 3535080, 1, NULL, 16),
(1217, 'Silver Butterfly', '1JBC4W559A85U8Y', 'carga', 3595626, 0, NULL, 24),
(1218, 'Zeppeling', '00Q7FO24T3R1J8M', 'combate', -2226390, 2, NULL, 90),
(1219, 'Weha', 'O833VYQWWSSDP2O', 'pasajeros', -3347757, 15, 36, 65),
(1220, 'Tucohonedi', '4293ERS9635Q0DA', 'pasajeros', -9419331, 419, 1, 80),
(1221, 'Aqabonamu', '8SCROW3H3S20I71', 'pasajeros', 927655, 1, 22, 8),
(1222, 'Cloudy Bajukeka', 'F24H9WQ6PKX1VYJ', NULL, NULL, 7, NULL, 54),
(1223, NULL, '3J238RW03E1Y3D2', NULL, NULL, 374, 34, 3),
(1224, 'Shiny Obogove', '4L8AOW0Z08I64KJ', 'carga', 5698437, 14, 17, 99),
(1225, 'Fox', 'PX2DTFYX428I35Z', 'combate', 8691427, 0, NULL, 45),
(1226, 'Stormy Axekoqahona', '85XBTMR225K8384', 'pasajeros', 3951884, 8, 4, 4),
(1227, 'Silver Qecexari', 'GRJ490L08BZO0O9', 'exploración', -5710260, 8, NULL, 95),
(1228, 'Dito', '5NSAE3688S23L6D', 'pasajeros', -6387983, 1, NULL, 46),
(1229, 'Grand Toqapuqune', 'Q9M36347681CI38', 'carga', -7341206, 9, 6, 54),
(1230, 'Cloudy Ibuwuso', '953CM191PA0FY0P', 'carga', -5547, 2, NULL, 16),
(1231, 'Rawego', '0Z5CTN03U8AL455', 'combate', -2882851, 4, 25, 44),
(1232, 'Shiny Xecogabe', 'Q56ND64LO0S8798', 'combate', -9783, 1, NULL, 52),
(1233, 'Ro', '7LR683Z795B9B5Q', 'carga', 13, 7, 3, 59),
(1234, 'Big Hudeva', 'IT2ZRI21E0NF97K', 'pasajeros', -1632392, 296, NULL, 10),
(1235, 'USS Fish', '79SA6J03W203ESV', 'carga', 3547986, 116, 44, 21),
(1236, 'Xavatuteba', 'JRO6C9J4OI9M186', 'pasajeros', 336307, 11, NULL, 2),
(1237, 'Sutowife', '5L1I3J3TVM91E53', 'carga', 6358193, 3, NULL, 91),
(1238, 'Silver Fish', 'P2MLY0X4N1H6703', 'carga', -2657443, 4, 18, 30),
(1239, 'Little Fish', '17W9XRWWF3XQE6K', 'carga', 4, 1, NULL, 19),
(1240, 'Little Xorasu', '5DVPCF237391XXN', NULL, NULL, 1, 43, 66),
(1241, 'Stormy Vosiqabe', 'D9UPX6Q34179YQ0', 'carga', 5163543, 0, NULL, 72),
(1242, 'Ala', '290UR4US7T9QD5D', 'carga', 9634910, 0, NULL, 16),
(1243, 'Little Tefi', '9N86841GEY0Z4O3', 'pasajeros', 3717594, 67, 50, 57),
(1244, 'Nicatori', '48OFZKD03Q027JT', 'exploración', 838, 226, NULL, 66),
(1245, 'Nerame', 'U6VF6JW6Q2KV2L6', 'exploración', -1, 457548, NULL, 8),
(1246, 'USS Naqe', '75KR5F27DEE6FXA', 'combate', -831, 3, NULL, 8),
(1247, 'Stormy Owe', '2MN3T5QXM8TUT42', 'combate', -3146854, 9, NULL, 90),
(1248, 'Big Vuhocu', '13RD56N916UPW6L', 'carga', 18, 181, 8, 82),
(1249, 'Shiny Eriwehenu', '21HU263L50JV525', 'exploración', -1635930, 1, 50, 15),
(1250, 'I', '58GSD31S8L2ZK2H', 'combate', -161443, 3, NULL, 14),
(1251, 'Hafuduvi', 'Z4761MD17LG0K5T', 'pasajeros', 8013993, 1, 10, NULL),
(1252, 'Grand Honepovata', '093J82S9L91WQAC', 'carga', 0, 0, 30, 86),
(1253, 'Stormy Uvahovegigo', 'PT69OY5XAZ25QG7', 'pasajeros', -7223695, 6, NULL, 37),
(1254, 'Big Zekotozohi', '6ZS71ZSCMC33M2Y', 'carga', 6931121, 11, 49, 23),
(1255, 'Fish', '68IKE52987FZVLM', 'pasajeros', NULL, 7, 12, 8),
(1256, 'Shiny Adege', '876L8TPG54WZNTL', 'exploración', -1650711, 1, 14, NULL),
(1257, 'USS Xamusokuso', 'XWBUIA4X547UJ4W', 'carga', -2717112, 10, 2, 74),
(1258, 'Fufezuke', '3ZQ65H6X1F5NNTQ', 'carga', 4229272, 2, NULL, 32),
(1259, 'USS Xifoco', 'TKLR8E85NT6591M', 'exploración', 34, 1, 8, 52),
(1260, 'Silver Ahalecu', 'JQ86T56M2TOASS9', 'pasajeros', NULL, 1, NULL, 73),
(1261, 'Shiny Gojoge', 'P2H5BJ8630TP3H9', 'pasajeros', -9682850, 1, 40, 17),
(1262, 'Fixasule', 'ON4703DWLX2EAK7', 'exploración', 1032810, 0, NULL, NULL),
(1263, 'Lakoni', 'A34XGE1Y8LH3CC3', 'carga', 7201596, 13, 13, 26),
(1264, 'Butterfly', '3179T55WZ5XE6E1', 'carga', 938, 0, 14, 49),
(1265, 'Little Coti', '45N4CCEJCC68171', 'pasajeros', -3469575, 0, 7, 21),
(1266, 'Lil'' Dame', 'C681880V3K88R5I', 'carga', NULL, 10, NULL, 49),
(1267, 'Cahafifeve', '9P4IW6K701K1F61', 'carga', -8087972, 10, 8, 18),
(1268, 'Zeppeling', 'LIJ0G5AH28ES383', 'pasajeros', 31, 13, 1, 8),
(1269, 'Linare', 'P1K321682399QEF', 'exploración', 7424, 195, 42, 76),
(1270, 'USS Vuko', '4NQ6JW1124YDUHY', 'combate', 7, 555638, 17, 52),
(1271, 'Grand Emaloxo', 'ZA39V0L29403406', 'pasajeros', -1, 430, 16, 88),
(1272, 'Sarajajo', '48O2361NO5ZK2NG', 'exploración', 4336658, 1, NULL, 41),
(1273, 'Bacuvo', '2E16E5AFZS98WKS', 'carga', 3692297, 11, 25, 99),
(1274, 'Ova', 'Q64D4ID11D2N42W', 'combate', -252170, 14, 24, 3),
(1275, 'Cloudy Wasabe', 'F1Y2K1KQJ02020J', 'carga', -5305262, 13, NULL, 38),
(1276, 'Silver Ehifa', '3198GBS0M0EI6C3', 'pasajeros', 6427872, 246016, NULL, 19),
(1277, 'USS Misule', '83Y3C12LO71MI32', 'combate', 8530067, 3, 16, 83),
(1278, 'Ileqoro', 'V25NLO37RBE9FVD', 'pasajeros', 77, 71, 17, 65),
(1279, 'USS Omaqaje', '35687NO9ZA1N6MI', 'exploración', 2548487, 14, NULL, 8),
(1280, 'Lil'' Fish', 'BC4HE44GDY9436X', 'carga', -361, 4, 14, 25),
(1281, 'Condor', 'H2T2I99A31L6Z8U', 'exploración', -7065292, 1, 42, 96),
(1282, 'Grand Dukore', '2I3PL33ET05HDK4', 'pasajeros', -1756000, 11, NULL, 34),
(1283, 'Hozequ', '026463F4L555DDY', 'exploración', -69, 12, NULL, 14),
(1284, 'Golden Mafivugu', 'RYYMEGYRE2PXN4D', 'pasajeros', -242, 0, 38, 51),
(1285, 'Eagle', '93X8H4ZC32DG66S', 'carga', 4267794, 8, 5, 39),
(1286, 'Butterfly', '60FBZV7Z89L8R73', 'pasajeros', 9, 4, NULL, 61),
(1287, 'Golden Qetibahazo', '6F7S2YPL5BEID0M', 'carga', 152, 11, 45, 45),
(1288, 'Cloudy Ihifi', 'V2R7W96E551Y7O4', 'exploración', NULL, 3, NULL, 3),
(1289, 'Utaju', '698I0B9757X99WM', 'carga', -135, 1, NULL, 49),
(1290, 'USS Guwe', '7363SRH13M4UI3T', 'exploración', NULL, 5, 41, 41),
(1291, 'Xuce', 'A6U4YB30TDWTDS6', 'carga', -8307481, 1, NULL, 97),
(1292, 'Pozoqerame', '3LK4H389O75A46J', 'carga', -2765796, 14, NULL, 76),
(1293, 'Baqaza', 'D1SPCMR4FR01T9U', 'carga', 5000313, 10, NULL, 14),
(1294, 'Ecoxe', '290019H86DBN1V5', 'pasajeros', 433033, 62473, 37, 77),
(1295, 'Gupeneqe', '93O93J5BY7BDZB0', 'pasajeros', -9608505, 1, NULL, 4),
(1296, 'Little Kihozo', 'WC22GR1JTGE3X24', 'pasajeros', 8307258, 262, NULL, 52),
(1297, 'Stormy Vaxo', '5PNNHV028Z3EB15', 'pasajeros', 3951749, 4, 47, 39),
(1298, 'Cloudy Zujobafa', 'WCI2K58O96J7553', 'carga', 9427640, 3, NULL, 72),
(1299, 'Lil'' Bijugo', '80C68Z66LRUY0E0', 'carga', 9613946, 5, NULL, 80),
(1300, 'Etazi', '7V8E7UD487N6LS0', 'carga', 8614, 1, 12, 56),
(1301, NULL, 'BQF6JG67712XBTO', NULL, NULL, 10, NULL, NULL),
(1302, 'Big Ujeve', '1QKZU224H4Q463W', 'pasajeros', 4318187, 237, NULL, 16),
(1303, 'Grand Amepuhupica', 'E32DZC77J43RC85', 'carga', 96, 29, NULL, 88),
(1304, 'Sugasopato', 'XFD9U4Y6T618IB4', 'carga', -192, 0, NULL, 100),
(1305, 'Zeppeling', '7I5Q9S6E5KU360D', 'exploración', -8, 4, NULL, 35),
(1306, 'Fubukerohi', 'C91EN40R9A36AQE', 'carga', 2041735, 129, NULL, 50),
(1307, 'Cloudy Benaqo', 'UX5DFH39GLVWJ9I', 'pasajeros', -4479839, 306, NULL, 35),
(1308, 'USS Zolajibi', 'YQB72971G1XUW54', 'carga', -4882298, 0, NULL, 96),
(1309, 'Eagle', '1E6I69JS2P858EF', 'pasajeros', -4054401, 461, 39, 3),
(1310, 'Cudifixa', '4R1V893W3M1KSN0', 'carga', 74, 8, NULL, 1),
(1311, 'Gadacova', '918BD0KT8468E58', 'exploración', -6885578, 12, 8, 46),
(1312, 'Bewafi', 'S358N0OD0044WG2', 'exploración', -507980, 25, 50, 30),
(1313, 'Big Xuguxodexo', '76BJ0G3P073BOB9', 'pasajeros', -2, 0, NULL, 93),
(1314, 'Golden Ipefeve', '02T196N843567X2', 'carga', -1752396, 0, 28, 93),
(1315, 'Qodewuju', '98EK68N8Y8WY8D2', 'carga', -5, 0, 31, 33),
(1316, 'Big Butterfly', 'ADD68SVLT143CIB', 'pasajeros', 8985429, 15, 33, 92),
(1317, 'Avokanoke', '9X52WTOTI9DXLNH', 'carga', 6010974, 12, 24, 90),
(1318, 'Condor', '92SND46T8ZH76BJ', 'exploración', -40, 12, NULL, 7),
(1319, 'Big Catoxa', '37I8FBD65YNB852', 'pasajeros', 44, 7, 10, 1),
(1320, 'Condor', 'H377PTQ005U1888', 'exploración', -367, 9, NULL, 92),
(1321, 'Golden Butterfly', '0182001801B5EWV', 'carga', -7627292, 12, NULL, 20),
(1322, 'Rujiqeje', '28VO2LW1CF57LEH', 'carga', 7233304, 1, NULL, 79),
(1323, 'USS Nusini', 'H40WM22N0W1394S', 'carga', 6163232, 6, 50, 23),
(1324, 'Grand Zuhevaxi', 'FLQ08309F67R828', 'carga', 89, 0, NULL, 99),
(1325, 'Silver Pima', '66DM6A370U7V7WW', 'combate', 133, 410, NULL, NULL),
(1326, 'Stormy Ejicahu', '406Y4M69Y6K46V5', 'pasajeros', -6031, 0, 25, 4),
(1327, 'Xamo', '3HE33864GX7VSDX', 'carga', -9619, 15, 41, 45),
(1328, 'Stormy Pupi', 'YKFY2J232W79LG7', 'pasajeros', -5958974, 4, NULL, NULL),
(1329, 'Big Condor', 'LU3S1Z3JUQIX93S', 'carga', 5627687, 1, 45, 80),
(1330, 'Iga', 'K8OA2GK2M36SS60', 'carga', 3728107, 471, NULL, 27),
(1331, 'Lil'' Tixu', '6K99KZG99Y2WV9L', 'pasajeros', 67, 1, 43, 49),
(1332, 'Ca', 'IJB3MZGETF0DU06', 'exploración', -1649050, 3, NULL, NULL),
(1333, 'Gimacamu', '9CA11728223CDY5', 'carga', -6098949, 0, 23, 92),
(1334, 'Iza', '3L8G8H6T1G4CAIZ', 'carga', 3802092, 2, NULL, 2),
(1335, 'Ugawo', '7I1A12P08K00342', 'carga', -8, 0, NULL, 2),
(1336, 'Bolazuha', '71OCU1LT754PP54', 'pasajeros', -3, 0, 18, 80),
(1337, 'Jatihafe', 'T60VM7772G7608S', 'carga', -8586834, 7, 22, 47),
(1338, 'Deji', '01IIHN0FC86XKA5', 'carga', -8844620, 11, 23, 37),
(1339, 'Condor', '82X6MR3EL5ELNY5', 'combate', NULL, 13, 4, 34),
(1340, 'Grand Lawovoxuhu', '63RX52Z695OAIV2', 'carga', -1322126, 3, 24, 3),
(1341, 'Ponohu', 'K86C753YQ835A81', 'pasajeros', 912787, 12, 44, 91),
(1342, 'USS Wuloco', '27FPL30PAT8BEK1', 'carga', -554088, 14, 48, 1),
(1343, 'No', 'E0BUT86RHE0773K', 'carga', -8957840, 2, NULL, 56),
(1344, 'Big Gemecu', '70FHQB89CGSF49V', 'carga', 9, 14, NULL, 22),
(1345, 'Big Ozezozoma', '13BR3LV046DZ9P3', 'carga', 3745799, 1, NULL, 58),
(1346, NULL, '7D504ULX47G9X02', NULL, NULL, 1, 26, 87),
(1347, 'Stormy Vinilabo', '70AM9IZG4FHP08G', 'exploración', -22, 8, 25, 53),
(1348, 'Eferelela', 'H885262142B9ST5', 'pasajeros', -4, 8, NULL, 83),
(1349, 'Shiny Voluwerebi', 'R7C369P022PW36Q', 'carga', NULL, 69, 21, 5),
(1350, 'Shiny Fox', '346P5920SF2KXMX', 'carga', 55, 15, 5, 61),
(1351, 'Lil'' Ogiqo', '0G4381525MPU985', 'pasajeros', -7140407, 6, 9, 41),
(1352, 'Little Zeppeling', '1DD4Z8X8C7943LQ', 'carga', 4, 4, NULL, 18),
(1353, 'Lil'' Ralurehuda', 'VNGGMP1QUQCO7F4', 'pasajeros', NULL, 0, NULL, 35),
(1354, 'Loqola', '4ORGG941PJ1FU5V', 'carga', 2203938, 438, 3, 56),
(1355, 'Little Qonapefe', '0KMU0E4R9EVI715', 'carga', 700, 13, 40, 56),
(1356, 'Bubohi', '4J87W37P3AI3SZZ', 'combate', -4348357, 8, 42, 41),
(1357, 'Zeppeling', '29BJ362UO3VEOQQ', 'combate', -151, 11, 23, 45),
(1358, 'Grand O', '5PZSI93P60I5Q3Q', 'carga', -723159, 3, 21, 27),
(1359, 'Grand Simezune', 'TZ97X46Z1NOWF52', 'carga', 5316250, 1, NULL, 83),
(1360, 'Shiny Gusugene', '7R6H8CZC121K1L7', 'carga', 1113681, 0, 21, 14),
(1361, 'Little Acune', 'S08O03A49FF5LH9', 'carga', -791577, 2, NULL, 29),
(1362, 'Shiny Fox', 'YO7QMYJ1CSZ9Y45', 'carga', -7956974, 4, NULL, 73),
(1363, 'Lil'' Qiqolu', 'L2096RO37461804', 'exploración', -7363023, 5, 41, 18),
(1364, 'USS Ciqobu', '5RH8F82QNV1D909', 'pasajeros', 6807155, 0, NULL, 10),
(1365, 'Apemo', '24P70TVD7I6S57C', 'carga', -4407, 10, 49, 23),
(1366, 'Miguquto', '21A83Y6GJJK4R6E', 'pasajeros', 209796, 10, 19, 41),
(1367, 'Sifulu', '61AM4CYSN79QFM7', NULL, NULL, 8, NULL, 19),
(1368, 'Saxofavogi', 'G57071166H0939E', 'combate', -809822, 9, NULL, 68),
(1369, 'Grand Fish', 'L27M1WAKA9Q0H50', 'carga', -5606342, 0, 46, 65),
(1370, 'Lil'' Fucowefifi', '0TA5XUW5R650U39', 'carga', 2401268, 276, 12, 19),
(1371, 'Nabimica', 'YYQ6OG82MWVHNOQ', 'pasajeros', -9928547, 34, NULL, 47),
(1372, 'Hiqa', '0YEFACHO2511M5A', 'pasajeros', -59, 11, 11, 26),
(1373, 'Jiwisa', '89BI759DTY7734J', 'carga', -4383036, 13, NULL, 25),
(1374, 'Jafumuvi', 'C3Y3QL67YWRR39I', 'pasajeros', 2976642, 0, NULL, NULL),
(1375, 'Shiny Iveko', '9T9NT5R184MSA46', 'exploración', 8, 1, 8, 35),
(1376, 'Silver Retuci', 'Z61H05PV36283EO', 'carga', 4463863, 1, 30, 1),
(1377, 'Butterfly', 'YG8WMN7FGX48MV2', 'carga', 7524874, 1, 44, 69),
(1378, 'Grand Liguvehi', 'A5F67DT908NLEM9', 'pasajeros', -8246911, 7, 46, 7),
(1379, 'Big Pinudapo', 'L86SQ3J257P12ZO', 'pasajeros', -4, 236, NULL, 58),
(1380, 'Coku', '0CF91C5DFO9310M', 'pasajeros', -7468, 3, NULL, 92),
(1381, 'Fonusecihu', 'I798WU431P62S6Y', 'pasajeros', -5531062, 4, NULL, 86),
(1382, 'Stormy Une', '30484DP64S6088O', 'combate', 1651405, 0, NULL, 67),
(1383, 'Qijucezewe', '264NN4GXPRC4L03', 'combate', 7062683, 9, 8, 50),
(1384, 'Qipahetozu', '3SG0P8POITPL772', 'pasajeros', -2820085, 5, NULL, 69),
(1385, 'Waqatu', 'Q6155703N65O1F6', 'carga', 534, 0, 8, 74),
(1386, 'Eagle', 'IW8F03OOO2VQU3A', 'pasajeros', -3, 17, 39, 54),
(1387, 'Suki', 'W1YZSJDZ8JVI10K', 'pasajeros', 44, 3, 50, 46),
(1388, 'Fish', '14284PCHLN1C8NY', 'carga', -8125246, 1, NULL, 7),
(1389, NULL, '4PF6HWGU66O67DW', NULL, NULL, 9, 50, 63),
(1390, 'Sicefuhi', '4130B1YA99059NI', 'pasajeros', 292, 11, 25, NULL),
(1391, 'Bivisofipe', '8G4E01RGG88RM45', 'carga', 1844, 5, 17, 40),
(1392, 'Cloudy Ufohu', 'L5D0PJ523HH8Z2D', 'carga', 4790756, 11, NULL, 31),
(1393, 'Butterfly', 'OZ0X807ZC13JX0W', 'carga', -5250, 0, NULL, 29),
(1394, 'Rowe', '697R2XUATM4T3QF', 'combate', -2552446, 1, 15, 55),
(1395, 'Shiny Melivu', 'J8U31O4DGW4HBDO', 'carga', -1160746, 14791, 37, 9),
(1396, 'Butterfly', 'J7291497224PYF3', 'carga', 5207869, 1, NULL, 10),
(1397, 'Fujurewe', 'J718M68MY85B6NM', 'pasajeros', -3187280, 15, NULL, 59),
(1398, 'Natisune', '063AGBN98HGN264', 'carga', 287, 5, 8, 4),
(1399, 'USS Putoduroxe', 'VSQDHV9D1TN742A', 'pasajeros', 7907543, 1, NULL, 32),
(1400, 'Zeppeling', '5E458Y019K7U6EH', 'carga', 1960791, 7, NULL, 38),
(1401, 'Grand Bedeze', '8927SZ6Z17S48LM', 'combate', -4442909, 6, NULL, 20),
(1402, 'Utesilota', '14B6F5524X7SISC', 'pasajeros', -85, 9, 28, 4),
(1403, 'Little Sogepi', 'XH0L549D06AJ2Z5', 'carga', 4336802, 1, 5, 49),
(1404, 'Butterfly', '7P0238JBY62K848', 'carga', -312, 63, NULL, 88),
(1405, 'Stormy Jeremeja', '3Q2E04G04190GV7', 'carga', -2, 14, NULL, 30),
(1406, 'Gevicoxo', '43D93H95N46R11A', 'pasajeros', NULL, 7, NULL, 52),
(1407, 'Grand Uze', 'O7NO15821ZC1QQ0', 'pasajeros', -1624857, 11, 23, 42),
(1408, 'Silver Xapiwa', '32VA1LLXRFMV09W', 'carga', 8113121, 15, NULL, 5),
(1409, 'Lil'' Hebuvujano', '09631M1L88T7G0R', 'pasajeros', 4777459, 2, 3, 18),
(1410, 'Fohapaxofeke', 'LC27E90INTJ798O', 'pasajeros', 7882283, 5, NULL, NULL),
(1411, 'USS Fish', 'J126QW8FA65450F', 'pasajeros', -612, 11, NULL, 75),
(1412, 'Ocu', 'V3920LB588D6440', 'carga', NULL, 10, 3, 12),
(1413, 'Lorinu', 'GVSI6KY2H7SV1NA', 'carga', -3550382, 192, NULL, 7),
(1414, 'Fish', '9KM8626EM50R718', 'combate', -1048664, 4, NULL, 37),
(1415, 'Retececu', '14WENSE20197FZ2', 'pasajeros', -4870823, 9, 16, 41),
(1416, 'Grand Qesu', 'EIIDNN5R5B49GF7', 'carga', -1882008, 1, 1, 63),
(1417, 'Cloudy Zeppeling', 'O97I1IWWHC4YVTK', 'carga', -4764992, 411, NULL, 44),
(1418, 'Vasure', '6V84I24UPIO9627', 'carga', 9894794, 0, NULL, 33),
(1419, 'Silver Gemuzezu', '2Y371VM49YK777Y', 'carga', 363, 14, 43, 2),
(1420, 'Ukefoce', 'U8043B08A266A14', 'pasajeros', 9687644, 13, 16, 19),
(1421, 'Little Muneruki', '29UB0R52LG16316', 'combate', -9960194, 404, NULL, 88),
(1422, 'Fitimate', '4W7V76C1QZ3V5YI', 'carga', NULL, 13, 5, 20),
(1423, 'Wutomu', '3Y46QT81X9VE31D', 'carga', 99, 1, 22, 81),
(1424, 'Grand Wukaqo', 'I7NHM4DEUSA1V71', 'carga', -9, 11, NULL, 85),
(1425, 'Grand Ejudi', 'YUX4554YJG6PH4G', 'carga', -6491, 1, 3, 75),
(1426, 'Shiny Condor', '5V5RO183154Q9UZ', 'exploración', -2058825, 0, 42, 55),
(1427, 'Silver Dosa', '68IR5T1RT834138', 'combate', 446, 14, NULL, 5),
(1428, 'Sixemiwida', 'QXJM208O02A33PT', 'pasajeros', -7656988, 2, 24, 31),
(1429, 'Stormy Dixakaqi', '8LAYAC2FFTDX271', 'pasajeros', 85838, 10, NULL, 24),
(1430, 'Little Fish', 'I42RT05T671TX71', 'carga', -1684311, 8, NULL, 32),
(1431, 'Golden Tojilu', 'EI743A5229XLM00', 'carga', 9722588, 11, 49, 32),
(1432, 'Stormy Zeppeling', 'OO9108OHULT4360', 'exploración', 1863226, 8, 34, 17),
(1433, 'USS Fox', '825V959L0P78I4E', 'carga', 3415373, 2, 38, 55),
(1434, 'Vuhuka', '4R647F1KOH21F9W', 'carga', 1184794, 0, 46, 49),
(1435, 'Cloudy Tukelaga', '5K64JT8Y60W0Q2C', 'pasajeros', 2118750, 0, NULL, 37),
(1436, 'Ziqope', '91LJQ2364906C32', 'carga', NULL, 3, 23, 88),
(1437, 'Fox', '897IZKX5I7Q0102', 'carga', 7677805, 13, NULL, 81),
(1438, 'Zoqe', '04LLBQ836UE7Y77', 'carga', -9313491, 8, NULL, 53),
(1439, 'Golden Fish', 'X496JQC9S8U535Z', 'pasajeros', 795483, 342, NULL, 6),
(1440, 'Shiny Fish', '6X1TKVQKVGQ3I35', 'combate', 5741864, 3, 13, 26),
(1441, 'Eba', '42V600TMX944J9G', NULL, NULL, 1, 12, 81),
(1442, 'USS Ixefu', 'LD40292EW96O3ZI', 'carga', NULL, 112, 35, 67),
(1443, 'Cireqoke', 'MS0U23345929KLD', 'combate', -3730158, 14, NULL, 63),
(1444, 'Taceculubi', 'UZ06FQO426BJDW2', 'exploración', 679, 2, 18, 50),
(1445, 'Fitilu', '3SUZZIS42519FPY', 'carga', -3584761, 0, 24, 96),
(1446, 'A', 'A58P495DBA04KY3', 'pasajeros', -5, 481, NULL, 72),
(1447, 'Seteda', '50ZNZ0TE51OG0P8', 'exploración', 6, 12, NULL, 8),
(1448, 'Golden Butterfly', '2ENAW3O5BR8LRSH', 'combate', 95, 5, 45, 47),
(1449, 'Shiny Ijulopi', '7D7Y3Q9874XDVR6', 'carga', NULL, 15, 2, 85),
(1450, 'Grand Pahufi', '167X1V1B020Q3K6', 'carga', 9696394, 4, NULL, 76),
(1451, 'Cloudy Rexijawezo', 'Q6G45I2LHAPZ80V', 'pasajeros', -2664441, 10, 50, 95),
(1452, 'Puhehucidu', '94YOEXK8AD5GKMK', 'carga', -2557518, 11, NULL, 20),
(1453, 'Ije', '7R85EY218I26633', 'pasajeros', 6, 0, NULL, 59),
(1454, 'Shiny Vi', '3SPBTO71338X717', 'exploración', 1758191, 11, 46, 42),
(1455, 'Grand Mupetaza', 'L409N6LD6C6138X', 'exploración', NULL, 13, NULL, 84),
(1456, 'Jujadaqe', '3LA8296CCM800N5', 'carga', 143779, 0, NULL, 49),
(1457, 'Jilu', 'Q7CS47R3A2X2W09', 'carga', -67690, 12, 39, 72),
(1458, 'Zeppeling', 'J55PIKE5UK9RT28', 'carga', 7047445, 11, 29, 67),
(1459, 'Hulu', 'F9WHS25JRZY6YML', 'carga', -4639409, 12, 43, 77),
(1460, 'Sicoqoho', '104I6F5H93Q587R', 'carga', -578698, 13, NULL, 22),
(1461, 'Uhahucevo', '155B3KW97P2G821', 'carga', 3291752, 11, 45, 73),
(1462, 'Condor', 'XGOT6G6995VO3UM', 'pasajeros', -4996016, 0, NULL, 26),
(1463, 'Stormy Ifoni', 'O52722J0GN9WP80', 'pasajeros', -1014437, 2, 20, 51),
(1464, 'Lil'' Condor', 'X9PB052XK1N216H', 'pasajeros', 5, 580677, NULL, NULL),
(1465, 'Gizofo', 'S5ZWOUN0UPE8F40', 'carga', -7780812, 8, NULL, NULL),
(1466, 'Big Eagle', '82P98O0UM8LAZ35', 'carga', 38, 0, NULL, 67),
(1467, 'Vitiwu', 'U9KEU4V66773410', 'exploración', -8822067, 0, NULL, 38),
(1468, 'Fox', '9SKD7E7D6U1H616', 'carga', -7292997, 5, NULL, 16),
(1469, 'Apozici', '66W2QQNZ81T6405', 'combate', 1923705, 3, NULL, 32),
(1470, 'Coqujevuzu', '463UMA208QNTT03', 'carga', 3026638, 1, NULL, 86),
(1471, 'Silver Piziwuluhe', 'UBI0TP15RQQOJY1', 'carga', -5353, 8, 22, NULL),
(1472, 'Panidegi', 'P7GA22YJZC30813', 'carga', -9, 0, NULL, 89),
(1473, 'Cloudy Jefosazika', 'IV58A7F82573NG3', 'pasajeros', -42303, 1, NULL, 72),
(1474, 'USS Catatofe', 'QUF41NB731R2X44', 'carga', 1234182, 0, NULL, NULL),
(1475, 'Golden Zeppeling', 'G4403O2102STS0E', 'carga', -4779920, 0, 3, 99),
(1476, 'Stormy Zeppeling', '49XJC23292LL0W5', 'carga', -5191278, 141, NULL, 81),
(1477, 'Silver Butterfly', '5J30Z7OFMZD3M53', 'exploración', 9, 0, 22, 71),
(1478, 'Pihocosequ', '9M7U6E0J79X4628', 'pasajeros', -444, 15, NULL, 43),
(1479, 'Xevedewuluxu', 'BAV2I83Q594SO1K', 'exploración', 8531817, 12, NULL, 40),
(1480, 'Shiny Gafu', '7MFJR2VJD0VK83P', 'carga', 7222239, 7, NULL, 38),
(1481, 'Eginegakoku', 'AT92316I3B4945E', 'carga', -4, 0, 24, 49),
(1482, 'Shiny Rirovo', '8E25AHL1X96L4Y1', 'pasajeros', -5802330, 6, 27, 85),
(1483, 'Shiny Kijuwiha', 'MA7884VGDHWAJVQ', 'pasajeros', -8111944, 433, NULL, 88),
(1484, 'Big Fish', 'W12X226F43578I2', 'carga', -13, 13, NULL, 32),
(1485, 'Kefihe', '386FEPD3A2N4DE7', 'carga', 5105693, 9, 9, 5),
(1486, 'Vumaqe', '1T447SKZH313846', 'carga', 6652577, 1, NULL, 53),
(1487, 'Big Hujomi', '79LTWEH80OF0462', NULL, NULL, 1, 39, 2),
(1488, 'Shiny Curice', 'M2B1Q072XB3Z9EJ', 'carga', 405, 1, 25, 15),
(1489, 'Ani', '0C8FV52O45K0639', 'exploración', 9520130, 14, 28, 8),
(1490, 'USS Tujuta', '6O99DCT9TMU8RPY', 'pasajeros', 4, 1, 13, 7),
(1491, 'Zonubafu', '6LC78I7GMB1LOR5', 'pasajeros', -4465177, 1, NULL, 57),
(1492, 'Fox', 'L8309JQ45C0S3KT', 'carga', -7047316, 0, 28, 49),
(1493, 'Shiny Condor', '7R69Y99UU9K17PI', 'exploración', -6101794, 168, 21, 5),
(1494, 'USS Eagle', 'JUUF5VF0V4KCECE', 'pasajeros', -79, 1, NULL, 84),
(1495, 'Huriwogaje', 'XK8CTMUQXBCU015', 'carga', -1175692, 1, 33, 58),
(1496, 'Nodohotula', '8DQLKV61E4065I1', 'carga', -524406, 1, 37, 32),
(1497, 'Pejulise', 'J08B7RR0PUU71CM', 'carga', -1551551, 15, 30, 21),
(1498, 'I', '0UD4T03L0357R5X', 'carga', 5265397, 6, NULL, 5),
(1499, 'Ruzomi', '44B32IE0N85J51H', 'carga', -98933, 8, 49, 98),
(1500, 'Etola', '77YMV3L3S47A6YW', 'carga', -8661449, 407, NULL, 30),
(1501, 'Ubi', '7Y948BMD71STF5R', 'combate', 591, 361, NULL, 7),
(1502, 'Shiny Jusomoka', '3T199B9U6DG0OQ2', 'pasajeros', 8025742, 1, 23, 72),
(1503, 'USS Tahequfoqiva', 'H47H7O1ZN68HGLT', 'carga', -4, 1, NULL, 28),
(1504, 'Zuwuho', '1552MB3UYM8537M', 'exploración', -3604006, 12, 37, 55),
(1505, 'Dikexoqo', 'RX9PX4500VRN8QV', 'carga', 511831, 0, NULL, 24),
(1506, 'Eagle', '12PC0IO6K679027', 'pasajeros', 3655469, 1, 20, 4),
(1507, 'Bofanarijo', '8XGN67WEL8XQQ60', 'carga', 1982045, 0, 29, 89),
(1508, 'Shiny Ijekecobu', '62WHU7D70RKPB46', 'carga', -4131179, 11, 47, 21),
(1509, 'Cinaduvo', 'SVH390HWH757KBP', 'carga', -3978, 1, 46, 86),
(1510, 'Silver Ufibefuga', 'L4H2BL3DB9LC71J', 'carga', 1, 8, NULL, 91),
(1511, 'Stormy Eagle', '85N7O2F05R2RKM3', 'pasajeros', -8404338, 1, NULL, 71),
(1512, 'Stormy Qamoca', 'O85226E6U1B6F0K', 'carga', 1725857, 0, NULL, 1),
(1513, NULL, 'DL7227J2PU58YKM', NULL, NULL, 1, 48, 22),
(1514, 'Ikumixi', 'TK3KIV5O4A08Z7E', 'pasajeros', -57, 0, 37, 72),
(1515, 'Golden Okici', '0CM70GZ3OJROO5X', 'carga', 80, 1, NULL, 10),
(1516, 'Hokiqu', '5I81UKU30P1L27D', 'exploración', -17, 14, 4, 67),
(1517, 'Little Sogo', 'BPEDUJ39ZW2F100', 'exploración', 7126369, 0, 50, 13),
(1518, 'Gepo', 'ZX515VBTN0737GC', 'carga', -4211703, 2, NULL, 97),
(1519, 'Big Bobiho', '7O750654Y3YSW0M', 'combate', -3929813, 12, NULL, NULL),
(1520, 'Fuvijo', 'FHO99P4AC3Z9U31', 'carga', 7, 9, 25, 38),
(1521, 'Grand Qahazuqosa', 'O6S5FWG9G07V626', 'carga', 2532817, 358, NULL, 42),
(1522, 'Rowajoxo', '0JRPWES9925KB52', 'carga', 0, 0, NULL, 87),
(1523, 'Shiny Farudani', '5X4ML6ONNCR54XD', 'exploración', 8517241, 1, 24, 21),
(1524, 'Cloudy Condor', '99JK81JB17QB0I9', 'exploración', 3990843, 8, NULL, NULL),
(1525, 'Big Uzikozoki', 'P981E3YJ18Y76FP', 'pasajeros', 1328521, 11, 35, 53),
(1526, 'Big Nosiku', 'E31325WJ9697V9U', 'carga', 4684820, 1, NULL, 31),
(1527, 'Lil'' Decife', 'RP3JJ8Z4RIEKNMY', 'pasajeros', 8873926, 14, NULL, 11),
(1528, 'Cloudy Ebogo', 'QTU8J14N19BYKGR', 'carga', -3676, 285798, NULL, 74),
(1529, 'Lil'' Doniza', '3090126B26DRN44', 'carga', 2539241, 1, NULL, 98),
(1530, 'Eduxoje', 'UQPGXYFG702X077', 'carga', 5937669, 1, 17, 68),
(1531, 'Hiceho', '9JYVXPWHMX0MNFI', 'carga', -4459399, 8, 33, 4),
(1532, 'Deconacela', '1809U551OE28CNI', 'combate', 1033870, 5, 3, NULL),
(1533, 'Icemudo', 'C1658GVV02F18X2', 'pasajeros', 7202352, 358, NULL, 35),
(1534, 'USS Fish', '176V13B50ZME9V6', 'carga', 353, 14, 30, 45),
(1535, NULL, 'RI8LJ5C87AUD709', NULL, NULL, 7, 23, 21),
(1536, 'Butterfly', 'I4PJ9X3R92ZV59Q', 'carga', -2259789, 0, NULL, 40),
(1537, 'De', '16FR3HR64IFIUQ8', 'exploración', 136, 9, 35, 11),
(1538, 'Socabi', 'H83MF615D4W8C42', 'carga', 9, 6, 20, 39),
(1539, 'Silver Wepodexahico', '99DA6697R8CA23M', 'pasajeros', 7, 2, 23, NULL),
(1540, 'Grand Butterfly', 'L444LT5G9EFQ510', 'exploración', 5921290, 9, 28, 29),
(1541, NULL, 'QE9RKQ4597A3313', NULL, NULL, 355, 33, NULL),
(1542, 'Butterfly', '65TNJ97QAQET62A', 'carga', -4, 7, NULL, 95),
(1543, 'Little Aqana', 'R9E81W5912SIU76', 'pasajeros', NULL, 9, NULL, 65),
(1544, 'Big Ditake', 'U5NC5R63E357O4H', 'pasajeros', 4205483, 380, NULL, 96),
(1545, 'Pufu', 'SQ0S1KBDT9TSUK6', 'pasajeros', -719, 456, NULL, 46),
(1546, 'Bola', 'S3ND4J9XGI3D6MI', 'carga', 360, 1, 21, 65),
(1547, 'Fox', '186V268X1R41Y56', 'carga', 7026217, 1, 10, 78),
(1548, 'Gifuku', '8FX8F81T44UTIB8', 'exploración', 8361698, 12, NULL, 18),
(1549, 'USS Zeraxerina', 'DOMRW66M2ZO338T', 'carga', 8801253, 0, NULL, 81),
(1550, 'Silver Qewequnu', 'A569V89C2E8XU90', 'carga', -546, 12, 24, 29),
(1551, 'Stormy Jabico', 'XHCB3941RGW86O3', 'pasajeros', -7300169, 0, 33, 46),
(1552, 'Haqowi', 'S05036C4P0O3QX4', 'exploración', -3978213, 5, NULL, 75),
(1553, 'Uhufe', 'U0NVU6W8V084RK8', 'carga', -4072, 187, 11, 35),
(1554, 'Tasaqabuzetu', 'V31OAX1ZEP4QIXN', 'pasajeros', -2732077, 1, 21, 71),
(1555, 'Wuloji', '79XMW3T1NE461ON', 'carga', -6720176, 1, 42, 10),
(1556, 'Golden Dutoge', '8LI97961R32M5NI', 'carga', 3824877, 10, 6, 30),
(1557, 'Xirihi', '8B95OKL5U21VJ0V', 'pasajeros', NULL, 0, 42, 26),
(1558, 'Lil'' Ipa', '659PXWM11D9N430', 'combate', -8141146, 6, 32, 92),
(1559, 'Silver Nolovu', 'Z3F332A7BVT5JFB', 'combate', 5296387, 14, NULL, NULL),
(1560, 'Qekabiwi', '9WM3TKFF0GUJS9B', 'pasajeros', 215, 67, NULL, 31),
(1561, 'Ixa', '7Q6B769GOLUTPB6', 'carga', -8424213, 6, 44, 24),
(1562, 'Evihiqi', 'T7DER4KB1S2GG12', 'carga', 6213469, 0, NULL, 31),
(1563, 'Fegonuza', 'MM7AW8OE3J1AVLC', 'carga', -565, 5, 4, 66),
(1564, 'Lil'' Weqonadu', '74X12L0H11VYXY6', 'carga', 4056805, 0, NULL, 34),
(1565, 'Ifosuto', 'W62I9L24W1745M4', 'pasajeros', 3366217, 4, 48, 42),
(1566, 'Egowo', 'D4S3KVWN1365SOY', 'exploración', 9497659, 11, 6, 42),
(1567, 'Stormy Kidozi', '4XF526262B7590I', 'exploración', 645403, 1, NULL, 21),
(1568, 'Big Tebagodu', '0WHC2W8TG96R53Z', 'carga', -8086, 3, NULL, 90),
(1569, 'Grand Geluza', 'WWX42Q148BUCKX1', 'combate', -6596479, 11, NULL, 39),
(1570, 'Upowaqe', '5A6DW17774YA9M2', 'pasajeros', -77, 0, 19, 16),
(1571, 'Condor', '4U1GO98H5IJ062F', 'carga', -4509791, 5, 18, 17),
(1572, 'Golden Pezatu', 'L41LU18I561WSF2', 'carga', 8545414, 5, 45, NULL),
(1573, 'Unipa', 'VZ5JTE6SA2TTMNZ', 'carga', -515697, 1, 50, 53),
(1574, 'Oliripami', 'V5VUX62IW402Q9Q', 'combate', 941, 1, 33, 97),
(1575, 'Apoluwope', 'T398K019PS6XQJH', 'carga', 464, 5, 19, 63),
(1576, 'Lil'' Zu', '823650C6655T2K5', 'pasajeros', -74, 2, NULL, 66),
(1577, 'USS Otanada', '63PWGHGDN487Z9T', 'carga', -215, 0, NULL, 62),
(1578, 'Cadero', '8RZ4292E88PFI14', 'pasajeros', 821759, 1, NULL, 15),
(1579, 'Dowezi', '82OUITOPOEYA8RS', 'carga', -1383549, 8, 26, 8),
(1580, 'Shiny Pafohome', 'SRV2Y80L61K4V34', 'pasajeros', 2215199, 6, 34, 7),
(1581, 'Stormy Iloledezo', 'XFTLU45HZRL8B00', 'carga', 3576345, 1, 3, 100),
(1582, 'Cloudy Lo', '9KU4PRL46PBE3ED', 'exploración', -8189273, 12, 22, 7),
(1583, 'Hatone', 'PR2V4409G04TZJV', 'carga', 9122217, 329303, NULL, 67),
(1584, 'Wodede', 'I679294S25YQWDY', 'carga', -9732398, 2, 33, NULL),
(1585, 'Grand Puxiku', 'R6OEWTL7E3303TJ', 'pasajeros', -2349275, 177, NULL, 79),
(1586, 'Cloudy Gilafiqeqi', '0MGV64BAINR9YW6', 'carga', -7668, 12, 39, 39),
(1587, 'Grand Zuniduqa', '7Q70DLVD542C9BW', 'carga', 5, 13, 38, 30),
(1588, 'Little Ramoviqame', '4C4BJ228S215995', 'carga', 3525726, 454, NULL, 21),
(1589, 'Ojimope', '5H70YCN25691IN6', NULL, NULL, 7, NULL, 11),
(1590, 'Golden Oxorahiwaga', '8RGGZP2EAOLPCZD', 'pasajeros', 9865629, 6, NULL, 41),
(1591, 'Vorojegu', 'V6VH21RXXI3TXFX', 'carga', -5534234, 459, NULL, 9),
(1592, 'Lil'' Kemace', '7Z09CL0339PW09L', 'pasajeros', -2197381, 0, NULL, 56),
(1593, 'Butterfly', 'L235QDCD6WT4854', 'carga', -5241, 7, 3, 8),
(1594, 'Wime', 'J4D4JC46I7WYHAN', NULL, NULL, 10, NULL, 71),
(1595, 'Big Qehavigupi', '8K5PEY58M291SNI', 'pasajeros', -5928660, 7, 4, 88),
(1596, 'Ifa', 'G59T3J84845GHXE', 'carga', -9064937, 12, NULL, 7),
(1597, 'Big Wimuna', '2IA4OPF90ELOQ65', 'carga', -4532411, 12, NULL, 45),
(1598, 'Golden Icofipu', 'G61038L6S87SE8A', 'carga', -6, 9, NULL, 92),
(1599, 'Stormy Melikira', '40ZBNU3P98O5497', 'carga', -5613492, 11, NULL, 77),
(1600, 'Lil'' Wexice', '888TVY4G58F866J', 'carga', -1819337, 10, NULL, 46),
(1601, 'Kabegigu', 'F6TB5T8452XTON3', 'exploración', -9708169, 242, 31, 15),
(1602, 'Dami', 'G22N565M0PRB012', 'pasajeros', 370, 2, 4, 14),
(1603, 'Big Fish', 'S2MIA3703L5X4M4', 'carga', 176934, 251479, 49, 53),
(1604, 'Silver Afofebu', 'DF58ONE80Z44D70', 'pasajeros', 6220133, 5, 3, 29),
(1605, 'Gocerubuzo', '5E42931D92H26I4', 'pasajeros', -5599868, 9, 43, 81),
(1606, 'Gapumi', 'N168V64X8K2BB5P', 'carga', NULL, 0, 8, 36),
(1607, 'Big Hatamigewu', 'U8KY50R8W4D81S0', 'pasajeros', NULL, 13, 5, 11),
(1608, 'Silver Butterfly', '8MU28L835PYSPYA', 'carga', 6334377, 2, NULL, 2),
(1609, 'Shiny Daloleba', '01T3W55BO42WSNR', 'carga', NULL, 15, 41, 22),
(1610, 'Cexokuho', '6H2TGBE83AZ5L1L', 'carga', 8097939, 5, NULL, 85),
(1611, 'Urifa', 'NKWEQ4VB6KOBK9F', 'combate', -167569, 15, 30, 77),
(1612, 'Xugaluqido', 'B97OM4R73R0C643', 'pasajeros', -8783012, 0, NULL, 49),
(1613, 'Boruzu', 'GB8MX1186NA72AM', 'pasajeros', 961842, 1, 34, 59),
(1614, 'USS Qoki', '7G1CAP9D813Y90A', 'exploración', 33158, 46, NULL, 93),
(1615, 'Jarubanu', 'LS418Z9NH8SY95U', 'carga', -1459404, 3, 1, 95),
(1616, 'Wuqecaki', 'B4Q5ZO714MS77GN', 'carga', -9325075, 0, 43, 8),
(1617, 'Fadupune', '47FBK061QI4QRFM', 'carga', -4368156, 0, 21, 19),
(1618, 'Nesela', '8U425G6P91NQM89', 'carga', 5873294, 109, 20, 99),
(1619, 'Amilepice', 'AUWE3N9K95VE8F4', 'carga', -8429904, 2, NULL, 88),
(1620, 'Onaqe', 'E2245LG6KGHNTN8', 'pasajeros', NULL, 5, 47, 54),
(1621, 'Cloudy Micozurenope', 'RSJ2SNA22XA5018', 'carga', 514685, 10, NULL, 16),
(1622, 'Johozibe', '68EL41TA4W0VQ8P', 'carga', -6, 1, 8, NULL),
(1623, 'Ixixetosu', '3HZGKBB8B48MT8H', 'pasajeros', 3593248, 0, NULL, 34),
(1624, 'Iremati', '4PKTK890GGQB3AF', 'carga', -7, 1, NULL, 84),
(1625, 'Rivexuku', 'NT3R17NBEB776MS', 'pasajeros', -6039638, 1, NULL, 10),
(1626, 'Sigoco', '3400N067FPB0F73', 'carga', -75247, 3, NULL, 65),
(1627, 'USS Gicetage', 'HW6187NV3R3H96R', 'carga', 5899736, 1, NULL, 78),
(1628, 'Shiny O', 'S63HV39UZ33FBCS', 'carga', -6168842, 10, 47, 61),
(1629, 'Egeqofoti', '14I1EOV453Q03UJ', 'carga', -8282730, 15, 13, 73),
(1630, 'Cloudy Ifiso', '856783PU9R74XX5', 'pasajeros', -1192779, 15, NULL, 18),
(1631, 'Butterfly', '7M4NY8R86F873EU', 'pasajeros', 2700514, 5, 31, 24),
(1632, 'Butterfly', 'FCLCWDLV0X7YAJJ', 'carga', -4059476, 8, 46, 62),
(1633, 'Shiny Dikavo', '322T35I034OO210', 'carga', -4379861, 7, 15, 38),
(1634, 'Golden Zejevemiko', '3EWM0S76947JRH8', 'combate', 5793548, 444, 41, 14),
(1635, 'Poremi', '3U393Y6XT1L8WIP', 'pasajeros', 6531213, 388, NULL, 98),
(1636, 'Stormy Ifi', 'A678SWYT587B8EB', NULL, NULL, 9, NULL, 48),
(1637, 'Shiny Afi', 'JUAX8O5I37570I6', 'pasajeros', -69, 4, 8, 22),
(1638, 'Cakemo', 'FTA981RUJKH7KYR', 'carga', -4081876, 0, 36, 39),
(1639, 'Grand Atovi', 'H13F9Y4076992L4', 'pasajeros', 1620281, 1, 50, 71),
(1640, 'Feto', '797H78D2DEL2UR3', 'combate', -381, 9, NULL, 26),
(1641, 'Hufanuho', 'BN079ZW07KHK3OP', NULL, NULL, 1, NULL, 6),
(1642, NULL, '33CZ25YZD57K793', NULL, NULL, 373, NULL, 7),
(1643, 'Fish', 'J2U11T1U07BUL81', 'exploración', -2632, 0, 1, 83),
(1644, 'Big Suwatu', 'V36S160938P47O6', 'carga', 3329865, 2, NULL, 87),
(1645, 'Daboja', '0R71Z149WVS1X7P', 'carga', -1241578, 0, NULL, 56),
(1646, 'Cloudy Wamezuzu', 'O623258895Y7L5R', 'carga', 2649978, 3, 2, 19),
(1647, 'Ruboru', '86VUE941Z6R907J', 'combate', 9910372, 1, NULL, 82),
(1648, 'Bojuda', 'Y60ABLQYWXOM3CK', 'carga', -8, 2, NULL, 2),
(1649, 'Wusejone', '4FC11933JOEOL2U', 'carga', -7561681, 145, NULL, NULL),
(1650, 'Xifuso', '1WG05LV8QGAOI9Q', 'pasajeros', 487, 8, NULL, 83),
(1651, 'Qelusegoma', '54586LONV8M9GWG', 'pasajeros', 2928059, 7, 24, 45),
(1652, 'Ihasucu', '3YCPAX74C6PR4Q5', 'pasajeros', 9123240, 204, NULL, 5),
(1653, 'Ufodiha', 'C7ATJU2R9KU3340', 'carga', 1143289, 1, NULL, 93),
(1654, 'Cloudy Oganoxu', 'G8Q985D0B40KUT2', 'carga', 773, 8, NULL, NULL),
(1655, 'Shiny Butterfly', '4G571HET52106AM', 'pasajeros', -8328180, 0, NULL, 79),
(1656, 'Dusetonujamo', '4YC86EXSU09H072', 'combate', -8125957, 5, NULL, 53),
(1657, 'Upa', '67QNB9YVTCMDBPL', 'carga', -7395540, 5, NULL, 90),
(1658, 'Ze', 'WX4Y16PWFHK508P', 'carga', -5830038, 61, NULL, 25),
(1659, 'Eagle', '1W2K5CXM79WRU01', 'pasajeros', 523057, 9, 40, 35),
(1660, 'Lil'' Pacufipuka', '9SF9C8Q2W535HT7', 'exploración', 89, 145101, 39, 73),
(1661, 'Iqa', '2VX4Q3LMYLA2A3M', 'exploración', -8922334, 0, NULL, 78),
(1662, 'Grand Ocuvu', 'AV1IKH0I949797N', 'exploración', -4607, 2, NULL, 92),
(1663, 'Stormy Butterfly', 'Z8T9UW78C695G3W', 'carga', -1975164, 4, 6, 70),
(1664, 'Little Nu', '8BQ4518LK1V63FE', 'carga', NULL, 269, NULL, 2),
(1665, 'Lavoxe', '1XL73XIEO2YXGQE', 'carga', -8160558, 249, NULL, NULL),
(1666, 'Big Ufojomu', 'Z6JREAL4P05SLSW', 'pasajeros', 83, 14, 29, 82),
(1667, 'Biqajobomo', 'Y5ASL1U76XXPXLL', 'carga', 4661412, 11, NULL, 53),
(1668, 'Vatadufu', '5616L6J4B35Y07T', 'carga', 17, 0, 16, 100),
(1669, 'Lil'' Wuxe', '8K6026UAGL8OD9S', 'pasajeros', -22, 0, 12, 5),
(1670, 'Golden Vetekehake', 'R5J3A22PZ6LQA4Y', 'carga', -9589651, 0, NULL, 79),
(1671, 'Cijugo', '0XD92C4I440BM0Y', 'pasajeros', -8392949, 7, NULL, 21),
(1672, 'Stormy Tabiwogo', 'R4971I30P397NQL', 'combate', -296001, 129967, NULL, 36),
(1673, 'Sufupefumo', 'Z597W52Q98343S6', 'pasajeros', -4262, 4, 50, 4),
(1674, 'Lil'' Iwilari', 'N88W8VLYXS4I448', 'combate', -4579813, 8, 32, 7),
(1675, 'Kudubogeso', '52851X0597E6097', 'carga', 9705094, 4, NULL, 14),
(1676, 'Big Paku', 'FQA97W552H1C3OJ', 'carga', 1571637, 2, NULL, 44),
(1677, 'Sutima', 'B0808055183Y1GJ', 'carga', -7671164, 1, 3, 48),
(1678, 'Golden Sasuvihi', '3659G42603I0S94', 'carga', 56, 1, NULL, 39),
(1679, 'Little Gifuxo', 'A4BS5N46645K2YG', 'pasajeros', 5246, 397, 44, 90),
(1680, 'Lil'' Jiwora', 'YLZ3AZ1GQ5188W6', 'combate', 610, 9, 25, 24),
(1681, 'Coki', 'EREO0GWW46K111V', 'pasajeros', -2340055, 9, 34, 27),
(1682, 'Tipoxejihe', '8P1B299K3KE1SNP', 'pasajeros', -204186, 0, NULL, 13),
(1683, 'Golden Hozomo', '945D38F81PR75KL', NULL, NULL, 11, 49, 92),
(1684, 'Stormy Wizu', '6YVC61Z3I6E8C74', 'pasajeros', -9685618, 11, NULL, 1),
(1685, 'Butterfly', 'H2J512XEIMR966Z', 'pasajeros', -8241296, 0, NULL, 60),
(1686, 'Little Voru', 'Q7AH03QM0YV3O0K', 'carga', 1478, 5, 18, 53),
(1687, 'Shiny Qoso', '69N0K7AAICT0781', 'pasajeros', -2298, 8, 5, 64),
(1688, 'Bipuba', '512RLG6BC75TIJD', 'exploración', 1395628, 8, NULL, 7),
(1689, 'Fujelami', 'E3D6B379YV31MFI', NULL, NULL, 387, 15, 34),
(1690, 'Zeppeling', '16B483ZO334KOK3', 'pasajeros', 2099961, 0, NULL, 10),
(1691, 'Big Fish', '1UXO317NC4WES55', 'exploración', -8966, 0, NULL, 35),
(1692, 'Condor', 'V5NS7FU73S41R4P', 'carga', 5, 11, NULL, 1),
(1693, 'Cloudy Omuwalu', '3Z5YK241GDGYNN2', 'carga', -5, 2, NULL, 5),
(1694, 'Stormy Tujopixoco', 'H261VHX7MP94L17', 'pasajeros', 23, 0, 16, 2),
(1695, 'Shiny Omapi', 'PVUNXY97DV4NQ00', 'carga', -9, 10, 17, 43),
(1696, 'Obezixa', '1LKD359TN128474', 'pasajeros', -1131073, 0, 29, 8),
(1697, 'Lehoboci', 'XO4T076GVZ1RVQB', 'carga', -5167030, 8, 50, 21),
(1698, 'Nidisosa', '7JLB0Z703O36M08', 'pasajeros', -3496213, 0, NULL, 76),
(1699, 'Padizowa', 'X0R422137063O7W', 'pasajeros', 68, 5, 22, 83),
(1700, 'Wavuzoli', '2B0J9PT5J51W58U', 'pasajeros', -319611, 4, NULL, 83),
(1701, 'Grand Haroxufu', 'Q5M5Q94WZLIC21L', 'combate', -7162866, 0, 1, 41),
(1702, 'Little Okoqoxu', 'H0R9IR49BR3Z2FQ', 'pasajeros', -5759763, 30, NULL, 33),
(1703, 'Gomoduvi', 'W05290UG5OZAF6Q', 'carga', -7846229, 3, NULL, 49),
(1704, 'USS Dufahize', '2KRO4RKBV4L19C8', 'pasajeros', 4627725, 212, NULL, 79),
(1705, 'Lufetisosuke', '872V936P0EQ68C4', 'pasajeros', 230, 0, NULL, 1),
(1706, 'Golden Fish', 'ZQ080NWB08XJ82U', 'exploración', 8368178, 5, 11, 29),
(1707, 'Little Ronedijo', '813B27ML8E07HFB', 'carga', -2012317, 1, NULL, 9),
(1708, 'Anewi', 'WMQ59U5H4W8B7TU', 'pasajeros', 100, 11, 47, NULL),
(1709, 'Nuxa', '9N9WHK5PMF43G1L', 'pasajeros', -9959764, 0, NULL, NULL),
(1710, 'Little Nebefuquge', 'X80M929PQF5R7OD', 'carga', -10, 10, 37, 91),
(1711, 'Owihepo', '248ANYZTZWAA596', 'pasajeros', -8785, 10, 47, NULL),
(1712, 'Fish', '6A5586WN9958E90', 'carga', 665792, 7, NULL, 92),
(1713, 'Quhemome', '942JR97GF10S2X7', 'pasajeros', NULL, 1, NULL, 74),
(1714, 'Golden Masulidomuju', '94GUO8S31306G71', 'combate', -1, 1, 9, 50),
(1715, 'Sogihina', '83I293T5RVENBQV', NULL, NULL, 10, NULL, 85),
(1716, 'Silver Coga', '08AJ64YYRV7433C', 'carga', 4729523, 121, NULL, 91),
(1717, 'Shiny Ihixuke', 'CJWO4662DD4B96I', 'pasajeros', 5229911, 0, 37, 38),
(1718, 'Kexajeto', '119N2DG75N1K4E9', 'carga', 2, 11, 28, 53),
(1719, 'Golden Loqe', '429R0680LSACI43', 'carga', -1825587, 8, NULL, 34),
(1720, 'Higazopote', 'B5M7IBX54ZF8VR4', 'carga', 1023279, 1, 38, 87),
(1721, 'Eagle', '2I04CB8U54ZUQZM', 'carga', 6689, 1, 45, 42),
(1722, 'Shiny Iwilu', '2J18YB6E966WK13', 'pasajeros', -61, 9, 5, 28),
(1723, 'Eagle', 'D2Y057S0D6096X4', 'pasajeros', -993, 0, 46, 26),
(1724, 'Towoke', 'XL31AY5MKP0EFIL', 'pasajeros', -16408, 10, NULL, 24),
(1725, 'Davuci', '5580431JN417EWQ', 'exploración', 7265542, 178, NULL, 92),
(1726, 'Big Eagle', 'VRVP8H9181358YQ', 'carga', -1513529, 12, NULL, 3),
(1727, NULL, '085E6WICK03CPV7', NULL, NULL, 9, 46, 83),
(1728, 'Zizoqe', 'VR9Z9005Y31O677', 'pasajeros', -6127566, 3, 6, 11),
(1729, 'Luqutibi', 'WJ4E00U6F849FHT', NULL, NULL, 0, NULL, 2),
(1730, 'Pupamo', 'DI0D7LCY0XB5K9N', NULL, NULL, 11, NULL, NULL),
(1731, 'Stormy Ebexi', '36FD5IZ27ONK136', 'exploración', 4579956, 1, NULL, 24),
(1732, 'Lil'' Zidulipa', '7A2XS708Z1SAVT6', 'exploración', 189, 13, 33, 84),
(1733, 'Big Kodiduqa', '2076NE2DZS2VHK4', 'pasajeros', -7581956, 4, NULL, 2),
(1734, 'Zeppeling', 'T2827SW75CP70I4', 'combate', 8439, 6, NULL, 77),
(1735, 'Dukafebo', '1C7GU61CN5EOSJW', 'pasajeros', -1148290, 0, 16, 22),
(1736, 'Stormy Kaza', '3Q34QRTSP6XX9UN', 'pasajeros', -4677155, 9, 28, 58),
(1737, 'Cuwutuke', 'M37V200D60AQY84', 'pasajeros', 2681118, 6, NULL, 29),
(1738, 'Ve', '671I95R1CP46PA4', 'carga', -8424746, 15, NULL, 91),
(1739, NULL, 'F4K7KKMQS34QRP1', NULL, NULL, 5, NULL, NULL),
(1740, 'Big Fox', '9CYH4M583LQ8F5J', 'carga', -5552161, 9, NULL, 15),
(1741, 'Mazexoleco', '43W6U5R09ACW086', 'exploración', 2278068, 9, NULL, 15),
(1742, 'Hideta', '09F84P25VW4QUSS', 'carga', 86, 0, NULL, 40),
(1743, 'Silver Gakoxa', '8154VZ1IQH2P64X', NULL, NULL, 11, 17, 24),
(1744, 'USS Hilekado', 'AK4EGT25PV5O13Y', 'carga', 6918223, 5, 32, 61),
(1745, 'Silver Ceru', 'O34S4N63FP0XAP8', 'carga', -2723543, 7, 5, 44),
(1746, 'Big Sodakako', 'P93PX0453C7C0YB', 'pasajeros', -1, 2, NULL, 75),
(1747, 'Golden Do', 'GPI68CB4YJ9YG4X', 'pasajeros', -3887648, 13, 26, 76),
(1748, 'Butterfly', '2W375K31NQ5C0OB', 'carga', 9029, 8, 46, 3),
(1749, 'Tuciwitaro', '8RS8IJR6EK2S7H9', 'exploración', NULL, 9, NULL, 79),
(1750, 'Silver Giboti', '0JAW091R375F1FW', 'carga', -2989954, 11, 7, 32),
(1751, 'Stormy Wucigiriwa', 'H4Y9U7378ZISF22', 'pasajeros', -2757657, 1, 11, 78),
(1752, 'Fish', '04U251I7DI1I02G', 'pasajeros', -43, 45, 41, 29),
(1753, 'Little Gehe', '5UYBOGL2PHK54G6', 'carga', 9302414, 2, NULL, 64),
(1754, 'Fojula', 'C54VN6Y12699J4T', 'carga', 8246875, 14, NULL, 29),
(1755, 'USS Tahaxa', '827Y0H347B39JS9', 'combate', 6947, 1, 22, 75),
(1756, 'USS Butterfly', 'L56Q5482Z0EV0PY', 'carga', -9604954, 7, 30, 42),
(1757, 'Cloudy Ividoxu', '6ER34HIH8OA04J3', 'carga', 9204901, 9, 40, 80),
(1758, 'Darucunisu', 'SN7ZJQ6FZRDJK32', 'carga', 2944637, 0, NULL, 81),
(1759, 'Niwipoha', 'WPV59IG3JG8860P', 'carga', 2568027, 119, 42, 9),
(1760, 'Cloudy Uzuse', '677PW935C24YJD4', 'carga', 958734, 1, NULL, 7),
(1761, 'Big Wohi', 'N3F5JY0Z98DV112', 'combate', 1805, 1, 24, 27),
(1762, 'Condor', '52R74FOLS67P5Y0', 'carga', 9702558, 0, NULL, 11),
(1763, 'Ferovuro', 'W9A75518U400E30', 'pasajeros', 0, 1, NULL, 10),
(1764, 'Big Zeppeling', 'Q5TEJUIDM17A12M', 'carga', -5857449, 4, 41, 71),
(1765, 'Silver Condor', '95A40H84RLAP4P3', 'carga', 2119162, 6, NULL, 63),
(1766, 'Shiny Tucozuvi', '7A0ZJ5CB115G958', 'pasajeros', -608537, 5, 26, 87),
(1767, 'Grand Cufukabero', 'DAE299CXM27OQA5', 'combate', -857, 1, 15, 3),
(1768, 'Alucu', '08E4GN086XAJ028', 'carga', -5515510, 8, NULL, 13),
(1769, 'Mufu', '4Y3525VMP613E90', 'pasajeros', -8849506, 316, NULL, 53),
(1770, 'Lil'' Butterfly', '963MW07J6N46M2K', 'pasajeros', 8, 14, 36, 9),
(1771, 'USS Vamuka', 'L7T789013L0A50T', 'pasajeros', 8816, 7, 45, 59),
(1772, 'Shiny Pati', '136V1787LN4FZY4', NULL, NULL, 1, NULL, 74),
(1773, 'USS Elugaxu', 'PS1GL69D743175P', 'combate', -3570599, 442, 43, 49),
(1774, 'Kazaxi', '73VN0EKL95K09EX', 'pasajeros', -1540975, 1, 39, 5),
(1775, 'Cloudy Eagle', '9R9GX97CO0AMLXI', 'combate', -1491206, 6, NULL, 6),
(1776, 'Tiwu', 'FZ322S5N1H1E2MD', 'pasajeros', 8001443, 9, NULL, 68),
(1777, 'Stormy Pukibi', 'X3DE06Q8S5PXJS1', NULL, NULL, 389, 17, 96),
(1778, 'Wecaquceho', '3R8I4M7J2A6VC5D', 'pasajeros', 6, 7, NULL, 88),
(1779, 'Cerijaqo', '8FN6YLEIZ4GVTG9', 'combate', -9718907, 1, 11, 98),
(1780, 'Cloudy Buzoradomu', '00W9MX7RWBVNF74', 'combate', -4892269, 1, NULL, 72),
(1781, 'Nedaxi', 'TT8OB4K46G11QZ1', 'pasajeros', 3377, 0, NULL, 61),
(1782, 'Wufali', 'A86XQ8662660WU6', 'carga', -387, 311, NULL, NULL),
(1783, 'Eagle', '3485G81J8SXKQ8Y', 'pasajeros', 2294071, 1, NULL, 5),
(1784, 'Golden Zeppeling', '7D6YVA0P8Z1J549', 'carga', 869009, 13, 5, 42),
(1785, 'Cloudy Ho', '6O4C5A92142K451', 'pasajeros', 1135531, 5, 7, 66),
(1786, 'Sasikunaboho', 'C9J0505XI2ZZ6IO', 'carga', -56, 0, 8, 33),
(1787, 'USS Muti', '5B00GVD81639R05', NULL, NULL, 11, NULL, 4),
(1788, 'Stormy Kita', '6B933F2SP9KEM5U', 'combate', 6112711, 7, 3, 51),
(1789, 'Silver Ximo', '05045S76IYN0B8W', 'pasajeros', -4195492, 1, NULL, 46),
(1790, 'Stormy Butterfly', 'S2696R8300ES47E', 'carga', -6506, 6, 30, 83),
(1791, 'Elamedu', 'I5306G4U1QVN562', 'pasajeros', -8455085, 0, 7, 61),
(1792, 'Kezufebo', 'YVE403MOFD5GNY7', 'pasajeros', 9929, 5, 1, 8),
(1793, 'Little Mubuqala', 'O2XTH8GB9B849I3', 'carga', -4885, 3, 9, 30),
(1794, 'USS Jidemede', '83A5K2AI30JV38G', NULL, NULL, 5, 15, 88),
(1795, 'USS Condor', '01TRS8O5B902N0X', 'carga', 3862, 0, 42, 74),
(1796, 'Lil'' Juha', '679DGLWXM261UM1', 'carga', -94, 8, NULL, 3),
(1797, 'Grand Tuxefise', 'MZ9BDUE2GE517T4', 'carga', 4109, 240, NULL, 88),
(1798, 'Big Kaxizeveha', 'BF11042NM7XGAU8', 'carga', 1465, 1, 27, 43),
(1799, 'Dozadadi', '1LM9LM4A010F751', 'carga', NULL, 1, 34, 27),
(1800, 'Lil'' Butterfly', 'XA8510VK94Y96TB', 'pasajeros', 8101017, 6, 9, 98),
(1801, 'USS Ligumufeqa', 'CUTS988659L1Y0V', NULL, NULL, 10, 13, 49),
(1802, 'Hawuniwuxa', '1TPCXO085BA5YOH', 'combate', 70, 1, 34, 63),
(1803, 'Stormy Isa', 'X0060F3NVTXQ45W', 'exploración', -798424, 9, 36, 40),
(1804, 'Tole', '2JZSB2IK7DM57X4', 'exploración', 5026962, 1, NULL, 90),
(1805, 'Onuja', '516WO1119F29YW4', 'carga', 949, 1, NULL, 29),
(1806, 'Big Elokako', 'N0RDVA6N469265I', 'pasajeros', -235159, 109, 28, 32),
(1807, 'Butterfly', '769Z800CYI17SSN', 'carga', 79, 0, 30, 76),
(1808, 'USS Oha', '816IIHIAS3J3MA6', 'pasajeros', -87, 1, 23, 76),
(1809, 'Jeputu', 'Y47XG5937PLPKKU', 'carga', -417, 0, NULL, 95),
(1810, 'USS Mokode', 'R0472K55G49Y0X7', 'exploración', -969349, 10, NULL, 61),
(1811, 'Stormy Fish', '4A4Z4UM803535U9', 'pasajeros', -4438352, 8, 29, 59),
(1812, 'Vojuwi', 'AP8KET15ZQU9ZB6', 'exploración', -5174962, 210, 31, 66),
(1813, 'Oxu', 'D9GIM2E9D26EX32', 'carga', -606550, 137, 8, 94),
(1814, 'Xaqebi', '6Z0TS4LVF28H2M3', 'carga', -7324292, 13, NULL, 13),
(1815, 'Suluvi', 'M701FE2Q971VY58', 'carga', 7984682, 0, 2, 60),
(1816, 'Igi', '0179PCV07QI7A4Q', 'carga', -1076026, 0, NULL, 76),
(1817, 'Fish', 'X04IOLX7V2154Z4', 'carga', 3942865, 1, 25, 97),
(1818, 'Silver Fumifo', 'M3557S7452I368V', 'carga', -776326, 3, NULL, 12),
(1819, 'Fiteqi', 'O517S4OE965U6E2', 'exploración', 9847262, 1, 29, 6),
(1820, 'Silver Poketanemo', 'Y5UXU7KA776SMV8', 'carga', -656, 14, NULL, 79),
(1821, 'Fish', 'WD47F68D78HLA1U', NULL, NULL, 8, 40, 4),
(1822, 'Eagle', 'D7Q6U8KM4K8000X', 'pasajeros', 26, 0, NULL, 9),
(1823, 'Golden Ikeli', '850Q25DCV9VSX31', 'pasajeros', -8210299, 1, NULL, 59),
(1824, 'Shiny Fox', '095K6UXZS582R0Y', 'carga', 3426, 5, 15, 19),
(1825, 'Visi', 'TSLAK36H0JVC2Q4', 'carga', 7269599, 9, 46, 100),
(1826, 'Stormy Tamowi', 'B86529ZN99RT1V4', 'carga', 710, 218, 1, 93),
(1827, 'Tepeba', '8E4ZON0HMR123HO', 'pasajeros', -2650272, 7, NULL, 17),
(1828, 'Grand Vihu', 'P3BK1XAQ9SN341J', 'carga', -983, 9, 36, 8),
(1829, 'Imiro', 'DU62Y96AZC18LT4', 'carga', 2118285, 1, NULL, 56),
(1830, 'Grand Fasoka', 'H8YCI036SJ31PA6', 'carga', 8516091, 0, NULL, 48),
(1831, 'Uxoje', '9AN5D14ZS12765Z', NULL, NULL, 2, NULL, 63),
(1832, 'Shiny Ajeha', 'U7R4I148116WNA0', 'carga', -7634036, 3, NULL, 71),
(1833, 'Qihopobiva', '1801AW46N1KGCNR', 'combate', -84546, 6, NULL, 61),
(1834, 'Stormy Ake', '60X76V48N4AAFZ1', 'exploración', 6778064, 0, 11, 15),
(1835, 'Little Fox', 'C1W8W3A7EB578F6', 'carga', -1614, 8, 43, 72),
(1836, 'Little Ozebofe', '5F1673QSUG8HWSX', 'carga', -4689, 0, NULL, 3),
(1837, 'Zeppeling', '933PXTBU7AX34T1', 'combate', 3429563, 10, 47, 5),
(1838, 'Nuquce', 'A3OYYQLYLCRCY56', NULL, NULL, 1, 28, 39),
(1839, 'Powobesili', 'L12Q79L8J7R5JND', 'carga', 40, 1, NULL, 41),
(1840, 'Atifi', '14GXC74C8A55M7C', 'carga', 2058463, 2, NULL, 81),
(1841, 'Tutukofu', 'U36P2OT8SXMOR85', 'carga', NULL, 118, 4, 13),
(1842, 'Little Wivo', 'TGX299G1VUC1W6X', 'carga', 6955291, 0, NULL, 91),
(1843, 'Condor', 'HUC6G7X24S7467C', NULL, NULL, 12, 29, 22),
(1844, 'Golden Wudimoperu', '32W4I243070X4UD', 'pasajeros', -4495426, 7, NULL, 9),
(1845, 'Grand Fish', 'E900HW2ZG1VV40O', 'carga', 79, 1, 33, 52),
(1846, 'Lil'' Ifuze', 'H16P1696115CUKP', 'pasajeros', -8, 1, NULL, 2),
(1847, 'Xobutefe', '0TET5NQI6J3ZC98', 'carga', -9470431, 5, 25, 58),
(1848, 'Golden Zoxirawa', '02462JBX7NBY92I', 'carga', 841, 0, NULL, NULL),
(1849, 'Modobija', 'G4WC8Q2G5G95DKA', 'carga', 6824361, 0, NULL, 69),
(1850, 'Sategigipana', 'Z0WTU76V5299955', 'pasajeros', 8215815, 193, 27, 79),
(1851, 'Lil'' Sibeqiho', '7V70XR52TOUPQH5', 'pasajeros', -110154, 1, NULL, NULL),
(1852, 'Nezuwosama', '94YP8820OJZ4503', 'carga', 882, 0, NULL, 64),
(1853, 'Shiny Pebihovi', '3SC2T4JH0A6C5T2', 'carga', -6822678, 0, 8, 6),
(1854, 'Golden Anika', '29XR0MV5JZ7F0VN', 'pasajeros', 784963, 3, 16, 7),
(1855, 'Uwakatumu', 'Z8M9971U9LMM364', 'carga', NULL, 2, 19, NULL),
(1856, 'Lil'' Oba', '3SI0N92FG47P35I', 'carga', -1277423, 9, 45, 54),
(1857, 'Nifezedipe', 'B3G3GM01N0U1259', 'carga', -5305545, 418, NULL, 1),
(1858, 'Shiny Biqagiwe', 'F49Q1G48AV51BBS', 'pasajeros', NULL, 0, NULL, 58),
(1859, 'Cloudy Eagle', 'HD3T08G36TA67LN', 'pasajeros', 3075351, 9, NULL, 11),
(1860, 'Hovozahiga', 'U3Y5B367610M96R', 'combate', -93, 1, 32, 36),
(1861, 'Fejenoho', '59TN77P445P8UUS', 'carga', -149, 14, NULL, 44),
(1862, 'Ejuwepe', 'Z89L8Z9I4R4C85Z', 'carga', 632119, 12, 28, 7),
(1863, 'Big Temiru', 'V79F91W220N5Z61', 'carga', 2316002, 1, 21, 46),
(1864, 'USS Naba', '0Y4X29FILYM33L3', 'carga', NULL, 196, NULL, 49),
(1865, 'Cloudy Sedego', 'TN8879R994S8806', NULL, NULL, 15, NULL, 38),
(1866, 'Fotehucuzu', '48SIYVV57FGN1MD', 'carga', -4615, 339, NULL, 52),
(1867, 'Condor', 'K05E4J1V0363Q0Z', 'carga', 1757237, 15, NULL, 40),
(1868, 'Cloudy Condor', 'ZANIII24NL9KJ0F', 'combate', 4623540, 14, NULL, 64),
(1869, 'Grand Vucizi', 'O73199R79E71BL8', 'combate', 770, 0, 46, 17),
(1870, 'Nujozupu', '7098G63R17X344N', 'pasajeros', -7779425, 0, 50, 50),
(1871, 'Golden Condor', 'EC9ZOJEP75RHT4X', 'pasajeros', 8, 226, NULL, 55),
(1872, 'Ozari', '8RR726LU3O8CMAK', 'pasajeros', 6255331, 1, 7, 48),
(1873, 'Lil'' Anute', '44772F68SVYTDM8', 'pasajeros', -4987475, 10, NULL, 57),
(1874, 'Ilumuxumu', '8W37YWMWZR1KFS5', 'carga', 5200901, 14, 28, 39),
(1875, 'Stormy Fish', '4545697ZPK4F29U', 'pasajeros', 4036066, 6, 21, 2),
(1876, 'Fox', 'J2L910901N586K6', 'carga', -7030571, 1, 18, 59),
(1877, 'Condor', 'FN57PO5A8ZB8S70', 'carga', NULL, 9, 22, 79),
(1878, 'Golden Fish', '234F373TU6WUNO5', 'pasajeros', -6316290, 6, NULL, 71),
(1879, 'Colo', 'M22R6L4FA93I296', 'carga', 46, 9, 28, 66),
(1880, 'USS Lenu', '63HLPW2TR0AFR4J', 'carga', -6753113, 11, 2, 5),
(1881, 'Mimi', 'H548832XC3OP44A', 'combate', 2360643, 6, NULL, 34),
(1882, 'Ziba', '0VE113143R72P69', 'carga', 2184474, 1, NULL, 14),
(1883, 'Zeppeling', 'X8N32XR197N8O8A', 'carga', -8341430, 0, NULL, 57),
(1884, 'Butterfly', 'T4237LT2BJ5955B', 'carga', -486, 0, NULL, 84),
(1885, 'Shiny Idaraxomu', 'K7IUR2H7Y3117XM', 'carga', -9355102, 277, 34, 99),
(1886, 'Fish', '64KJ96R8OVSW460', 'combate', 1453365, 8, 43, 1),
(1887, 'Golden Ilu', '4RT7Q3310Q8O6ZC', 'pasajeros', -9, 11, 47, 17),
(1888, 'Big Moxuki', '13JPSKG17A12Q08', 'pasajeros', -6582165, 14, 38, 28),
(1889, 'Kagike', '3977Y1V6OT9I996', 'pasajeros', 7013025, 2, 13, 99),
(1890, 'Golden Duwonigo', '0AOZ7WTDWU33IB3', 'combate', 529854, 0, NULL, 62),
(1891, 'Cobizi', '2RYIP4QV0NOZ7IH', 'pasajeros', -619, 0, NULL, 86),
(1892, 'Cecifi', '9RBE22QF3D0704U', 'pasajeros', -27, 1, NULL, 44),
(1893, 'Big Ropepuke', '5482ZNETQ62924N', NULL, NULL, 9, 26, 70),
(1894, 'Bovaka', '726BSAI77CIBN2F', 'carga', 8749340, 458426, NULL, 74),
(1895, 'Stormy Puhemune', 'CCI5Q9D321OZWXO', 'pasajeros', 2065963, 420, NULL, 31),
(1896, 'Golden Birekesu', 'TEDRQ93OT18TDNZ', 'exploración', -65, 6, 48, 49),
(1897, 'Silver Opusi', '56G07K16WJ9R863', 'combate', 5, 1, 23, 12),
(1898, 'Cloudy Eagle', '15B547521VB29U7', 'pasajeros', 707308, 8, NULL, 9),
(1899, 'Nagipedewevo', 'L5CQ606138I2WW5', 'carga', -7554484, 0, 50, 22),
(1900, 'Big Mucaho', 'L793BN4X974MCU7', 'pasajeros', -3637534, 0, 29, 57),
(1901, 'Fotipipade', '8G498I3SD3X2TY7', 'carga', 3946290, 3, 25, 61),
(1902, 'Hakohu', 'Y44G8A9L89HL402', 'exploración', -5912201, 385, 2, 10),
(1903, 'Fish', '2VSPP5LXCAU8A95', 'pasajeros', 8078954, 182, NULL, 88),
(1904, 'Golden Otuzexahu', '77PH89126HR7GQB', 'carga', -9295653, 0, NULL, 40),
(1905, 'Agapeka', '0S60195IGXJOT8O', 'carga', -31, 1, NULL, 27),
(1906, 'USS Mu', 'GL7Y966LHF1N512', 'carga', 8469197, 1, NULL, 22),
(1907, 'Huvo', 'F3K4P33U6WN5W00', 'carga', -3209084, 5, 5, 6),
(1908, 'Stormy Rekucekiju', 'B7LS4564P93P3O0', 'pasajeros', -3, 13, 1, 62),
(1909, 'Gojadi', '36C16O8JDITO06M', 'carga', -4383017, 15, 5, NULL),
(1910, 'Silver Pafudo', 'PEI0VB31ATD90GQ', 'carga', -5, 1, NULL, 56),
(1911, 'Himuje', 'R1F76QN14M9I9M5', 'carga', -2617001, 13, NULL, 66),
(1912, 'Wepika', '8SGMKNO75R3KUKH', 'pasajeros', 5917226, 7, NULL, 88),
(1913, 'Ojesava', 'TR30BK0H04W4D51', 'carga', -8199171, 8, NULL, 16),
(1914, 'Juxuhise', 'CBVI6L9TLYWNWVS', 'combate', 4178929, 8, 28, 89),
(1915, 'Golden Luhezu', 'Z9Q01X357G2OO51', 'carga', -2799064, 23, NULL, 50),
(1916, 'USS Fapaxe', 'Q5282DM03G947VY', 'pasajeros', 4613853, 0, 44, 1),
(1917, 'USS Hufaqapa', 'MC0989H4CD7UBN4', 'pasajeros', 3, 4, 16, 2),
(1918, 'Stormy Vaqetiniwi', '3L7Q93ZH81S2Z7L', 'carga', NULL, 112, NULL, 96),
(1919, 'Shiny Ewohehori', '090TL2O2VP30935', 'carga', 6719, 393, 48, 13),
(1920, 'Eso', '23E1HL973Z13TL0', 'exploración', -7289094, 0, NULL, 86),
(1921, 'Silver Butterfly', '75DW87T0JA617MK', 'carga', -73, 7, NULL, 35),
(1922, 'Silver Eca', 'YVOY6A2AP18RZ26', 'pasajeros', 7852862, 7, 37, 62),
(1923, 'USS Butterfly', '4J6P4110SS62G4J', 'carga', 987595, 10, NULL, 5),
(1924, 'Canapinuno', '32FM62SQ41Q2QR3', 'carga', -9930, 1, NULL, 9),
(1925, 'Stormy Fuje', '6NHH6DQ04F709GB', 'combate', -6291087, 1, NULL, 14),
(1926, 'Zeppeling', '3T664U3QH3OYD6U', 'combate', -9243, 4, NULL, 75),
(1927, 'Asidoje', '970R2AHI692Y84R', 'combate', -1588913, 12, NULL, 83),
(1928, 'Condor', '71NZC7C61U6N41U', 'carga', -14, 12, NULL, 35),
(1929, 'Qavapeqe', 'D1I00XG36V38608', 'carga', 1439629, 2, 1, 6),
(1930, 'Lil'' Eca', '3Y6XY47Z2692BN2', 'carga', -2325857, 65, 17, 40),
(1931, 'Little Wucipibu', '9E47362FHP00W2G', 'pasajeros', 5638226, 462937, NULL, 84),
(1932, 'Lil'' Suta', 'NL973150M094011', 'pasajeros', 6296228, 13, 33, 80),
(1933, 'Fox', '803BTZ59HZ443C9', 'pasajeros', -8, 2, NULL, 20),
(1934, 'Nekivo', '51EFN43H32L1Q58', 'exploración', -370826, 0, NULL, 94),
(1935, 'Jivase', '5L16334JP05L034', NULL, NULL, 372, NULL, 18),
(1936, 'Azimotu', 'AVP6Z3WSFS0P5H1', 'pasajeros', -8177351, 4, 31, 26),
(1937, 'Lil'' Ini', '1OLCT27M3WXQIPV', 'carga', -824, 0, 39, 23),
(1938, 'Cloudy Pazeqo', '44FOV45T2RTD256', 'carga', 1611, 1, NULL, 95),
(1939, 'Shiny Ukaruze', '5J76848L4Q3T12O', 'pasajeros', -7241, 0, NULL, 15),
(1940, 'Tesibi', '0R4703IR5172140', 'pasajeros', -1996884, 158, 1, 98),
(1941, 'Litutu', '3H39MIH5WO8T50R', 'pasajeros', -9974465, 132, 28, 81),
(1942, 'Mohu', '714B559738R9EBL', 'carga', -6412376, 4, NULL, 61),
(1943, 'Mubewadawi', '1XF2WUQI5M5YHMZ', 'carga', -200385, 13, 3, 5),
(1944, 'Rivi', 'RM85FO30CH5SI88', 'carga', 3099234, 11, NULL, 35),
(1945, 'Silver Fecisihi', '74CG7C0PAWZ6D4Q', 'carga', -7519825, 0, 1, 7),
(1946, 'Shiny Qumo', '21E6LXC2A862C96', 'carga', 6243826, 14, 32, 17),
(1947, 'Zolemo', 'S31575HR337QZ12', 'carga', -9233133, 14, 7, 23),
(1948, 'Wuve', 'O656Y386H27897X', 'carga', -8629245, 166, 19, 67),
(1949, 'Wemigusu', '852NAL072GMUE13', 'pasajeros', 241547, 0, NULL, 100),
(1950, NULL, 'MFURPPE56868H3P', NULL, NULL, 14, 25, 9),
(1951, 'Stormy Eagle', '973HH3N3W6GNND5', 'combate', 5056730, 0, NULL, 23),
(1952, 'Padeje', '0YERU658586NY58', 'combate', -9049248, 0, NULL, 86),
(1953, 'Shiny Otuvo', '35P4YQF79VZY123', 'combate', 1504289, 15, 37, 88),
(1954, 'Qahibe', '8C8G13XH705YHQR', 'pasajeros', NULL, 451, NULL, 1),
(1955, 'Big Jocivocu', '031HQEU588P3032', 'carga', -8262219, 12, 6, 81),
(1956, 'Secisuho', '23C536Z40I25079', 'pasajeros', 1335773, 1, 7, 24),
(1957, 'Stormy Pata', 'PEAD6MC33MJ4580', 'carga', 7526435, 1, 43, 96),
(1958, 'Xalica', 'CS32193Y2U0S6HA', 'carga', 2291403, 395, NULL, 57),
(1959, 'Abume', '8Z6JBT571F009SG', 'pasajeros', 8960, 0, 7, 82),
(1960, 'Little Nojelote', '14TMQCTS89LT6BS', 'carga', -5, 10, 6, 24),
(1961, 'Gutocajexo', 'GXLJJ1FVIZND392', 'carga', -1497046, 4, 38, 67),
(1962, 'Zeppeling', 'C8317P2IYZ3ES32', 'carga', -4044457, 1, NULL, 90),
(1963, 'Stormy Kaboxi', 'BO111J72T6J92Y4', 'carga', -5794, 288, 42, 89),
(1964, 'Stormy Jiho', 'P6EVT1RNYZFZJ1Z', 'exploración', 7643252, 11, NULL, 8),
(1965, 'Nisugi', 'XBE5MB5P5529L14', 'pasajeros', 7, 0, NULL, 39),
(1966, 'Bamuvo', 'L2T3D1DA2Y7518Q', 'pasajeros', -138625, 490437, 43, 43),
(1967, 'Cloudy Ufi', 'L5N21X8Y3YX2FXB', 'pasajeros', 8313869, 1, NULL, 45),
(1968, 'Aco', 'LHUN09ZE47ML0B6', 'exploración', -8382560, 7, 15, 8),
(1969, 'Eagle', 'O1CME54QM383241', 'combate', 4189056, 6, 48, 7),
(1970, 'Ge', '848J576LSCL233I', 'carga', 783593, 9, 31, 4),
(1971, 'Egujigize', '3Z5FTOD19J0M3Y3', 'carga', -6245554, 98, NULL, 94),
(1972, 'Gozuvosoba', '3IL0169K5FOOI5H', 'carga', 713041, 14, NULL, 76),
(1973, 'Grand Maku', 'G7COHHW5JPH9QX3', 'carga', 6, 43, 32, 65),
(1974, 'Somime', 'TI8ZXCI618UOI73', 'exploración', 54, 0, 2, NULL),
(1975, 'Zeppeling', 'B3N6F96PM5D76EW', 'carga', -208, 1, NULL, 27),
(1976, 'Rurozavu', '4YE4C2E671IM561', 'carga', 687124, 6, 46, 2),
(1977, 'Balefo', 'R1HO72B9GHM23T3', 'carga', 3486, 0, 35, 26),
(1978, 'Qosasa', '0VKF70WP2S51WAC', 'carga', -20, 0, 5, 27),
(1979, 'Lixidibu', 'N0VB4Q78QZ18HC6', 'carga', -8835571, 9, NULL, 10),
(1980, 'Little Dunu', '3UT0H31BC3EQO48', NULL, NULL, 12, NULL, 51),
(1981, 'Fish', 'A549D13TC5A2274', 'pasajeros', 1217, 0, 5, 89),
(1982, 'Juna', '0L0Z52IB0FLU9MV', 'combate', -66, 3, NULL, 77),
(1983, 'Fish', '5MB46698928FYI2', 'pasajeros', -5346, 3, NULL, 9),
(1984, 'Pujejiga', '1D7G41EN9XPBDIO', 'pasajeros', NULL, 238, 30, 43),
(1985, 'Acugibo', 'R97Z1K19L6S66I0', 'carga', -64, 391, NULL, 44),
(1986, 'Grand Notihije', '62I4E43HQ1MFAR2', 'carga', NULL, 3, 38, 83),
(1987, 'Little Irocodo', 'I8UD0CV9PDM14HA', 'combate', NULL, 1, 50, 27),
(1988, 'Stormy Kuziqe', '7YW994U6R0345PC', 'carga', 3004060, 6, NULL, 58),
(1989, 'Silver Vofogo', '8H663IMQM12N19T', 'combate', 990659, 8, 5, 88),
(1990, 'Golden Erevanimu', '8412HZ020425XHL', 'combate', -7938565, 6, NULL, 88),
(1991, 'Fox', 'R223GQ4RX8Q9835', 'combate', 792, 14, 35, 21),
(1992, 'Big Soveqali', 'IM0S824F2L7FA08', 'pasajeros', -50, 4, 18, 3),
(1993, 'Xifucexi', 'L60Q7N5KU9R8AH2', 'carga', -877363, 499, NULL, 55),
(1994, 'Fox', 'HMB0X445C4CTZTI', 'pasajeros', -385, 6, 30, 51),
(1995, 'Cloudy Wenexofa', '6NB61UP5GTVO493', 'combate', -9059570, 7, 42, 6),
(1996, 'Fox', '4SKN3C68970454T', 'carga', 1065652, 4, 20, NULL),
(1997, 'A', 'QIQUL083338504L', 'carga', -8983242, 11, NULL, 90),
(1998, 'Ixetu', 'B13F992659GDM00', 'pasajeros', 4035665, 0, 7, 86),
(1999, 'Lil'' Zimupi', '0OZ0376E2Y789G5', 'carga', -8317930, 13, 50, 45),
(2000, 'Grand Oqelo', '7GI6E9TSTDX9NBQ', 'carga', NULL, 1, 4, 30),
(2001, 'Butterfly', '84Z8W5399K3Q75W', 'carga', -8236938, 11, NULL, 98),
(2002, 'Stormy Qunaqitemi', 'QG1B01S4MOQ20AK', 'pasajeros', 1580827, 1, 8, 100),
(2003, 'Nimu', '8O44D6Q2W36V1HC', 'carga', -6698216, 0, NULL, 99),
(2004, 'Grand Zeppeling', 'KHGNLI273IOI0RD', 'carga', -10, 10, 8, 62),
(2005, 'Bedalo', 'S486R062VW5Q8Z7', 'exploración', -4938, 7, 46, 22),
(2006, 'Cloudy Zuse', '4R33XR086192872', 'carga', -3614896, 3, 5, 71),
(2007, 'Silver Jawisi', 'KOIUXUSV67FX0Y8', 'pasajeros', 2191354, 0, 2, NULL),
(2008, 'Tiwarode', '19H7I36675QB6GX', 'pasajeros', NULL, 6, NULL, 44),
(2009, 'Fish', 'T7461LL9JX7VK28', 'carga', 6687580, 10, 29, 86),
(2010, 'Unuriqa', 'O2XN8JWB78L78A4', 'carga', 2, 5, 5, 4),
(2011, 'Butterfly', '68380H32YL0OG8K', 'carga', 6049, 1, 45, 53),
(2012, 'Awujetito', 'WB353446IUYZ9QF', 'combate', -9381467, 156, NULL, NULL),
(2013, 'Ujitoca', 'B15V1WV1J70672G', 'exploración', -1814388, 0, 22, 9),
(2014, 'Fish', 'Y346QP69B3C756N', 'carga', -1, 7, NULL, 21),
(2015, 'Cuqiba', '87IETO5OR9G822N', 'pasajeros', 54, 14, NULL, 36),
(2016, 'Stormy Kipudocoka', '3LMNIR1O4YM0610', 'carga', 9317, 163, NULL, 94),
(2017, 'Lil'' Opata', '9R4941BYEI8VY17', 'carga', -1690072, 368, NULL, 93),
(2018, 'Sererotu', '3X94M86YZY85FS9', 'pasajeros', 4, 415502, NULL, 13),
(2019, 'Luvavupigi', 'T00VM5Q373L9182', NULL, NULL, 2, NULL, 99),
(2020, 'Golden Ago', 'R6X8837D7XU3294', 'combate', 5824448, 4, NULL, 78),
(2021, 'Silver Sibowa', 'L96OR11NRVLQ8S1', 'pasajeros', -2910264, 384, NULL, 9),
(2022, 'Kaxiguba', '26CHGT931362R6W', 'pasajeros', -5844174, 4, 16, 10),
(2023, 'USS Exeti', '0CACX360H545MPN', 'carga', 2565271, 3, NULL, 93),
(2024, 'Little Vireti', 'S62T945451YFDWV', 'pasajeros', 8462890, 0, NULL, NULL),
(2025, 'Galonixu', '9717K45K4U2E104', 'pasajeros', -16, 1, NULL, 44),
(2026, 'USS Muhocike', '036OPV7O2HYK2I8', 'exploración', 6662455, 15, 19, 94),
(2027, 'Qabaxusaxodo', 'EHLN7I85M43GQ8L', 'pasajeros', 4037364, 7, NULL, 17),
(2028, 'Getopuhe', 'O1ERH0G61U93RIR', 'combate', 9136, 2, NULL, 11),
(2029, 'Pewusi', '7Q6XSUUR799CC5B', 'carga', 689398, 12, 26, 25),
(2030, 'Guruguquhe', 'EOUTV14N05XV6IH', 'carga', -33, 6, NULL, 83),
(2031, 'Wuba', 'D6MW70Z90089E04', 'carga', -91, 392, NULL, 7),
(2032, 'Xudumepi', '1A675JAWJ7V3MUJ', 'combate', 1280383, 296135, 13, 81),
(2033, 'Wuwirele', 'WZGF1I0XU865TK2', 'pasajeros', -4476384, 5, 38, 42),
(2034, 'Kaba', '5Q20W8BOZCN6IF6', 'carga', 7, 15, 2, NULL),
(2035, 'Hijajojemi', 'OC75W6T3C4MPK6F', 'pasajeros', -6188096, 1, NULL, 89),
(2036, 'Grand Xumehexi', 'ON2ZG821Y6AU559', 'pasajeros', -7377703, 1, NULL, 5),
(2037, 'Big Okidasuqo', '8M3E0E94335AR2G', 'carga', -6, 11, 26, 63),
(2038, 'Uvabe', 'HNTZP710ZZ2G0O0', 'pasajeros', -7419880, 3, 8, 40),
(2039, 'Little Hoxo', 'BO7XR17274A6428', 'carga', -6785531, 1, 18, NULL),
(2040, 'Cloudy Fesepupene', '175IPSO44FVK59Q', 'pasajeros', 50, 1, NULL, 97),
(2041, 'Hacaduqe', '4CUR611E8AWL557', 'pasajeros', -71, 8, NULL, 40),
(2042, 'Ehodafuru', 'WJIT1BE5K714XYY', 'carga', 2184168, 0, 18, 29),
(2043, 'Silver Rure', '87NAF2HZEVZI5W5', 'carga', -5745458, 5, NULL, 20),
(2044, 'Kiwozipe', '64DM675JK7P7L9A', 'combate', -3504110, 202, NULL, 52),
(2045, 'Lil'' Gacamuvo', '5410F59U4LM2I26', 'pasajeros', -612, 9, NULL, 70),
(2046, 'Pagacufo', 'K5I823H336001N8', 'pasajeros', -9450252, 4, NULL, 100),
(2047, 'Butterfly', 'K667VO4I2U4WT7O', 'combate', -9799464, 0, 30, NULL),
(2048, 'Zeppeling', 'K7GOUVQ3V7WJ768', 'pasajeros', -8, 12, NULL, 50),
(2049, 'Silver Fifeda', 'RP8AGYDV145G1MO', 'combate', -3434800, 0, 24, 33),
(2050, 'Stormy Vegi', '7P5DM84KZ1HPDOS', 'combate', -5091105, 15, NULL, 49),
(2051, 'Little Zawujawiku', 'IF5WO2RM139C70V', 'pasajeros', -58, 2, 36, 40),
(2052, 'Egazi', 'ECAOY14840JUQ94', 'exploración', -4735461, 11, 25, 65),
(2053, 'Cloudy Xiwaxobe', 'E498WBL042CK7OJ', 'pasajeros', -7568511, 3, 36, 8),
(2054, 'Lil'' Ugaru', '20H3MO0K8X9AA5R', 'carga', -8323407, 85, 20, 63),
(2055, 'Abukuja', 'XS4VTD6W3YV42L3', 'pasajeros', 5351667, 13, NULL, 31),
(2056, 'Famivogile', 'VBMI83I6AVKU2T3', 'pasajeros', -9408, 3, 7, 8),
(2057, 'Eagle', 'G8060XZV33B9L13', 'exploración', 4161627, 0, 6, 25),
(2058, 'Condor', '0BS4XEW338Q686T', 'carga', 1, 370, NULL, 86),
(2059, 'Butterfly', 'GLJ7898L2WOF1B0', 'carga', 2103, 7, 29, 32),
(2060, 'Cloudy Daraci', '5B4D5UXLSP2TTIS', 'carga', 8984, 0, 39, NULL),
(2061, 'Stormy Aqalo', 'V6A6OA02NK5S70N', 'combate', -8272608, 1, NULL, 76),
(2062, 'Golden Gafuma', '81IKD42EH2Q10X2', 'carga', NULL, 14, 19, 50),
(2063, 'Silver Temujepo', '0BGXI82943O0K81', 'carga', -9256270, 0, 2, 16),
(2064, 'Grand Tuju', 'UT71L7CNP4T59HS', 'carga', 6496261, 1, NULL, 4),
(2065, 'Cloudy Omu', 'Y28JB209C3XD8RC', 'pasajeros', 349342, 85, NULL, 89),
(2066, 'Coqosi', '45PBEQ0BRX27LTS', 'carga', -1784016, 0, 42, 30),
(2067, 'Erefi', 'MJ7L8Q28IXT8HIZ', 'pasajeros', 5667460, 0, 20, 90),
(2068, 'Xe', '6CBXKUOXTF2O1CN', 'pasajeros', -2703489, 14, 29, 56),
(2069, 'Silver Bunalaqe', 'O57852I4491773R', 'carga', -3445620, 9, 16, 37),
(2070, 'Silver Sokucexe', 'A9M9PAY1QAM35KZ', 'carga', 9409185, 1, 9, 64),
(2071, 'Shiny Nuhuwago', 'QBT1OUEQH33RUCF', 'carga', -87, 6, NULL, 100),
(2072, 'Qonasebu', '480C8Y0MWHCT5M5', 'carga', NULL, 0, 44, 42),
(2073, 'Little Ojagoxihe', 'Z1BC16094YQY833', 'combate', 0, 11, 10, 33),
(2074, 'Xomubibo', '0YU8H73E6Z928IP', 'pasajeros', 6, 0, 1, 31),
(2075, 'Camidazuji', '61O5C3YZ4U18W52', NULL, NULL, 443, 26, NULL),
(2076, 'Umi', '2LTA6KQLF2YX4A9', 'carga', -8133586, 13, 6, 14),
(2077, 'Buzi', 'XHR077Y6Y13183J', 'carga', -1458832, 4, 26, 41),
(2078, 'Shiny Xawosu', 'LQ288150096C9J3', 'carga', 6735153, 4, 31, 69),
(2079, 'Big Dulo', '9U4N46295343BCO', 'carga', 4, 13, NULL, 99),
(2080, 'Condor', 'SC1PD665R55K5SL', 'pasajeros', 9122, 3, 19, 94),
(2081, 'Silver Zigajiri', 'XVE39M227673209', 'combate', 8156788, 3, NULL, 93),
(2082, 'Tiki', '9T55DDC9MAQU2V3', 'exploración', 3630586, 1, NULL, 5),
(2083, 'Big Ebicaxeka', 'JLFBL3SEU22FU5V', 'carga', 3550436, 1, 3, 10),
(2084, 'Grand Toconosa', 'Q09SWY88344J11X', 'exploración', 4188703, 1, 14, 19),
(2085, 'Silver Fox', 'DS1YV81B310IGWB', 'carga', 64, 480, 24, 73),
(2086, 'Julemido', 'T0LUD723BVR33LQ', 'carga', -648007, 1, 32, 84),
(2087, 'Stormy Zahe', '9B8EQ74JCLU638N', NULL, NULL, 10, 8, 71),
(2088, 'Abemefohe', 'B48G1Q77UQ6C7Q0', 'carga', NULL, 368, NULL, 12),
(2089, 'Stormy Temoze', '9MF435M1H90B764', 'carga', 9877281, 1, NULL, 39),
(2090, 'Fox', '9E47UE070NK7SV7', 'combate', -1099396, 15, 46, 5),
(2091, 'Hujezi', 'QFM5979205RZ670', 'carga', 2401284, 8, 41, 3),
(2092, 'Eheni', 'J1H3P033705CMS9', 'combate', -6594, 15, 5, 49),
(2093, 'Shiny Zeva', 'NC28W5Z6PF495NC', NULL, NULL, 1, 30, 80),
(2094, 'Big Odiwixezu', '109PJSQB96IQDHY', 'pasajeros', NULL, 0, 14, 22),
(2095, 'Ilogide', 'PI6T5SWMG98LKSG', 'combate', -745, 1, NULL, 46),
(2096, 'Big Tuqoquti', 'Q2SZ0M40OGM56KA', 'carga', -9972535, 6, 2, 70),
(2097, 'Iwirimu', 'Z6HC08N8CXUOU34', 'carga', 6544199, 1, NULL, 56),
(2098, 'Zeppeling', 'QW79VCK7QB3A9XB', 'pasajeros', -200, 6, 16, 46),
(2099, 'Lil'' Opafi', 'VYXTZ00SI09BYR7', 'carga', -9661681, 1, 19, 92),
(2100, 'Tomaqo', 'BV52BZJ5EVQ9064', 'pasajeros', -36, 5, 24, 75),
(2101, 'Ewawevo', '4941Z5YEDCIB9F6', 'exploración', -6924022, 12, 30, 15),
(2102, 'Lil'' Giluhu', '1IJH5799Z6JWJ4L', 'carga', -738648, 7, NULL, 35),
(2103, 'USS Udisi', 'WW9R7X7O1PN9WF5', 'carga', 5001190, 341, 45, 85),
(2104, 'USS Tiredu', 'WNICB8E1O5ZY6AI', 'carga', 211095, 446, NULL, 91),
(2105, 'Ijalami', '626EAAV29D5BFP2', 'carga', -9748599, 0, NULL, 52),
(2106, 'Nodi', '88I6CIFJ5QKJ8DU', 'carga', 82, 3, 34, NULL),
(2107, 'Little Wuvajita', 'L7M9W8UNH34O0OU', 'pasajeros', 5974075, 0, 40, 4),
(2108, 'Golden Jime', '5NE892U4ZP34M1O', 'carga', 8244844, 4, 35, 96),
(2109, 'Xahuniduxo', '56TAT9O7RNC6NJO', 'carga', -7943183, 319, 34, 24),
(2110, 'Lil'' Tizefa', 'J4JAS0877C5N155', 'exploración', -1, 12, 19, NULL),
(2111, 'Gaciruxiho', 'SHIK5O3XD0DC4DK', 'pasajeros', -3, 47, NULL, 39),
(2112, 'O', 'T369RVC2B552CGQ', 'carga', 2915950, 9, NULL, 59),
(2113, 'Shiny Wisajiso', 'WO4L6FU249I0NOO', 'combate', -5385048, 14, NULL, 73),
(2114, 'Lawoke', '1KKA7469419F6E8', 'carga', 6992, 4, NULL, 87),
(2115, 'Idosetafa', '74TN3O9Z5G8Z6BS', 'carga', 6546621, 4, NULL, 81),
(2116, 'Eagle', '0YL1SMM95NLKS1S', 'carga', 3700045, 1, NULL, 77),
(2117, 'Mono', 'K2AE6J15S1G320T', 'carga', -9759609, 4, NULL, 10),
(2118, 'Golden Hijumi', 'RJA51KKNEC2E36L', 'carga', -2642366, 70, 24, 3),
(2119, 'Heruzanuzace', '01ER30P9MTUQ8S9', 'pasajeros', 1568249, 0, NULL, 13),
(2120, 'Fish', 'BP6Q19F41WHUP55', 'carga', -475257, 3, 47, 63),
(2121, 'Kaqeju', '182V63I6S9C3IJO', 'carga', -7643288, 9, 1, 39),
(2122, 'Stormy Pebo', 'QD1CO56L1P2E9NJ', 'pasajeros', 7758382, 0, NULL, 4),
(2123, 'Silver Hedepuco', 'M2891CMJ43M02XF', 'carga', -93, 12, 43, 24),
(2124, 'Big Pepokowo', 'Y8REX4YAU9R1I3A', 'pasajeros', 8, 546466, 43, 25),
(2125, NULL, '0L631O66IZ06J0L', NULL, NULL, 15, NULL, 57),
(2126, 'Silver Vanukaju', 'G8C185WQ75MO1U3', 'pasajeros', 72, 12, 39, 4),
(2127, 'USS Valehorato', '71G4B49Q2DOE2O9', 'carga', -9162551, 5, 14, 4),
(2128, 'Butterfly', '6LUO89VO0Q3SCS8', 'carga', 4168443, 2, NULL, 26),
(2129, 'Lazufeke', '0KRLE8514OH54MV', 'carga', -6356869, 0, NULL, 5),
(2130, 'Vupeca', '7D16NGO73QI1V50', 'carga', 6345456, 1, 1, 83),
(2131, 'Iqedo', '702WSJDQ905939R', 'combate', -8, 15, NULL, 44),
(2132, 'USS Zuvukedi', '3KBUJ8313Q4MUEK', 'pasajeros', -4636241, 0, 26, 98),
(2133, 'Ginoxoca', '5J7VI760C6439EN', 'carga', 93, 3, 4, 81),
(2134, 'Laromavi', 'E500U6090J44IE5', 'combate', 2145430, 0, NULL, 60),
(2135, 'Lil'' Muwina', 'KRV0VPC4J2ZSGB8', 'pasajeros', -3165154, 1, NULL, 2),
(2136, 'Cloudy Mawifu', '3P8750BWG7B96IE', 'carga', 8527677, 189, 30, 6),
(2137, 'Eagle', 'WONONEZ2YR1UZ3N', 'carga', -4, 1, 3, 39),
(2138, 'Cloudy Ika', 'CNLSB6734USOZL0', 'carga', -8280675, 1, NULL, 87),
(2139, 'Silver Vucemu', 'UV5ZYGF234UR8GX', 'pasajeros', 555, 0, NULL, 61),
(2140, 'Big Hapohiru', '0SA5R91YO2XHPH4', 'pasajeros', -4592199, 1, NULL, 56),
(2141, 'Jatupuqi', 'O6B6F08XT23T7JO', 'pasajeros', -1184221, 347, NULL, 8),
(2142, 'Cepohuxu', 'MDC92P27DKW2E32', 'carga', -1746919, 1, NULL, 76),
(2143, 'Grand Osa', 'BAD4B11K3HYFC75', 'exploración', 0, 0, NULL, 9),
(2144, 'Cizicu', '6TB5KRFR4L59ZJT', 'carga', -9465993, 8, NULL, 83),
(2145, 'Big Lohulebi', 'T70Z285407K6EJ6', 'carga', 9723716, 10, 20, 36),
(2146, 'Little Cihere', '0VZ22UQA1J83TT5', 'carga', -559, 0, NULL, 71),
(2147, 'Viweli', 'Z4VEU3TUWKX52UG', 'pasajeros', -475687, 1, 1, 43),
(2148, 'Tudoca', '46EW2V27G52D9DL', 'carga', 2787312, 8, NULL, 52),
(2149, 'Grand Zeppeling', '5VE55S070E6I2OQ', 'carga', 2274307, 15, 40, 98),
(2150, 'Gatuleca', '09GC2DLP3HL82K8', 'carga', 7988546, 0, NULL, 35),
(2151, 'Oxi', '26CXDXPFZV6QROR', 'pasajeros', -4073163, 0, NULL, 79),
(2152, 'Silver Fox', '53614LTT2W6AX42', 'combate', -8568212, 1, NULL, 18),
(2153, 'Grand Zeppeling', '53CACXX1DY30BKK', 'carga', -6930074, 14, NULL, 45),
(2154, 'Xucebuge', 'D1223NQMHZ86L51', 'pasajeros', -9888059, 1, 29, 73),
(2155, 'Golden Kojimiko', '046I5A19C5X5442', 'pasajeros', -9427156, 13, NULL, 56),
(2156, 'Silver Hule', '5DLC5RH680C7K9J', 'pasajeros', -660026, 1, 1, 38),
(2157, 'Fish', 'BW4A7PC46MJVPXM', 'carga', -6523557, 13, NULL, 5),
(2158, 'USS Condor', 'CWFC0YHZ53WB0M6', 'combate', 613, 523200, 43, 98),
(2159, 'Piku', 'LCZR045A6WZ55C5', 'pasajeros', 0, 11, NULL, 1),
(2160, 'Butterfly', '24A42TL00CF4817', 'carga', 7, 6, NULL, 20),
(2161, 'Fixujovu', 'Z93173GPQ74Z92C', 'pasajeros', -1509411, 384, NULL, 4),
(2162, 'Atokevu', 'A97NZEF36KCA660', 'carga', -3005, 8, NULL, 41),
(2163, 'Fox', '1289QTD34K834LO', 'combate', -5128009, 1, NULL, 94),
(2164, 'Zutavuvone', '5G0TRPL2H586VO5', 'pasajeros', -65, 7, NULL, 32),
(2165, 'Lil'' Rebegufe', 'W5A63FE91C2J8A8', 'carga', 956, 1, NULL, 55),
(2166, 'Golden Ekovu', 'MGCU328CPS34642', 'carga', -372, 5, 39, 55),
(2167, 'Fish', 'M6Z5R839QV4J8Z9', 'pasajeros', 6403128, 354, NULL, 91),
(2168, 'Stormy Se', '4257W1T5J839H59', 'carga', 3628063, 1, NULL, 7),
(2169, NULL, '837Y2DJS7U3178B', NULL, NULL, 4, 47, 86),
(2170, 'Grand Siquloqo', '3U7X46TGW52OBV0', 'carga', 490870, 13, 6, 66),
(2171, 'USS Xuna', '1XZ8H69IK4TOT97', 'carga', -9898569, 398, 17, 59),
(2172, 'Cloudy Dakohita', '1GN2J87W707K1V2', 'carga', -3637, 1, 37, 11),
(2173, 'Tixugu', 'J4NWA7WZR4T6BFL', 'pasajeros', 3908954, 495, NULL, 42),
(2174, 'Stormy Ibeqedu', 'LZ2TJ8B9L928H4P', 'carga', 4306900, 136802, 18, 53),
(2175, 'Mufekuhibu', 'F4QUG896R211479', 'carga', 3608320, 5, 9, 30),
(2176, 'Stormy Junore', '4B3PCBX3L2E8A79', NULL, NULL, 5, 3, 13),
(2177, 'Paqehabega', '530AF12VOXO1GGB', 'carga', 2218651, 1, NULL, 48),
(2178, 'Shiny Dolo', '327YW4B81XF8045', 'carga', 5173405, 1, NULL, 11),
(2179, 'Doqase', '7H79VWROEKFPY9Q', 'carga', -52586, 10, 8, 84),
(2180, 'Noli', '6IJ0DW9I24X34OB', 'carga', -7297, 1, NULL, 51),
(2181, 'Iwu', 'QTBP84CTH63Y381', 'pasajeros', -39, 5, 1, NULL),
(2182, 'Golden Eroji', 'BHBZ93TB4G3BL0B', 'carga', 112, 1, NULL, 20),
(2183, 'Xisobicode', '66V4Y2EO1B65GH7', 'exploración', -1080288, 0, 26, NULL),
(2184, 'USS Buqupawa', '50C2DURI57D15S2', 'exploración', -8, 254, NULL, 12),
(2185, 'Lil'' Fojecije', '2N9L20A47913P6T', 'pasajeros', 7070539, 27, 25, 60),
(2186, 'Condor', '35716PQ3XUJCR64', 'carga', NULL, 3, NULL, 3),
(2187, 'Stormy Soqaxugo', 'E6E77V9R8088531', 'pasajeros', -9712344, 4, 27, 25),
(2188, 'Big Sasakitada', '2M2I50BZ021684P', 'combate', -9, 7, NULL, 78),
(2189, 'Golden Ducajanatu', 'V6P3R9RIJ55R31H', NULL, NULL, 2, 7, 8),
(2190, 'Conudogico', '5QEZV39RL4IPX1M', NULL, NULL, 0, 37, 8),
(2191, 'USS Bomobuze', '0K419OAOHYS0893', 'carga', 4906112, 0, NULL, 53),
(2192, 'Ododulecu', 'GT35QSS75Y8ESFB', 'carga', 5, 0, 26, 57),
(2193, 'Bidelo', 'M2F90V5BSWA10U2', 'carga', 3364233, 9, 17, 93),
(2194, 'Little Lugebawi', '50893Q9SP2XGST4', 'combate', 8559817, 3, 7, 38),
(2195, 'Little Zeppeling', '6FNGWJ94B9GJXXG', 'carga', -42, 1, 2, 8),
(2196, 'Kecexopi', 'N2I7M4A5ZR3W505', 'carga', 9333670, 12, 40, 99),
(2197, 'Kopapisa', 'H1Z330F9N0R4GG9', 'pasajeros', -4959739, 2, NULL, NULL),
(2198, 'Grand Visemero', '9KF68GJQNFY3EOX', 'carga', -8935454, 0, NULL, 70),
(2199, 'Ce', 'VC7HM88Y3BD1331', 'combate', 2137, 0, NULL, 93),
(2200, 'Big Fox', '0E90BG6D6X3LIU5', 'carga', -4402491, 2, 22, 60),
(2201, 'Big Ejegubohu', 'ZSV10X98VZK1GY3', 'carga', -16, 13, NULL, NULL),
(2202, 'Shiny Gili', 'YAI1TV6SC3652C8', 'combate', -6629481, 67, NULL, 44),
(2203, 'Giqaqafifi', 'S5J778Q0LJU29N4', 'combate', 5506324, 0, 7, 52),
(2204, 'Nasemu', 'GLT5816XCA4CJZV', 'carga', 4, 15, NULL, 81),
(2205, 'USS Akawa', 'C2NKZD7L239D58D', 'pasajeros', 48, 1, NULL, 36),
(2206, 'Stormy Rogo', 'H688699178XSN8J', 'carga', NULL, 278, NULL, 30),
(2207, 'Golden Nupamepu', 'S541OL33G9CL0XG', 'combate', 7947862, 0, NULL, 12),
(2208, 'Okofi', '24DPODGBZ74BP0X', 'carga', 1264491, 15, 17, 43),
(2209, 'Shiny Cikanuboge', 'BQA03VH5K1X7J33', 'combate', -5672388, 5, NULL, 85),
(2210, 'Finobige', '2QQ5FGV65Z44LHY', 'exploración', 67, 1, 50, 9),
(2211, 'Xori', 'T495CX9P1U0I9SN', 'carga', 45, 0, 6, 73),
(2212, 'Stormy Noqiluxo', 'I6Y8LN9609M419B', 'pasajeros', 843843, 3, NULL, 15),
(2213, 'Xewolonisuno', 'H94318EVP7K698H', 'carga', -1704543, 2, NULL, 43),
(2214, 'Fazazumuvi', '90X5M93Q58079A0', 'carga', 1231223, 1, 30, NULL),
(2215, 'Zeppeling', '3J2ORH1275838HZ', 'carga', 1339583, 310, NULL, 6),
(2216, 'Xafekaqa', '37H2E939QFA75MC', 'pasajeros', 2, 14, NULL, 61),
(2217, 'Owupa', 'KE4QC3MS2DFK8WK', 'carga', 6024516, 1, NULL, NULL),
(2218, 'Grand Zeppeling', 'J9M30E4Z86B99B3', 'carga', 727342, 0, 22, 91),
(2219, 'Zago', '7WV7G3M16P6YB53', 'carga', 97, 293, NULL, 71),
(2220, 'Fox', 'Z91G92C06568E00', 'pasajeros', -6271669, 4, 42, 27),
(2221, 'Grand Eagle', '0F2B20825GGAL3L', 'pasajeros', -11, 1, NULL, NULL),
(2222, 'Bijuto', '17ZL69LN4490TEE', 'pasajeros', NULL, 10, NULL, 79),
(2223, 'Musutu', 'MG6XHIRGYBI45LU', 'combate', -4548952, 70, NULL, 9),
(2224, 'Cuzakamoba', '16OY90HTN73P71M', 'carga', 5521894, 7, 15, 31),
(2225, 'Gukofevi', '93UOXGB929T7N8Q', 'pasajeros', 1706341, 4, NULL, 93),
(2226, 'Ibapife', 'X6P8VE8LOQG6452', 'carga', -1935729, 4, NULL, 76),
(2227, NULL, 'CHSB14JQ5227YS6', NULL, NULL, 14, 13, 60),
(2228, 'Dazipu', 'K8NOBVABAGN5TO4', 'exploración', -4428618, 0, 7, 43),
(2229, 'Demomu', '49UC0FDNNWO9093', 'carga', 3, 14, NULL, 1),
(2230, 'Condor', '754CF4SFWM3Q716', 'carga', 9564775, 1, NULL, 52),
(2231, 'USS Ena', 'FV59IN50216WQSZ', 'carga', -1113850, 4, 34, 72),
(2232, 'Condor', 'EBK6J059D0R36T4', 'combate', -8, 115, NULL, 72),
(2233, 'Shiny Pifecifo', 'GL55PG5LD8I4W31', 'combate', -621, 92, 8, 40),
(2234, 'Stormy Kopicusi', '08BVDTWB7X73YSW', 'carga', 131, 393, NULL, 42),
(2235, 'Rejuqi', 'IKAQL379IQTG9S6', 'pasajeros', 6240112, 13, NULL, 34),
(2236, 'Ina', '6XEE30238NABG5G', 'combate', -5513, 6, 32, 34),
(2237, 'Zijuxadoseve', 'A62PT9M4HH0457S', 'combate', -4052674, 0, NULL, 7),
(2238, 'Golden Xugewebi', '8FY32EX8R2LW41Z', 'carga', 2447738, 14, NULL, 12),
(2239, 'Dikusu', '0RN3H00B30C7G69', 'pasajeros', NULL, 15, NULL, 48),
(2240, 'Silver Vejodiki', '7NC8J77WUOP6059', 'carga', 822, 385, NULL, 9),
(2241, 'Mamapihi', '4A1Z03A6HI0TKHZ', 'carga', 162557, 0, 35, 11),
(2242, 'Golden Fish', 'AB3843BXMV93M1J', 'pasajeros', -9889015, 0, 45, 93),
(2243, 'Cahefo', '33F2NN0656ZY4J9', 'carga', -6916493, 336, 33, 54),
(2244, 'Lil'' Eticu', '720YA41LUMHNG30', 'carga', NULL, 15, NULL, 92),
(2245, NULL, 'Y3Y8506524L7BTV', NULL, NULL, 6, 36, 71),
(2246, 'Ubamovuta', 'I1YM4NSN5D7G62R', NULL, NULL, 10, 46, 22),
(2247, 'Big Pifo', 'M1V6560RLD0LB90', 'pasajeros', -1492, 8, 12, 13),
(2248, 'Rezinuwodo', 'IBN011PR15918K9', 'carga', -4, 6, NULL, 9),
(2249, 'Cloudy Alo', 'Q6848702B351JP3', 'pasajeros', -8687461, 5, NULL, 80),
(2250, 'Bavu', '75N6MX47M18MF1O', 'pasajeros', -9917160, 12, 34, 87),
(2251, 'Tigoheqo', 'T4X5QW13559WGK7', 'exploración', -658, 13, NULL, 13),
(2252, 'Gabolapo', '1Z5P91NMH9TN4T0', 'pasajeros', 842, 10, 33, 65),
(2253, 'Ma', '4G68POBU535J519', 'carga', -5174392, 0, 6, 82),
(2254, 'Fukuce', '847A8RC4783PWUH', 'exploración', 4629, 12, NULL, NULL),
(2255, 'Wori', 'I2A8T7PBK1RF58Z', 'carga', -16, 4, 11, 61),
(2256, 'Shiny Oqebovena', '7QJ957SA3842R12', 'pasajeros', 28, 2, NULL, 42),
(2257, 'Sivuna', 'A5448DMRF23K121', 'carga', -96, 1, 2, 37),
(2258, 'Grand Tujebo', '8GMH894TWLORHEU', 'carga', 1191732, 5, NULL, 67),
(2259, 'Shiny Nazoqevedo', '764EL6W2ZWAS78A', 'carga', -5326914, 0, NULL, 15),
(2260, 'Cloudy Butterfly', 'IW94704EF9R1567', 'combate', 3261772, 7, 14, 93),
(2261, 'Gijavufenu', '4558L8BX597U4L3', 'pasajeros', 3510378, 14, 21, 56),
(2262, 'Hureko', '7J7120930FWYMWU', 'carga', 9420, 190, 15, 89),
(2263, 'Zelinasa', '44LK095X00A2HFB', 'pasajeros', 5555, 12, NULL, 65),
(2264, 'Qerupego', '5D4830NR3961Y2I', 'carga', 24, 0, NULL, 33),
(2265, 'Golden Butterfly', 'WP9K5U994G11P5H', 'pasajeros', -2529690, 1, NULL, NULL),
(2266, 'Silver Tavisacu', '98W5MUB67ANS346', 'carga', 8451946, 1, NULL, 96),
(2267, 'Silver Ecejulu', 'AGGJY67JD7Y4407', 'pasajeros', -3, 13, 23, 3),
(2268, 'Miwu', 'J3R2ZPO6WSWK7J1', NULL, NULL, 3, NULL, 29),
(2269, 'USS Uhevu', '7R67N1M04ADAY3C', 'pasajeros', -6, 8, NULL, 6),
(2270, 'Little Xikakodano', '18QL0961WC71X0X', 'carga', -1707021, 12, 42, 49),
(2271, 'Cloudy Kuhuve', '131Q9A0OW0P4RID', 'carga', -8984482, 6, 5, 87),
(2272, 'Nuhawo', '30PQBTENWN9TRT5', 'pasajeros', 8561898, 15, NULL, NULL),
(2273, 'Zazuzaxiboba', 'X5440QG77C0DU0Z', 'carga', -1, 12, 39, NULL),
(2274, 'Stormy Cemi', 'S27OC4720N2K9D8', 'carga', 451, 0, NULL, 74),
(2275, 'USS Fish', 'A15181YVV4CZ3RG', 'carga', -8693734, 11, 33, NULL),
(2276, 'Shiny Arosu', '5K8ZD989CU22W51', 'carga', 9520007, 246, NULL, 6),
(2277, 'Butterfly', 'MT4O883I625M39T', 'pasajeros', -62, 9, NULL, 83),
(2278, 'Zene', 'H65EYMMZJN22P8P', 'exploración', 1844114, 13, NULL, 68),
(2279, 'Grand Vidira', '7WRCR2O16601OVB', 'exploración', 775, 11, 33, NULL),
(2280, 'Kukesi', '3YDY5Z6ELK0N6W0', 'carga', -9858659, 0, 11, NULL),
(2281, 'Lil'' Jopunado', '959AP145ZO1IV47', 'carga', -6325563, 376, 35, 66),
(2282, 'Cloudy Juxaxurovo', '78EVQ1QTS6U714L', 'carga', 3, 563420, 10, 12),
(2283, 'USS Eguzi', 'KJPK3W6E91192K9', 'pasajeros', NULL, 3, NULL, 97),
(2284, 'Silver Butterfly', '620E1O57YZ56Q79', 'pasajeros', -8138, 1, NULL, 87),
(2285, 'USS Dimiso', '1IEYE140NZM00BL', 'carga', -3125319, 174, NULL, 62),
(2286, 'Little Condor', 'YKR417P938F0HA0', 'combate', -103, 4, NULL, 44),
(2287, 'Zeppeling', '67N66THWQA9YVUC', 'pasajeros', 7, 12, NULL, NULL),
(2288, 'Golden Zeppeling', 'F83P65U894N1CIV', 'pasajeros', -1498412, 6, NULL, 7),
(2289, 'Little Geqivavu', '56UQ7WU687WE91H', 'carga', -9706795, 13, NULL, 43),
(2290, 'Big Haci', '26K2VJ5O1ZASQ17', 'carga', 206, 481, NULL, 56),
(2291, 'Xujomiqu', '2J20Z1Z76WU87Z7', 'carga', 4661626, 2, NULL, 65),
(2292, 'Big Qileqiloxo', 'ZE132C2N7BJD7S9', 'carga', -8045547, 2, NULL, 53),
(2293, 'Big Izisi', '07S0G8PK7DF7E08', 'carga', -2414679, 10, 7, 34),
(2294, 'Butefofama', '67913AFMN1SFBD2', 'pasajeros', -38, 0, NULL, 91),
(2295, 'Grand Bapafe', '6I1A0007BOEOW2B', 'combate', -5172338, 15, NULL, 76),
(2296, 'Cibapute', 'JVQK772B4G74U7U', 'carga', 9700, 0, 3, 60),
(2297, 'Cloudy Wona', '9UM2T2612NC2W8O', 'carga', 8693265, 14, NULL, 90),
(2298, 'Big Fuga', 'SZUQ1S6ZZ290OSK', 'pasajeros', -3706285, 9, 18, 50),
(2299, 'Grand Vujajise', 'TI0CKF5933C10R1', 'carga', 4753, 0, 24, 69),
(2300, 'Ihexoloje', 'H4KPYRX487Y4LW4', 'combate', -8414927, 2, NULL, 73),
(2301, 'Febawoqa', 'U5O244H331V17CO', 'carga', 6, 5, NULL, 17),
(2302, 'Lil'' Osifi', '1R7I30L6E728NM6', 'carga', 9189274, 0, NULL, 11),
(2303, 'Xigiva', '118365536R1SL0Z', 'pasajeros', -656881, 284, 33, 71),
(2304, 'Silver Jubivato', '04TJIR257DX72FG', 'combate', -253, 7, 20, 5),
(2305, 'Eagle', 'V54Q5MQE4H9013O', 'pasajeros', 6263655, 0, NULL, 51),
(2306, 'Stormy Sibize', '5J1K05Y256AO520', 'carga', 1716334, 12, 25, 81),
(2307, 'Golden Qipakiwuvi', 'WT5E2D21KIQ7YLT', 'carga', 8133, 15, 2, 7),
(2308, 'Keguxa', 'YLA2BO84GGT70ME', 'carga', 1386354, 1, 40, 22),
(2309, 'USS Mixapo', 'G3D6HH8ES1J9ACK', 'pasajeros', 9617725, 48, NULL, NULL),
(2310, 'Silver Butterfly', '3C11ZRWC8I7X42U', 'carga', -8207725, 12, NULL, 3),
(2311, 'Golden Fawoja', 'LMF5QS3SOBF3W34', 'pasajeros', -9015901, 1, NULL, 8),
(2312, 'Lil'' Revonunilusa', 'KAD68IIWT64ADJI', 'exploración', NULL, 5, NULL, 88),
(2313, 'Zeppeling', 'Y97378D9U8N8HI9', 'carga', -1507657, 7, NULL, 28),
(2314, 'Qohazoki', 'G0879JWU2HMP1RZ', 'carga', 7832357, 188, 39, 57),
(2315, 'Shiny Elavibe', 'Y65Q40YGFLT9R3N', 'exploración', 7302778, 9, 47, 54),
(2316, 'Xecaduqufi', '2G022XP7UJ48NI5', 'pasajeros', 6436355, 14, 5, NULL),
(2317, 'USS Butterfly', 'X18HW5YSGU575W1', 'carga', 689931, 11, NULL, 65),
(2318, 'Shiny Fulo', 'A94887731WA7Q0S', 'carga', -8678014, 6, 17, 2),
(2319, 'Eagle', 'UFBGPZ266708A2J', 'carga', 2520, 1, NULL, 27),
(2320, 'Cloudy Tatahili', '3NER7VTZF90W4O7', 'carga', 2873254, 10, 39, 62),
(2321, 'Gisiboto', '43894JD8F256M11', 'carga', 3, 5, 14, 6),
(2322, 'Zeppeling', 'D2U0881M610UJU4', 'carga', -8716831, 6, 6, 30),
(2323, 'Shiny Lebirahi', 'BQRH04P44QZ9U7C', 'pasajeros', 8812226, 1, NULL, NULL),
(2324, 'Cloudy Sopebo', 'Y84EM0VC7059B10', 'carga', 68, 8, NULL, NULL),
(2325, 'Stormy Ehonajege', '71GU3O52U2W8BEW', 'carga', 8484239, 190, 39, 58),
(2326, 'Jamemope', '8Q94X191U0LBZTW', 'combate', -8999431, 11, NULL, 70),
(2327, 'Golden Sadeqo', '2C066S3JN824GD3', 'carga', 9912630, 151, NULL, 59),
(2328, 'Zaca', 'X9204WO1WVG53W2', 'pasajeros', -6028876, 9, NULL, 62),
(2329, 'Little Wupimirehu', 'Q4M1U2915I747II', 'carga', 5798105, 13, NULL, 33),
(2330, 'Revanixu', 'TY79993I1JCX5P8', 'combate', NULL, 5, 13, 74),
(2331, 'Wubacilulo', '36Q04U0M747RS67', 'carga', 7, 3, NULL, 89),
(2332, 'Ba', 'RDE4035T4W4884N', 'pasajeros', 3543740, 270, NULL, 45),
(2333, 'Fish', 'L37L6OT1RTESGO6', 'pasajeros', 2925006, 1, NULL, NULL),
(2334, 'Golden Kiquco', '0TH784WD08169FI', 'exploración', -765, 1, 10, 17),
(2335, 'Shiny Ocabe', '8N993103PKEPGO3', 'carga', -9952326, 9, NULL, 18),
(2336, 'Wenobomi', 'I746I24E4P1S2DQ', 'combate', -2035711, 13, NULL, 44),
(2337, 'Cloudy Gaposu', 'MF50N9I24IBI5K4', 'carga', 2022587, 0, 45, 80),
(2338, 'Big Xefahifo', 'Q5Y2UC8NDD86CGI', 'carga', 7165983, 1, NULL, 35),
(2339, 'Shiny Lequmoneme', 'S32V92Q62K2G9G4', 'carga', 2, 0, 9, 67),
(2340, 'Borigacojo', 'OPV822E9Q1OOENC', 'carga', -4384102, 1, NULL, 25),
(2341, 'Silver Supagu', 'W2QD2C0SY236TOY', 'carga', 6740389, 15, NULL, 48),
(2342, 'Grand Semopiri', '9RJ6KC2A2UH4QF8', 'carga', 3, 14, NULL, 48),
(2343, 'Golden Pexu', '30M08A453H9CAT1', 'exploración', NULL, 10, 19, 5),
(2344, 'Stormy Xugave', '77KL91WSS960767', 'pasajeros', 3867635, 3, NULL, 51),
(2345, 'Lil'' Su', 'D5V454UWS5TV939', 'pasajeros', -8275872, 8, 29, 79),
(2346, 'Grand Jutiwojo', '54A6VEPYV188OWZ', 'carga', 7126084, 266, 5, 99),
(2347, 'Wuquhe', '3KM35SW171AIDUF', 'pasajeros', NULL, 432, NULL, 53),
(2348, 'Shiny Ofise', '9H91GTWYA72FTG5', 'combate', -8061977, 13, NULL, 21),
(2349, 'Big Joweki', 'DSY76J210KOY874', 'pasajeros', -66, 5, 28, 36),
(2350, 'Golden Kutoni', '713KC9JR74G416B', 'carga', -651, 156, 17, 68),
(2351, 'Jilununi', '2NPPOEYUZ888509', 'carga', -9368137, 2, 43, 63),
(2352, 'Big Jicefoju', '0ACW255AZ11U810', 'pasajeros', 3752850, 59, 18, 75),
(2353, 'Daxima', 'FPAX8ZKU2U6Q1CH', 'carga', -3660001, 11, NULL, 68),
(2354, 'Cojosu', '08SRT52KSO977TZ', 'pasajeros', 7096814, 14, 48, 46),
(2355, 'Qapufupewu', '561D1YRAS9O3250', 'pasajeros', 7668024, 4, 26, 68),
(2356, 'Shiny Lega', '04P65A7QC0J1YN1', 'pasajeros', -9651058, 0, 44, 60),
(2357, 'Condor', '3B9CPTPZNY968ZI', 'pasajeros', -5274009, 0, NULL, 5),
(2358, 'Golden Condor', 'R050CF0OL58O529', 'carga', -4281327, 5, NULL, 30),
(2359, 'Little Wahazu', 'P2I7WI0IC4K8613', 'pasajeros', 9937714, 9, 7, 29),
(2360, 'Silver Iruxomi', '3V55499N4Z9C6WQ', 'carga', -3252669, 0, 18, 50),
(2361, 'Silver Agu', '5GSJSW1WLL6637Z', 'pasajeros', -8607667, 103, NULL, 17),
(2362, 'Stormy Zowo', '9N78R64D0AA1Z50', 'exploración', -559, 10, 7, 7),
(2363, 'Little Medubipu', '50BLHHHH5ZV36XV', 'exploración', 3657531, 9, 34, 86),
(2364, 'Dasivi', '8582E5VTZFXL7Z9', 'pasajeros', -1155574, 15, 39, 33),
(2365, 'Fox', '0SXFZ6C8C87Z3JG', 'carga', -1879962, 1, NULL, 78),
(2366, 'Shiny Bakefazi', 'XC200Y65RC35NLL', 'pasajeros', -9756706, 1, 7, 52),
(2367, 'Pocacaqe', '7J00Y63A2142VP2', 'carga', 1948335, 0, 25, 11),
(2368, 'Condor', 'VHX7UF6KI47QW43', 'carga', 4315591, 6, 2, 55),
(2369, 'Fish', 'Z6BT8XN811S1H1Z', 'combate', -8, 9, NULL, 47),
(2370, 'Shiny Inovere', 'CVDI3H5UIPEK7U7', 'pasajeros', -51, 6, 33, 50),
(2371, 'Buwila', '47MSC99R90TUVR0', 'carga', 6673736, 3, 7, 27),
(2372, 'Mosulari', 'PR4O7T5J9F4V49L', 'pasajeros', 6002712, 0, 29, 58),
(2373, 'Sijugajeko', 'O23HYKJ4PJ12F93', 'carga', -5213025, 8, 17, 63),
(2374, 'Big Lunuxe', '406D1T4P0N3GF37', 'exploración', 22, 1, NULL, 27),
(2375, 'Limilekoqi', '6T5K8Y608519894', NULL, NULL, 0, 12, 61),
(2376, 'Cloudy Kutuzewu', 'W8P11R8UQ233DQU', 'exploración', -534, 0, 35, 23),
(2377, 'Silver Nazi', 'M7L16Q1FK4RJ4K9', 'pasajeros', 2563191, 0, 32, 37),
(2378, 'Lil'' Dudasi', 'IC5Z0G17UF6L4I3', 'carga', -4039917, 0, NULL, 40),
(2379, 'Lil'' Zeppeling', '30Q50YCG0QM05L0', 'combate', -7504635, 13, NULL, 13),
(2380, 'Silver Zubiwohoja', 'H1C88ZTVROS6TZM', 'pasajeros', 9450173, 215, NULL, 71),
(2381, 'Tuxedo', 'D638XOR7900EF64', 'combate', -929, 80, 44, 28),
(2382, 'Golden Zeppeling', '9263KBP27HRZX55', 'carga', 9092044, 13, 20, 58),
(2383, 'USS Vizogo', 'JNZM8BQ7F00OV00', 'carga', 3454188, 7, NULL, 18),
(2384, 'Wo', 'W5BIRLA3K30XYNB', 'exploración', 7512, 14, NULL, 59),
(2385, 'Golden Gi', 'YR8655AO6Z2438X', 'combate', 706321, 14, NULL, 91),
(2386, 'Udohi', '56U52IC35DI43H7', 'pasajeros', 1141204, 6, NULL, 32),
(2387, 'Lil'' Mife', 'PMT0MGMZ9VT2228', 'pasajeros', -8879467, 15, 46, 34),
(2388, 'Benurufehe', '52STH83TD9K2E6C', 'carga', -7587, 14, NULL, 86),
(2389, 'Zomedo', '5IFQ7FIYKCCN170', 'combate', 2076881, 7, NULL, 74),
(2390, 'Fish', 'T7LPAA6SNXQ3D7B', 'carga', -8779042, 1, 36, 99),
(2391, 'Samugi', '26VAQAHFAB37125', 'carga', 6755365, 7, NULL, 33),
(2392, 'Big Focoli', '3V654JK4H9OOOUT', 'carga', -3876507, 10, 15, 7),
(2393, 'Qoruxo', '1EXERNONTKPFNA2', 'pasajeros', -9135312, 6, 26, 65),
(2394, 'Tucudohogima', 'VK5RF66TO15Y60D', NULL, NULL, 2, 26, 57),
(2395, 'Aneriva', 'Q747LMGEAK2962T', NULL, NULL, 0, NULL, 74),
(2396, 'Lil'' Giqejobati', '2374N3IZPI8INE5', 'pasajeros', -8820991, 0, 35, 90),
(2397, 'Silver Wocemeko', 'A6764W4HOTP14HB', 'pasajeros', -762, 2, 44, 69),
(2398, 'Eagle', 'YMM556H4LM5BVD7', 'pasajeros', -521930, 15, 21, 39),
(2399, 'USS Fish', '6T2YB3X5C2EDO30', 'carga', 23, 3, NULL, 77),
(2400, 'Golden Giveza', '06M933E9RR7756K', 'carga', 7620661, 11, 46, 26),
(2401, 'Xitumivatu', '4N4PXJQZD5Q07G3', 'combate', 9671114, 13, 5, 100),
(2402, 'Lil'' Tozefu', '54P8DHJ4AUP10HU', 'carga', 8496, 0, 17, NULL),
(2403, 'Little Agomoza', '106AFT09Y3KJ630', 'pasajeros', 9207419, 480, 34, 27),
(2404, 'Imoliqa', '3O02FM7N7V445IC', 'combate', -27, 3, NULL, 2),
(2405, 'Little Notenefale', '76XF6QC9783WV3L', 'pasajeros', 810, 14, 47, 77),
(2406, 'Fish', 'C6AP3SIA3965586', 'combate', 6094331, 2, NULL, 90),
(2407, 'Zeppeling', 'O4FVOW84F6R83L2', 'pasajeros', 39, 13, NULL, 98),
(2408, 'Big Ivido', '9483D92C32MJC55', 'pasajeros', 45, 0, NULL, 50),
(2409, 'Quwamo', '4FS1HG0X57VMXSY', 'carga', -8108923, 1, 13, 22),
(2410, 'Stormy Butterfly', 'N20VP3X793I6088', 'carga', -4009902, 4, NULL, 6),
(2411, 'Little Jaqese', '646G92QX7V02A1I', 'pasajeros', 2454314, 0, 8, NULL),
(2412, 'Jepuzoducami', '74C4ASE770N4TWW', 'pasajeros', 3946, 26, NULL, 2),
(2413, 'Ifica', '343JVP5AII98394', 'combate', 8039, 9, 3, 3),
(2414, 'Kivelo', 'Z4AG1FVE07JSPBW', 'carga', -8613662, 12, 23, 7),
(2415, 'Viboci', 'K408JFQ2NBM488K', 'pasajeros', 10, 14, 26, 97),
(2416, 'Big Wukaviquxu', '687M0RGH351TH9S', 'pasajeros', 6573412, 7, NULL, 17),
(2417, 'Shiny Ohopotu', '2K3COT3A2R8YBGD', 'pasajeros', -14631, 4, 43, 79),
(2418, 'Habeduvumo', 'C399AS49J1D3R3Y', 'carga', 7674683, 9, NULL, 3),
(2419, 'Butterfly', 'LR2460S8SDT81I5', 'carga', 2261917, 1, NULL, 70),
(2420, 'Golden Nozika', '70JJ35D90V94X34', 'exploración', NULL, 7, NULL, 90),
(2421, 'Silver Uzucike', '1G34904R2546369', 'exploración', -68, 10, NULL, NULL),
(2422, 'Condor', 'C3O9C4JOF09FY8M', 'exploración', -8503521, 3, NULL, 93),
(2423, 'Cloudy Bikuqaxi', '0H8M36M058DO868', 'carga', -3324168, 0, 19, 41),
(2424, 'Grand Lizo', 'T441N1FJRX7AC91', 'pasajeros', -5577505, 5, NULL, 42),
(2425, 'USS Dizilu', 'X036XM0IAS56FS1', 'carga', 2744694, 0, 42, 85),
(2426, 'Cidafi', '93YHZEF94RNMS2G', 'carga', 9759263, 353, NULL, 57),
(2427, 'Condor', '8NR5Q4997PLHAGB', 'pasajeros', -3974220, 10, 8, 56),
(2428, 'Ogeho', '2OG7L248T1K4L8V', 'carga', -1444581, 9, NULL, 30),
(2429, 'Shiny Kucijenawi', '14TA63TV26609VP', 'pasajeros', 7039203, 1, 6, 25),
(2430, 'Lil'' Kutewo', '66UH8P24OF2MY2J', 'exploración', 6006434, 0, 15, 8),
(2431, 'Cloudy Fish', 'G6S8B2A6ZCA5GIE', NULL, NULL, 1, 43, 84),
(2432, 'Fox', '01ZJ1PP6S93A831', 'pasajeros', 4725107, 1, NULL, 86),
(2433, 'Little Condor', '52S9KB0U011P8YG', 'carga', -5855924, 10, NULL, 55),
(2434, 'USS Pesomo', 'G37GUK1WR3LDFEN', 'carga', 2203817, 1, NULL, 44),
(2435, 'Grand Ujalaqitu', 'LH09D88W942C151', 'carga', -7360406, 0, 24, 51),
(2436, 'Lil'' Mesi', '15H507H39X9JHHU', 'carga', NULL, 13, 24, 26),
(2437, 'Rotaloti', '32M2UJNM854Z76D', 'carga', -73, 4, 33, 44),
(2438, 'Viguci', '2ZC7VL48V2EKU9J', 'pasajeros', -6028310, 0, NULL, 54),
(2439, 'Stormy Ka', 'VM0FXF19UX2T72E', 'combate', 520260, 12, NULL, 52),
(2440, 'Lagomiqi', '4E2R1EL615400KF', 'carga', 79, 0, NULL, 95),
(2441, 'Little Vutoguza', '993K9RS1YHU49U9', 'carga', -8178359, 0, NULL, 39),
(2442, 'Lil'' Hupamamu', '01PQ24J3T0XA5XY', 'carga', -1622630, 5, 34, 39),
(2443, 'Lelafusoxu', '55F87H5842J85E5', 'carga', 6134539, 13, NULL, 86),
(2444, 'Ovoqa', 'TEOF17W854Y8H6M', NULL, NULL, 13, 28, 24),
(2445, 'Cloudy Uguxena', '69U141885517OLB', 'carga', -175067, 5, NULL, 48),
(2446, 'Ifema', '2N8Z4NF802PDGZ5', 'carga', 2275059, 14, 41, 9),
(2447, 'Silver Vowulefa', '4GRK5WK901C15QY', 'pasajeros', -733, 2, 4, 80),
(2448, NULL, 'BV98574127BFV97', NULL, NULL, 1, NULL, 51),
(2449, 'Grand Fish', 'AY595T5Z279BKP4', 'carga', NULL, 13, 25, 63),
(2450, 'Vukijece', '7ZU49M8PAJ0583N', 'combate', 9, 5, 2, 100),
(2451, 'Lil'' Giwewixo', 'K210OR3D05JPNK8', 'exploración', NULL, 11, 8, 85),
(2452, 'Big Turumagi', 'Z2Y282H9X79VB7R', 'carga', 3209234, 1, 42, 79),
(2453, 'Zulesitopu', '7V83549DQLRCT82', 'pasajeros', -5370462, 2, NULL, 57),
(2454, 'Zufizi', '57GVPDVK0EUZR0Y', 'combate', -796, 11, 28, 40),
(2455, 'Osigu', '1B0Y85130TE6JY6', 'carga', 3108926, 114, 40, 2),
(2456, 'Xawokele', '09R7JBS532U6VR8', 'carga', -7916209, 0, 28, 67),
(2457, 'Malenawibo', '5845V84MW8OCAKM', 'carga', 9163569, 0, 19, 2),
(2458, 'Shiny Zosotoro', 'C149WC17T308QOZ', 'carga', -7869080, 4, 44, 70),
(2459, 'Guqicufo', 'Z8562CP74D883Q5', 'carga', -4469, 5, NULL, 3),
(2460, 'Adikise', 'WK6K63CU7FUT99J', 'exploración', 4630142, 2, NULL, NULL),
(2461, 'Tinagiho', '3M7YRF3AU3N4J4W', NULL, NULL, 291, NULL, 47),
(2462, 'Big Vigaxe', 'C065GVPD5157GR7', 'carga', 5866, 10, NULL, 16),
(2463, 'Silver Gifodefo', '4868Y3R6ZYEYYLW', 'pasajeros', 5962828, 0, 1, 61),
(2464, 'Lil'' Ezaqihoxe', '83I0ZSF9EW5L516', 'carga', -9623098, 0, NULL, 84),
(2465, 'Butterfly', '45NG10487PED7RN', NULL, NULL, 2, NULL, 45),
(2466, 'Nicofuji', '7N9U7273M2H48F3', 'carga', -8332366, 285, NULL, 39),
(2467, 'Dovehuvo', 'OL3S144273DKOE9', 'carga', -2706188, 0, NULL, 36),
(2468, 'Stormy Fihuri', '6QK3ELG99R7J0Q7', 'carga', 8, 7, 14, 51),
(2469, 'Big Eagle', 'PV3UO0MP34YCFP1', 'carga', 70, 1, 2, 97),
(2470, 'Ikevuzu', '73W7L414C91GD13', 'carga', -4189199, 9, NULL, 88),
(2471, 'USS Butterfly', '2G84Y5HM5F02OT6', 'carga', 1032193, 1, 46, 56),
(2472, 'Cloudy Kehavowo', '94AO3624553FAZ0', 'carga', 8, 12, NULL, 99),
(2473, 'Fish', 'CZ3UL4BCXO78A45', 'pasajeros', -5709744, 7, 10, 66),
(2474, 'Stormy Ikuki', '84D4IOC0U96IVOX', 'exploración', 18, 496, NULL, 18),
(2475, 'Eleluvupo', '41R8H639HIQ4R8R', 'carga', 4031919, 3, 16, 74),
(2476, 'Shiny Viwidasa', 'NH6DBON57TI8CZ5', 'carga', 726, 1, 13, 32),
(2477, 'Stormy Eagle', '6L7GH7WKU088EZS', 'pasajeros', -1218303, 5, NULL, 11),
(2478, 'Pifi', '97K7LD4M23NR021', 'pasajeros', -5587, 10, NULL, 11),
(2479, 'Eagle', '53905MK31H1I9XJ', 'pasajeros', 4913, 3, 47, 29),
(2480, 'Cikagajeke', '43YPHKU7ZL0UR38', 'pasajeros', NULL, 12, NULL, 93),
(2481, 'Ibofe', '4SY5YGI488K9O42', 'pasajeros', 2790, 0, NULL, 77),
(2482, 'Golden Cima', '1F168TP8777MMK3', 'pasajeros', 8616844, 1, NULL, 3),
(2483, 'Big Rivoso', '44SD22MJ15KT79H', 'combate', 9766, 0, 44, 82),
(2484, 'Kejaqukiku', '09K680E5F0OM23P', 'exploración', 62, 4, 24, 24),
(2485, 'Fox', '46NI0RIU46H8O5W', 'pasajeros', 3833119, 9, 27, 96),
(2486, 'Golden Uwo', 'L9HBGIC1374X88Y', 'combate', -5175678, 1, 39, 27),
(2487, 'Lil'' Cunite', '0HM2Q4701HOW7V6', 'pasajeros', 5600946, 3, NULL, 50),
(2488, 'Little Eagle', 'YD35IA9Y9HGR85I', 'exploración', NULL, 389, NULL, 64),
(2489, 'Tibobo', '441N7NJV4T3UCTL', 'pasajeros', 6105254, 0, NULL, 93),
(2490, 'Bojuko', '20358ZUSM3PLD0Y', 'exploración', 6316334, 0, 1, 24),
(2491, 'Peweso', 'V3JP17TZ594VY83', 'carga', 8, 12, 29, 76),
(2492, 'Ginuxipexa', '8069PJ3XNO5134R', 'exploración', -831745, 211, 46, 85),
(2493, 'Shiny Ewonaki', '3827J1389LVW503', 'exploración', 5, 2, 24, 47),
(2494, 'Wiropabi', '0BLA0Q732V6792C', 'pasajeros', 1, 0, 41, 15),
(2495, 'Qopiwikulu', '2FAX11U61Z74858', 'carga', 4908, 0, 42, 23),
(2496, 'Fox', '3IK45T290T6L81T', 'carga', -4609834, 1, 11, 59),
(2497, 'USS Vogo', '21JO578B76NX5P2', 'carga', -9, 14, NULL, 81),
(2498, 'Idoro', '797U9W4B67LB8FX', 'carga', NULL, 2, NULL, 89),
(2499, 'Lil'' Edixeloti', 'MRA14K09ALT6V45', 'combate', -4382, 10, 29, 73),
(2500, 'Silver Popupegazo', 'T215NKC92166GAD', 'carga', 3229924, 269, 14, 27),
(2501, 'Lil'' Nigoxoxa', '3CXR37XH2077H40', 'pasajeros', -6982375, 3, 47, 54),
(2502, 'Little Joweqo', 'CRGIC2G938HZJVT', 'combate', NULL, 1, 15, 40),
(2503, 'Ceqajizase', '604K9ZH9146C6L0', 'pasajeros', 9131820, 472, NULL, 8),
(2504, 'Ibazejavi', '872D4U076BJOR8U', 'combate', -1206213, 12, NULL, 87),
(2505, 'Cloudy Nifi', '07HLS0E6ZLG6Q63', 'carga', 3, 12, NULL, 100),
(2506, 'USS Uruhitadi', 'G94ZN6HD8152HZ3', 'pasajeros', -5, 40, NULL, 38),
(2507, 'Jifajino', '28S53FDDSX776W3', 'carga', 5605783, 15, NULL, 71),
(2508, 'Little Ehasa', 'M0EM7HH0OO3IT08', 'exploración', 4581299, 8, 17, 45),
(2509, 'Big Kepugo', '6X5CS11481KAO18', 'carga', -2520776, 0, 10, 36),
(2510, 'Lomivija', '5C51ZLD373E926B', 'pasajeros', NULL, 14, 19, NULL),
(2511, 'Xupepo', '143M6RBQGH4499E', 'carga', 5027, 13, 45, 94),
(2512, 'Silver Zowoti', 'A5OU9CSE5Y0132G', 'carga', 6850306, 2, NULL, 12),
(2513, 'Cloudy Newo', 'T7G62D30C95E94C', 'carga', 9039703, 15, NULL, 48),
(2514, NULL, 'MM9S4690111JO57', NULL, NULL, 11, NULL, 61),
(2515, 'Stormy Folujejotu', '02Y55AQJPHG4W07', 'pasajeros', 6740, 0, NULL, 24),
(2516, 'Qitimu', '1S0TARCAKX92J6R', 'pasajeros', -1539409, 14, 12, 82),
(2517, 'Condor', 'CWG14CO3U8EJ19L', 'carga', -66, 14, NULL, 39),
(2518, 'Icenicu', '3BFZ128KJ6MUF0I', 'pasajeros', -7775629, 13, 49, 35),
(2519, 'Lil'' Misewewu', 'EC7JA7LYB3872PH', 'carga', 2335857, 8, NULL, 55),
(2520, 'Big Odu', '4S3YI81QE941860', 'exploración', -4, 1, NULL, 57),
(2521, 'Befiloge', 'CEW3KJ449CG6HP4', 'carga', -8613438, 13, NULL, 76),
(2522, 'Grand Bokuleso', '4D90Z0D44415QL5', 'carga', -983929, 0, 50, NULL),
(2523, 'Tozodixosu', '23F57BH479T4N09', 'carga', -8656581, 1, 24, 68),
(2524, 'Ejumuke', 'O5C78312Q8U7O00', 'carga', 5955577, 0, NULL, 2),
(2525, 'Nupocala', '9J3D7T88K0OM5K1', NULL, NULL, 12, NULL, 24),
(2526, 'Je', 'WRV482F42M5V012', 'pasajeros', -5558974, 0, 46, 20),
(2527, 'Cageke', '68J5EK6FN3CXAS1', 'pasajeros', -9621826, 182, 44, 57),
(2528, 'Condor', '070D15WKSOK7BI1', 'carga', 3722694, 6, NULL, 94),
(2529, 'Shiny Ofa', 'Q2WRV0391LPH823', 'carga', 883687, 7, 6, 54),
(2530, 'Lil'' Abunufare', 'HEMTL6R115V29Z8', 'exploración', 663, 4, 28, 16),
(2531, 'Nowiwi', '279YH85EAM476C9', 'pasajeros', 4, 113, NULL, 60),
(2532, 'Fajojazi', '9H9HH76H7JQH0DA', 'carga', -8403836, 1, 16, 52),
(2533, 'Daxakehi', 'GGQFP260WLI78X0', 'carga', -2871955, 1, 10, 10),
(2534, 'USS Bapu', '66005ZY34U3CH16', 'carga', -4398, 7, 16, 90),
(2535, 'Cloudy Omupijuhu', '1XVZ085NE272RL7', 'pasajeros', 188, 0, NULL, 6),
(2536, 'Fesugokila', 'TTIX4JS797W4M4X', 'pasajeros', -5289129, 72, NULL, 46),
(2537, 'Paxu', '9ITF8JO334XT2V1', 'combate', -8060, 0, NULL, 76),
(2538, 'Binutu', 'P6279N65LRC10CP', 'pasajeros', 9489698, 9, 40, 78),
(2539, 'Big Rirecerige', '2ZN92JD85229YIJ', 'pasajeros', 1741, 29, 11, NULL),
(2540, 'Qepirufe', '80ZL9P2J2263ES6', 'combate', 6691, 15, NULL, 48),
(2541, 'Iqe', '0S019Q6R376X7YU', 'pasajeros', 420, 10, NULL, 94),
(2542, 'Difexovu', '73K69SQEH6WEYXL', NULL, NULL, 5, 20, 1),
(2543, 'Gumalu', 'HC0ALSDH3R53T0I', 'exploración', -794, 2, 22, 21),
(2544, 'Cloudy Gamodeno', '2NVJSFU3V10ZY6Z', 'pasajeros', NULL, 10, NULL, 41),
(2545, 'Cloudy Eagle', 'S364HJLC1B48N58', 'pasajeros', -837126, 2, NULL, 21),
(2546, 'Grand Fi', 'R9D8MILL5H1121Q', 'carga', -8297, 1, 8, 3),
(2547, 'Fox', 'I6E47K69ZLD29P5', 'exploración', -1037315, 1, NULL, 89),
(2548, 'Iroquko', 'J89T93W236TF367', 'pasajeros', 737, 8, 11, 80),
(2549, 'Gedike', 'J05J7OKD804B331', 'carga', -69, 211, NULL, 6),
(2550, 'Fish', '8617CZ4763M771I', 'carga', 2547387, 8, NULL, 33),
(2551, 'Toqeqa', '08TWO0A795P4M55', 'carga', -11, 7, NULL, 72),
(2552, 'Stormy Qituriwijomu', 'QIUKCZHK8XQT0P4', 'combate', -4486501, 3, NULL, NULL),
(2553, 'Lil'' Gojaji', '3RR350839PVY7EV', 'pasajeros', -8035975, 1, 17, 52),
(2554, 'Dazo', '2INX715352B644K', 'pasajeros', 1240195, 0, NULL, 89),
(2555, 'Ibepa', 'KL9100LJF04336Z', 'carga', 6520232, 11, 21, 1),
(2556, 'Eagle', 'LTG19T9MB61L2OZ', 'carga', -434092, 1, NULL, 40),
(2557, 'Shiny Luhabadu', '7U2ZC9363H25S4P', 'pasajeros', 2632948, 165, NULL, 48),
(2558, 'Shiny Duqumu', '06A8893340Y1JPE', 'carga', -8667280, 4, 21, 9),
(2559, 'USS Fish', '07VVZDWL8M92X7W', 'carga', 2, 1, 44, 26),
(2560, 'Vanesufaza', '664Y19TYM9M7X43', 'pasajeros', -157, 6, 49, 2),
(2561, 'Dukoca', '4A7216QY2QO60JP', 'carga', 8061379, 370, 5, 45),
(2562, 'Uvepiba', 'ILM733215R24534', 'carga', -7603672, 1, 40, 8),
(2563, 'Lil'' Xaru', 'EX97H5G595C52NO', 'combate', -7840037, 332, NULL, 5),
(2564, 'Lil'' Sisa', '1487IOL080GA07H', 'carga', 328, 14, 28, 79),
(2565, 'Fox', 'G70W72BL67Y4FKB', 'carga', 1744367, 5, NULL, 58),
(2566, 'Anawaje', 'T5234913YT7RATP', 'carga', 7202194, 1, NULL, 64),
(2567, 'Lil'' Mejefixi', 'Y2HUT4A5998NA6T', 'pasajeros', -6195303, 0, 7, 99),
(2568, 'Grand Fish', '2I8BMN3NC683B7M', 'carga', 22, 388, 47, 79),
(2569, 'Golden Pukuce', 'T4T47V1154U1O7W', 'pasajeros', 3945234, 13, NULL, 99),
(2570, 'Gebuhufuwa', '13L25NPE2A6BEJV', 'carga', 5886825, 1, 34, 41),
(2571, 'Ico', 'N0MJXH89YB1O933', 'pasajeros', 9752462, 0, NULL, 2),
(2572, 'Stormy Ejenete', 'XN88ORCM4A0D4E1', 'carga', -1618741, 4, NULL, 80),
(2573, 'Stormy Efute', '095481UU6C8FE83', 'combate', 2994736, 15, NULL, 44),
(2574, 'Condor', 'U64OF8CO10G7372', 'pasajeros', -13, 10, NULL, 30),
(2575, 'Little Fish', '7G2THR4R2TFDPMD', 'pasajeros', -1625592, 15, 36, 9),
(2576, 'Shiny Bilisawa', 'AU53LC75YE6A6OV', 'pasajeros', 7438887, 3, 7, 15),
(2577, 'Silver Girede', '244ZNFRRE29D15V', 'exploración', 6, 7, 27, 47),
(2578, 'Surawafi', '8YL6GL5DWF22A60', 'pasajeros', -975, 8, NULL, 84),
(2579, 'Pofujute', '716RJ67GEIAT6X8', 'pasajeros', -4159625, 4, NULL, 26),
(2580, 'La', '5X931G54L8G209P', 'pasajeros', -686100, 1, NULL, 27),
(2581, 'Eagle', 'X03W8LAMFB8VS89', 'carga', -4771510, 4, NULL, 88),
(2582, 'Masifobe', '3P37G6054WAQLA2', 'exploración', -9320844, 0, 45, 51),
(2583, 'Lonalenu', 'I098V01M1SJ0Y5Q', NULL, NULL, 5, 16, 83),
(2584, 'Difewu', '3MU914OW3HN0HZD', 'carga', 957, 5, NULL, 16),
(2585, 'Hecu', '1Z7Q10WL60M1K5Z', 'combate', -3507710, 4, 23, 7),
(2586, 'Lil'' Warako', '96599VB3N7HIB4K', 'combate', 5387928, 1, NULL, 47),
(2587, 'Gekezabu', '0N608M4QIX5KL8C', 'exploración', -6539956, 229, 27, 14),
(2588, 'Zova', '8O7D02SK0HXP9M7', 'exploración', -8921827, 73, 7, 35),
(2589, 'Fox', 'JH2198L10MI534C', 'pasajeros', 4613893, 1, 50, 62),
(2590, 'Necukaginawa', 'F59N7J360A382B1', 'carga', 1211778, 236, NULL, 30),
(2591, 'Grand Woxovuqose', '2R33X7UEQ04R55Y', 'carga', 9678246, 1, 8, 81),
(2592, 'Qohano', '6OWX0A5QF4ILQXT', 'combate', 7173802, 2, 42, 76),
(2593, 'Cloudy Fish', '2P162XD72VC3G0V', 'carga', 5834664, 12, 38, 93),
(2594, 'Cloudy Ihawesu', '680TB364551393H', 'pasajeros', -9394588, 14, NULL, 3),
(2595, 'Lil'' Uqafa', '1G7BZTAM155G8I2', 'combate', -5752513, 387, NULL, 4),
(2596, 'Golden Itu', '1L4203UEBJ1KTE7', 'pasajeros', 7220, 3, 32, 41),
(2597, 'Grand Puxarodi', 'K77CXR69QDW3Q72', 'pasajeros', -96, 10, 9, 72),
(2598, 'Opakome', 'HDR9D5ERKNA3620', 'carga', -2850221, 0, NULL, 9),
(2599, 'Domemame', '9QBY8Y7XMU3U3QA', 'carga', -1601605, 110, 28, NULL),
(2600, 'Shiny Xovojabo', 'RR3A4T924RE354G', 'carga', -5750576, 3, 25, 33),
(2601, 'Silver Hicocose', 'M1A2DNLZGFS1028', 'carga', 1497946, 11, NULL, 60),
(2602, 'Butterfly', '0096970V34Z7UJL', 'pasajeros', -8252, 6, 18, 64),
(2603, 'Ivecaba', '0TR1BD0X5AVFREJ', 'pasajeros', -24, 0, 4, 1),
(2604, NULL, 'BJAG74DBBK5FQC1', NULL, NULL, 2, NULL, NULL),
(2605, 'USS Lakuju', 'EEP8Q2O2PN14844', 'pasajeros', -875, 0, NULL, 45),
(2606, 'Jagigicofe', 'ZIFMQ1UQI65VE49', 'pasajeros', -4655753, 0, NULL, 80),
(2607, 'Texa', 'A926PLZ33HTZL39', 'carga', -2093794, 0, NULL, 71),
(2608, 'Rihokame', 'JBKG37N347PM564', 'pasajeros', 7918781, 6, 6, 100),
(2609, 'Big Xejoqosa', '4YEZ8S836P1F7KD', NULL, NULL, 284, NULL, 15),
(2610, 'Atumo', '16D11LA6368N0D2', 'exploración', -3170937, 449, 9, 85),
(2611, 'Sexuqeva', 'TAUW885Z894O4F7', 'combate', -2704500, 11, 11, 81),
(2612, 'Olusuwo', 'Q928WPVIN1IN1MX', NULL, NULL, 0, NULL, 85),
(2613, 'Cloudy Hekedudiqa', 'U390P6F777281Y9', 'pasajeros', -11, 1, 29, 1),
(2614, 'Niqubosa', '5O7G19X1QXOS7OD', 'pasajeros', -953, 5, 34, 53),
(2615, 'Big Sazo', '8Z861752EVD8J3B', 'carga', 6538675, 9, NULL, 12),
(2616, 'Nixino', 'KNN35ZQ6JZCAEJP', 'combate', -3530327, 12, 13, 2),
(2617, 'Inuvuxe', 'N3A75UUIO45G03D', NULL, NULL, 4, NULL, 38),
(2618, 'Fedazi', 'E6Q83P8N2ZUAPHC', 'pasajeros', -7978, 12, 11, 74),
(2619, 'USS Zijivaqe', 'E8QBLCU3NW8M30R', 'carga', 4897024, 388, 23, 55),
(2620, 'USS Condor', '7I7AOLOE5LKHG6X', 'carga', 1298769, 13, 39, 24),
(2621, 'Little Siziwu', 'BC57DUZZD000OT3', 'carga', 6080742, 0, 21, 90),
(2622, 'Big Sebibo', 'EX3Q533T5I75263', 'carga', 54, 3, 49, 53),
(2623, 'Ogaze', 'AO793X2W08EF052', 'combate', 841, 2, NULL, 3),
(2624, 'Xugebumuki', 'KT81HC77443DRAS', 'carga', -7499006, 7, 31, 12),
(2625, 'Cloudy Jamobopi', '83BRV880R504K4E', 'carga', -7295902, 0, NULL, 19),
(2626, 'Grand Dicu', 'H0NRMME92JTOV2X', 'carga', 27279, 2, NULL, 75),
(2627, 'Silver Zopivu', 'MF16MM16X334KWN', 'exploración', NULL, 1, NULL, 15),
(2628, 'Uxavodona', 'NK3MW3PW6EDB1Z7', 'exploración', 8684573, 0, NULL, 73),
(2629, 'Butterfly', '7260YX5QPY29LW6', 'carga', -7860404, 11, 28, 35),
(2630, 'Little Ce', 'JE4RVDK6S8GK0ZI', 'carga', 2863, 72, NULL, 88),
(2631, 'Fox', '2751MME6SMK22X2', 'pasajeros', -828, 3, 38, 80),
(2632, 'Fish', 'C02UVGO7VA7G3P6', 'pasajeros', 8081373, 13, 24, 66),
(2633, 'Big Fox', '12T22LG60MN2P77', 'exploración', 5901, 5, NULL, 45),
(2634, 'Oru', '338A3N47KDZ0372', 'combate', -251, 1, 26, 93),
(2635, 'Grand Uvukepa', 'TP2Q60DT24G904W', 'exploración', -5729726, 3, NULL, 14),
(2636, 'Vuvamopini', '77Y5R32R3C9Y873', 'combate', -4343884, 14, 24, 97),
(2637, 'Shiny Condor', '672RP881L21ZW45', 'carga', -3681135, 120, 46, 3),
(2638, 'Fox', 'P944G0611Z3HR7X', 'carga', -915, 3, NULL, 67),
(2639, 'Golden Gexesokikale', '96WSU0V6MZX1W25', 'carga', -57811, 1, NULL, 47),
(2640, 'Celeqele', '7R8V5F7E69X96BO', 'carga', 6815418, 11, 3, NULL),
(2641, 'Silver Buta', 'TZBHM5Q8G4051O6', 'pasajeros', 4380031, 428, NULL, NULL),
(2642, 'Lil'' Butterfly', '1HF25F4D6C93602', 'combate', -7714668, 1, 46, 55),
(2643, 'USS Fox', '811C0J7NSPGSMLA', 'exploración', 2838770, 58036, 47, 32),
(2644, 'Uhareheji', 'N80056HHG54B3L7', 'pasajeros', 65, 7, 26, 5),
(2645, 'Little Dekere', '5LQ9147AK7C0V78', 'carga', 9232456, 0, 11, 59),
(2646, 'Pijevu', '4N077346A74N491', 'exploración', -2059701, 12, NULL, 92),
(2647, 'Grand Eagle', 'P2ZZY108S42Z8FD', 'pasajeros', 6090056, 0, 10, 48),
(2648, 'Cloudy Camufe', 'HUU1X6E2540P6U9', 'combate', -4315172, 8, 47, 83),
(2649, 'Shiny Fox', 'C5P8D89TU30Q1N2', 'carga', -6810417, 0, NULL, 17),
(2650, 'Little Vubageke', '64AZL6Y2E2H4H2J', 'carga', -8181, 1, 4, 59),
(2651, 'Grand Edema', 'TGX9V4X7VU4096B', 'exploración', -2387269, 9, 10, 36),
(2652, 'Grand Mifi', 'NMGNMT2TU99TP59', 'carga', -5, 1, 46, 28),
(2653, 'Witewaka', '19C3453T0ZSJ2UK', 'carga', -6658986, 0, NULL, NULL),
(2654, 'Bevo', 'I734I7N87GB3D24', 'pasajeros', NULL, 0, NULL, 41),
(2655, 'Torejo', '0B9367425A63D36', 'carga', -7927256, 1, 46, 68),
(2656, 'Laweca', 'OYX8AJ30T1V66CO', 'carga', 3003, 7, NULL, 37),
(2657, 'Xasada', 'W1O8I5Y8W94TVHW', 'carga', -10, 3, NULL, 44),
(2658, 'Izoxumesu', '9H525C60949MABY', 'pasajeros', 7303, 5, NULL, 29),
(2659, 'Fumaceje', '7Z3BA558R07879Z', 'exploración', -8, 13, NULL, 17),
(2660, 'Wonoto', '549UHA0KQGG39IY', 'carga', 4792210, 0, 8, NULL),
(2661, 'Silver Fish', '3COE7937743C646', 'pasajeros', -5240445, 291, 47, 64),
(2662, 'Grand Zeppeling', '5356R702SBFKXSA', 'pasajeros', -4903342, 0, NULL, 44),
(2663, 'Big Ehive', 'XXMI30LWY7K6X5F', 'carga', NULL, 1, NULL, 80),
(2664, 'Cloudy Ibuxomuma', '5V20EWV6P7U622E', 'carga', -6, 138, 9, 60),
(2665, 'Fox', '0W7QLZ6SNX70NS7', 'pasajeros', -4100830, 1, 26, 71),
(2666, 'Opamozigo', '7F23E1T717DTJ14', 'pasajeros', 4633749, 1, NULL, 28),
(2667, 'U', '5111T2A6555K4I2', 'combate', 4664380, 14, NULL, 62),
(2668, 'Ebeki', 'DWZQ50P8W3S3M5D', 'combate', -407, 0, 7, 65),
(2669, 'Ocu', '1TZ8GHI0FLAQ359', 'pasajeros', -8511277, 0, NULL, 18),
(2670, 'Silver Zeppeling', '720RUO370BB9D2G', 'pasajeros', 8079865, 1, NULL, 18),
(2671, 'Kixa', 'HZG56486997LWXB', 'carga', -6842554, 433, 19, 38),
(2672, 'Fish', 'QL29M868DFWS5T8', 'pasajeros', -3895, 0, NULL, 4),
(2673, 'USS Mivisice', '8E4VWB0B99KY01X', 'carga', -8959857, 0, 41, 5),
(2674, 'Grand Guxowofe', 'PXH9523DRD82N51', 'carga', -1940197, 0, NULL, 56),
(2675, 'Isi', '2O04DBU887772V6', 'pasajeros', 96, 7, NULL, NULL),
(2676, 'Bavugami', '816LZ8154X47399', 'combate', -7699527, 1, 19, 31),
(2677, 'Grand Fu', 'N39RO7H7WGI8715', 'pasajeros', -6, 14, NULL, 84),
(2678, 'Cloudy Sajuxefi', 'E1W0G2D4Z9BHJNY', 'carga', -747, 0, 33, 44),
(2679, 'Stormy Condor', '6RB0567E9C041PA', 'carga', -3585041, 9, 34, NULL),
(2680, 'Big Fish', 'ZZC758S9J8SE498', 'carga', -6308772, 5, 12, 4),
(2681, 'Little Diciparo', '3AU2X7K6MR028DW', 'carga', -1602428, 11, 6, 44),
(2682, 'USS Butterfly', 'H5GVZBB3VO64M32', 'pasajeros', -7735, 2, NULL, 5),
(2683, 'Jezano', '2T0160966T26G6N', 'carga', -3227766, 1, NULL, NULL),
(2684, 'Cloudy Voja', '11PS4MKBLK11N7C', 'combate', 798878, 15, 7, 57),
(2685, 'Zeppeling', 'AR08KT7419L2E4N', 'carga', -7105, 5, 13, 72),
(2686, 'Lobewa', '5961Y9R7V3S4J9D', 'carga', -6, 5, NULL, 2),
(2687, 'Vovudece', '9NT9326VS18VJWZ', 'pasajeros', 66, 1, NULL, 23),
(2688, 'Nuxanuze', 'W0V4RJ4W1932X9K', 'combate', -1515286, 14, NULL, 17),
(2689, NULL, 'H6P2E4H312TZG22', NULL, NULL, 274663, 19, 86),
(2690, 'USS Butterfly', 'AL4SKJEENQ12Z8P', 'carga', -2098315, 1, NULL, 15),
(2691, 'Shiny Luxiniba', 'T050R0AW49G3O21', 'pasajeros', 9361354, 10, NULL, 61),
(2692, 'USS Kile', '59D8YDDSE0JIUD0', 'carga', NULL, 0, NULL, 68),
(2693, 'Vacowimubu', '44575743E74468L', 'pasajeros', 0, 0, 5, 34),
(2694, 'Golden Efegobalo', 'IDH7KJ2417E2GBE', 'carga', -6128596, 124, 1, 32),
(2695, 'Shiny Nigeludeqi', 'UC14Z269N30085X', 'carga', 2852999, 4, 43, 61),
(2696, 'Sivovu', '693TL8916W8QI3U', 'carga', -110749, 9, NULL, 9),
(2697, 'Raro', 'Z3DT2VOU45005P2', 'pasajeros', 5530489, 1, NULL, 26),
(2698, 'Cloudy Uhepocime', '670U3EDVB50H414', 'carga', 6, 0, 12, 56),
(2699, 'Big Nuniqira', '8F2221JJACR2Y38', 'pasajeros', 151, 12, 29, 97),
(2700, 'Shiny Osomaxufodo', '241F8O2334L0DZ4', 'exploración', -9, 76, NULL, 100),
(2701, 'Little Vodoqotinu', '2RE5F032M6CSOFW', 'carga', 6070203, 0, NULL, 11),
(2702, 'Fox', '6143K9ZVJI78OBG', 'pasajeros', 9670523, 1, 44, 31),
(2703, 'Xememe', '0XIMFOUEG135WC3', 'pasajeros', 7281842, 5, 18, 24),
(2704, NULL, '6VL1B00XC553705', NULL, NULL, 193, 24, 79),
(2705, 'Grand Guwa', '1PR1X29ZMTJV693', 'carga', -7532913, 0, NULL, 52),
(2706, 'Wakamukano', '10FH8XAK141BXEM', 'pasajeros', 5016796, 4, NULL, 35),
(2707, 'Lil'' Ziroparo', '9BW91I98G3WJK59', 'pasajeros', -9286, 111, NULL, 55),
(2708, 'Little Sepicahihu', 'LU8FCU32HZP49LQ', 'combate', NULL, 193, 2, 3),
(2709, 'Kuleli', 'A0531LP76T52K4D', 'carga', -6106052, 2, 9, 24),
(2710, 'Lil'' Ruheke', 'P8Q7X5W816IW5VL', 'pasajeros', 1, 0, 2, 99),
(2711, 'Cloudy Rogetexo', 'OTH7HG91917BGS8', 'carga', -2086489, 122, 16, 23),
(2712, 'Umevobudi', 'NBW9M0999T1H3I4', 'carga', -3056829, 15, NULL, 77),
(2713, 'Abe', '6NCVK2I16IKU6QB', 'pasajeros', -9159047, 1, NULL, 70),
(2714, 'Koqa', '76UV5I355GM109O', 'carga', 7082123, 0, 8, 11),
(2715, 'Lil'' Jofocisuku', 'LY57BH8U42PCHZ4', 'pasajeros', NULL, 6, NULL, 20),
(2716, 'Fofa', 'Z4JV96M5B8556Q6', NULL, NULL, 5, 26, 8),
(2717, 'Fox', '19BI7D35D194628', 'carga', 6874975, 1, 20, 11),
(2718, 'Silver Fish', '36TL5RT73WGL71U', 'pasajeros', -802, 10, NULL, 8),
(2719, 'Lumukaze', 'TZF4SXU71Z6VNML', 'pasajeros', 6455160, 5, NULL, 24),
(2720, 'Ijiku', 'DNC9OT7C0I81002', 'carga', NULL, 6, 2, 82),
(2721, 'Grand Wepecetaro', 'GIK88D4CX5M005C', 'carga', -9950791, 1, 23, 30),
(2722, 'Jiba', '92KCP61R90Y7W1L', 'carga', -779, 0, 28, 55),
(2723, 'Jotatexe', 'Z2DQNZP5W9C70UI', 'carga', -2510655, 0, 40, 15),
(2724, 'Zeppeling', '9X39WAJ49QER2W1', 'combate', -5705098, 421, 43, 88),
(2725, 'Boqihehi', 'XABQNBKN2R5SWXP', 'combate', -54, 8, NULL, 72),
(2726, 'Stormy Kijofida', '507O07K61Z21A86', 'carga', -6908824, 4, NULL, 46),
(2727, 'Shiny Bicafaxu', 'BA654RP90KUJ47O', 'carga', 132, 464, NULL, 5),
(2728, 'USS Civonatizo', 'D3G275E8A2Z5V6V', 'carga', -929, 7, 9, 87),
(2729, 'Cu', 'V5I1CFHSLBUV8S8', 'exploración', 818629, 9, NULL, 46),
(2730, 'Lil'' Lohapu', 'QA7J093H95YFRS6', 'pasajeros', -3352649, 0, 33, 23),
(2731, 'Joqo', '1H4XO99OZ0JX231', 'combate', -55993, 1, 15, 85),
(2732, 'Butterfly', '8378DCN9T1IB3Z5', 'pasajeros', 9991347, 5, 15, 77),
(2733, 'Qe', '6HSI2LZ294332DG', 'pasajeros', -8715280, 13, 9, 85),
(2734, 'Lowunoko', '4E3CR6NX8HZMCK4', 'carga', -73, 11, 21, 62),
(2735, 'Big Tikulezu', 'Y3F76ZOK1534A40', 'pasajeros', -5, 0, NULL, 9),
(2736, 'Golden Loku', 'ONFG2UN847KCEL6', 'carga', -894616, 7, 32, 49),
(2737, 'Pojuli', '31H6S40I67FN611', 'pasajeros', -2706855, 8, NULL, 85),
(2738, 'Stormy Numeroke', '63F066GE4HR9176', 'carga', 139, 1, NULL, 1),
(2739, 'Moze', '6312M2Y6K3L6UQH', 'carga', NULL, 1, 46, 35),
(2740, 'Little Fox', 'BJGWR1X541M57Q1', 'pasajeros', 4, 192, 22, 2),
(2741, 'Ihupe', 'X11X909UGK5H2F0', 'carga', 2358422, 14, 7, 80),
(2742, 'Noma', '69S2ZS605CH2488', 'carga', -6532311, 13, NULL, 46),
(2743, 'Grand Butterfly', '7QSKOAO9S6T3506', 'carga', NULL, 11, NULL, 81),
(2744, 'Lil'' Kidunajo', 'F0TGIH6W01B7E1Y', 'pasajeros', 41, 446, 13, NULL),
(2745, 'Shiny Fish', '19LF2S19741M4RL', 'exploración', -525, 1, 4, 59),
(2746, 'Big Sevejajijade', '5XOMI88K17X1637', 'pasajeros', -9476518, 194, NULL, 2),
(2747, 'USS Acofumubo', '2492CP312NF6EM9', 'carga', -6661106, 1, 3, 58),
(2748, 'Ipilojoti', 'ZFX9T2ML65U05Y1', 'combate', -4033569, 1, 1, 10),
(2749, 'Xubosu', 'N3S1B9HWMYCTP7A', 'carga', 4312750, 1, NULL, 57),
(2750, 'Ukawopa', '2L10R2H9844XI35', 'exploración', -7091087, 1, 28, 64),
(2751, 'Tonufu', 'FAK0VJHKKTQ5VMR', 'pasajeros', -7254512, 2, NULL, 14),
(2752, 'Lil'' Fish', 'U0D4662K0873OCX', 'carga', 3, 12, 49, 11),
(2753, 'Silver Fuboreja', '7925G63QQN00B2O', 'carga', NULL, 6, 8, 56),
(2754, 'Big Jojoti', '9SUTT6718K6AAAP', 'carga', 1637552, 0, NULL, 39),
(2755, 'Mitawahi', 'VFD4079F2C3HI1O', 'exploración', 5402665, 380, NULL, 83),
(2756, 'Zeppeling', '9OD0874D23ZE8H4', 'carga', -1136820, 58, 28, 7),
(2757, 'Gucikadi', 'D7KKIJ1PF755099', 'carga', -548, 135, NULL, 31),
(2758, 'Wovaga', 'GKFSW4IM2MBAPV9', NULL, NULL, 12, 7, 96),
(2759, 'Big Condor', '671J11C264ROF5Z', 'carga', -7384711, 13, 8, 67),
(2760, 'Golden Bogima', 'W215I9ER1I79F34', 'pasajeros', -7091, 8, 28, 79),
(2761, 'Shiny Ikonera', '6L5244C6599X857', 'carga', -649480, 9, 19, 89),
(2762, 'Golden Bipexelamigi', '904J7T0NQ9EE4Y9', 'exploración', -9651758, 11, 23, 7),
(2763, 'Big Fijexu', 'PO1AY29PM744DK8', 'pasajeros', 2464988, 11, 40, 2),
(2764, 'Fox', 'G92UP4LMB7RY0P2', 'pasajeros', NULL, 5, NULL, 68),
(2765, 'Shiny Egolodukuqo', 'TLN988V842OW2JU', 'carga', 9473055, 1, 15, 85),
(2766, 'Stormy Gijiso', '9KH85163L2AP2A4', 'carga', 51, 12, 1, 30),
(2767, 'Fox', 'G8KGD18202QU65M', 'pasajeros', 3, 0, 33, 16),
(2768, 'Lil'' Qifi', 'K3A1LTC6488R60E', 'carga', 258252, 15, 35, 85),
(2769, 'Silver Zeppeling', '70K6X2V64486VMZ', 'pasajeros', 7, 305, 41, 71),
(2770, 'Fohalato', 'SCR44L3H7FF9486', 'pasajeros', 3051804, 13, NULL, 44),
(2771, 'USS Gumabe', '296PSU016UWAI9M', 'pasajeros', 9070318, 6, 3, 6),
(2772, 'Silver Ipafo', '6V51U3364P2OE4Z', 'exploración', -3258890, 145, 6, 14),
(2773, 'Nufiruti', 'LBCFP283490X5UZ', 'combate', NULL, 1, NULL, 9),
(2774, 'Gatoxisi', '239N8FKF4W93FXE', 'carga', 293, 13, NULL, 68),
(2775, 'Shiny Fox', 'XWY2V1524E823Z1', 'combate', 4398165, 3, 4, 95),
(2776, 'Lutiru', '366OYSKKXN5C1M9', 'exploración', -6988100, 2, NULL, 62),
(2777, 'Hulaju', 'F9S5W8S6E79382G', 'combate', 8808, 10, NULL, 20),
(2778, 'Qi', '4TW8K22VD824KQ5', 'carga', 2236978, 1, NULL, 8),
(2779, 'Condor', '03224W6LIY1YYK6', 'pasajeros', -9861606, 4, NULL, 69),
(2780, 'Grand Waxu', 'T7E81V2RQ77ILZK', 'carga', NULL, 13, 1, 90),
(2781, 'Silver Leja', 'AM2G5YT79632MHF', 'carga', -1502274, 2, NULL, 51),
(2782, 'Cloudy Vepehavoca', '27E1V1I7PBPHBM8', 'carga', 0, 153, NULL, 37),
(2783, 'Golden Umatuzinira', 'UP98EIP737OWYBL', 'carga', -2631256, 0, NULL, 89),
(2784, 'Lil'' Gofo', '9BUYM1M9FUU8XFO', 'combate', 7605486, 0, 32, 23),
(2785, 'Stormy Fox', '66OK3JM2207Y174', 'combate', 4, 10, NULL, 8),
(2786, 'USS Anogini', 'X4YP6766VQHUL71', 'exploración', NULL, 13, 21, 5),
(2787, 'Fodiqa', '29O79T4D51AXSOG', 'carga', 1347969, 11, 20, 44),
(2788, 'Bibapago', 'VH021Z70T67O1D0', NULL, NULL, 9, NULL, 1),
(2789, 'Golden Likakujo', 'L49IPRMIGBQLUJ2', 'carga', -26, 2, NULL, 75),
(2790, 'USS Jecetula', '7S5FU7E9T0583YO', 'carga', -16, 1, NULL, 75),
(2791, 'Golden Butterfly', 'IL2967LJ2B68HZ6', 'pasajeros', -430, 4, NULL, NULL),
(2792, 'Fozicasa', 'K48IYZVN766DVV6', 'pasajeros', 5326144, 1, 13, 92),
(2793, 'Butterfly', '4F64CGMJ3109EN8', 'combate', 9908875, 4, NULL, 28),
(2794, 'Ludagibi', '0229C9W41E34CA9', 'carga', -4473448, 12, NULL, 26),
(2795, 'Shiny Qemegalipa', 'K5Q0JVD4D56R92X', 'pasajeros', 6005808, 6, NULL, 11),
(2796, 'Cloudy Tobowolo', '2TQ055X0092DC35', 'carga', 8493219, 1, NULL, 2),
(2797, 'USS Zogelisu', '0JEJ55DO0BZR05C', 'pasajeros', NULL, 17, 33, 36),
(2798, 'Ciqimu', '2Q1ZQ2B3GC5H2A8', 'pasajeros', NULL, 0, 14, 8),
(2799, 'Big Gajuholimu', '6S34LEORB6IYHJ8', 'pasajeros', 5191066, 485, NULL, 80),
(2800, 'Lupe', '751MHHN0LF954D5', 'exploración', 4485911, 9, NULL, NULL),
(2801, 'Dafoho', 'XS8X5UE9067H7KW', 'carga', -7011144, 7, NULL, 70),
(2802, 'Grand Soriholi', '54ZL1QI33F56251', 'combate', -1586834, 1, NULL, 23),
(2803, 'O', 'WN446L90Z3PK9ZR', 'carga', 53, 0, 7, 8),
(2804, 'Shiny Godocova', '3KYXQ33EUV7VS39', 'carga', 7819240, 12, 29, 25),
(2805, 'Butterfly', '984GI23C17O9538', 'carga', -6, 2, NULL, 5),
(2806, 'Silver Sezuwaquna', '371WE986S3FKNGD', NULL, NULL, 8, NULL, 3),
(2807, 'Ihecojuja', '3961JJ9G0YL8AJ4', 'carga', -722, 0, 11, 78),
(2808, 'Qujeqefuta', '420ZGOQJ2YQ3R8Z', 'exploración', -12, 84721, NULL, 2),
(2809, 'Xafisiwa', '4OE636M0Z97HDW0', 'pasajeros', -4166813, 12, 6, 99),
(2810, 'Lil'' Efika', '3ZB4MXHI6Y22M31', 'combate', 6, 1, 16, 77),
(2811, 'Pehu', '67032OQH76742DU', 'carga', 3110813, 6, NULL, 83),
(2812, 'Grand Ibequbi', '2R827YTDG724FD7', 'carga', -286, 8, 8, 22),
(2813, 'Grand Tugijaha', 'ZY7K9C5QH1K6K6B', 'pasajeros', -2, 114, 11, 35),
(2814, 'Little Ekihoke', '0I6R1K5W901111V', 'combate', -1723634, 496, 34, 23),
(2815, 'Lil'' Oto', 'T13SL211XA8184W', 'pasajeros', 468, 0, NULL, 95),
(2816, 'Vugigive', '59UAC3Y496B4KGP', 'carga', 4615802, 5, NULL, 28),
(2817, 'Lil'' Nabe', 'S955H518082ZIZP', 'pasajeros', -497126, 1, 4, 76),
(2818, 'Grand Xucenida', '822UPF90MR78Y6Y', 'combate', -1983, 2, NULL, 68),
(2819, 'Wape', '96XL8AQ86V86H4F', 'pasajeros', -7, 0, NULL, 7),
(2820, 'Itu', '1OSE1PG90G64ZU9', 'pasajeros', 2, 6, NULL, 58),
(2821, 'Stormy Fox', 'J4R3YFO72DE3IKG', 'pasajeros', 5478914, 7, NULL, 60),
(2822, 'Havebonine', 'Z5NL406404RGC2M', NULL, NULL, 3, 26, 1),
(2823, 'Gibule', '92V86CW1CKW1W50', 'carga', 8875697, 7, 4, 42),
(2824, 'Lil'' Nuvacuseza', 'Y4069P7FEW0T75Q', 'pasajeros', 9746803, 8, NULL, 46),
(2825, 'Big Rakage', 'VA4EX691JJZL1E7', 'carga', 9308290, 111, 2, 70),
(2826, 'Vadu', 'YW27LG122X25B42', 'exploración', 4345, 9, NULL, 10),
(2827, 'Ewale', 'VRH64E846GQ8P95', 'carga', -8, 0, NULL, 63),
(2828, 'Stormy Vubebediga', 'DF1B0G8Q2B425Z5', 'carga', -3734, 15, NULL, 42),
(2829, 'Menoti', '074PHE79586122B', 'pasajeros', 766, 1, NULL, 57),
(2830, 'Big Gibiro', 'MJ775U119PU5WSJ', 'pasajeros', -1, 9, 46, 88),
(2831, 'Cloudy Lusihe', '0J1FL2Y9F1H6YZ8', 'carga', 50, 8, NULL, 31),
(2832, 'Lil'' Butterfly', 'L34IGU70K1I2HVB', 'carga', 0, 1, NULL, NULL),
(2833, 'Qikafomu', '0B268BZ379H2U70', 'carga', -1, 1, NULL, 63),
(2834, 'Cokapuxa', '19I2L63I6ZRKCRM', 'carga', 1702, 419, NULL, 61),
(2835, 'Jukomogu', '26G8M1Q3K2U1V52', NULL, NULL, 12, 44, 81),
(2836, 'Pewace', '8TFR5KPUSI39280', 'carga', -4316913, 6, NULL, 27),
(2837, 'Lil'' Butterfly', 'S8889K8EA96RFK0', 'carga', -252, 13, NULL, 5),
(2838, 'Fabimima', 'A6836XI480QTG4U', 'carga', -43, 6, NULL, 16),
(2839, 'Cloudy Lemetigamo', 'XZ379003498YD2R', 'combate', 637, 15, NULL, NULL),
(2840, 'Fish', 'KJ3DS0621MQW438', 'pasajeros', 3707088, 6, NULL, 20),
(2841, 'Cloudy Zeqote', '5IMSKD0B5HD27S2', 'pasajeros', 5488433, 10, NULL, 73),
(2842, 'Hagehu', 'H8Q2232WK2E11T7', 'pasajeros', -8271864, 5, 20, 97),
(2843, 'Sebawakali', '7F21S75D58EB3B2', 'carga', -1665981, 1, 47, 19),
(2844, 'Shiny Zarifa', 'Y7AST6C1T49IJOM', 'combate', -7737210, 1, 16, 83),
(2845, 'Silver Lecofazeha', 'E9MVGHRQYB5HPOW', 'carga', 2639346, 14, 2, 94),
(2846, 'Big Ohabahame', 'MPU78XOJ19809Z4', 'carga', -247, 5, NULL, 3),
(2847, 'Orameci', '5TEV8131WP135ZM', 'pasajeros', 492333, 1, NULL, 78),
(2848, 'Big Condor', 'ROFZ1CQP8F20N00', 'combate', 2618, 15, 20, 4),
(2849, 'Silver Dupulo', 'HQTB1454T4E956B', 'pasajeros', -6821424, 12, 39, 5),
(2850, 'Cinuqexe', 'Q119Q5VKTQD083G', 'pasajeros', 9521966, 2, NULL, 9),
(2851, 'Eagle', 'IB02MV2DO7E5904', 'carga', -2550305, 0, 43, 9),
(2852, 'Onaliru', 'ZJ5OL1MT52CI8T8', 'exploración', 1006212, 6, 38, 43),
(2853, 'Shiny Zikaquhe', 'UI0GA7P83T11CWE', 'exploración', -837, 0, NULL, 96),
(2854, 'Silver Bakiga', 'ZK36J68Z13JE1NV', 'combate', 9663909, 9, NULL, 32),
(2855, 'Be', 'AR5300HZ9VZ0EGQ', 'combate', 8098624, 141, NULL, 82),
(2856, 'Adujofiba', 'G1HIN1433R9PF9R', 'carga', 6367547, 13, 23, 12),
(2857, 'Stormy Zeppeling', '44187V8RTDK0355', 'carga', -2775, 14, NULL, 100),
(2858, 'Grand Iliho', '33PJB61814V80OT', 'carga', 4820667, 5, NULL, NULL),
(2859, 'Ekuha', '6TDLLA4VCGUELY7', 'pasajeros', 4082017, 10, NULL, 74),
(2860, 'Kidezavo', 'SOPFJR15H21V364', 'carga', NULL, 1, NULL, 37),
(2861, 'Ginakifiqu', 'B4VL83XVVU8UCZZ', 'carga', -2490818, 0, NULL, 88),
(2862, 'Fox', 'G1ZN317I02UMU79', 'carga', 2433496, 9, 4, 36),
(2863, 'Cloudy Huhugidu', 'BCQ20QPQ5779OVH', 'carga', -800275, 123, NULL, 82),
(2864, 'Grand Fox', 'BI07MS7W4EFE927', 'pasajeros', 28, 0, 11, 33),
(2865, 'Himisi', '19VV11L3LA4B7J9', 'carga', 7653638, 7, NULL, 19),
(2866, 'Little Dewowemuviki', '77C23C3R417Y586', 'carga', -676, 11, NULL, 77),
(2867, 'Fewi', '38C0I374V42N460', 'pasajeros', 6058, 14, NULL, 4),
(2868, 'Vavudo', '546E4CXNB72ST31', 'carga', -9709992, 0, 40, 24),
(2869, 'Grand Udozoka', '5Y88485AF1J80XN', 'carga', -5788171, 0, NULL, 56),
(2870, 'Okazizo', '43672P04PH89C6M', 'carga', -8, 7, 40, 63),
(2871, 'Fox', 'I513338D3S2ZU0R', 'pasajeros', -5083920, 6, 38, 4),
(2872, 'Govome', 'JY27FSN0RFIM3BG', 'carga', -6453, 2, 31, 82),
(2873, 'Gosicufa', '8KG1X917D8SIS8P', 'carga', 9, 294, NULL, 43),
(2874, 'Ketanuma', '26B619850W5ID6R', 'exploración', 5686798, 1, NULL, NULL),
(2875, 'Big Fish', '45909R6YDO92Y6N', 'carga', -3948615, 1, 6, 81),
(2876, 'Mimugu', 'J4ATJZ23Q07N2F3', 'exploración', -5468006, 421, NULL, 54),
(2877, 'Big Dotiqo', '8ZXX479P642LY79', 'combate', -4470398, 1, 27, 15),
(2878, 'Little Butterfly', '1RWOW42BZYQ6VTT', 'carga', -6, 1, NULL, 40),
(2879, 'Big Emaho', '205005G773W7OO0', 'carga', -2, 49, NULL, 15),
(2880, 'Belaxeqa', 'W24N8E6XC42G5R5', 'carga', -8161472, 0, NULL, 90),
(2881, 'Imeweki', '5BTO5NQJNU0E3N9', 'pasajeros', 77, 0, 15, 5),
(2882, 'Big Oxuzu', 'UQX7UB53E80AUQ2', 'pasajeros', -2432133, 5, NULL, 28),
(2883, 'Xequ', '0CMYY9P7LO5CEUB', 'carga', -9466517, 0, NULL, 2),
(2884, 'USS Ranivu', '9KLA14EF13SD1J3', 'carga', 4974075, 0, 49, 47),
(2885, 'USS Nemozofu', 'W9MXN57HUM7F9RQ', NULL, NULL, 6, NULL, 27),
(2886, 'Bedu', '7D3EI2DB6005M2K', 'carga', -5201174, 0, 33, 54),
(2887, 'Izesu', '01BDQG22992F3BJ', 'pasajeros', -2500846, 304, 13, 4),
(2888, 'Shiny Itihita', 'M1X1JTYAI64O4K0', 'carga', 3784316, 9, NULL, 39),
(2889, 'Kuzala', 'A4780E5640Y3OXX', NULL, NULL, 236, NULL, 81),
(2890, 'Tiqamasoti', 'VAVZ5DM716HSD47', 'carga', 3656522, 1, NULL, NULL),
(2891, 'Fox', 'Y079O9AJY5412W9', 'carga', -4486025, 9, NULL, 16),
(2892, 'Little Movuro', '81528127E5CO88G', 'exploración', -7557604, 9, 34, 41),
(2893, 'Gaminu', '09892I9S7ESP89D', 'carga', 821, 11, 32, 99),
(2894, 'Lil'' Zeppeling', 'BFGE8OSGS15RS29', 'pasajeros', 8814891, 0, 21, 32),
(2895, 'Lil'' Beku', 'BN7BEG83M4VHA02', 'carga', 1142304, 5, 46, 21),
(2896, 'Shiny Jajolipi', '4PE2MG434QB3TVC', 'carga', 3713, 330, 5, 6),
(2897, 'Big Pi', 'W1904EC4HEC1ZE4', 'carga', 8329888, 474, NULL, 75),
(2898, 'Monuji', '9901W3K0Y9BL4X3', 'pasajeros', -9591258, 1, NULL, 74),
(2899, 'Cloudy Ujejinu', 'M2BV0N1RJU274IR', 'pasajeros', -793, 5, NULL, 98),
(2900, 'Mefifurihi', '2JO9G051B1G7462', 'pasajeros', 5159242, 3, NULL, 96),
(2901, 'Cloudy Federaru', '19584M59WY74QYD', 'pasajeros', 46, 1, NULL, 15),
(2902, 'Pititicigi', 'HISOKO9NN0UPT60', 'carga', -2367957, 1, NULL, 70),
(2903, 'Golden Condor', '36316P0N6T0Z467', 'pasajeros', 2438303, 5, NULL, NULL),
(2904, 'Big Afucohoha', 'E0QH7H0N06VI015', 'carga', -5175258, 4, NULL, 47),
(2905, 'Golden Ecexo', '9V76YKJS38TE444', 'pasajeros', NULL, 201947, NULL, 21),
(2906, 'Silver Muzohozi', '09H782Y15444516', 'carga', -463570, 0, NULL, 79),
(2907, 'Zeppeling', 'V2HJ6571S2FZ976', 'pasajeros', 9, 12, 12, 80),
(2908, NULL, '413NH17R17267C6', NULL, NULL, 208, NULL, 29),
(2909, 'Butterfly', '6F27I6VPNL47PFO', 'pasajeros', -6720234, 14, NULL, 99),
(2910, 'Dejevoka', '7L1992CC0564D11', 'pasajeros', -1150376, 0, NULL, 6),
(2911, 'Grand Evalale', '958LZ7H349KY01Z', 'combate', 5212883, 1, NULL, 2),
(2912, 'Grand Kogogoqa', '6OB2276OWZX249F', 'pasajeros', 8095613, 4, NULL, 7),
(2913, 'Fish', '3U6916K73TM5UL7', 'combate', -9676935, 8, 5, 60),
(2914, 'Little Uvewoja', 'ES0VPU5B15451ZI', 'combate', 9817, 15, 1, NULL),
(2915, 'Qeqacuwinu', '2E0WO11F31GVAWX', 'carga', 678, 1, 12, 89),
(2916, 'E', 'FWQ3U7BK1N4DN3I', 'carga', -8201, 2, NULL, 82),
(2917, 'Silver Hemigo', '0IRAGN0YI01MHH4', 'carga', 49, 0, NULL, 22),
(2918, 'Shiny Desu', '26N6J42W525AXJW', 'carga', -4916328, 12, NULL, 17),
(2919, 'Lil'' Pekeki', 'MPMKUUUFL6555KL', 'carga', 8529761, 15, NULL, NULL),
(2920, 'Silver Cohunawe', '778B335UYFZ9RGN', 'pasajeros', -3575, 1, NULL, 80),
(2921, 'USS Uso', '4QYI45RXT8ZL623', 'pasajeros', -7329897, 4, NULL, 21),
(2922, 'Wona', 'S0R0M51EG5X701G', 'carga', 8708823, 487, NULL, 2),
(2923, 'Zaka', 'H48V36WC49IOA94', 'carga', 7757406, 0, NULL, 23),
(2924, 'Idaheqe', 'J1L55239K2O4RQE', 'pasajeros', -2323108, 0, 1, 97),
(2925, 'Little Butterfly', '1657559O0Y21459', 'pasajeros', NULL, 1, 32, 43),
(2926, 'Fish', '9M59B9684X8P16U', 'carga', 3918975, 13, NULL, 16),
(2927, 'Golden Zeppeling', '2R2265AQW14C67Z', 'carga', -34193, 0, 30, 90),
(2928, 'Fox', '0819QZJ31838DCB', 'carga', -1438165, 4, NULL, 22),
(2929, 'Lil'' Jatoru', '6R99648IZ7BDMT1', 'carga', -6000434, 3, NULL, 44),
(2930, 'Lil'' Jekitamu', '2763URCMIG350I7', 'carga', 6154894, 0, 19, 23),
(2931, 'Valevecebu', '4Y873MJ54FRZY7J', 'pasajeros', 6515166, 0, NULL, 80),
(2932, 'Eagle', '2550Y00XB9N9M1J', 'carga', -79, 0, 38, 14),
(2933, 'Eagle', '18298BQ3766IB3R', 'carga', -54, 0, 10, 82),
(2934, 'Shiny Vide', '67C4N6136N3XY69', 'carga', -6761485, 5, 44, 69),
(2935, 'Cloudy Hupevulu', '5DZF6AOS1SCQ3W2', 'carga', 9, 0, NULL, 8),
(2936, 'Bosodube', '3JJ6K80UP2ITK31', 'pasajeros', 5375525, 7, NULL, 10),
(2937, 'Shiny Coci', '72G4557DJCH807N', 'combate', 7, 1, NULL, 63),
(2938, 'Wobeci', '77F9W9U8431HR5C', 'carga', -3105892, 12, NULL, 63),
(2939, 'Eagle', '847KRUJ0SRP37P7', 'carga', 5, 0, NULL, 65),
(2940, 'Shiny Fox', 'TKSOO209UF2SU75', 'exploración', NULL, 0, 50, 83),
(2941, 'Silver Cuhonofu', '91NC75HL7W1V2A7', 'combate', 8473021, 10, 41, 22),
(2942, 'Fenigi', 'MOE2612W95C98F1', 'pasajeros', 3454, 59, NULL, 32),
(2943, 'Silver Lilete', '52ZM32H937VR9XO', 'pasajeros', NULL, 0, NULL, 5),
(2944, 'Golden Ahohu', '84SDFDNXZN2P711', 'combate', -8375744, 79, 18, 89),
(2945, 'Mapo', '7JRIC5J6P4ADX15', 'carga', -2954030, 0, 7, 59),
(2946, 'USS Zahe', '67ZXE0RU7TEPOA4', 'carga', -614004, 124, NULL, 7),
(2947, 'Lil'' Cukuqu', '0AZS2VLGI0G6PMA', 'carga', 6257532, 465, NULL, 99),
(2948, 'Eagle', '9GI4BTUUH3MKZO3', 'pasajeros', 4253805, 1, 26, 50),
(2949, 'Condor', '6M88632O2E99652', 'carga', NULL, 1, NULL, 40),
(2950, 'Jijobugehu', 'TSRS9HOP89YM85T', 'carga', -3069367, 4, NULL, 92),
(2951, 'Little Zeppeling', '5FZV0ZMX2F8T812', 'pasajeros', -6470180, 6, NULL, 77),
(2952, 'Wofalarafusu', 'TCV1RPTCVNO9QS5', 'exploración', -8738864, 0, NULL, 6),
(2953, 'Lil'' Rijiguxepa', 'M83X6O48Q13HF9G', 'pasajeros', 17, 12, 42, 52),
(2954, 'Punonunu', 'YOR376301P15F2I', 'pasajeros', 187, 8, 6, 17),
(2955, 'Big Derobo', '2X496XD9F68YZ4B', 'exploración', NULL, 108, NULL, 65),
(2956, 'Cisusafi', 'T805XBA07M80P4Y', 'carga', 723, 1, NULL, 23),
(2957, 'Silver Ewu', 'D77576SBAK2189V', 'carga', -5181536, 0, 17, 42),
(2958, 'Unuru', 'LMT20S0J5FN116M', 'carga', -5016182, 15, 31, 78),
(2959, 'Big Zeppeling', '1YR00598J56H4T1', 'pasajeros', 2297729, 13, NULL, 33),
(2960, 'USS Pexu', 'PD1M5Q666NBWBR6', 'carga', 4291875, 14, NULL, 95),
(2961, 'Lil'' Urecacequ', 'FWJB3V5Q03705O8', 'pasajeros', 7293695, 0, 35, 31),
(2962, 'Little Gocahiruqa', 'L5XMM31IBMB24CU', 'exploración', 4906360, 0, 27, 17),
(2963, 'Samareku', '20EIH598H194OG7', 'carga', 7471871, 0, NULL, 17),
(2964, 'Lil'' Hocaxe', '0G34F7V7SXG3404', 'carga', 3774688, 0, NULL, 2),
(2965, 'Silver Zowuhibi', 'GN5K02J832Y5CSC', 'combate', 7940975, 0, NULL, 35),
(2966, 'Eagle', '4D9BV2C7355J0RZ', NULL, NULL, 95120, 28, 38),
(2967, 'Stormy Butterfly', '135467QN0K7J64I', 'carga', -4360603, 4, 1, 8),
(2968, 'Little Wazohesa', 'FGOEGVYD38074C1', 'carga', -7017327, 0, NULL, 11),
(2969, 'Otivi', 'GQ6L6H0318J63H0', 'pasajeros', -703, 1, NULL, 78),
(2970, 'Shiny Debatuta', '779TE95146TOPKJ', 'pasajeros', 2710941, 1, 38, 6),
(2971, 'Biji', 'L17EE6Y1RK6YV05', 'exploración', 6965385, 9, 11, 45),
(2972, 'Little Rehabole', 'UEB2E6XJI748V14', 'carga', -2250572, 13, NULL, 58),
(2973, 'Condor', 'VF356223BE23P8E', 'exploración', 9225214, 9, 8, 49),
(2974, 'Moguzaji', 'MS0357DTXD61LV1', 'carga', -5561529, 2, 9, 49),
(2975, 'USS Febanobu', 'NT2DMNNZYO3A8UO', 'pasajeros', 48, 5, NULL, 95),
(2976, 'Grand Fape', '090IKWG7T577GU1', 'pasajeros', -93, 9, NULL, 75),
(2977, 'Silver Idaga', '75XI2A6C756K2PC', 'combate', 5, 6, NULL, 95),
(2978, 'Zuhulo', '096779AXIE52LU9', 'pasajeros', -2265691, 0, NULL, 38),
(2979, 'Gekeniti', '1P29Y9FSX12PF39', 'carga', 885, 235, 16, 83),
(2980, 'Cloudy Fox', '38089HBN193WG1O', 'carga', 6, 0, 40, 63),
(2981, 'Big Viqeruxe', 'XU57G6Z842UI241', 'carga', -81, 3, 42, 4),
(2982, 'Okeke', '2KHROD2HX010496', NULL, 7154697, 246, NULL, 77),
(2983, 'Big Gipibopopo', '0OL3R2W96925051', NULL, NULL, 0, NULL, 65),
(2984, 'Huzama', 'SW1A0M7SC920306', NULL, NULL, 0, NULL, 5),
(2985, 'Qetohoko', 'DW4MGO2VJY2L0SV', NULL, NULL, 2, 36, 81),
(2986, 'Xobuwifusu', '9F6UVTPY9H20HB3', NULL, NULL, 14, NULL, 1),
(2987, 'Fudibaha', 'J7Y6P8BNC79EI18', NULL, NULL, 12, 46, 18),
(2988, 'Buzureli', '7A1KDSFU83J0827', NULL, NULL, 12, NULL, 11),
(2989, 'Caqewu', '3S4T2T522QZU54Z', NULL, NULL, 12, NULL, 99),
(2990, 'Shiny Xiqo', '0T70422PAY215P6', NULL, NULL, 0, NULL, 71),
(2991, 'Eagle', '0F8ELB44790QZU8', NULL, NULL, 9, NULL, 63),
(2992, 'Shiny Bija', '520142945W8G9CH', NULL, NULL, 76, NULL, 66),
(2993, 'Big Fox', '0N9Y93V76R548I2', NULL, NULL, 7, NULL, 89),
(2994, 'Grand Caracihofa', '0E1107Q39R887F2', NULL, NULL, 15, NULL, 15),
(2995, NULL, '9HVQI49KKNQ3BIX', NULL, NULL, 178, NULL, 27),
(2996, NULL, 'PA282QM4BBX9V4J', NULL, NULL, 15, NULL, 55),
(2997, NULL, 'O5MH7K41EBYT54B', NULL, NULL, 13, NULL, 46),
(2998, NULL, '4S2I7N1K0E39XBG', NULL, NULL, 0, NULL, 94),
(2999, NULL, 'O459Y77S3302F87', NULL, NULL, 121, NULL, 5),
(3000, NULL, 'G4PG6I0E018WT8K', NULL, NULL, 0, NULL, 31);

INSERT INTO nave_tripulante(id_nave, id_tripulante) VALUES
(1541, 642),
(1963, 1471),
(1202, 456),
(635, 1152),
(1172, 1081),
(540, 570),
(349, 296),
(2163, 1137),
(1618, 1121),
(82, 721),
(2489, 857),
(522, 306),
(2453, 1424),
(2990, 1354),
(447, 457),
(1444, 987),
(2451, 80),
(2913, 1256),
(1304, 619),
(8, 146),
(2845, 501),
(1402, 872),
(2433, 15),
(1767, 1165),
(484, 106),
(5, 692),
(2280, 1053),
(2782, 722),
(2844, 948),
(3, 1277),
(302, 217),
(2976, 297),
(140, 810),
(2243, 1404),
(2200, 770),
(2165, 1387),
(90, 756),
(49, 231),
(421, 1486),
(1, 1015),
(2, 550),
(1352, 1286),
(493, 620),
(55, 1257),
(834, 1002),
(4, 488),
(819, 166),
(988, 147),
(88, 793),
(804, 286),
(1441, 629),
(1212, 351),
(2893, 916),
(2265, 673),
(2027, 81),
(1214, 1099),
(923, 307),
(222, 31),
(20, 1138),
(200, 136),
(623, 257),
(359, 1166),
(549, 971),
(914, 93),
(281, 643),
(2230, 1153),
(1588, 1016),
(87, 1305),
(1291, 1405),
(9, 1434),
(65, 472),
(1447, 824),
(534, 843),
(2902, 931),
(85, 794),
(586, 1367),
(2194, 298),
(2245, 1207),
(1275, 400),
(1149, 1122),
(1, 458),
(8, 1204),
(1594, 287),
(2267, 1453),
(86, 521),
(1272, 1113),
(2056, 1339),
(2655, 644),
(2446, 1082),
(948, 49),
(1416, 322),
(149, 606),
(1, 67),
(157, 963),
(2622, 873),
(240, 1287),
(5, 551),
(485, 182),
(4, 1258),
(61, 1167),
(1645, 473),
(1676, 148),
(413, 218),
(2533, 429),
(750, 932),
(2731, 795),
(6, 1355),
(1277, 1435),
(550, 1487),
(189, 1425),
(2465, 1406),
(2524, 988),
(1953, 674),
(2823, 538),
(1705, 1220),
(8, 1054),
(270, 1240),
(32, 1139),
(2112, 1288),
(2051, 1037),
(2279, 771),
(722, 1208),
(2202, 371),
(1980, 244),
(131, 886),
(41, 1368),
(1341, 621),
(1671, 107),
(1074, 1306),
(2544, 441),
(2746, 271),
(732, 645),
(764, 1067),
(2902, 299),
(1271, 772),
(274, 1188),
(2217, 989),
(543, 502),
(1805, 949),
(2489, 149),
(640, 917),
(1255, 352),
(912, 338),
(944, 382),
(2867, 904),
(2859, 693),
(1009, 503),
(2517, 489),
(1549, 707),
(1299, 1038),
(37, 232),
(42, 1003),
(70, 68),
(3, 353),
(2939, 1055),
(555, 1140),
(2392, 219),
(2158, 300),
(345, 94),
(249, 796),
(97, 905),
(360, 121),
(380, 972),
(1061, 1189),
(1189, 1017),
(2837, 646),
(1592, 258),
(3, 82),
(1697, 660),
(716, 825),
(2717, 1068),
(70, 1436),
(1728, 69),
(688, 797),
(924, 1114),
(404, 1056),
(1686, 272),
(1084, 780),
(351, 1454),
(2039, 220),
(18, 1324),
(2126, 323),
(1024, 1039),
(1981, 401),
(69, 1278),
(2398, 757),
(713, 137),
(2918, 811),
(927, 736),
(2340, 150),
(2053, 990),
(573, 630),
(26, 675),
(6, 552),
(2118, 1259),
(2494, 1289),
(649, 964),
(2366, 858),
(308, 1407),
(41, 1190),
(2506, 622),
(1613, 1356),
(2892, 308),
(1236, 580),
(2526, 1141),
(493, 1209),
(569, 1260),
(388, 70),
(2235, 1426),
(378, 826),
(2872, 661),
(2047, 474),
(502, 1408),
(2624, 1472),
(64, 1279),
(2800, 1437),
(1, 844),
(1081, 647),
(1389, 522),
(871, 906),
(1590, 1040),
(2426, 324),
(73, 533),
(1022, 459),
(2735, 812),
(3, 1221),
(1780, 1123),
(1524, 1083),
(946, 1057),
(2467, 798),
(1820, 122),
(639, 723),
(2484, 309),
(346, 288),
(175, 1388),
(12, 1261),
(2350, 1168),
(685, 662),
(2908, 676),
(2322, 233),
(651, 1290),
(2398, 694),
(194, 83),
(2052, 1369),
(1183, 773),
(428, 108),
(1321, 845),
(163, 402),
(85, 32),
(29, 273),
(1455, 918),
(10, 138),
(392, 123),
(35, 907),
(5, 1325),
(388, 933),
(1241, 874),
(2180, 301),
(521, 183),
(72, 460),
(494, 887),
(693, 1058),
(791, 827),
(2722, 383),
(797, 1069),
(935, 607),
(2850, 1307),
(1650, 553),
(595, 1241),
(1591, 388),
(196, 403),
(1526, 310),
(939, 781),
(2700, 234),
(508, 1222),
(272, 16),
(832, 592),
(1032, 461),
(1414, 1427),
(6, 274),
(1546, 1455),
(639, 200),
(150, 475),
(2, 1084),
(1581, 245),
(2393, 631),
(8, 991),
(563, 430),
(1156, 1115),
(2086, 442),
(341, 221),
(2232, 325),
(2156, 581),
(300, 124),
(636, 539),
(7, 504),
(2198, 71),
(1902, 534),
(546, 677),
(347, 648),
(4, 1370),
(562, 908),
(304, 222),
(637, 1308),
(381, 1438),
(1653, 1018),
(2185, 554),
(1442, 1357),
(816, 372),
(7, 33),
(1261, 259),
(1732, 72),
(817, 50),
(2292, 1210),
(888, 1340),
(1424, 724),
(93, 782),
(2881, 354),
(77, 1154),
(2018, 95),
(1676, 167),
(224, 1291),
(74, 708),
(1355, 737),
(7, 623),
(613, 275),
(1883, 201),
(635, 1191),
(1716, 1223),
(115, 404),
(30, 111),
(1918, 84),
(1654, 223),
(2928, 389),
(450, 431),
(1256, 1142),
(1140, 125),
(1899, 1059),
(281, 109),
(1264, 1041),
(1560, 1169),
(2331, 339),
(21, 859),
(484, 262),
(138, 1409),
(1475, 151),
(1231, 1456),
(91, 507),
(733, 888),
(1366, 490),
(1616, 523),
(728, 357),
(8, 1389),
(1308, 246),
(2048, 1473),
(94, 1242),
(1916, 1309),
(585, 799),
(1970, 1488),
(144, 235),
(582, 632),
(242, 373),
(7, 17),
(420, 1),
(1326, 1192),
(2169, 1019),
(1283, 1457),
(1695, 1358),
(349, 1341),
(1862, 919),
(2291, 892),
(1786, 276),
(711, 593),
(780, 168),
(96, 934),
(1197, 85),
(2384, 1087),
(75, 758),
(693, 742),
(1433, 1100),
(2682, 875),
(2140, 738),
(2781, 893),
(1095, 540),
(1521, 1042),
(184, 649),
(2004, 390),
(1634, 608),
(2526, 508),
(1100, 126),
(1137, 1393),
(2049, 555),
(2977, 152),
(709, 236),
(2487, 1371),
(2106, 505),
(1118, 1070),
(2000, 889),
(4, 1489),
(1865, 524),
(172, 800),
(2722, 973),
(341, 96),
(2043, 582),
(2233, 937),
(2863, 51),
(2845, 950),
(747, 743),
(335, 1004),
(1235, 1101),
(2367, 992),
(2128, 1390),
(2755, 1170),
(2910, 340),
(2, 2),
(369, 355),
(479, 650),
(1022, 1439),
(222, 894),
(2541, 247),
(1581, 184),
(2010, 831),
(1364, 1085),
(2090, 1262),
(2859, 1088),
(101, 801),
(38, 1410),
(2204, 358),
(25, 695),
(75, 1292),
(463, 651),
(1942, 443),
(423, 1024),
(117, 1310),
(8, 1440),
(617, 759),
(2154, 202),
(213, 744),
(1633, 1193),
(548, 813),
(81, 448),
(1152, 1043),
(35, 374),
(2130, 594),
(1712, 895),
(342, 1175),
(2732, 1263),
(3, 73),
(5, 97),
(671, 405),
(1974, 509),
(8, 609),
(642, 1124),
(283, 802),
(2144, 739),
(257, 920),
(9, 681),
(1893, 1293),
(256, 506),
(2100, 18),
(1854, 1071),
(2393, 783),
(1084, 1194),
(1779, 34),
(1989, 652),
(951, 938),
(2263, 1020),
(1995, 432),
(2567, 760),
(248, 828),
(724, 890),
(2727, 185),
(704, 359),
(2225, 921),
(40, 1477),
(2883, 525),
(1660, 510),
(2616, 260),
(605, 541),
(2982, 311),
(2103, 678),
(2643, 832),
(286, 846),
(2615, 725),
(27, 207),
(2571, 1342),
(1, 682),
(1217, 740),
(2225, 491),
(2993, 696),
(33, 57),
(1648, 1155),
(2797, 462),
(1203, 1025),
(1961, 375),
(2473, 1490),
(9, 829),
(830, 1243),
(8, 1330),
(2647, 169),
(1561, 1044),
(307, 745),
(2697, 1411),
(863, 1176),
(3, 1224),
(1016, 1391),
(1110, 974),
(2300, 1343),
(7, 1372),
(1597, 19),
(273, 633),
(2374, 556),
(1521, 784),
(415, 1005),
(2677, 406),
(29, 444),
(5, 360),
(86, 1125),
(90, 526),
(47, 110),
(2027, 1225),
(728, 1244),
(580, 1089),
(96, 1478),
(659, 951),
(2502, 312),
(502, 557),
(2537, 341),
(1, 391),
(1870, 663),
(2929, 511),
(2562, 52),
(1041, 35),
(94, 407),
(733, 634),
(592, 935),
(1690, 1373),
(304, 1171),
(1799, 170),
(1041, 1441),
(16, 208),
(50, 583),
(1981, 20),
(82, 1102),
(2649, 1491),
(1, 891),
(2555, 58),
(1343, 1021),
(858, 1226),
(2899, 1086),
(1187, 1246),
(1298, 1195),
(1644, 975),
(310, 1264),
(1832, 1072),
(1771, 171),
(7, 814),
(2131, 833),
(2139, 356),
(69, 203),
(87, 361),
(2225, 876),
(1353, 261),
(1774, 726),
(945, 847),
(1278, 1126),
(1686, 952),
(443, 21),
(2651, 683),
(37, 1344),
(2067, 939),
(2177, 936),
(2695, 1294),
(440, 172),
(935, 1331),
(688, 224),
(1867, 1374),
(2145, 153),
(66, 664),
(716, 209),
(2808, 595),
(2706, 1412),
(38, 558),
(2573, 697),
(413, 1479),
(1718, 463),
(4, 1026),
(882, 1392),
(93, 1227),
(2580, 1442),
(2481, 1245),
(763, 1458),
(2198, 512),
(149, 408),
(384, 1326),
(2127, 1295),
(1303, 248),
(2520, 741),
(182, 313),
(13, 1177),
(2385, 559),
(1977, 1492),
(1349, 542),
(7, 433),
(2388, 22),
(84, 53),
(1690, 922),
(2992, 785),
(2332, 1027),
(847, 815),
(2216, 709),
(1822, 204),
(2020, 848),
(7, 1332),
(1663, 186),
(7, 1474),
(181, 1073),
(1626, 1345),
(49, 584),
(2832, 173),
(233, 376),
(1720, 59),
(1978, 476),
(8, 1045),
(2020, 1394),
(2973, 923),
(1002, 3),
(5, 409),
(2120, 610),
(1131, 86),
(2, 976),
(484, 54),
(93, 877),
(217, 896),
(1337, 237),
(1879, 761),
(2453, 560),
(80, 1443),
(565, 210),
(2, 1493),
(2, 23),
(2698, 834),
(267, 665),
(2259, 698),
(2494, 727),
(402, 860),
(47, 635),
(1227, 1178),
(1902, 112),
(2706, 1327),
(119, 849),
(2498, 599),
(605, 464),
(1182, 1074),
(907, 611),
(1091, 1211),
(53, 362),
(1411, 492),
(1985, 449),
(2835, 710),
(2589, 36),
(843, 98),
(1708, 445),
(415, 174),
(1475, 1346),
(854, 326),
(1148, 342),
(2790, 1265),
(93, 263),
(5, 1028),
(20, 1196),
(399, 762),
(1637, 1296),
(8, 410),
(1926, 816),
(174, 909),
(2205, 679),
(2858, 1179),
(1034, 1127),
(800, 699),
(2288, 513),
(968, 878),
(1859, 187),
(61, 277),
(2681, 205),
(267, 1060),
(397, 561),
(2442, 37),
(479, 1475),
(3, 392),
(1974, 188),
(566, 684),
(1982, 249),
(2621, 1090),
(2403, 1328),
(2997, 1046),
(580, 600),
(389, 1156),
(527, 411),
(380, 830),
(2219, 1311),
(880, 596),
(2259, 477),
(450, 493),
(491, 786),
(59, 1103),
(1761, 1494),
(226, 1029),
(418, 1347),
(2, 1006),
(861, 1480),
(2226, 327),
(811, 728),
(868, 55),
(1896, 24),
(1088, 746),
(468, 74),
(1521, 1180),
(1873, 1413),
(501, 636),
(1231, 363),
(31, 225),
(2951, 612),
(531, 175),
(478, 1333),
(2256, 154),
(1347, 38),
(396, 314),
(186, 514),
(584, 562),
(2005, 446),
(1017, 1459),
(1029, 835),
(2222, 4),
(2763, 850),
(2439, 87),
(1658, 412),
(1399, 1266),
(966, 543),
(29, 343),
(514, 1476),
(8, 478),
(830, 563),
(2326, 787),
(5, 494),
(4, 910),
(506, 413),
(62, 1375),
(1137, 977),
(2053, 238),
(2721, 564),
(2067, 1128),
(8, 99),
(2670, 434),
(331, 1359),
(2790, 364),
(1933, 250),
(1041, 1414),
(1309, 450),
(161, 414),
(2381, 1061),
(331, 1172),
(353, 100),
(2130, 861),
(2383, 1157),
(492, 700),
(2990, 1030),
(1124, 940),
(2268, 155),
(908, 924),
(2401, 527),
(170, 113),
(2370, 88),
(2424, 465),
(1233, 127),
(856, 206),
(620, 879),
(2122, 264),
(119, 1212),
(7, 377),
(1262, 189),
(221, 1091),
(2349, 1181),
(723, 1495),
(1768, 565),
(546, 601),
(1572, 1228),
(1, 1022),
(7, 711),
(1068, 1075),
(1, 393),
(1434, 1197),
(2662, 685),
(49, 415),
(2237, 544),
(1900, 566),
(2881, 978),
(1669, 1047),
(38, 763),
(167, 666),
(1153, 836),
(2939, 315),
(2640, 1247),
(63, 1031),
(2804, 1267),
(597, 851),
(217, 1481),
(2714, 466),
(255, 60),
(115, 316),
(2882, 211),
(1768, 897),
(579, 1348),
(3, 1360),
(1260, 416),
(2454, 637),
(2993, 567),
(717, 686),
(1504, 729),
(9, 1444),
(162, 417),
(1680, 56),
(7, 1312),
(5, 467),
(317, 862),
(1361, 925),
(2562, 451),
(780, 953),
(2037, 701),
(831, 788),
(50, 1173),
(1, 39),
(2424, 568),
(1306, 1334),
(54, 911),
(89, 5),
(1204, 418),
(2799, 680),
(1940, 114),
(1265, 278),
(2244, 1129),
(1603, 75),
(2689, 569),
(866, 837),
(1984, 317),
(3, 1182),
(1880, 1460),
(2578, 638),
(1421, 419),
(396, 597),
(2850, 1007),
(507, 941),
(600, 1104),
(1718, 1297),
(1571, 852),
(93, 447),
(478, 1313),
(198, 61),
(410, 289),
(716, 1198),
(1563, 156),
(551, 1395),
(82, 1280),
(89, 687),
(381, 1329),
(691, 817),
(77, 954),
(1124, 789),
(1882, 598),
(1392, 1158),
(799, 139),
(788, 1248),
(1405, 1105),
(8, 639),
(2020, 290),
(7, 1376),
(1981, 1496),
(2729, 790),
(301, 1023),
(717, 1482),
(1641, 712),
(1429, 880),
(2975, 1092),
(2886, 226),
(5, 965),
(848, 328),
(457, 602),
(2430, 585),
(2349, 1174),
(84, 730),
(1759, 528),
(2372, 942),
(2254, 1048),
(3, 1032),
(2426, 128),
(861, 76),
(2689, 239),
(2296, 1229),
(1552, 190),
(2563, 420),
(957, 479),
(257, 435),
(7, 747),
(589, 1445),
(2387, 803),
(2235, 838),
(347, 667),
(840, 1116),
(76, 1500),
(8, 394),
(6, 1415),
(658, 1349),
(1175, 1335),
(609, 1377),
(1116, 140),
(23, 329),
(1613, 640),
(92, 515),
(384, 1230),
(1540, 279),
(1871, 265),
(2560, 1268),
(124, 291),
(2, 1396),
(2422, 468),
(1630, 1183),
(634, 480),
(674, 1199),
(1342, 1008),
(1550, 1416),
(1481, 1143),
(566, 1298),
(23, 1249),
(2590, 774),
(2343, 6),
(866, 688),
(527, 1269),
(2665, 966),
(688, 227),
(2282, 1378),
(669, 330),
(56, 251),
(407, 545),
(1087, 586),
(2186, 898),
(1918, 1213),
(2563, 1483),
(2517, 613),
(1659, 101),
(5, 1497),
(2981, 1033),
(2012, 365),
(2380, 141),
(51, 863),
(1500, 344),
(1206, 955),
(2940, 1049),
(2470, 571),
(933, 481),
(2110, 157),
(8, 624),
(773, 115),
(2602, 7),
(2565, 839),
(1554, 775),
(72, 764),
(1840, 881),
(375, 1350),
(2282, 516),
(1139, 713),
(2596, 1417),
(1784, 818),
(31, 252),
(45, 158),
(2881, 993),
(22, 1184),
(935, 366),
(1210, 1106),
(2803, 1117),
(1060, 979),
(1099, 384),
(2492, 1397),
(3, 378),
(2650, 266),
(734, 702),
(2665, 212),
(468, 436),
(122, 77),
(1622, 864),
(2078, 421),
(390, 40),
(2214, 129),
(2501, 1034),
(2483, 1498),
(1920, 748),
(947, 529),
(312, 1231),
(2046, 899),
(2836, 1336),
(1968, 791),
(2378, 653),
(859, 587),
(1238, 1446),
(800, 1461),
(2181, 280),
(930, 318),
(2433, 1484),
(745, 625),
(1891, 469),
(1663, 25),
(29, 1130),
(2354, 1361),
(213, 1159),
(1716, 749),
(1104, 292),
(2343, 1299),
(276, 437),
(2986, 1447),
(627, 980),
(2207, 1076),
(74, 614),
(191, 1314),
(2995, 967),
(4, 1214),
(4, 62),
(9, 1131),
(246, 776),
(2424, 1144),
(1108, 853),
(251, 495),
(773, 900),
(1650, 1462),
(71, 213),
(307, 641),
(2022, 1270),
(854, 535),
(1270, 1062),
(1568, 1093),
(28, 804),
(584, 588),
(258, 8),
(1615, 572),
(766, 191),
(2208, 319),
(36, 654),
(191, 1418),
(1872, 102),
(411, 714),
(9, 345),
(2318, 116),
(1277, 865),
(836, 253),
(783, 956),
(1516, 626),
(823, 452),
(1692, 981),
(1896, 438),
(62, 517),
(2756, 130),
(2947, 1250),
(17, 89),
(2544, 228),
(2146, 1271),
(750, 943),
(8, 1379),
(44, 385),
(1, 422),
(1255, 1337),
(1986, 1132),
(1999, 1315),
(2893, 240),
(2893, 926),
(752, 1428),
(2467, 982),
(1484, 1362),
(2466, 1077),
(623, 805),
(271, 765),
(426, 1200),
(186, 267),
(3, 1215),
(2885, 1185),
(2169, 1419),
(21, 731),
(2659, 777),
(2, 470),
(522, 689),
(1941, 1363),
(36, 750),
(408, 159),
(2410, 1281),
(1674, 1133),
(21, 1429),
(1234, 882),
(2346, 281),
(1929, 117),
(901, 331),
(535, 1351),
(1722, 983),
(1629, 840),
(391, 103),
(2922, 703),
(1583, 715),
(241, 63),
(2385, 589),
(1861, 573),
(785, 496),
(2, 142),
(1488, 1050),
(2424, 1107),
(830, 901),
(2780, 690),
(1556, 1499),
(1492, 9),
(1509, 1035),
(2, 668),
(32, 131),
(1272, 994),
(787, 1282),
(2, 819),
(2441, 912),
(1472, 346),
(1140, 367),
(1314, 655),
(654, 854),
(902, 957),
(682, 866),
(1137, 927),
(1635, 1463),
(2217, 395),
(1151, 1300),
(314, 1430),
(2998, 160),
(1822, 669),
(699, 806),
(655, 1009),
(1990, 627),
(2814, 302),
(1407, 716),
(602, 751),
(1530, 546),
(2, 497),
(1976, 704),
(506, 1283),
(56, 423),
(1902, 1063),
(964, 347),
(2163, 10),
(788, 41),
(2198, 482),
(1746, 656),
(2202, 214),
(1657, 1201),
(13, 1108),
(1188, 268),
(990, 192),
(2162, 1272),
(627, 453),
(2787, 1145),
(2887, 1078),
(1544, 867),
(43, 1118),
(2756, 902),
(2821, 732),
(2146, 1216),
(2540, 161),
(2168, 1232),
(1474, 78),
(508, 958),
(304, 42),
(496, 1186),
(73, 1364),
(3, 1094),
(2697, 176),
(8, 229),
(1674, 1316),
(2272, 1036),
(1105, 1109),
(1535, 293),
(1056, 752),
(2447, 26),
(2545, 1380),
(2000, 1051),
(5, 1420),
(2039, 944),
(1831, 11),
(8, 90),
(1004, 193),
(1011, 303),
(1318, 807),
(1731, 498),
(2276, 717),
(2047, 43),
(595, 968),
(636, 995),
(480, 1464),
(778, 959),
(842, 1095),
(2292, 1233),
(1443, 79),
(1229, 162),
(4, 1146),
(2169, 841),
(982, 1317),
(17, 855),
(836, 379),
(2937, 1398),
(750, 691),
(1971, 913),
(423, 282),
(2066, 1251),
(2702, 996),
(2827, 1381),
(2074, 332),
(618, 705),
(86, 1119),
(2812, 1234),
(369, 820),
(531, 1273),
(1606, 903),
(544, 454),
(969, 1217),
(977, 177),
(1684, 928),
(1335, 241),
(1528, 1421),
(1465, 320),
(2733, 118),
(1455, 1134),
(2860, 64),
(2712, 471),
(2401, 883),
(675, 439),
(73, 483),
(93, 132),
(1741, 27),
(1984, 1187),
(1468, 1352),
(518, 842),
(617, 590),
(525, 1202),
(1546, 304),
(733, 348),
(2552, 91),
(2457, 1079),
(1581, 333),
(2411, 143),
(786, 1399),
(3, 1110),
(1847, 321),
(2686, 1382),
(512, 518),
(396, 1448),
(9, 396),
(1, 1160),
(2414, 1365),
(415, 778),
(8, 530),
(1491, 945),
(2685, 929),
(240, 455),
(210, 792),
(2318, 856),
(307, 215),
(1430, 1064),
(1943, 706),
(2441, 969),
(2759, 12),
(72, 283),
(1, 65),
(429, 753),
(2493, 1052),
(2779, 615),
(10, 603),
(2288, 1080),
(708, 1120),
(4, 163),
(1070, 868),
(19, 574),
(2190, 294),
(794, 766),
(928, 754),
(960, 194),
(350, 380),
(4, 1252),
(669, 531),
(2233, 1235),
(2630, 216),
(467, 484),
(2194, 1205),
(4, 178),
(3, 1400),
(653, 1383),
(2332, 547),
(403, 616),
(708, 66),
(668, 44),
(1686, 230),
(82, 28),
(2872, 670),
(8, 1253),
(2382, 144),
(2807, 179),
(1950, 1485),
(269, 133),
(169, 1353),
(1538, 984),
(955, 334),
(565, 1338),
(1060, 821),
(2, 1096),
(9, 733),
(1916, 485),
(2243, 960),
(27, 946),
(1497, 284),
(4, 1401),
(1206, 884),
(2239, 767),
(1331, 368),
(1636, 134),
(72, 242),
(2914, 1236),
(979, 1203),
(1367, 657),
(515, 628),
(83, 269),
(20, 13),
(2514, 536),
(2265, 195),
(4, 1135),
(310, 617),
(15, 1218),
(1742, 424),
(2394, 305),
(383, 1254),
(1205, 381),
(2686, 970),
(2648, 45),
(48, 254),
(2052, 119),
(746, 1147),
(515, 1465),
(1645, 1206),
(1360, 1274),
(775, 604),
(349, 985),
(77, 1301),
(2623, 196),
(2, 1111),
(6, 1097),
(1319, 1422),
(1919, 914),
(601, 734),
(1124, 997),
(1465, 718),
(387, 519),
(2862, 46),
(2437, 1431),
(1620, 1275),
(2498, 808),
(2676, 369),
(9, 1318),
(69, 885),
(1188, 164),
(2523, 779),
(4, 869),
(422, 930),
(1630, 1136),
(2008, 1284),
(2352, 397),
(2905, 92),
(2936, 29),
(2748, 1010),
(2612, 532),
(5, 1402),
(262, 499),
(55, 1423),
(13, 520),
(45, 1276),
(1774, 1432),
(42, 548),
(407, 270),
(391, 961),
(1627, 1065),
(614, 575),
(2032, 1466),
(775, 947),
(611, 349),
(882, 719),
(432, 386),
(7, 285),
(365, 1384),
(5, 14),
(956, 370),
(396, 768),
(2252, 1285),
(118, 398),
(1773, 755),
(936, 1112),
(1073, 537),
(8, 1098),
(2962, 1449),
(113, 870),
(67, 135),
(1970, 671),
(1899, 104),
(1938, 1366),
(2741, 605),
(1762, 962),
(893, 1148),
(1375, 549),
(780, 120),
(2260, 1161),
(2110, 618),
(894, 1302),
(17, 387),
(99, 1255),
(2028, 440),
(12, 986),
(2726, 295),
(388, 769),
(898, 1450),
(1723, 1403),
(2507, 165),
(1623, 1237),
(4, 1319),
(5, 335),
(1701, 255),
(661, 425),
(68, 720),
(436, 1467),
(2849, 1433),
(1328, 105),
(2613, 1303),
(143, 871),
(578, 1385),
(937, 399),
(2759, 1011),
(6, 486),
(821, 145),
(695, 1451),
(2806, 1320),
(545, 576),
(423, 197),
(741, 426),
(2655, 1162),
(2636, 998),
(1170, 735),
(1899, 1468),
(1675, 336),
(2268, 500),
(1824, 915),
(16, 1149),
(37, 1238),
(2, 487),
(2351, 822),
(1131, 577),
(1636, 350),
(2815, 1012),
(941, 180),
(68, 1321),
(2176, 243),
(2110, 256),
(9, 337),
(88, 1386),
(14, 1066),
(631, 999),
(524, 1239),
(394, 47),
(1431, 1219),
(218, 658),
(1577, 198),
(1073, 1150),
(700, 1163),
(1509, 427),
(266, 1469),
(2555, 30),
(733, 1322),
(2945, 1000),
(6, 1013),
(129, 578),
(174, 1164),
(2863, 1151),
(13, 672),
(2597, 181),
(845, 48),
(588, 1001),
(1741, 1470),
(1293, 1304),
(2955, 199),
(1156, 809),
(2388, 591),
(647, 428),
(65, 1014),
(46, 1452),
(1395, 1323),
(668, 579),
(2129, 823),
(2758, 659);

INSERT INTO persona(id, nombre, edad, id_cuerpo_celeste) VALUES
(1, 'Lihepoma ', 90, 523),
(2, 'Yoba Luyije', 108, 496),
(3, 'Papusa ', 3, 329),
(4, 'Ne ', 5, 551),
(5, 'Lord Tapaxu ', 215, 335),
(6, 'Dr. Folojo ', 35, 443),
(7, 'Sr. Uosajo Qixidaqini', NULL, 596),
(8, 'Sir Ui ', 196, 367),
(9, 'Don Turo ', 7, 508),
(10, 'Eeriru Pemo', 159, 367),
(11, 'Dr. Fapata ', 243, 356),
(12, 'Yevafe ', 8, 483),
(13, 'Don Zawijo Tasoki', 239, 540),
(14, 'Zuwe Hezayepu', 311, 550),
(15, 'Keho Xopa', 32, 249),
(16, 'Sra. Ooheyaho ', 312, 415),
(17, 'Lord Fese ', 480, 368),
(18, 'Sir Suzu ', 0, 371),
(19, 'Daqazimo ', 5, 244),
(20, 'Xu Tureximune', 230, 506),
(21, 'Lezeki Foluco', 6, 517),
(22, 'Bizoha ', 256, 404),
(23, 'Sir Yige Ripopuzu', 11, 218),
(24, 'Doña Oe ', 421, 351),
(25, 'Fo ', 492, 521),
(26, 'Doña Seva Bexebe', 448, 553),
(27, 'Don Aoci Gajivapu', NULL, 551),
(28, 'Don Iacipe ', 295, 600),
(29, 'Puve Aato', 218, 441),
(30, 'Doña Ro Nayameduwe', 320, 442),
(31, 'Ridi Pukisu', 276, 260),
(32, 'Luceka ', 256, 416),
(33, 'Doña Vome ', NULL, 238),
(34, 'Sr. Zolujere ', NULL, 276),
(35, 'Lady Vekeze Xabewuxu', 149, 343),
(36, 'Jaga Oikewa', NULL, 504),
(37, 'Re Waga', 278, 515),
(38, 'Lady Iijakowu ', 160, 597),
(39, 'Sidulo ', 197, NULL),
(40, 'Lady Qabifa Xacoti', 333, 330),
(41, 'Doña Eagiqi Renuke', NULL, 534),
(42, 'Tu Tiyosa', 244, 562),
(43, 'Don Qekoje Kopa', 99, 378),
(44, 'Bofome Yuwibilama', 489, 534),
(45, 'Ze ', 399, 380),
(46, 'Xonu ', 411, 250),
(47, 'Aaqa Eedabo', 379, 498),
(48, 'Don Ja ', 443, 294),
(49, 'Zaga Uitaye', 321, 400),
(50, 'Wugico Kukadelo', 176, 347),
(51, 'Qova ', 391, 228),
(52, 'Fofupi Yija', NULL, 565),
(53, 'Eace ', 57, 597),
(54, 'Dr. Ieyo Lanopaguyu', 224, 575),
(55, 'Oife Paliguruce', 5, 503),
(56, 'Naye Yubitu', 3, 568),
(57, 'Gace ', 3, 596),
(58, 'Lord Auvawi ', 9, 282),
(59, 'Lord Soxalaxo Yu', NULL, 468),
(60, 'Kemu ', 168, 544),
(61, 'Lady Qibulu ', 274, 321),
(62, 'Yame ', 347, 285),
(63, 'Lady Kasosije Cadamode', 456, 567),
(64, 'Dolo Juheyuci', 386, 224),
(65, 'Sra. Aazo Iuza', 198, 252),
(66, 'Don Oeha Rulita', 293, 335),
(67, 'Leku ', 239, 520),
(68, 'Sir Je Ouhubizi', 112, 561),
(69, 'Lady Depe Puxuviji', 358, 571),
(70, 'Fuzapugi Kokite', 83, 295),
(71, 'Pexori ', 246, NULL),
(72, 'Sr. Cocu Coma', NULL, 582),
(73, 'Uimogu ', 427, 468),
(74, 'Sr. Uote ', 494, 354),
(75, 'Pico Tabezu', 0, 412),
(76, 'Koniyu Cuze', 52, 220),
(77, 'Hedino ', NULL, 553),
(78, 'Dr. Iugovu ', 385, 467),
(79, 'Riha Miviji', NULL, 261),
(80, 'Sr. Iufeve ', 144, 435),
(81, 'Sra. Gikano Runanofe', 422, 552),
(82, 'Don Ooboboko ', 304, 529),
(83, 'Dr. Xowo ', 130, 246),
(84, 'Sr. Woku ', 6, 528),
(85, 'Hisu Beromojilu', 249, 380),
(86, 'Mijoho Xuzive', 37, 497),
(87, 'Sra. Ailovo ', 60, 309),
(88, 'Cibu Rixaku', 334, 279),
(89, 'Aoqaca ', 436, 560),
(90, 'Sir Jutugole ', 235, 334),
(91, 'Sir Gahi Qutinimu', 234, 267),
(92, 'Sr. Diboge ', 47, 508),
(93, 'Tihe Yo', 456, 467),
(94, 'Lady Vomedeho Oiva', 4, 404),
(95, 'Uigiqa ', 47, 303),
(96, 'Lady Gupukone ', 372, 482),
(97, 'Damo Pahulo', 353, 377),
(98, 'Dr. Ridima Vadayuso', 329, 461),
(99, 'Gulosi ', 327, 300),
(100, 'Faka ', 103, 560),
(101, 'Lord Oa ', 480, 489),
(102, 'La Tijozage', 370, 560),
(103, 'Lady Auhupo ', 4, 509),
(104, 'Zonegi Uihe', 33, 400),
(105, 'Suxi Uiwiqilifa', 76, 390),
(106, 'Bifo Dedefu', 476, 358),
(107, 'Zape Guge', 34, 493),
(108, 'Sr. Ciwedi ', 1, 377),
(109, 'Zadehato ', 335, 261),
(110, 'Don Rino Jasesora', 73, 246),
(111, 'Cuneqize Damafobo', NULL, 278),
(112, 'Sir Eeso Qo', 454, 573),
(113, 'Ia Migu', 123, 394),
(114, 'Lady Kura ', 474, 481),
(115, 'Sir Meko Cuboyelubo', 268, 240),
(116, 'Vi ', 157, 574),
(117, 'Lord Ialuze ', NULL, 529),
(118, 'Doña Fosicu Yukeqe', 395, 322),
(119, 'Doña Kavo ', 24, 565),
(120, 'Dr. Ye ', 61, 277),
(121, 'Oobuyo ', 323, 523),
(122, 'Aipacaxo Uova', 379, 424),
(123, 'Lady Kavaji Euxo', 198, 446),
(124, 'Lady Cuju ', 45, 483),
(125, 'Dr. Qigu Citaja', 161, 588),
(126, 'Ve ', 59, 545),
(127, 'Cihami ', 53, 369),
(128, 'Lady Haba Vibejika', 256, 531),
(129, 'Sr. Auyogi ', 403, 315),
(130, 'Wuci ', 5, 251),
(131, 'Doña Horenaku Zoyilukoce', 201, 486),
(132, 'Goro Jomapopu', 149, 447),
(133, 'Nuti ', NULL, 414),
(134, 'Pujeki ', 296, 208),
(135, 'Sra. Kico Jinizi', 6, 436),
(136, 'Gujigu Uo', 297, 368),
(137, 'Iaqawa ', 417, 404),
(138, 'Lejokeki ', 27, 349),
(139, 'Cipe ', 463, 459),
(140, 'Lady Giho ', 75, 290),
(141, 'Don Kujizu ', 93, 431),
(142, 'Sra. Eovove ', 221, 466),
(143, 'Xejowu ', 448, 526),
(144, 'Jiwuso Futu', 87, 312),
(145, 'Sipadu Fazu', NULL, 382),
(146, 'Lord Dipi ', 362, 457),
(147, 'Rajewuwa Godo', 389, 396),
(148, 'Fuji Uovubu', 299, 331),
(149, 'Lord Yafudo ', 451, 598),
(150, 'Sra. Mudica ', 410, 457),
(151, 'Lo ', 482, 315),
(152, 'Wuyabilu ', NULL, 417),
(153, 'Dr. Eoraci ', 411, 436),
(154, 'Lord Deho Fijuxiju', 275, 345),
(155, 'Sra. Fika Ledo', 363, 559),
(156, 'Lady Muwuciwe ', 450, 286),
(157, 'Neze ', 375, 516),
(158, 'Ciqe ', NULL, 577),
(159, 'Pidivu Pasahuge', 172, 556),
(160, 'Wogigi Oe', 38, 409),
(161, 'Lady Rodukezu ', 202, 580),
(162, 'Laronu ', 46, 258),
(163, 'Na Wiqiwuhe', 167, 257),
(164, 'Xuve Muro', 214, 454),
(165, 'Sr. Eidoze Yuxivasu', 230, 258),
(166, 'Xi ', 32, 249),
(167, 'Lady Ruvoqo Qilevu', 411, 505),
(168, 'Fuceluqi Tane', 490, 252),
(169, 'Verahifo Xewunuwu', 282, 583),
(170, 'Dafuza Oote', 316, 425),
(171, 'Zuno Qele', 214, 526),
(172, 'Sir Aexixe ', 5, 516),
(173, 'Kuqigu Lokeki', 165, 205),
(174, 'Dr. Aonida Halefipe', 387, 201),
(175, 'Dr. Denipi ', 211, 238),
(176, 'Doña Qa Be', 227, 257),
(177, 'Lady Yato ', 109, 296),
(178, 'Lady Iu Zatodoye', 2, 366),
(179, 'Uoye ', 275, 311),
(180, 'Don Dozibe Hudoji', 379, 497),
(181, 'Tuxeze ', 156, 592),
(182, 'Dr. Iuse Rovo', 152, 414),
(183, 'Riza Meyiseza', 218, 492),
(184, 'Iuvu Xutoqi', NULL, 207),
(185, 'Sra. Cijuxi Rotoyi', 221, 594),
(186, 'Dr. Tusina ', 336, 492),
(187, 'Radedibu ', 62, 410),
(188, 'Don Yodekuwu ', NULL, 237),
(189, 'Doña Riro Da', 37, 570),
(190, 'Leqe Iu', 314, 429),
(191, 'Xiliqi ', 112, 200),
(192, 'Jo Hidove', 114, 331),
(193, 'Kocuqo ', 99, 449),
(194, 'Sra. Maceze ', 271, NULL),
(195, 'Sr. Tayise Vedasuli', 290, 508),
(196, 'Eewa Fivobakodo', 323, 235),
(197, 'Joxaho Xetaze', 307, 447),
(198, 'Sir Xegacu Coxuvowo', 19, 484),
(199, 'Futako Qejesodike', 276, 570),
(200, 'Sir Miqiri ', 183, 480),
(201, 'Lady Razu Outefucoho', 169, 447),
(202, 'Sra. Devapo ', 89, 203),
(203, 'Sra. Ciheteha ', 38, 422),
(204, 'Outuca ', 8, 596),
(205, 'Lord Subota ', 62, 496),
(206, 'Fize ', NULL, 308),
(207, 'Hugora ', 439, 397),
(208, 'Vina ', 145, 537),
(209, 'Tibe ', 427, 485),
(210, 'Sr. Yaqe ', 17, 352),
(211, 'Sra. Uoca Vero', NULL, 346),
(212, 'Sra. Muco Xadabuha', 203, 224),
(213, 'Lupe Tidohahi', 70, 209),
(214, 'Sr. Goredi ', 66, 205),
(215, 'Doña Qido Buyuhi', 25, 453),
(216, 'Desevi ', NULL, 484),
(217, 'Gupi ', 209, 345),
(218, 'Laroteza ', 208, 499),
(219, 'Suzo Mifiju', 257, 304),
(220, 'Aejeco Cafuwa', 62, 541),
(221, 'Wapa ', 471, 227),
(222, 'Sr. Eoku ', 411, 285),
(223, 'Sir Mufu Eozuqayexa', 183, 286),
(224, 'Uokawa Du', 213, 215),
(225, 'Vohenu Yeyihupi', 219, 473),
(226, 'Lord Ci ', 49, 353),
(227, 'Aazuwovo ', 277, 279),
(228, 'Sir Iaxobu Mumi', 266, 448),
(229, 'Lady Zefidohu Copusi', NULL, 233),
(230, 'Jaba Puha', 258, 223),
(231, 'Sir Kinokika ', 116, 241),
(232, 'Hoqa ', 106, 341),
(233, 'Euho ', 167, 264),
(234, 'Iiyokegu Uuwetaji', 153, 557),
(235, 'Sra. Ha ', 431, 236),
(236, 'Lady Ee ', NULL, 382),
(237, 'Qifako ', 152, 438),
(238, 'Mule Mejemaza', 156, 299),
(239, 'Don Tiya Oiga', 380, 393),
(240, 'Dr. Yeqozavo Febiwexu', 466, 239),
(241, 'Yubivu Uijimixo', 6, 321),
(242, 'Don Iawixe ', 35, 238),
(243, 'Vuzogi ', 459, 501),
(244, 'Iogaco ', 2, 342),
(245, 'Dr. Rufope Iimorada', 180, 490),
(246, 'Dr. Cizuve ', 37, 325),
(247, 'Pabero ', 250, NULL),
(248, 'Sir Hohira Cijekexe', 374, 401),
(249, 'Qiwe ', 409, 511),
(250, 'Segu Pabiqe', 29, 308),
(251, 'Ce ', 383, 228),
(252, 'Leso ', 100, 394),
(253, 'Lord Nonigu ', 352, 396),
(254, 'Doña Ioya Oesohe', 28, 313),
(255, 'Lord Kedu ', NULL, 423),
(256, 'Don Sucu ', 496, 379),
(257, 'Dr. Xezo ', 276, 222),
(258, 'Dace ', 210, 323),
(259, 'Iajiri ', 44, 386),
(260, 'Don Juluco Ieka', 371, 237),
(261, 'Dovala Qefagugi', 496, 410),
(262, 'Sa Uijebugi', 107, NULL),
(263, 'Dikeni ', NULL, 439),
(264, 'Wecego ', 232, 394),
(265, 'Jawuje Livojise', 137, 477),
(266, 'Iiyahu Eavado', 447, 532),
(267, 'Mabulimo Vipopemo', 138, 300),
(268, 'Doña Zaco Jonobewato', 62, 227),
(269, 'Ge ', 439, 538),
(270, 'Gude Zejagi', 73, 320),
(271, 'Jomoha Hebu', 247, 425),
(272, 'Sra. Oineje Roneqose', 164, 362),
(273, 'Don Quzawave ', 261, 521),
(274, 'Zaqe Nekulumaje', 1, 248),
(275, 'Dr. Binara ', 134, 325),
(276, 'Doña Wejebi Zi', 407, 564),
(277, 'Suto Ridoriso', 106, 407),
(278, 'Don Uibazupa ', 6, 243),
(279, 'Aaqe Vuyuzefa', 252, 490),
(280, 'Fasomu ', 241, 245),
(281, 'Dr. Ribaxu ', 434, 253),
(282, 'Doña Hosecajo ', 44, 340),
(283, 'Lord Popi ', 67, 346),
(284, 'Wirufahe ', 180, 536),
(285, 'Bi Cebirebu', 110, 538),
(286, 'Pokifexa ', NULL, 355),
(287, 'Doña Ranovo ', 25, 538),
(288, 'Doña Aemo ', 214, 487),
(289, 'Lady Nenuru ', 155, 316),
(290, 'Doña Faraha ', 174, 253),
(291, 'Sra. Oujika ', 424, 399),
(292, 'Sir Kaso ', 45, 409),
(293, 'Doña Boyihu Goja', 214, 369),
(294, 'Lady Zoseyebi Zedibo', 357, 244),
(295, 'Dr. Sodala ', 196, 213),
(296, 'Sra. Gumenu ', 5, 433),
(297, 'Wanu Vutede', 337, 519),
(298, 'Rege ', 451, 456),
(299, 'Qale ', 30, 382),
(300, 'Doña Eike ', NULL, 400),
(301, 'Povami Aesuzi', NULL, 317),
(302, 'Necuhi Iuzewo', NULL, 418),
(303, 'Lord Wuqoje ', 360, 209),
(304, 'Doña Te Xopefuho', 402, 296),
(305, 'Geze ', 311, 222),
(306, 'Sra. Xahihiku Hazavega', 20, 566),
(307, 'Teyocumo ', 461, 338),
(308, 'Sra. Wupa Fequ', 3, 542),
(309, 'Aigefa Colohe', NULL, 549),
(310, 'Lord Jeli ', 84, 405),
(311, 'Oupo ', 226, 585),
(312, 'Doña Cuniwa ', 499, 577),
(313, 'Sir Hi Euliba', 14, 399),
(314, 'Famomife ', NULL, 320),
(315, 'Fowaha ', 212, 315),
(316, 'Dr. Tuwo ', 104, 278),
(317, 'Eowoyu ', 463, 590),
(318, 'Don Zoca Ribuke', 474, 263),
(319, 'Sir Kodeje Jabeqo', 434, 455),
(320, 'Don Fexi ', 79, 247),
(321, 'Lady Ga ', NULL, 528),
(322, 'Yovati ', 4, 487),
(323, 'Sr. Pezi Yijepu', 40, 500),
(324, 'Lord Cevacapi ', 399, 396),
(325, 'Sir Habi Makufa', 331, 497),
(326, 'Nape Xuke', NULL, 384),
(327, 'Zaqaxo Jupuvu', 343, 300),
(328, 'Tizu ', 83, 536),
(329, 'Viko ', 250, 205),
(330, 'Coze Vixoge', 137, 529),
(331, 'Ragiki ', 313, 234),
(332, 'Gahike Figado', 99, 228),
(333, 'Sir Lonepu Vecuqeqobo', 26, 458),
(334, 'Don Yoqemoxo Tohiyida', 469, 404),
(335, 'Ye Fajijoja', 102, 383),
(336, 'Eilu ', 192, 440),
(337, 'Tukugu ', 260, 577),
(338, 'Sr. Hinuqowo Dobanabemi', 31, 293),
(339, 'Gewu Wine', 49, 243),
(340, 'Don Zacixo ', 473, 243),
(341, 'Lord Bisa ', 95, 325),
(342, 'Yocu ', 352, 372),
(343, 'Ha Yipu', 246, 233),
(344, 'Xopuvi ', 48, 241),
(345, 'Sr. Niyo Gecoroye', 359, NULL),
(346, 'Sra. Ei Zoqibo', 473, 314),
(347, 'Sra. Leqe ', NULL, 491),
(348, 'Wowu ', 119, 561),
(349, 'Dr. Xedali Luhesugo', 496, 401),
(350, 'Dedi Yenajeku', NULL, 475),
(351, 'Doña Futudi ', 369, 391),
(352, 'Eiqe ', 47, 361),
(353, 'Aoge Vodi', 380, 326),
(354, 'Dr. Mi ', 476, 333),
(355, 'Lady Dewi ', 476, 469),
(356, 'Aojo ', 386, 449),
(357, 'Xo Qaroje', NULL, 579),
(358, 'Suvo Fucuwaxi', 27, 523),
(359, 'Dr. Qadu Supena', 143, 351),
(360, 'Sr. Sude Eele', 152, 553),
(361, 'Doña Zolume Pabeve', 251, 567),
(362, 'Lady Liyipo Jinute', 251, 596),
(363, 'Mexeqahu Jipa', 277, 465),
(364, 'Rudaloje ', 3, 470),
(365, 'Dr. Qekuwo ', 492, 524),
(366, 'Uiju Kinavo', 98, 271),
(367, 'Lady Qecuyu Panenafu', 130, 343),
(368, 'Sr. Vuke Joleci', 131, 549),
(369, 'Lord Wesa ', 119, 433),
(370, 'Kakuhe Kuhi', 452, 420),
(371, 'Lord Sala Jopoxika', 11, 401),
(372, 'Rone Bafube', 163, 461),
(373, 'Ai Nulufa', 129, 480),
(374, 'Xiguto Leke', 155, 568),
(375, 'Leboyu Weposo', 53, 250),
(376, 'Sr. Euwo ', 418, 552),
(377, 'Eukilicu ', 289, 395),
(378, 'Ruxa Gu', 443, 225),
(379, 'Sir Toqewi ', 408, 344),
(380, 'Dijuru ', NULL, 327),
(381, 'Dr. Qa Eiwa', NULL, 238),
(382, 'Oope ', 377, 337),
(383, 'Qexo ', NULL, 333),
(384, 'Doña Sajaze Jiyini', 472, 279),
(385, 'Lady Auyulu ', 349, 244),
(386, 'Don Lewoqi Husesi', 111, 443),
(387, 'Yunifohi ', 263, 401),
(388, 'Sr. Kuxa Qowozoge', 305, 260),
(389, 'Wujipi ', NULL, 529),
(390, 'Don Jimopi Xosayu', NULL, 333),
(391, 'Lord Suda Subi', 111, 363),
(392, 'Sr. Savu ', 354, 251),
(393, 'Daki ', 19, 597),
(394, 'Iuluduwa ', 471, 441),
(395, 'Sra. Qugi Levuri', 26, 507),
(396, 'Taza ', 302, 542),
(397, 'Doña Se Kora', 396, 522),
(398, 'Qureco ', 387, 508),
(399, 'Licoxa Baja', 475, 213),
(400, 'Sir Sayo Lavoyi', 21, 553),
(401, 'Cekeha Eogikafo', 61, 245),
(402, 'Eiwahu Xabiki', 5, 541),
(403, 'Iaka Xige', 384, 545),
(404, 'Ziye Kutozeri', 54, 362),
(405, 'Ouje Gofoso', 430, 503),
(406, 'Wuwozari ', 183, 246),
(407, 'Kamu ', 7, 537),
(408, 'Don Geqiji ', 250, 329),
(409, 'Wo Aisipozo', 237, 322),
(410, 'Co ', 57, 487),
(411, 'Peda ', 143, 202),
(412, 'Vebeye Uazeje', 25, 374),
(413, 'Ie ', 287, 308),
(414, 'Tosalu Pezo', 5, 512),
(415, 'Tota ', NULL, 253),
(416, 'Aimi ', NULL, 380),
(417, 'Sr. Qajixo ', 30, 319),
(418, 'Riqule Bebufi', 416, 369),
(419, 'Zoqaro Mixu', 417, 324),
(420, 'Sahemahi Iinoju', 6, 348),
(421, 'Subuni Qenocu', 66, 445),
(422, 'Don Bufida Zonodi', 124, 475),
(423, 'Lady Xece Uihugova', 361, 584),
(424, 'Gigu Oaqi', 343, 438),
(425, 'Qava ', 305, 534),
(426, 'Doña Vadepeye ', 189, 218),
(427, 'Doña Zabu ', NULL, 528),
(428, 'Ioyalime Gaqede', 422, 229),
(429, 'Riquma Jogepo', 317, 548),
(430, 'Yisi Divururo', 30, 465),
(431, 'Oara ', 30, 207),
(432, 'Sra. Culedo ', 206, 430),
(433, 'Neci Maluyi', 338, 265),
(434, 'Laho Aoriwu', 31, 457),
(435, 'Lord Eodowo ', NULL, 381),
(436, 'Dr. Euweli Huwiwu', 264, 429),
(437, 'Dr. Ouqomo Riheva', 471, 288),
(438, 'Tafebi Curari', 467, 224),
(439, 'Dr. Yivokoye ', 314, 558),
(440, 'Sra. Bica ', 180, 511),
(441, 'Qogi ', 200, 494),
(442, 'Lord Daka ', 348, 350),
(443, 'Hijixe ', 242, 327),
(444, 'Doña Hi ', NULL, 343),
(445, 'Eofixa Qaqa', 91, 227),
(446, 'Oejojawu Vixodubalu', 68, 247),
(447, 'Dr. Eofojipo ', 61, 377),
(448, 'Dose ', 68, 373),
(449, 'Doña Kukiqe Jajuzi', 323, 527),
(450, 'Dr. Xuneza ', 352, 403),
(451, 'Lady Peyeca ', 1, 600),
(452, 'Lord Dikavo ', 433, 365),
(453, 'Sra. Xuki We', 260, 204),
(454, 'Jozu ', 390, 293),
(455, 'Dezubi Derapihuvi', 28, 360),
(456, 'Doña Lavuze ', 265, 322),
(457, 'Kufuvu ', 437, 373),
(458, 'Hogonawa Uanojiwu', 127, 298),
(459, 'Sra. Fuxi ', 138, 285),
(460, 'Yupawa ', 177, 553),
(461, 'Dr. Rolevi Havife', 266, 429),
(462, 'Qefe Qozobukaha', 336, 452),
(463, 'Kaga Ziliqaloxu', 81, 471),
(464, 'Zo Soloci', 342, 508),
(465, 'Lady Ludo Fuhu', 335, 363),
(466, 'Nepiba ', 288, 378),
(467, 'Oaga ', 81, 377),
(468, 'Tiwuti ', 214, 467),
(469, 'Sra. Qicoxigo Vadidi', 342, 389),
(470, 'Nukawu Qo', 289, 347),
(471, 'Lady Duyuza ', NULL, 468),
(472, 'Sir Heba ', 135, 445),
(473, 'Sra. Zoneri Aisuki', NULL, 543),
(474, 'Iawu Fiqasaho', NULL, 323),
(475, 'Eugo Aerake', 144, 440),
(476, 'Doña Yajo Zetoserolo', 345, 296),
(477, 'Don Mohuci Eixula', 274, 555),
(478, 'Dimuleri Xofejo', 316, 501),
(479, 'Pe ', 81, 407),
(480, 'Joju ', 77, 239),
(481, 'Zo ', 187, 553),
(482, 'Mufi Lito', 8, 423),
(483, 'Wesu Ouroce', 8, 257),
(484, 'Siciho ', 375, 324),
(485, 'Piha ', 3, 322),
(486, 'Nake ', 1, 279),
(487, 'Sra. Mogedotu Oibagilu', 209, 556),
(488, 'Yiyuqami ', 433, 283),
(489, 'Doña Bokari ', NULL, 575),
(490, 'Ho ', 329, 276),
(491, 'Re ', 38, 481),
(492, 'Pega ', 16, 511),
(493, 'Lady Qere Pujiyo', 126, 546),
(494, 'Mocu Yacumo', 245, 224),
(495, 'Sir Defu ', 1, 211),
(496, 'Don Cenejo ', 311, 566),
(497, 'Biqoqu Yidofuso', 44, 569),
(498, 'Don Demo ', 141, NULL),
(499, 'Sr. Nefuza ', 9, 567),
(500, 'Basaje Jewutufucu', 190, 221),
(501, 'Kulabiwo ', 97, 230),
(502, 'Joxi Soworuyu', 185, 346),
(503, 'Dariruda ', NULL, 442),
(504, 'Zomepoto Oineridubi', 335, 462),
(505, 'Va Uepe', 198, 457),
(506, 'Hagiqe ', NULL, 361),
(507, 'Uegaxe ', 303, 487),
(508, 'Aake Poyumode', 280, 346),
(509, 'Sr. Eofe ', 421, 431),
(510, 'Eunura ', 358, 325),
(511, 'Lord Jeha ', 489, 465),
(512, 'Sir Oaza ', 450, 420),
(513, 'Iijuwo ', 0, 213),
(514, 'Lady Uame ', 255, 554),
(515, 'Namoruca ', 52, 237),
(516, 'Oidoho ', 111, 218),
(517, 'Dr. Du ', 234, 281),
(518, 'Vowe Laxacemu', 335, 552),
(519, 'Sra. Veqe Wowo', 138, 270),
(520, 'Don Canazuzi ', 262, 577),
(521, 'Eidodo ', NULL, 569),
(522, 'Mupi ', 24, 408),
(523, 'Sra. Ualu ', 272, 274),
(524, 'Doña Rekape ', 276, 573),
(525, 'Sabubu Hapepucu', 253, 231),
(526, 'Fiha Gulikawi', 488, 561),
(527, 'Mimi ', 299, 292),
(528, 'Fafava ', NULL, 512),
(529, 'Dr. Iegawa ', 96, 308),
(530, 'Rugaha ', 170, 391),
(531, 'Nuli ', 168, 386),
(532, 'Aufu ', 30, 569),
(533, 'Se Eobe', 288, 232),
(534, 'Ceva Nixofica', 72, 221),
(535, 'Qefuxi Menuci', NULL, 451),
(536, 'Sra. Mupu Diqidoho', 474, 384),
(537, 'Sra. Pa ', 477, 493),
(538, 'Lo Caca', 252, 385),
(539, 'Sir Eoyoja Febe', 208, 216),
(540, 'Bibexu Roxa', 4, 292),
(541, 'Povimu Tetu', 112, 516),
(542, 'Refodo Iibidu', 9, 422),
(543, 'Vocija Aemumaje', 69, 576),
(544, 'Lakapi Tuhi', NULL, 446),
(545, 'Sir Jolulize ', 3, 352),
(546, 'Lord Sa ', 457, 261),
(547, 'Cajexo ', NULL, 579),
(548, 'Sr. Rute Sonipawuvu', 189, 417),
(549, 'Sr. Mogida ', 31, 229),
(550, 'Uo Weta', NULL, 300),
(551, 'Ione ', 259, 578),
(552, 'Zaribu Qizo', 180, 225),
(553, 'Sir Migujume ', 451, 440),
(554, 'Don Jelehoga Xanazebi', 377, 313),
(555, 'Doña Zupi Reqofa', 426, 337),
(556, 'Lord Qu ', 276, 354),
(557, 'Doña Takiqa Li', 254, 548),
(558, 'Jideyu Eijugafi', 0, 394),
(559, 'Cusuvu ', 275, 312),
(560, 'Ae ', 275, 277),
(561, 'Ooju Panuya', 315, 548),
(562, 'Lord Wuquve Pidu', 496, 465),
(563, 'Oihu ', 322, 462),
(564, 'Pobexe ', 436, 438),
(565, 'Sra. Iadi Buxefoko', 203, 387),
(566, 'Sir Moza ', 269, 426),
(567, 'Tejo Dora', NULL, 438),
(568, 'Vumuho ', 262, 374),
(569, 'Lady Eubo Depunowave', 349, 457),
(570, 'Don Oucaka Raxuxe', 29, 588),
(571, 'Dr. Tako Zebefe', 244, 466),
(572, 'Lady Goquda Fezali', 77, 557),
(573, 'Lady Papuha Baye', 1, 587),
(574, 'Raquxu Auwo', 7, 473),
(575, 'Keji ', 63, 404),
(576, 'Lord Pamatebe ', 488, 328),
(577, 'Liwazu Fejo', 188, 359),
(578, 'Ribaba Yegiqeqefi', 474, 400),
(579, 'Guca Aakilo', 8, 234),
(580, 'Sir Zowoha Tixesiza', 204, 579),
(581, 'Iegomasa ', 50, 572),
(582, 'Sr. Resiba Jejufewe', 9, 329),
(583, 'Sra. Liro Riti', 5, 354),
(584, 'Sra. Zodu Vihena', 422, 370),
(585, 'Don Tiwo Pejetoyigo', 283, 366),
(586, 'Lebi Guki', 209, 276),
(587, 'Doña Eozeko Roquhi', 4, 340),
(588, 'Sir Cuto Daqaba', 56, 537),
(589, 'Sane ', 111, 559),
(590, 'Aajatohi Zuzoha', 72, 344),
(591, 'Sr. Bogozu Puxigi', 66, 428),
(592, 'Yuzizu ', 2, 373),
(593, 'Lord Eelo Aezado', 81, 390),
(594, 'Yiriku Picehi', 469, 592),
(595, 'Wikame Deturu', 408, 374),
(596, 'Sra. Eizufo ', NULL, 451),
(597, 'Bivexi Qifuxabacu', 150, 462),
(598, 'Lady Pukovi ', 255, 513),
(599, 'Fuceci ', 196, 336),
(600, 'Sir Ea ', 408, 318),
(601, 'Bazo ', 290, 369),
(602, 'Uazi Iusa', 496, 323),
(603, 'Sr. Go Yugaxuja', 374, 311),
(604, 'Ja Togidu', 464, 346),
(605, 'Maqike ', 3, 229),
(606, 'Uociduvo Yihi', 262, 341),
(607, 'Sra. Momiti ', 328, 322),
(608, 'Lord Hido ', 277, 449),
(609, 'Eixafi Teruda', 161, 216),
(610, 'Doña Xupe Ge', 176, 522),
(611, 'Nona Ce', 66, 300),
(612, 'Oofu ', 209, 540),
(613, 'Cumabe ', 3, 203),
(614, 'Bamo ', NULL, 284),
(615, 'Sr. Veza ', 215, 514),
(616, 'Iayi Fupoyu', 44, 364),
(617, 'Sr. Buhiluvo ', 250, 267),
(618, 'Vo ', 380, 429),
(619, 'Eeni ', 1, 207),
(620, 'Lady Yu Iuvusere', 265, 411),
(621, 'Iiguvi Tuco', 252, 548),
(622, 'Xegeve ', 76, 416),
(623, 'Soqifi ', 428, 347),
(624, 'Nanodeyi ', 89, 388),
(625, 'Zopo ', 326, 277),
(626, 'Lord Oohado Guzixucu', 8, 459),
(627, 'Doña Zoju Yumewe', 400, 392),
(628, 'Yayama Dejarenuku', 423, 243),
(629, 'Don Uu ', 314, 477),
(630, 'Jecofa ', 361, 392),
(631, 'Leyomiho Hife', NULL, 394),
(632, 'Sir Mido ', 464, 532),
(633, 'Pe Eipo', 60, 504),
(634, 'Pebi ', 9, 242),
(635, 'Da Coya', 365, 282),
(636, 'Uikunequ ', 42, 565),
(637, 'Lady Qeya ', 409, 401),
(638, 'Don Vamagoxa Ziqimi', 126, 289),
(639, 'Lord Yero Zozi', 99, 271),
(640, 'Jusila Pe', NULL, 385),
(641, 'Lady Ge ', 75, 235),
(642, 'Tukixuci Wuguwupi', 431, 536),
(643, 'Lord Tufiyi ', 455, 283),
(644, 'Sr. Xozalo Yabo', 217, 596),
(645, 'Don Zinapu ', 202, 220),
(646, 'Dehihebe ', 386, 375),
(647, 'Wabo Euvanebo', 293, NULL),
(648, 'Jazu Gehuhohi', 330, 512),
(649, 'Ma ', 167, 464),
(650, 'Sir Tayamo ', 128, 430),
(651, 'Lady Zexave Zogaxehi', 378, 499),
(652, 'Dr. Pe ', 280, 353),
(653, 'Oogigi Zotorewu', 493, 310),
(654, 'Vajamopi ', 10, 599),
(655, 'Dr. Aovo ', 15, 261),
(656, 'Vafepu ', 77, 392),
(657, 'Pilumipa Cadobowa', NULL, 419),
(658, 'Don Po Jagi', 27, 307),
(659, 'Jahula ', 9, 564),
(660, 'Earufape ', 118, 315),
(661, 'Ce ', 137, 396),
(662, 'Ga Tayucitexo', 53, 494),
(663, 'Uuhujo Naqefa', 134, 216),
(664, 'Rajegu ', 327, 269),
(665, 'Sir Suvahu ', 63, 215),
(666, 'Fokivibe ', 423, 275),
(667, 'Lady Ui Lejenobavu', 81, 452),
(668, 'Sra. Cibo Deja', 69, 311),
(669, 'Liwo Oaya', 66, 222),
(670, 'Rukoye Filiheka', 435, 461),
(671, 'Kosome Oukegamo', 71, 564),
(672, 'Dr. Ouvola ', 97, 377),
(673, 'Wi ', NULL, 345),
(674, 'Doña Le Uehilo', 270, 456),
(675, 'Dr. Bahe ', 293, 467),
(676, 'Dr. Feleho ', 466, 579),
(677, 'Mufogi Jejonu', 1, 293),
(678, 'Don Le ', 198, 276),
(679, 'Sir Qaxapegu Lodegu', 186, 414),
(680, 'Foxi Jo', 413, 276),
(681, 'Lord Se ', 251, 298),
(682, 'Sra. Sekejuda ', 278, 325),
(683, 'Lady Buvu ', 340, 250),
(684, 'Ausuxi Iedafo', 83, 271),
(685, 'Sr. Xewaxa ', NULL, 481),
(686, 'Lord Jecaqo ', 184, 295),
(687, 'Curuba Pacu', 215, 494),
(688, 'Peqize Iowebi', 335, 220),
(689, 'Qapa Tapubado', 66, 371),
(690, 'Gune ', 199, 252),
(691, 'Sir Puwawa Baki', 425, 283),
(692, 'Jodoki ', 141, 600),
(693, 'Huroye Jazoxaya', 143, 490),
(694, 'Doña Soju Hocehe', 247, 214),
(695, 'Mekihi ', 42, 353),
(696, 'Sra. Iaquvo Wesasaje', 255, 209),
(697, 'Yoguli ', 407, 331),
(698, 'Fayo Za', 7, 464),
(699, 'Sr. Nadome Oeganoqufe', 126, 567),
(700, 'Sir Bemici ', NULL, 257),
(701, 'Nimada ', 219, 501),
(702, 'Zitunusu Bepudoceti', 442, 367),
(703, 'Lord Quniro Aagiqe', 419, 342),
(704, 'Wafi Xowi', NULL, 475),
(705, 'Sr. Hoyu Mogagu', 496, 452),
(706, 'Na Eoqa', 463, 209),
(707, 'Don Mado ', 485, 446),
(708, 'Dr. Luzuju ', 108, 333),
(709, 'Iiribo ', 419, 529),
(710, 'Yuwipu Buki', 51, 376),
(711, 'Don Sulu ', 52, 549),
(712, 'Don Qoze ', 49, 570),
(713, 'Uelohuxa ', 459, 263),
(714, 'Gute ', 178, 382),
(715, 'Sr. Xeyo Wuyuyuli', 373, 255),
(716, 'Sir Qofe ', 426, 316),
(717, 'Sir Gupaku ', NULL, 212),
(718, 'Dr. Uowe ', 226, 263),
(719, 'Lady Kafo Coga', 82, 446),
(720, 'Leya ', 155, 410),
(721, 'Sr. Wu ', NULL, 261),
(722, 'Qapi ', NULL, 528),
(723, 'Pavediqi ', 263, 374),
(724, 'Keno ', 216, 456),
(725, 'Au Caga', 220, 585),
(726, 'Sir Teyudiqo Iozowububi', 223, 330),
(727, 'Sr. Yubi ', 57, 520),
(728, 'Doña Pa ', 428, 523),
(729, 'Pato ', 1, 356),
(730, 'Xase ', NULL, 430),
(731, 'Sir Mokamowe Xokuluda', 328, 358),
(732, 'Eixa Gevayuda', 7, 539),
(733, 'Oaxopede ', 451, 463),
(734, 'Doña Habiju ', 207, 588),
(735, 'Posiki ', 247, 325),
(736, 'Don Xebe ', 161, 477),
(737, 'Sra. Cusuyo ', 6, 205),
(738, 'Doña Xugi Fudu', 340, 571),
(739, 'Huha ', 154, 555),
(740, 'Ianu Aiga', 393, 261),
(741, 'Va ', NULL, 210),
(742, 'Sra. Bezagu Fexixo', 218, 312),
(743, 'Dr. Zu Yusapu', 282, 344),
(744, 'Doña Ki Hicupa', 128, 446),
(745, 'Tudiqo Yucisibo', 387, 522),
(746, 'Sra. Xi Doqivaci', 40, 448),
(747, 'Sr. Kahuto ', 3, 447),
(748, 'Lord Fociqu Oazelazo', NULL, 538),
(749, 'Sir Ro ', 8, 395),
(750, 'Sra. Aatege ', 360, 539),
(751, 'Jujexe ', 17, 475),
(752, 'Pejo Oagune', 59, 508),
(753, 'Taqu ', 101, 465),
(754, 'Yize Wigeyo', 369, 547),
(755, 'Heruco ', 91, 284),
(756, 'Niso Soma', 387, 538),
(757, 'Sir Kupa ', 403, 588),
(758, 'Sir Xumohu Io', 7, 520),
(759, 'Mugezege Xorecasi', 48, 364),
(760, 'Jala ', 490, 428),
(761, 'Sra. Uabiju Vofoci', 290, 309),
(762, 'Torowitu Lamulo', 302, 304),
(763, 'Muxune ', 301, 565),
(764, 'Lady Euxa Doju', NULL, 508),
(765, 'Sir Xizufe ', 117, 472),
(766, 'Sr. Yazoro Zuzu', 272, 409),
(767, 'Don Aigi Oaxiti', 232, 483),
(768, 'Lady Datacode Kudolara', 352, 249),
(769, 'Roci ', 401, 206),
(770, 'Aufojo ', 305, 482),
(771, 'Lord Yiqa Yuwuji', 427, 330),
(772, 'Sr. Ha ', 250, 433),
(773, 'Sebu Seyubaje', 230, 314),
(774, 'Yo ', NULL, 276),
(775, 'Lord Aa Cemulemu', NULL, 389),
(776, 'Lady Taripo Oudopoyo', 242, 495),
(777, 'Xayiru ', 187, 583),
(778, 'Doña Wodoxu ', 186, 488),
(779, 'Jicubito ', NULL, 243),
(780, 'Sir La ', NULL, 456),
(781, 'Don Lekelaga Eina', 491, 256),
(782, 'Mace Yanazeje', 402, 378),
(783, 'Jura Rarayaho', 423, 374),
(784, 'Uevocaga ', 8, 388),
(785, 'Rame Aefikahi', 265, 486),
(786, 'Sra. Aa Eote', 28, 491),
(787, 'Euxu ', 421, 405),
(788, 'Lulo Yecopale', 466, 502),
(789, 'Ratesavo ', 117, 537),
(790, 'Don Zafeqi ', 496, 242),
(791, 'Kune Nimi', 444, 461),
(792, 'Lord Curo ', 500, 237),
(793, 'Fi ', 303, 280),
(794, 'Doña Kazo ', 1, 282),
(795, 'Sir Wobu ', 344, 547),
(796, 'Yifa ', 185, 225),
(797, 'Doña Ruseye ', 243, 512),
(798, 'Doruwi ', 4, 377),
(799, 'Duwo Geziqi', 398, 595),
(800, 'Lord Pikiri Jesura', 223, 494);

INSERT INTO tripulante(id, fecha_inicio, fecha_fin, cargo, id_persona) VALUES
(1, '1977-01-21', '1979-07-01', 'Técnico de comunicaciones', 332),
(2, '1985-06-04', '1990-03-23', 'Científico', 63),
(3, '1972-02-04', '1976-07-29', 'Médico', 337),
(4, '1970-02-28', '1971-05-23', 'Médico', 720),
(5, '2000-11-30', '2001-07-19', 'Científico', 694),
(6, '1983-11-04', NULL, 'Científico', 786),
(7, '2004-05-14', NULL, 'Capitán', 652),
(8, '1970-07-16', '1973-07-25', 'Científico', 497),
(9, '2016-08-04', '2019-04-17', NULL, 447),
(10, '2013-03-14', '2013-04-16', 'Científico', 23),
(11, '1998-03-18', '2001-07-03', 'Técnico de comunicaciones', 347),
(12, '1973-09-10', '1976-08-07', 'Capitán', 24),
(13, '1987-11-01', '1989-01-05', 'Médico', 188),
(14, '1970-02-10', NULL, 'Científico', 690),
(15, '1970-01-08', '1970-12-31', 'Técnico de comunicaciones', 749),
(16, '2018-04-22', '2022-04-21', 'Capitán', 290),
(17, '1974-04-11', '1977-07-19', 'Capitán', 669),
(18, '1970-01-01', '1973-09-01', 'Capitán', 633),
(19, '2013-01-06', NULL, 'Científico', 653),
(20, '2018-05-11', NULL, 'Soldado', 318),
(21, '1976-05-14', NULL, 'Soldado', 5),
(22, '2008-04-27', NULL, NULL, 181),
(23, '1994-09-09', '1995-07-06', 'Capitán', 116),
(24, '1983-08-03', '1985-02-06', 'Soldado', 502),
(25, '1993-02-02', '1995-05-27', 'Capitán', 351),
(26, '1989-06-01', '1989-12-10', NULL, 356),
(27, '1976-07-28', NULL, 'Técnico de comunicaciones', 64),
(28, '1980-11-01', NULL, 'Científico', 701),
(29, '1975-04-22', '1979-10-18', NULL, 709),
(30, '1972-02-02', '1977-04-15', 'Médico', 278),
(31, '1975-02-20', '1978-07-29', 'Soldado', 625),
(32, '2010-10-31', '2014-07-30', 'Técnico de comunicaciones', 693),
(33, '1970-01-03', '1971-09-04', 'Capitán', 685),
(34, '1997-04-27', '2000-02-06', 'Soldado', 370),
(35, '1987-09-11', '1987-11-04', 'Médico', 728),
(36, '1970-01-08', '1972-11-29', NULL, 487),
(37, '2017-11-30', NULL, 'Técnico de comunicaciones', 409),
(38, '2001-08-13', '2001-09-14', NULL, 759),
(39, '1970-03-13', '1972-02-21', 'Soldado', 279),
(40, '2003-06-07', '2007-03-08', 'Capitán', 86),
(41, '1978-12-16', NULL, 'Científico', 498),
(42, '1985-11-21', '1988-02-05', NULL, 379),
(43, '1970-01-03', NULL, 'Médico', 498),
(44, '1970-03-05', NULL, NULL, 319),
(45, '2003-07-21', NULL, NULL, 74),
(46, '1970-04-06', '1973-03-24', 'Capitán', 60),
(47, '2003-08-30', '2006-01-19', 'Científico', 742),
(48, '1978-04-20', '1983-07-15', 'Técnico de comunicaciones', 444),
(49, '2001-08-28', '2004-04-23', 'Médico', 150),
(50, '1970-03-02', '1974-04-19', 'Soldado', 523),
(51, '1970-01-24', NULL, 'Científico', 744),
(52, '1993-01-06', NULL, 'Médico', 128),
(53, '1977-01-24', '1980-05-10', 'Científico', 654),
(54, '1984-05-29', NULL, 'Técnico de comunicaciones', 514),
(55, '2016-10-03', NULL, 'Capitán', 89),
(56, '1977-01-23', '1980-03-22', NULL, 584),
(57, '1976-01-09', NULL, 'Médico', 354),
(58, '2010-03-01', NULL, 'Médico', 588),
(59, '2014-05-09', NULL, 'Médico', 231),
(60, '1987-02-16', '1991-12-19', 'Científico', 487),
(61, '2005-06-05', NULL, NULL, 230),
(62, '1970-10-09', '1976-01-24', 'Médico', 161),
(63, '1970-01-09', '1972-02-06', NULL, 510),
(64, '1973-01-20', '1976-11-14', NULL, 755),
(65, '2007-10-30', '2012-05-31', 'Científico', 72),
(66, '1994-08-21', '1996-08-08', 'Científico', 143),
(67, '1981-06-25', NULL, 'Soldado', 214),
(68, '1978-08-13', '1982-07-03', 'Capitán', 324),
(69, '1970-01-05', NULL, 'Científico', 73),
(70, '1984-06-23', '1986-08-04', 'Técnico de comunicaciones', 210),
(71, '1981-01-20', '1985-01-12', 'Científico', 600),
(72, '1977-06-28', NULL, 'Soldado', 70),
(73, '1971-05-26', NULL, 'Capitán', 772),
(74, '1980-12-01', NULL, 'Médico', 687),
(75, '1982-07-04', '1983-11-26', 'Capitán', 8),
(76, '1981-07-21', '1985-04-12', 'Técnico de comunicaciones', 209),
(77, '2002-12-16', NULL, NULL, 580),
(78, '1999-11-07', NULL, NULL, 164),
(79, '1974-02-23', '1978-10-01', 'Científico', 537),
(80, '1978-10-18', '1982-03-22', 'Médico', 368),
(81, '1980-04-04', NULL, 'Médico', 347),
(82, '1970-11-06', '1973-11-03', 'Médico', 387),
(83, '2014-10-21', '2019-05-01', 'Médico', 63),
(84, '1988-11-16', NULL, 'Científico', 540),
(85, '2010-01-18', '2014-05-15', 'Científico', 186),
(86, '2002-10-20', NULL, 'Médico', 735),
(87, '2011-08-23', '2012-09-29', 'Soldado', 776),
(88, '1988-05-13', '1990-04-20', 'Técnico de comunicaciones', 370),
(89, '1981-11-11', '1986-06-11', 'Científico', 160),
(90, '2018-10-23', NULL, 'Soldado', 361),
(91, '2003-12-22', NULL, 'Médico', 576),
(92, '1999-03-24', '2004-01-10', 'Técnico de comunicaciones', 230),
(93, '1975-02-25', NULL, 'Capitán', 686),
(94, '2000-08-06', NULL, 'Soldado', 471),
(95, '2009-09-28', '2011-01-16', 'Soldado', 302),
(96, '2001-08-23', NULL, 'Soldado', 242),
(97, '1995-07-05', NULL, 'Científico', 731),
(98, '2017-01-14', NULL, 'Capitán', 2),
(99, '1970-01-03', NULL, 'Médico', 149),
(100, '1972-09-10', NULL, NULL, 86),
(101, '1989-10-09', '1993-04-25', 'Técnico de comunicaciones', 235),
(102, '1988-04-19', '1988-06-01', 'Técnico de comunicaciones', 212),
(103, '1974-03-05', '1974-11-05', 'Técnico de comunicaciones', 555),
(104, '1986-03-03', NULL, 'Científico', 437),
(105, '2007-03-17', NULL, 'Médico', 268),
(106, '1970-01-09', NULL, 'Capitán', 100),
(107, '1990-06-04', NULL, 'Médico', 260),
(108, '1970-04-06', '1975-05-05', 'Técnico de comunicaciones', 763),
(109, '1970-11-07', '1974-04-11', 'Soldado', 524),
(110, '1970-01-06', '1974-07-13', 'Capitán', 9),
(111, '1970-01-02', NULL, NULL, 775),
(112, '1990-10-24', '1995-04-09', 'Médico', 4),
(113, '1986-08-23', NULL, 'Científico', 698),
(114, '1970-01-06', '1972-04-16', 'Soldado', 445),
(115, '1984-11-16', '1989-04-27', 'Técnico de comunicaciones', 2),
(116, '1973-10-27', '1976-10-31', 'Capitán', 785),
(117, '1988-04-21', '1991-10-23', 'Capitán', 174),
(118, '1984-11-13', '1984-11-23', 'Científico', 81),
(119, '1991-09-12', NULL, 'Médico', 77),
(120, '1971-04-24', '1975-09-05', 'Soldado', 205),
(121, '1981-07-30', '1986-07-04', 'Soldado', 434),
(122, '2002-04-03', NULL, 'Soldado', 485),
(123, '1989-05-28', '1992-02-17', NULL, 677),
(124, '1970-03-27', '1974-11-07', 'Capitán', 633),
(125, '1988-04-17', '1988-06-16', 'Soldado', 269),
(126, '1970-01-07', NULL, 'Técnico de comunicaciones', 570),
(127, '1970-01-03', '1974-12-06', 'Soldado', 458),
(128, '1975-07-04', '1980-05-03', 'Soldado', 554),
(129, '2014-06-16', NULL, 'Científico', 4),
(130, '1983-09-17', '1985-12-07', 'Capitán', 754),
(131, '1995-10-19', NULL, 'Soldado', 84),
(132, '2017-08-10', '2017-09-28', 'Científico', 549),
(133, '1995-03-06', NULL, 'Científico', 185),
(134, '1989-12-03', NULL, 'Técnico de comunicaciones', 281),
(135, '2006-01-24', '2008-03-27', 'Soldado', 499),
(136, '1972-07-22', NULL, 'Científico', 401),
(137, '1970-01-03', '1970-02-18', 'Científico', 360),
(138, '1970-09-10', NULL, NULL, 2),
(139, '2013-04-22', NULL, 'Científico', 251),
(140, '1970-01-07', NULL, 'Científico', 4),
(141, '1978-12-11', NULL, 'Capitán', 785),
(142, '1970-02-02', '1970-02-16', 'Técnico de comunicaciones', 428),
(143, '1970-01-02', '1972-08-20', 'Médico', 249),
(144, '1989-04-03', '1989-12-13', 'Técnico de comunicaciones', 152),
(145, '1970-01-03', NULL, NULL, 1),
(146, '1977-09-29', '1983-01-13', 'Soldado', 102),
(147, '1972-03-04', '1973-06-09', 'Capitán', 67),
(148, '1970-04-10', '1971-03-28', 'Capitán', 438),
(149, '1970-01-22', NULL, NULL, 164),
(150, '1976-08-17', '1980-01-02', NULL, 176),
(151, '2005-04-27', '2007-09-19', 'Soldado', 186),
(152, '1999-06-16', NULL, 'Soldado', 468),
(153, '1992-05-01', '1996-01-13', 'Capitán', 113),
(154, '2001-07-18', '2006-04-14', 'Técnico de comunicaciones', 100),
(155, '2012-12-12', '2017-05-24', 'Soldado', 19),
(156, '1981-11-09', '1983-10-15', 'Médico', 488),
(157, '1989-02-27', '1992-04-25', 'Capitán', 645),
(158, '1985-01-23', '1987-03-19', 'Técnico de comunicaciones', 451),
(159, '1970-01-07', '1971-04-27', 'Soldado', 91),
(160, '1972-05-24', NULL, 'Capitán', 59),
(161, '1993-09-07', NULL, 'Científico', 69),
(162, '1970-04-01', '1970-07-12', 'Soldado', 27),
(163, '2002-07-16', '2008-01-02', 'Científico', 427),
(164, '2016-02-04', NULL, 'Soldado', 114),
(165, '1981-12-17', NULL, 'Soldado', 299),
(166, '1972-06-17', '1974-11-19', 'Médico', 201),
(167, '1979-12-15', '1980-06-16', 'Científico', 105),
(168, '1993-06-13', '1996-12-28', 'Técnico de comunicaciones', 328),
(169, '2015-11-17', NULL, NULL, 579),
(170, '1986-06-13', '1989-10-23', 'Capitán', 417),
(171, '2016-07-20', '2017-06-06', 'Científico', 145),
(172, '2001-08-25', NULL, 'Médico', 682),
(173, '1970-01-08', NULL, 'Científico', 53),
(174, '1980-11-19', '1984-05-10', 'Soldado', 9),
(175, '2013-12-20', '2017-05-02', NULL, 605),
(176, '1995-06-06', NULL, 'Capitán', 95),
(177, '1997-02-20', NULL, 'Técnico de comunicaciones', 668),
(178, '1971-11-19', NULL, 'Médico', 5),
(179, '1971-03-12', NULL, 'Soldado', 684),
(180, '1996-09-08', NULL, 'Médico', 293),
(181, '1981-05-23', '1981-09-10', 'Soldado', 643),
(182, '1979-12-29', '1980-12-25', 'Capitán', 624),
(183, '1993-02-09', '1998-04-13', NULL, 145),
(184, '1970-01-07', NULL, 'Médico', 267),
(185, '1970-01-04', NULL, 'Médico', 3),
(186, '1972-06-03', '1973-01-27', NULL, 6),
(187, '1971-08-02', '1973-07-03', 'Técnico de comunicaciones', 94),
(188, '2005-08-06', '2009-06-18', 'Técnico de comunicaciones', 708),
(189, '2007-11-23', NULL, NULL, 269),
(190, '1970-01-03', NULL, 'Soldado', 91),
(191, '1972-04-28', '1976-04-13', 'Capitán', 452),
(192, '2008-10-02', '2012-12-03', 'Técnico de comunicaciones', 793),
(193, '1990-02-03', '1994-02-12', 'Técnico de comunicaciones', 331),
(194, '1989-01-14', NULL, NULL, 81),
(195, '2015-12-01', '2021-02-18', NULL, 28),
(196, '1986-06-12', NULL, 'Científico', 489),
(197, '2009-07-12', '2012-11-27', 'Técnico de comunicaciones', 1),
(198, '1970-07-12', NULL, 'Científico', 6),
(199, '2004-11-03', '2009-10-02', 'Técnico de comunicaciones', 124),
(200, '2004-09-07', '2008-01-22', 'Médico', 453),
(201, '1970-06-18', '1973-10-14', 'Soldado', 248),
(202, '1972-07-11', '1974-03-16', 'Capitán', 668),
(203, '1990-12-28', '1993-03-28', NULL, 648),
(204, '1971-08-04', NULL, 'Técnico de comunicaciones', 759),
(205, '1976-01-13', '1980-10-28', 'Capitán', 260),
(206, '1971-12-12', '1974-07-20', 'Técnico de comunicaciones', 64),
(207, '2013-08-10', NULL, 'Científico', 9),
(208, '2005-06-02', NULL, 'Capitán', 158),
(209, '2013-10-01', NULL, 'Médico', 3),
(210, '1990-08-01', '1993-06-28', 'Capitán', 598),
(211, '1978-06-24', '1981-03-21', 'Capitán', 477),
(212, '1970-01-01', NULL, 'Médico', 697),
(213, '2000-10-28', '2002-03-29', 'Médico', 20),
(214, '1974-04-24', '1977-04-21', 'Capitán', 499),
(215, '1993-01-10', '1998-05-11', 'Capitán', 670),
(216, '1983-12-31', '1985-01-04', 'Soldado', 81),
(217, '1970-01-04', '1970-01-22', 'Técnico de comunicaciones', 625),
(218, '1999-08-10', '2002-02-17', NULL, 317),
(219, '1986-07-22', NULL, 'Soldado', 117),
(220, '2008-12-07', NULL, 'Médico', 196),
(221, '2003-02-19', '2005-03-11', 'Técnico de comunicaciones', 3),
(222, '1984-09-10', NULL, 'Médico', 262),
(223, '1995-11-10', '1997-01-15', 'Soldado', 731),
(224, '2002-01-01', NULL, 'Científico', 144),
(225, '1987-12-02', '1992-03-29', NULL, 741),
(226, '2009-12-09', '2010-07-20', 'Soldado', 235),
(227, '2000-09-23', '2003-08-31', 'Científico', 440),
(228, '1970-04-09', '1974-05-29', 'Médico', 760),
(229, '1971-05-11', '1974-03-11', 'Capitán', 601),
(230, '2006-11-21', '2011-06-07', 'Capitán', 389),
(231, '1987-10-01', '1991-07-30', 'Capitán', 780),
(232, '2008-07-15', NULL, 'Soldado', 770),
(233, '1986-05-15', '1991-04-30', 'Soldado', 405),
(234, '1989-02-11', '1993-09-02', 'Soldado', 238),
(235, '1970-01-01', NULL, 'Soldado', 463),
(236, '2000-03-11', NULL, 'Técnico de comunicaciones', 592),
(237, '1974-09-01', '1979-07-30', 'Técnico de comunicaciones', 585),
(238, '1970-04-08', NULL, 'Médico', 7),
(239, '1970-01-07', NULL, 'Médico', 190),
(240, '1998-10-28', NULL, 'Técnico de comunicaciones', 383),
(241, '1992-12-24', NULL, 'Soldado', 551),
(242, '1970-09-28', NULL, 'Capitán', 417),
(243, '1970-01-06', '1970-12-17', 'Técnico de comunicaciones', 549),
(244, '1987-03-03', '1987-03-25', NULL, 394),
(245, '1975-05-05', NULL, 'Técnico de comunicaciones', 484),
(246, '2004-09-28', NULL, 'Médico', 529),
(247, '2005-12-08', '2006-07-16', 'Científico', 383),
(248, '2006-09-15', '2009-07-31', 'Científico', 132),
(249, '1977-02-22', '1980-10-23', 'Soldado', 766),
(250, '1970-01-07', '1972-12-18', 'Técnico de comunicaciones', 364),
(251, '1986-05-21', NULL, 'Médico', 70),
(252, '2013-05-19', NULL, 'Soldado', 388),
(253, '1971-02-20', NULL, NULL, 508),
(254, '1970-04-03', '1971-12-30', 'Capitán', 756),
(255, '1970-02-16', '1973-08-15', 'Científico', 150),
(256, '1976-09-05', '1979-09-30', 'Técnico de comunicaciones', 105),
(257, '1970-08-18', '1971-06-26', 'Científico', 32),
(258, '1970-01-10', '1970-04-11', 'Capitán', 369),
(259, '2008-01-17', '2011-04-11', 'Técnico de comunicaciones', 179),
(260, '1999-03-01', '2000-04-16', 'Soldado', 207),
(261, '1970-01-14', '1975-01-01', 'Capitán', 188),
(262, '1990-08-08', NULL, 'Técnico de comunicaciones', 360),
(263, '1970-01-20', '1975-05-08', NULL, 631),
(264, '1981-11-18', '1986-04-25', 'Capitán', 135),
(265, '1988-12-12', NULL, 'Capitán', 693),
(266, '1970-02-15', NULL, 'Capitán', 109),
(267, '2007-05-14', NULL, 'Técnico de comunicaciones', 31),
(268, '1970-04-30', '1973-12-05', 'Médico', 705),
(269, '1970-03-25', NULL, 'Médico', 8),
(270, '2017-02-01', '2020-06-11', 'Capitán', 358),
(271, '1970-01-03', '1974-03-28', 'Técnico de comunicaciones', 325),
(272, '2011-02-01', '2012-07-05', 'Técnico de comunicaciones', 629),
(273, '1974-01-04', NULL, 'Científico', 193),
(274, '1975-05-30', '1979-10-17', 'Científico', 66),
(275, '1996-05-15', '2000-07-11', 'Soldado', 190),
(276, '1974-06-07', '1977-08-21', 'Científico', 125),
(277, '1973-10-25', NULL, 'Soldado', 749),
(278, '1970-03-11', '1973-04-28', 'Científico', 613),
(279, '2006-11-22', NULL, 'Soldado', 119),
(280, '2003-10-27', '2009-02-14', 'Técnico de comunicaciones', 621),
(281, '2018-10-27', '2020-08-12', 'Científico', 570),
(282, '1982-03-20', '1983-04-04', 'Médico', 7),
(283, '1987-04-10', NULL, 'Capitán', 90),
(284, '1970-02-01', '1971-02-20', 'Científico', 779),
(285, '1996-07-28', '1998-08-05', 'Soldado', 69),
(286, '1989-05-14', NULL, 'Soldado', 403),
(287, '1970-01-10', NULL, 'Técnico de comunicaciones', 539),
(288, '1970-01-12', NULL, 'Capitán', 30),
(289, '1976-11-22', NULL, 'Capitán', 334),
(290, '1988-11-01', NULL, 'Médico', 655),
(291, '1995-05-04', '1995-12-28', 'Médico', 773),
(292, '1970-08-25', '1973-07-28', 'Soldado', 360),
(293, '1991-10-01', NULL, 'Médico', 96),
(294, '1970-06-26', '1975-01-26', 'Soldado', 711),
(295, '1975-04-19', NULL, 'Médico', 543),
(296, '1999-05-10', NULL, 'Científico', 523),
(297, '1970-01-01', NULL, 'Científico', 705),
(298, '1978-07-23', NULL, 'Capitán', 668),
(299, '1970-01-05', '1970-07-20', 'Científico', 444),
(300, '1970-01-13', '1974-12-25', 'Capitán', 257),
(301, '1970-01-02', NULL, 'Capitán', 35),
(302, '1970-08-28', NULL, 'Soldado', 166),
(303, '1972-08-01', '1972-11-10', 'Técnico de comunicaciones', 740),
(304, '2008-08-22', NULL, 'Capitán', 591),
(305, '1970-04-07', NULL, 'Soldado', 160),
(306, '1970-03-31', NULL, 'Científico', 747),
(307, '2008-06-11', NULL, 'Médico', 602),
(308, '1972-12-15', '1977-05-03', 'Médico', 230),
(309, '2014-02-12', '2016-01-26', 'Capitán', 9),
(310, '1983-04-09', NULL, 'Científico', 198),
(311, '1997-11-10', NULL, 'Soldado', 666),
(312, '1977-12-15', NULL, NULL, 135),
(313, '2014-03-19', NULL, 'Soldado', 422),
(314, '2001-12-23', NULL, 'Capitán', 134),
(315, '1970-01-08', NULL, NULL, 42),
(316, '1970-01-06', NULL, 'Científico', 142),
(317, '2016-03-19', '2016-11-15', 'Técnico de comunicaciones', 17),
(318, '1989-02-07', NULL, 'Técnico de comunicaciones', 496),
(319, '1970-01-09', NULL, 'Médico', 60),
(320, '1999-08-11', '1999-10-08', 'Técnico de comunicaciones', 485),
(321, '2017-04-30', NULL, 'Soldado', 333),
(322, '2011-10-14', '2014-12-12', NULL, 661),
(323, '1971-07-08', NULL, 'Médico', 624),
(324, '2016-10-05', '2021-09-06', 'Científico', 5),
(325, '1979-10-03', '1983-10-30', 'Médico', 126),
(326, '2012-09-15', NULL, 'Capitán', 361),
(327, '1978-07-13', NULL, 'Soldado', 287),
(328, '1987-12-14', NULL, 'Capitán', 453),
(329, '2009-03-23', NULL, 'Técnico de comunicaciones', 551),
(330, '2012-04-19', NULL, 'Soldado', 93),
(331, '1980-01-23', NULL, 'Médico', 768),
(332, '1993-07-05', '1997-01-03', 'Técnico de comunicaciones', 703),
(333, '1970-01-03', '1972-11-07', NULL, 424),
(334, '2015-05-01', NULL, 'Capitán', 2),
(335, '1978-01-29', '1978-02-11', 'Técnico de comunicaciones', 588),
(336, '1970-01-01', NULL, 'Médico', 312),
(337, '1971-04-28', NULL, 'Soldado', 119),
(338, '1997-05-17', NULL, 'Científico', 454),
(339, '2007-09-03', NULL, 'Médico', 158),
(340, '1970-04-10', NULL, 'Técnico de comunicaciones', 297),
(341, '2011-10-02', '2015-10-18', 'Médico', 442),
(342, '1984-10-09', NULL, 'Soldado', 6),
(343, '2005-01-27', '2006-03-31', 'Técnico de comunicaciones', 199),
(344, '2015-07-04', NULL, 'Técnico de comunicaciones', 81),
(345, '1990-02-08', NULL, 'Médico', 668),
(346, '2000-04-03', '2003-04-20', 'Capitán', 19),
(347, '1989-07-12', NULL, 'Soldado', 94),
(348, '1997-02-07', '2002-01-07', NULL, 449),
(349, '1970-08-01', '1971-02-04', 'Científico', 8),
(350, '2009-03-11', '2013-07-22', 'Científico', 491),
(351, '1986-04-16', '1989-03-06', 'Científico', 699),
(352, '1991-07-25', '1995-04-02', 'Científico', 357),
(353, '1978-11-21', NULL, 'Capitán', 296),
(354, '2009-03-20', '2012-10-28', 'Médico', 68),
(355, '1970-01-09', NULL, 'Capitán', 606),
(356, '2011-03-03', NULL, 'Técnico de comunicaciones', 265),
(357, '2018-04-21', '2022-12-15', 'Científico', 389),
(358, '2013-07-06', NULL, 'Técnico de comunicaciones', 3),
(359, '1993-05-03', NULL, 'Soldado', 488),
(360, '2013-06-30', NULL, 'Científico', 477),
(361, '1992-01-24', NULL, 'Médico', 458),
(362, '1995-08-26', '1999-10-14', 'Médico', 225),
(363, '1970-01-05', NULL, 'Capitán', 2),
(364, '1971-05-02', NULL, 'Médico', 79),
(365, '1982-11-15', NULL, 'Médico', 383),
(366, '2015-09-02', '2017-11-15', NULL, 440),
(367, '1970-11-28', '1972-09-22', 'Médico', 57),
(368, '1989-04-03', '1992-11-25', 'Técnico de comunicaciones', 1),
(369, '1984-12-05', '1990-01-14', 'Científico', 663),
(370, '1985-11-25', NULL, 'Soldado', 592),
(371, '1970-03-12', '1972-11-28', 'Científico', 660),
(372, '1981-05-16', '1985-03-21', 'Técnico de comunicaciones', 44),
(373, '1970-01-04', '1970-04-08', 'Científico', 17),
(374, '1979-12-10', NULL, 'Científico', 569),
(375, '1981-05-13', '1984-04-07', 'Técnico de comunicaciones', 9),
(376, '1991-07-08', '1992-12-05', 'Soldado', 90),
(377, '2001-03-04', '2004-06-09', 'Soldado', 163),
(378, '1997-04-10', '2000-12-31', 'Técnico de comunicaciones', 585),
(379, '2016-07-16', '2019-12-08', 'Científico', 39),
(380, '2001-12-29', '2003-02-16', 'Científico', 91),
(381, '1977-05-19', '1981-07-08', 'Médico', 3),
(382, '2013-08-18', '2014-01-19', 'Soldado', 751),
(383, '1970-01-06', '1970-04-23', 'Científico', 64),
(384, '1986-10-28', '1989-05-04', 'Técnico de comunicaciones', 34),
(385, '2015-06-11', '2018-02-26', 'Soldado', 391),
(386, '1987-03-21', NULL, 'Científico', 90),
(387, '1970-01-09', '1970-02-27', NULL, 3),
(388, '1985-01-19', '1988-03-02', 'Capitán', 392),
(389, '1970-10-07', '1971-11-19', 'Soldado', 16),
(390, '2010-10-15', NULL, 'Médico', 553),
(391, '1970-09-25', NULL, 'Técnico de comunicaciones', 214),
(392, '2007-09-07', '2007-11-22', 'Técnico de comunicaciones', 777),
(393, '1998-04-08', NULL, 'Soldado', 177),
(394, '1982-07-07', '1982-09-01', 'Científico', 25),
(395, '2010-04-05', NULL, 'Médico', 223),
(396, '1972-08-06', '1978-01-22', 'Científico', 443),
(397, '2015-06-15', NULL, 'Médico', 13),
(398, '1978-11-04', NULL, 'Médico', 276),
(399, '1991-04-16', NULL, 'Capitán', 792),
(400, '1970-03-19', '1975-02-19', 'Técnico de comunicaciones', 65),
(401, '2014-09-14', '2015-08-01', NULL, 650),
(402, '1974-08-03', '1978-10-28', 'Médico', 209),
(403, '2009-03-17', '2012-12-24', 'Científico', 222),
(404, '1996-02-07', '1997-07-12', 'Técnico de comunicaciones', 455),
(405, '1970-03-15', NULL, 'Capitán', 24),
(406, '2000-09-28', NULL, 'Capitán', 413),
(407, '1983-09-13', '1984-05-16', NULL, 330),
(408, '1988-04-12', NULL, 'Capitán', 437),
(409, '2007-01-15', NULL, NULL, 516),
(410, '1977-05-26', '1979-10-18', 'Médico', 9),
(411, '1987-07-17', '1991-11-11', 'Soldado', 281),
(412, '1999-04-19', '2002-09-01', 'Técnico de comunicaciones', 84),
(413, '2001-08-11', NULL, 'Capitán', 671),
(414, '2015-02-05', '2020-04-30', 'Técnico de comunicaciones', 463),
(415, '1987-03-15', '1991-05-30', 'Capitán', 606),
(416, '2017-07-02', '2018-11-16', 'Soldado', 614),
(417, '1989-10-09', NULL, 'Científico', 239),
(418, '1979-03-27', NULL, 'Capitán', 514),
(419, '1982-07-17', NULL, 'Soldado', 723),
(420, '1996-08-06', NULL, 'Médico', 275),
(421, '1972-01-08', NULL, NULL, 417),
(422, '1988-03-26', '1988-08-06', 'Soldado', 667),
(423, '1986-10-05', '1990-07-31', 'Soldado', 704),
(424, '1970-01-19', NULL, 'Soldado', 534),
(425, '2007-06-30', '2012-08-09', 'Científico', 95),
(426, '2001-10-15', NULL, NULL, 26),
(427, '1979-04-08', '1981-04-11', 'Médico', 603),
(428, '1974-02-17', NULL, NULL, 139),
(429, '1970-02-25', '1973-11-18', 'Técnico de comunicaciones', 102),
(430, '1970-04-08', NULL, 'Científico', 59),
(431, '1997-10-04', '1998-03-12', 'Soldado', 188),
(432, '1970-01-09', '1970-08-03', 'Técnico de comunicaciones', 617),
(433, '2017-08-11', '2018-05-15', 'Soldado', 382),
(434, '2007-02-06', NULL, 'Capitán', 733),
(435, '1998-12-02', '2004-04-03', 'Médico', 5),
(436, '1999-08-18', NULL, 'Capitán', 268),
(437, '1994-01-13', '1997-04-13', 'Soldado', 104),
(438, '1973-07-29', '1975-11-24', 'Científico', 702),
(439, '1989-04-23', '1990-10-29', 'Capitán', 556),
(440, '1998-08-20', NULL, 'Capitán', 640),
(441, '2003-11-14', NULL, 'Técnico de comunicaciones', 172),
(442, '1972-02-03', NULL, 'Médico', 534),
(443, '2000-02-28', '2003-08-28', 'Técnico de comunicaciones', 339),
(444, '1972-03-25', NULL, 'Médico', 238),
(445, '1973-08-19', '1975-01-22', 'Científico', 567),
(446, '2004-07-13', NULL, 'Técnico de comunicaciones', 552),
(447, '2014-05-20', NULL, 'Soldado', 212),
(448, '1985-03-02', NULL, NULL, 84),
(449, '2013-09-17', '2013-09-26', 'Médico', 4),
(450, '2017-03-21', '2019-04-15', 'Médico', 228),
(451, '2014-07-27', NULL, 'Capitán', 35),
(452, '1970-01-07', NULL, 'Soldado', 784),
(453, '1987-10-08', NULL, 'Soldado', 167),
(454, '1971-10-18', '1974-06-25', 'Capitán', 794),
(455, '1970-01-02', '1970-09-09', 'Capitán', 9),
(456, '1971-07-25', '1972-06-21', 'Capitán', 6),
(457, '1999-05-12', '2003-04-21', 'Técnico de comunicaciones', 366),
(458, '1970-01-08', '1971-12-09', 'Médico', 549),
(459, '2017-12-03', '2020-02-03', 'Soldado', 330),
(460, '1994-04-29', '1997-05-23', NULL, 664),
(461, '1971-05-17', '1976-08-14', 'Técnico de comunicaciones', 637),
(462, '1970-01-25', '1972-10-21', 'Soldado', 298),
(463, '2014-05-07', '2015-11-09', 'Médico', 516),
(464, '1995-08-27', '1999-05-31', 'Médico', 26),
(465, '1972-07-01', NULL, 'Capitán', 1),
(466, '1980-04-24', '1983-11-03', 'Técnico de comunicaciones', 324),
(467, '1995-10-17', '2001-01-01', 'Capitán', 192),
(468, '1977-12-05', '1980-01-29', 'Capitán', 308),
(469, '1981-06-30', NULL, 'Capitán', 323),
(470, '1973-08-07', NULL, 'Científico', 646),
(471, '1999-07-14', NULL, 'Médico', 342),
(472, '1992-04-09', NULL, 'Soldado', 152),
(473, '2014-04-16', '2018-02-21', 'Capitán', 777),
(474, '2000-10-26', NULL, 'Capitán', 346),
(475, '1970-01-12', NULL, 'Médico', 220),
(476, '1994-05-11', '1997-12-03', 'Médico', 524),
(477, '2001-01-26', '2005-04-26', 'Científico', 202),
(478, '1992-06-01', NULL, 'Científico', 475),
(479, '1996-08-31', '1998-10-05', 'Médico', 517),
(480, '1993-01-30', '1997-10-30', 'Científico', 4),
(481, '2007-09-18', '2009-07-01', 'Técnico de comunicaciones', 411),
(482, '2002-04-11', NULL, 'Capitán', 17),
(483, '2015-07-01', NULL, 'Capitán', 151),
(484, '2000-01-23', '2001-05-19', 'Capitán', 550),
(485, '1981-09-25', '1984-04-14', 'Médico', 307),
(486, '1995-03-11', NULL, 'Médico', 769),
(487, '1997-05-23', '1997-11-13', 'Capitán', 550),
(488, '2008-01-06', NULL, 'Científico', 343),
(489, '1978-11-20', NULL, 'Capitán', 550),
(490, '1982-09-20', NULL, 'Capitán', 720),
(491, '1970-02-06', NULL, NULL, 227),
(492, '1988-07-22', '1992-09-21', 'Científico', 555),
(493, '1971-04-09', NULL, 'Científico', 791),
(494, '1970-01-02', '1970-02-03', 'Técnico de comunicaciones', 108),
(495, '1991-04-20', NULL, 'Capitán', 342),
(496, '1998-12-19', NULL, 'Científico', 607),
(497, '1972-05-05', '1975-03-03', 'Capitán', 4),
(498, '1970-04-06', '1971-04-29', 'Médico', 187),
(499, '2006-01-04', '2008-08-17', 'Científico', 472),
(500, '1974-02-05', NULL, 'Técnico de comunicaciones', 241),
(501, '2003-04-07', NULL, 'Técnico de comunicaciones', 379),
(502, '2018-11-17', '2021-05-15', 'Científico', 511),
(503, '1970-03-09', '1970-09-07', 'Soldado', 2),
(504, '1980-05-29', '1982-09-11', 'Soldado', 422),
(505, '1970-04-07', NULL, 'Capitán', 112),
(506, '1990-12-25', '1991-02-19', 'Médico', 9),
(507, '1989-11-02', NULL, 'Médico', 393),
(508, '1982-03-05', NULL, NULL, 431),
(509, '1970-03-13', NULL, 'Soldado', 136),
(510, '2005-07-19', NULL, 'Científico', 494),
(511, '1971-08-19', NULL, 'Capitán', 602),
(512, '1970-01-05', '1971-01-30', 'Médico', 173),
(513, '2000-08-24', '2002-05-20', 'Científico', 120),
(514, '1976-01-24', '1979-09-30', 'Científico', 613),
(515, '2007-02-28', NULL, 'Capitán', 28),
(516, '1983-11-08', '1984-02-01', 'Capitán', 479),
(517, '1971-06-27', NULL, 'Científico', 70),
(518, '1982-04-22', NULL, 'Soldado', 375),
(519, '1970-03-15', NULL, 'Técnico de comunicaciones', 554),
(520, '1995-06-12', '2000-11-29', 'Soldado', 546),
(521, '1970-06-08', NULL, 'Capitán', 539),
(522, '1970-01-02', NULL, 'Soldado', 238),
(523, '1984-06-13', NULL, 'Soldado', 389),
(524, '1973-06-13', '1974-05-19', 'Capitán', 588),
(525, '1970-02-06', NULL, 'Médico', 99),
(526, '1992-07-12', '1993-05-20', 'Capitán', 418),
(527, '1990-12-15', NULL, 'Médico', 665),
(528, '1985-03-13', '1987-04-18', 'Técnico de comunicaciones', 707),
(529, '1988-04-19', NULL, 'Científico', 26),
(530, '1994-06-29', '1998-06-08', 'Técnico de comunicaciones', 6),
(531, '1997-08-11', '1998-11-24', 'Médico', 37),
(532, '2008-12-26', '2013-08-27', 'Científico', 436),
(533, '1976-06-15', '1977-02-03', 'Soldado', 3),
(534, '1970-11-10', '1973-03-25', 'Soldado', 252),
(535, '1975-11-17', NULL, 'Médico', 79),
(536, '1991-08-10', NULL, 'Soldado', 163),
(537, '1970-11-21', NULL, 'Técnico de comunicaciones', 556),
(538, '1987-09-01', '1989-12-16', NULL, 544),
(539, '1976-05-27', NULL, 'Soldado', 351),
(540, '1993-04-23', '1993-11-06', 'Capitán', 198),
(541, '2015-11-17', NULL, 'Científico', 64),
(542, '2004-11-14', NULL, 'Soldado', 328),
(543, '2006-10-12', '2010-10-30', 'Científico', 260),
(544, '2010-10-05', NULL, 'Soldado', 435),
(545, '1970-03-26', NULL, 'Médico', 423),
(546, '1970-01-04', '1970-08-26', 'Médico', 398),
(547, '2002-09-07', NULL, 'Capitán', 97),
(548, '1992-09-26', '1993-07-17', 'Soldado', 79),
(549, '1971-10-24', '1972-04-19', 'Capitán', 441),
(550, '1977-11-21', '1983-02-06', 'Capitán', 417),
(551, '1974-01-26', '1976-08-23', 'Técnico de comunicaciones', 663),
(552, '2000-09-30', NULL, 'Capitán', 50),
(553, '1992-08-04', '1996-05-26', 'Soldado', 394),
(554, '1970-01-28', NULL, 'Soldado', 372),
(555, '2000-12-21', '2003-08-26', 'Capitán', 185),
(556, '2017-01-10', NULL, 'Médico', 218),
(557, '2009-05-04', '2012-11-05', 'Científico', 398),
(558, '2015-12-08', NULL, 'Soldado', 709),
(559, '1970-01-08', '1973-05-09', 'Capitán', 271),
(560, '2010-11-18', '2014-01-09', 'Soldado', 7),
(561, '1970-01-07', '1975-01-01', NULL, 36),
(562, '1972-09-15', '1977-01-06', 'Médico', 426),
(563, '2004-09-05', NULL, 'Capitán', 286),
(564, '2008-11-16', '2013-09-18', 'Técnico de comunicaciones', 199),
(565, '1976-12-12', '1979-03-10', 'Científico', 670),
(566, '1981-12-28', NULL, 'Capitán', 483),
(567, '1987-05-31', NULL, 'Técnico de comunicaciones', 290),
(568, '2008-11-09', NULL, NULL, 347),
(569, '1990-09-07', '1994-06-04', 'Capitán', 735),
(570, '1970-03-31', '1973-05-21', 'Técnico de comunicaciones', 137),
(571, '2003-09-13', '2004-09-14', 'Científico', 244),
(572, '1973-05-12', NULL, 'Capitán', 66),
(573, '2006-09-16', NULL, 'Médico', 323),
(574, '1998-04-29', NULL, 'Capitán', 548),
(575, '1992-11-24', '1996-12-04', 'Soldado', 153),
(576, '1980-07-04', NULL, 'Técnico de comunicaciones', 596),
(577, '1989-11-21', NULL, 'Científico', 220),
(578, '1972-09-30', '1976-06-24', 'Científico', 474),
(579, '1991-04-06', '1993-12-03', 'Capitán', 609),
(580, '1996-09-22', NULL, NULL, 87),
(581, '1991-10-15', '1996-07-14', 'Científico', 227),
(582, '1987-03-25', '1992-03-25', 'Soldado', 796),
(583, '2017-01-22', '2020-08-27', 'Capitán', 172),
(584, '1970-04-10', '1970-07-15', 'Técnico de comunicaciones', 435),
(585, '2015-02-25', NULL, NULL, 750),
(586, '1984-03-26', '1989-02-25', 'Médico', 535),
(587, '1982-10-29', '1985-06-04', 'Capitán', 25),
(588, '2011-10-25', '2017-01-25', 'Soldado', 4),
(589, '1982-12-16', '1986-12-01', 'Capitán', 261),
(590, '2015-08-02', NULL, 'Soldado', 1),
(591, '1982-09-04', NULL, 'Soldado', 98),
(592, '2003-11-27', '2004-02-03', 'Soldado', 306),
(593, '1987-08-26', NULL, 'Científico', 348),
(594, '2016-11-01', NULL, 'Científico', 339),
(595, '1970-01-10', NULL, 'Capitán', 193),
(596, '2007-12-07', '2011-11-28', 'Capitán', 434),
(597, '1970-03-11', '1974-03-03', 'Científico', 33),
(598, '1971-09-23', '1972-08-16', 'Soldado', 148),
(599, '1978-04-23', '1981-09-19', 'Técnico de comunicaciones', 639),
(600, '1989-09-20', '1992-07-26', 'Científico', 296),
(601, '2001-01-18', NULL, 'Soldado', 292),
(602, '1974-06-07', NULL, 'Soldado', 5),
(603, '1986-02-18', '1990-10-31', 'Médico', 4),
(604, '1991-03-04', NULL, 'Científico', 68),
(605, '1971-11-24', '1974-06-29', 'Capitán', 5),
(606, '1983-04-16', NULL, 'Médico', 82),
(607, '1991-02-16', '1991-05-26', NULL, 705),
(608, '1989-05-18', '1994-05-29', 'Científico', 717),
(609, '1999-12-30', '2004-08-29', 'Científico', 89),
(610, '1994-07-06', '1994-10-22', 'Científico', 610),
(611, '1995-12-09', '1995-12-26', 'Médico', 72),
(612, '2007-10-20', NULL, 'Técnico de comunicaciones', 215),
(613, '2017-09-07', NULL, 'Capitán', 209),
(614, '1975-11-27', '1979-02-27', 'Médico', 551),
(615, '2001-05-05', NULL, 'Soldado', 7),
(616, '1986-07-27', '1989-05-08', 'Médico', 147),
(617, '2015-08-05', '2019-06-30', 'Médico', 417),
(618, '2011-05-23', '2013-01-01', 'Soldado', 67),
(619, '2014-05-06', '2017-01-03', 'Capitán', 296),
(620, '1972-02-09', '1977-04-05', 'Científico', 644),
(621, '1970-01-09', NULL, 'Soldado', 20),
(622, '1970-01-05', '1971-08-18', 'Médico', 272),
(623, '2004-12-26', '2009-02-06', 'Científico', 243),
(624, '1974-06-24', '1974-11-28', 'Médico', 412),
(625, '1970-03-03', '1970-09-01', 'Capitán', 501),
(626, '2002-02-07', '2005-08-09', 'Científico', 47),
(627, '1970-01-09', '1972-03-06', 'Capitán', 450),
(628, '2004-08-02', NULL, 'Capitán', 300),
(629, '1971-07-31', '1973-04-17', 'Soldado', 761),
(630, '1982-11-05', '1985-07-05', 'Técnico de comunicaciones', 561),
(631, '2015-02-05', NULL, 'Científico', 469),
(632, '1970-02-19', NULL, 'Soldado', 606),
(633, '1970-01-06', NULL, 'Soldado', 20),
(634, '1978-09-20', '1984-03-11', 'Científico', 134),
(635, '1979-05-25', '1983-04-18', NULL, 160),
(636, '1979-06-05', NULL, 'Científico', 733),
(637, '1993-06-11', '1994-05-07', 'Soldado', 563),
(638, '1981-02-05', NULL, 'Médico', 638),
(639, '2004-08-29', NULL, 'Técnico de comunicaciones', 103),
(640, '1978-05-08', NULL, 'Capitán', 563),
(641, '2001-06-13', NULL, 'Técnico de comunicaciones', 28),
(642, '1981-12-14', '1984-05-02', 'Capitán', 440),
(643, '1972-10-29', '1973-07-31', 'Técnico de comunicaciones', 548),
(644, '1997-12-07', NULL, 'Técnico de comunicaciones', 95),
(645, '1977-01-16', '1979-04-02', 'Científico', 238),
(646, '1972-05-26', '1973-11-21', 'Capitán', 689),
(647, '1970-01-04', NULL, 'Científico', 420),
(648, '2005-04-12', NULL, 'Técnico de comunicaciones', 42),
(649, '1995-02-23', '2000-02-28', 'Médico', 74),
(650, '1971-02-19', '1974-08-10', 'Médico', 289),
(651, '1990-02-14', '1993-06-29', NULL, 703),
(652, '1994-10-14', '1999-10-08', NULL, 472),
(653, '1996-06-01', NULL, 'Técnico de comunicaciones', 356),
(654, '1970-01-16', '1974-04-10', 'Soldado', 85),
(655, '2004-10-16', '2009-10-18', 'Médico', 566),
(656, '1993-10-03', NULL, 'Capitán', 598),
(657, '2016-04-09', '2016-09-20', 'Médico', 487),
(658, '2012-08-28', '2014-02-04', 'Científico', 93),
(659, '2014-09-14', '2019-07-26', 'Técnico de comunicaciones', 778),
(660, '1970-01-07', NULL, 'Científico', 507),
(661, '1994-04-07', '1999-06-19', 'Médico', 311),
(662, '1997-07-09', '2002-09-10', 'Científico', 310),
(663, '2008-05-25', '2012-12-23', 'Soldado', 542),
(664, '2013-11-17', NULL, 'Técnico de comunicaciones', 557),
(665, '2000-12-21', '2004-01-08', 'Científico', 73),
(666, '1985-12-07', NULL, 'Científico', 2),
(667, '2015-08-09', '2016-12-13', 'Soldado', 345),
(668, '1979-03-10', '1982-06-28', 'Médico', 764),
(669, '2006-08-11', NULL, 'Soldado', 22),
(670, '2000-01-26', '2001-06-02', 'Científico', 205),
(671, '1982-08-22', '1984-07-15', 'Capitán', 371),
(672, '1971-04-08', NULL, 'Médico', 752),
(673, '2002-07-07', NULL, 'Técnico de comunicaciones', 637),
(674, '2015-09-20', NULL, 'Médico', 21),
(675, '1995-11-05', '1997-12-20', NULL, 65),
(676, '1970-01-04', '1974-05-14', NULL, 39),
(677, '2016-12-08', '2018-05-07', 'Científico', 30),
(678, '1977-10-26', '1978-07-31', 'Capitán', 273),
(679, '2015-10-27', NULL, 'Médico', 539),
(680, '1997-04-07', '2002-07-24', 'Médico', 543),
(681, '2009-05-21', NULL, 'Científico', 43),
(682, '2016-03-27', '2021-07-19', 'Soldado', 750),
(683, '1983-07-26', '1988-06-17', 'Técnico de comunicaciones', 209),
(684, '2010-02-27', NULL, 'Médico', 306),
(685, '2007-03-14', '2008-04-26', 'Científico', 5),
(686, '1972-05-11', NULL, 'Técnico de comunicaciones', 767),
(687, '1985-08-24', '1987-11-04', 'Científico', 232),
(688, '2017-03-22', '2020-03-03', 'Capitán', 314),
(689, '1997-03-21', '2001-05-30', 'Médico', 90),
(690, '1992-12-09', NULL, 'Científico', 197),
(691, '1978-10-19', '1983-09-29', 'Capitán', 6),
(692, '1972-10-06', NULL, 'Capitán', 74),
(693, '2007-05-15', '2007-08-27', 'Médico', 95),
(694, '2011-02-19', '2013-04-17', 'Soldado', 8),
(695, '2013-05-04', NULL, 'Médico', 105),
(696, '1980-07-06', NULL, 'Técnico de comunicaciones', 38),
(697, '1989-05-20', '1991-07-20', 'Capitán', 461),
(698, '1970-01-10', '1973-07-14', 'Técnico de comunicaciones', 743),
(699, '1975-09-10', NULL, 'Científico', 496),
(700, '2015-01-06', '2019-06-10', 'Técnico de comunicaciones', 38),
(701, '2014-01-29', '2015-11-27', 'Científico', 85),
(702, '1970-04-07', NULL, NULL, 313),
(703, '1970-02-15', NULL, 'Soldado', 302),
(704, '1985-11-17', '1988-12-08', 'Médico', 563),
(705, '1970-01-09', '1973-09-13', NULL, 38),
(706, '1970-03-18', NULL, 'Técnico de comunicaciones', 456),
(707, '1995-01-05', '1998-10-06', NULL, 779),
(708, '2000-01-06', '2001-10-15', 'Científico', 454),
(709, '2013-12-26', '2014-03-21', 'Técnico de comunicaciones', 535),
(710, '1993-10-14', NULL, 'Técnico de comunicaciones', 196),
(711, '1995-09-25', '2000-06-22', 'Científico', 312),
(712, '1987-12-18', '1991-05-15', 'Médico', 366),
(713, '1999-03-24', '2001-07-24', NULL, 111),
(714, '1991-07-30', NULL, 'Científico', 509),
(715, '1992-03-16', '1994-04-14', 'Médico', 743),
(716, '2008-01-22', '2013-01-31', 'Científico', 207),
(717, '1987-12-02', '1988-06-01', NULL, 234),
(718, '2016-08-04', '2021-03-10', 'Técnico de comunicaciones', 702),
(719, '1999-09-12', NULL, 'Científico', 223),
(720, '1970-01-02', '1970-12-20', 'Científico', 655),
(721, '2003-01-06', '2005-10-13', NULL, 588),
(722, '2018-03-08', '2021-08-11', NULL, 784),
(723, '1985-04-19', NULL, 'Técnico de comunicaciones', 248),
(724, '1991-12-10', NULL, 'Capitán', 49),
(725, '1970-01-10', NULL, 'Capitán', 419),
(726, '1979-10-18', NULL, 'Científico', 727),
(727, '2013-05-20', NULL, 'Técnico de comunicaciones', 781),
(728, '1970-01-01', '1970-02-25', 'Científico', 310),
(729, '1970-08-10', '1971-09-20', 'Técnico de comunicaciones', 187),
(730, '1972-04-06', '1977-07-16', 'Capitán', 580),
(731, '1988-02-18', NULL, NULL, 348),
(732, '2006-01-22', '2009-03-21', 'Médico', 767),
(733, '1995-03-29', NULL, 'Técnico de comunicaciones', 9),
(734, '1981-09-04', NULL, 'Médico', 681),
(735, '1999-07-15', '2003-03-11', 'Técnico de comunicaciones', 520),
(736, '1991-11-30', '1994-08-11', 'Científico', 588),
(737, '1992-09-21', '1996-07-31', NULL, 454),
(738, '2010-11-18', NULL, 'Soldado', 165),
(739, '1980-09-26', NULL, NULL, 175),
(740, '1970-01-04', '1973-12-19', 'Científico', 173),
(741, '1970-03-03', NULL, 'Científico', 555),
(742, '2001-11-13', NULL, NULL, 625),
(743, '1983-02-11', '1983-07-06', 'Soldado', 341),
(744, '1991-03-17', NULL, NULL, 197),
(745, '1974-02-02', '1976-04-19', 'Capitán', 793),
(746, '1988-10-11', NULL, 'Soldado', 9),
(747, '1986-11-30', NULL, 'Técnico de comunicaciones', 331),
(748, '1970-01-09', NULL, 'Médico', 160),
(749, '1996-12-08', NULL, 'Científico', 763),
(750, '1988-02-29', NULL, 'Técnico de comunicaciones', 471),
(751, '1980-04-13', '1982-03-26', NULL, 554),
(752, '2011-01-08', NULL, 'Médico', 58),
(753, '2009-10-09', NULL, 'Capitán', 103),
(754, '2004-12-23', '2007-03-09', 'Capitán', 35),
(755, '1997-07-05', '1999-08-02', NULL, 436),
(756, '1972-12-09', '1978-01-15', 'Capitán', 457),
(757, '1980-01-17', '1981-07-18', NULL, 723),
(758, '2011-09-22', NULL, 'Capitán', 522),
(759, '2017-08-26', NULL, 'Soldado', 457),
(760, '1987-05-23', '1989-04-10', 'Científico', 293),
(761, '1970-04-02', '1971-01-02', 'Técnico de comunicaciones', 231),
(762, '2003-09-23', NULL, 'Capitán', 605),
(763, '2013-07-08', '2014-07-28', 'Soldado', 325),
(764, '1987-06-09', '1989-12-13', 'Científico', 6),
(765, '1970-03-26', NULL, 'Científico', 129),
(766, '1974-03-16', NULL, 'Científico', 739),
(767, '1972-09-08', '1973-10-27', 'Soldado', 592),
(768, '1975-11-26', '1978-05-21', 'Científico', 522),
(769, '1971-03-17', '1975-11-30', 'Médico', 191),
(770, '1970-02-22', '1973-08-09', 'Soldado', 227),
(771, '1972-05-28', '1973-07-14', 'Capitán', 421),
(772, '2004-09-24', '2008-04-04', 'Soldado', 167),
(773, '2018-01-29', '2019-09-04', 'Soldado', 456),
(774, '1981-06-02', NULL, 'Científico', 147),
(775, '2007-07-06', '2008-08-01', 'Médico', 484),
(776, '2013-01-17', NULL, 'Médico', 692),
(777, '1983-12-02', NULL, 'Capitán', 600),
(778, '2010-09-18', '2014-05-24', 'Médico', 7),
(779, '1971-05-27', '1976-09-19', 'Científico', 722),
(780, '1970-01-13', '1970-12-06', NULL, 643),
(781, '1970-01-02', NULL, 'Médico', 565),
(782, '1995-04-16', '1997-07-27', 'Científico', 412),
(783, '1971-05-14', '1973-09-30', 'Médico', 656),
(784, '2016-05-15', NULL, 'Capitán', 29),
(785, '1970-03-07', '1972-02-23', 'Científico', 341),
(786, '1982-02-26', '1983-06-06', 'Científico', 7),
(787, '1982-06-29', NULL, 'Científico', 375),
(788, '2015-12-14', '2020-01-17', NULL, 52),
(789, '1970-02-07', '1974-11-09', 'Capitán', 426),
(790, '2016-02-15', '2019-07-30', 'Capitán', 704),
(791, '1972-01-29', NULL, 'Soldado', 503),
(792, '1988-07-29', '1993-01-15', 'Capitán', 111),
(793, '2008-08-02', '2009-12-08', 'Técnico de comunicaciones', 559),
(794, '1985-06-03', NULL, 'Técnico de comunicaciones', 76),
(795, '2001-06-10', '2004-09-27', 'Técnico de comunicaciones', 347),
(796, '2016-04-11', '2018-05-10', 'Técnico de comunicaciones', 749),
(797, '2012-12-17', NULL, 'Soldado', 724),
(798, '1970-01-09', '1973-02-24', 'Científico', 146),
(799, '1995-08-18', '1998-12-01', 'Soldado', 316),
(800, '1998-12-25', NULL, 'Científico', 535),
(801, '1980-08-07', '1983-12-10', NULL, 246),
(802, '2012-10-25', '2014-01-29', 'Técnico de comunicaciones', 454),
(803, '1997-05-22', NULL, 'Técnico de comunicaciones', 202),
(804, '1970-01-09', '1972-07-31', 'Científico', 415),
(805, '1990-04-26', '1993-12-16', 'Capitán', 257),
(806, '1975-04-03', '1977-11-23', 'Técnico de comunicaciones', 1),
(807, '2011-12-04', NULL, 'Científico', 215),
(808, '2007-03-12', '2010-02-18', 'Científico', 762),
(809, '2011-12-01', NULL, 'Médico', 606),
(810, '1998-03-05', NULL, NULL, 295),
(811, '2012-08-03', '2015-06-30', 'Médico', 386),
(812, '1994-02-15', NULL, 'Técnico de comunicaciones', 369),
(813, '1985-10-08', '1986-10-07', 'Soldado', 74),
(814, '1972-09-17', '1976-07-07', 'Soldado', 696),
(815, '1970-04-10', '1974-08-22', 'Capitán', 255),
(816, '1979-10-25', '1980-11-13', 'Capitán', 241),
(817, '1970-01-06', NULL, 'Médico', 100),
(818, '1970-03-07', '1971-03-29', 'Médico', 291),
(819, '1987-02-13', '1991-09-30', 'Científico', 458),
(820, '1998-12-08', '2003-07-24', 'Médico', 7),
(821, '1970-08-02', NULL, 'Científico', 37),
(822, '1970-04-10', '1974-02-05', 'Médico', 370),
(823, '1972-05-21', '1977-09-27', 'Técnico de comunicaciones', 477),
(824, '1970-02-25', NULL, NULL, 73),
(825, '1977-10-22', '1981-09-20', 'Científico', 724),
(826, '1992-01-15', '1994-08-19', 'Capitán', 76),
(827, '2002-10-21', '2005-01-15', 'Médico', 568),
(828, '1970-01-01', '1970-02-13', 'Científico', 624),
(829, '1989-07-10', '1990-10-04', 'Capitán', 82),
(830, '2013-09-07', NULL, 'Capitán', 339),
(831, '1980-09-14', '1984-11-21', NULL, 305),
(832, '1971-11-11', '1975-12-15', 'Técnico de comunicaciones', 9),
(833, '2003-11-14', NULL, 'Capitán', 467),
(834, '2015-04-09', NULL, 'Médico', 424),
(835, '1994-10-06', '1999-11-07', 'Capitán', 494),
(836, '2010-01-13', '2013-04-22', 'Capitán', 756),
(837, '1975-04-23', '1979-07-04', 'Técnico de comunicaciones', 8),
(838, '1992-07-30', NULL, 'Técnico de comunicaciones', 88),
(839, '1987-11-08', NULL, 'Soldado', 7),
(840, '2000-07-18', NULL, 'Médico', 106),
(841, '1982-07-28', NULL, 'Médico', 270),
(842, '2004-12-18', '2007-04-21', 'Científico', 556),
(843, '2005-06-22', '2008-01-17', 'Científico', 182),
(844, '1970-03-04', NULL, NULL, 134),
(845, '1970-01-04', NULL, 'Técnico de comunicaciones', 187),
(846, '2014-02-14', NULL, NULL, 6),
(847, '1970-03-21', NULL, 'Científico', 30),
(848, '1986-05-13', NULL, 'Capitán', 210),
(849, '1981-04-16', NULL, 'Técnico de comunicaciones', 309),
(850, '2010-11-13', NULL, 'Técnico de comunicaciones', 238),
(851, '1988-11-03', '1993-04-06', 'Médico', 1),
(852, '1973-08-14', '1976-10-09', 'Médico', 354),
(853, '1971-04-02', '1973-02-17', NULL, 42),
(854, '1979-05-21', '1984-03-06', 'Científico', 657),
(855, '2013-07-01', '2014-12-05', 'Soldado', 657),
(856, '1970-01-05', '1970-02-07', 'Científico', 657),
(857, '1984-06-23', '1987-10-11', 'Soldado', 782),
(858, '1970-01-10', '1974-09-09', 'Médico', 698),
(859, '2016-06-05', NULL, 'Científico', 6),
(860, '1970-01-04', '1974-04-11', 'Técnico de comunicaciones', 599),
(861, '1983-03-19', '1985-02-20', 'Técnico de comunicaciones', 73),
(862, '1984-07-10', NULL, 'Capitán', 482),
(863, '1977-02-01', NULL, 'Médico', 120),
(864, '1970-01-07', '1973-09-09', 'Técnico de comunicaciones', 24),
(865, '1996-01-01', '1996-12-17', 'Técnico de comunicaciones', 546),
(866, '2010-08-28', NULL, 'Capitán', 510),
(867, '1979-06-23', NULL, 'Capitán', 1),
(868, '1979-11-13', '1981-09-25', 'Médico', 640),
(869, '1974-07-30', NULL, NULL, 625),
(870, '1995-05-11', '2000-08-28', 'Soldado', 101),
(871, '1976-07-12', '1981-04-30', 'Soldado', 598),
(872, '2002-05-01', '2005-02-21', NULL, 252),
(873, '2001-03-13', NULL, 'Científico', 133),
(874, '1970-01-04', NULL, 'Soldado', 797),
(875, '1998-08-23', '2002-08-23', 'Médico', 766),
(876, '2015-03-09', NULL, 'Médico', 68),
(877, '2002-08-28', '2006-06-11', 'Científico', 188),
(878, '1970-01-10', '1974-10-07', 'Médico', 475),
(879, '2007-07-08', '2008-01-27', 'Médico', 262),
(880, '1998-01-09', '1999-03-17', 'Capitán', 43),
(881, '1998-09-07', NULL, 'Científico', 468),
(882, '1971-10-03', '1977-01-02', 'Soldado', 778),
(883, '1978-07-18', NULL, 'Científico', 226),
(884, '1974-11-04', '1975-09-30', NULL, 221),
(885, '1995-04-13', '1999-05-05', 'Médico', 271),
(886, '1981-08-31', '1984-12-27', 'Científico', 786),
(887, '1987-09-14', NULL, 'Médico', 653),
(888, '1992-09-30', NULL, 'Técnico de comunicaciones', 713),
(889, '1990-08-24', NULL, 'Soldado', 283),
(890, '2001-05-13', '2004-07-31', 'Científico', 594),
(891, '1971-11-02', NULL, 'Médico', 684),
(892, '1998-04-17', NULL, 'Técnico de comunicaciones', 472),
(893, '2006-07-10', NULL, 'Médico', 511),
(894, '1994-01-04', '1998-04-25', NULL, 183),
(895, '1970-05-26', NULL, 'Capitán', 505),
(896, '1988-08-21', '1990-09-24', NULL, 541),
(897, '1992-10-16', '1995-10-08', NULL, 95),
(898, '1999-05-29', '2000-02-25', 'Científico', 60),
(899, '2006-07-11', '2006-08-21', 'Soldado', 54),
(900, '1994-08-16', '1998-03-31', 'Capitán', 295),
(901, '1970-12-31', '1973-06-09', 'Capitán', 6),
(902, '1971-06-20', '1971-10-25', 'Capitán', 143),
(903, '1985-09-26', NULL, 'Soldado', 291),
(904, '1996-08-21', '1998-06-11', 'Médico', 260),
(905, '1970-01-05', '1973-03-12', 'Técnico de comunicaciones', 5),
(906, '1970-12-15', '1976-01-23', 'Soldado', 15),
(907, '2012-01-07', NULL, 'Médico', 623),
(908, '1970-02-24', NULL, 'Capitán', 673),
(909, '1970-01-20', NULL, 'Científico', 99),
(910, '1973-09-22', '1973-12-01', 'Técnico de comunicaciones', 60),
(911, '1972-05-04', '1974-10-26', 'Médico', 13),
(912, '1977-07-19', '1981-09-12', 'Soldado', 208),
(913, '1992-06-07', '1995-03-13', 'Científico', 57),
(914, '1997-04-10', '1997-07-02', 'Soldado', 471),
(915, '1987-12-17', NULL, 'Soldado', 61),
(916, '1971-04-08', '1971-10-10', 'Científico', 341),
(917, '1970-05-17', NULL, 'Capitán', 257),
(918, '1999-01-31', '1999-03-05', 'Técnico de comunicaciones', 597),
(919, '1970-01-01', NULL, NULL, 682),
(920, '1976-12-25', '1981-09-07', 'Médico', 9),
(921, '1989-08-11', NULL, 'Médico', 1),
(922, '1970-01-12', '1973-07-31', 'Soldado', 42),
(923, '2009-03-15', '2014-06-21', 'Científico', 9),
(924, '1984-09-30', NULL, NULL, 150),
(925, '2002-01-02', '2005-12-02', 'Soldado', 584),
(926, '1992-12-23', NULL, 'Médico', 390),
(927, '2013-07-07', NULL, 'Científico', 589),
(928, '1976-07-28', '1981-10-15', 'Científico', 2),
(929, '2015-01-17', '2015-04-30', 'Técnico de comunicaciones', 383),
(930, '2015-03-15', '2018-08-05', 'Técnico de comunicaciones', 320),
(931, '1983-05-04', '1988-05-17', 'Médico', 648),
(932, '1972-05-29', NULL, 'Científico', 344),
(933, '1970-10-12', NULL, 'Técnico de comunicaciones', 15),
(934, '1977-08-20', '1978-06-28', 'Técnico de comunicaciones', 787),
(935, '1970-02-25', '1971-07-11', 'Técnico de comunicaciones', 432),
(936, '1994-04-01', '1998-07-18', 'Capitán', 172),
(937, '2007-05-03', NULL, 'Capitán', 411),
(938, '2000-02-03', '2005-06-27', 'Capitán', 5),
(939, '1971-09-12', NULL, 'Soldado', 180),
(940, '1970-01-10', '1971-05-04', 'Científico', 658),
(941, '1992-09-20', NULL, 'Científico', 610),
(942, '1998-03-19', '2001-06-03', 'Científico', 225),
(943, '1988-02-23', '1990-11-28', NULL, 423),
(944, '2016-02-05', '2019-07-07', 'Técnico de comunicaciones', 687),
(945, '1983-05-31', '1986-10-17', 'Médico', 127),
(946, '2007-03-28', '2010-03-23', 'Capitán', 100),
(947, '2011-03-26', '2014-06-23', 'Capitán', 680),
(948, '2004-08-14', '2004-09-02', 'Técnico de comunicaciones', 209),
(949, '1972-08-15', '1977-11-16', NULL, 8),
(950, '1983-07-20', '1988-10-17', 'Científico', 99),
(951, '2018-02-26', '2019-12-13', 'Soldado', 36),
(952, '1990-07-23', '1995-08-28', 'Técnico de comunicaciones', 8),
(953, '2005-05-14', '2010-10-26', 'Científico', 430),
(954, '1999-07-10', '2003-10-26', 'Científico', 150),
(955, '1971-07-31', '1976-06-01', 'Científico', 25),
(956, '2003-11-24', '2008-04-11', 'Científico', 728),
(957, '2011-02-24', '2015-02-11', NULL, 307),
(958, '1999-06-07', NULL, 'Soldado', 80),
(959, '2000-02-08', '2004-08-31', 'Técnico de comunicaciones', 185),
(960, '1997-07-10', '1999-11-23', 'Científico', 645),
(961, '1988-07-20', NULL, 'Médico', 249),
(962, '2010-11-03', '2013-02-06', 'Soldado', 66),
(963, '2001-12-05', NULL, 'Capitán', 778),
(964, '1979-03-11', '1984-06-09', 'Técnico de comunicaciones', 330),
(965, '1980-12-13', '1985-11-02', 'Capitán', 7),
(966, '1971-02-23', '1971-09-14', 'Científico', 7),
(967, '1970-01-06', NULL, 'Técnico de comunicaciones', 459),
(968, '1970-01-01', '1971-10-04', NULL, 798),
(969, '1989-05-12', '1993-10-29', 'Soldado', 641),
(970, '2014-08-19', '2014-11-28', 'Científico', 4),
(971, '2004-11-07', '2008-11-28', 'Técnico de comunicaciones', 81),
(972, '1974-03-03', '1974-12-12', 'Científico', 30),
(973, '1973-09-07', '1974-10-28', 'Médico', 76),
(974, '1976-01-27', NULL, 'Capitán', 399),
(975, '2005-06-10', NULL, 'Médico', 571),
(976, '2016-05-08', NULL, NULL, 223),
(977, '1978-02-06', NULL, NULL, 760),
(978, '2003-11-09', '2008-02-21', 'Científico', 310),
(979, '1975-07-29', '1976-12-08', 'Soldado', 244),
(980, '2013-12-23', '2018-08-03', 'Capitán', 43),
(981, '1996-02-10', NULL, 'Soldado', 371),
(982, '2014-03-28', '2015-10-24', 'Técnico de comunicaciones', 760),
(983, '2004-07-05', NULL, NULL, 336),
(984, '1971-01-05', NULL, 'Científico', 101),
(985, '1980-03-23', NULL, 'Médico', 438),
(986, '1970-01-16', NULL, 'Médico', 12),
(987, '1971-03-20', '1974-08-13', 'Soldado', 285),
(988, '1978-12-09', NULL, 'Científico', 389),
(989, '1970-01-10', NULL, 'Científico', 423),
(990, '1970-10-24', '1974-06-25', 'Científico', 394),
(991, '1970-01-23', '1972-01-31', 'Capitán', 100),
(992, '2000-09-07', NULL, 'Científico', 7),
(993, '1970-01-04', '1972-07-09', 'Soldado', 382),
(994, '1970-12-20', NULL, 'Científico', 277),
(995, '1970-02-25', '1973-12-19', 'Técnico de comunicaciones', 194),
(996, '1995-12-25', '1996-03-22', NULL, 473),
(997, '1977-10-21', NULL, 'Capitán', 55),
(998, '2003-03-25', '2008-03-09', 'Soldado', 147),
(999, '2014-10-07', '2016-04-02', 'Médico', 4),
(1000, '2008-05-14', '2008-07-08', 'Capitán', 94),
(1001, '1973-06-04', '1974-08-30', 'Médico', 362),
(1002, '2014-03-11', '2017-08-18', 'Científico', 181),
(1003, '1999-05-13', '1999-11-02', 'Médico', 394),
(1004, '2017-12-31', '2021-12-18', 'Científico', 618),
(1005, '1981-07-13', '1986-05-14', 'Médico', 378),
(1006, '1996-04-19', NULL, 'Científico', 417),
(1007, '1992-05-02', NULL, 'Científico', 239),
(1008, '2003-09-13', NULL, 'Técnico de comunicaciones', 351),
(1009, '2009-02-20', NULL, 'Técnico de comunicaciones', 313),
(1010, '2011-02-16', '2013-08-27', 'Médico', 611),
(1011, '1992-02-08', NULL, 'Científico', 8),
(1012, '1995-09-01', '1996-01-17', 'Científico', 231),
(1013, '2009-12-24', '2010-08-14', 'Soldado', 59),
(1014, '2006-02-06', '2011-07-06', 'Técnico de comunicaciones', 630),
(1015, '2011-08-14', NULL, 'Capitán', 428),
(1016, '2010-02-15', NULL, 'Técnico de comunicaciones', 471),
(1017, '1982-10-30', '1984-03-18', 'Científico', 637),
(1018, '1970-04-01', '1975-07-21', 'Científico', 8),
(1019, '1994-09-12', NULL, 'Capitán', 737),
(1020, '1971-01-17', NULL, 'Técnico de comunicaciones', 723),
(1021, '1982-03-23', '1983-12-13', 'Médico', 77),
(1022, '1970-01-03', '1973-05-08', 'Soldado', 793),
(1023, '1970-03-22', NULL, 'Capitán', 497),
(1024, '1970-01-05', '1971-03-19', 'Soldado', 560),
(1025, '1970-04-09', '1970-10-11', 'Científico', 13),
(1026, '2002-07-29', NULL, 'Científico', 539),
(1027, '1990-04-14', NULL, 'Técnico de comunicaciones', 18),
(1028, '1983-09-07', '1984-07-01', 'Técnico de comunicaciones', 412),
(1029, '1971-06-24', '1974-12-26', 'Médico', 456),
(1030, '2017-03-26', NULL, 'Soldado', 152),
(1031, '1971-10-09', NULL, 'Médico', 421),
(1032, '2013-01-10', NULL, 'Médico', 263),
(1033, '1971-07-31', '1974-02-03', 'Capitán', 432),
(1034, '1997-07-07', '2000-12-20', 'Soldado', 155),
(1035, '1975-01-17', '1979-02-21', 'Soldado', 218),
(1036, '2005-01-19', NULL, 'Soldado', 737),
(1037, '2018-06-16', NULL, NULL, 395),
(1038, '2002-08-08', '2006-11-28', 'Técnico de comunicaciones', 668),
(1039, '2007-08-24', NULL, 'Soldado', 270),
(1040, '2005-06-05', '2005-08-22', 'Científico', 711),
(1041, '1972-08-23', NULL, 'Científico', 42),
(1042, '2014-09-20', '2016-08-03', 'Médico', 79),
(1043, '2016-08-22', NULL, 'Capitán', 236),
(1044, '1999-08-04', '2004-12-22', 'Soldado', 348),
(1045, '2002-10-07', NULL, 'Médico', 243),
(1046, '2003-01-10', NULL, 'Médico', 83),
(1047, '1978-06-16', NULL, 'Capitán', 676),
(1048, '2011-05-03', NULL, 'Soldado', 529),
(1049, '1970-05-30', '1973-12-17', 'Científico', 523),
(1050, '1993-06-04', '1993-06-23', 'Científico', 664),
(1051, '1980-10-11', '1980-12-26', 'Médico', 580),
(1052, '1983-04-11', '1987-04-04', 'Capitán', 2),
(1053, '2017-07-12', NULL, 'Médico', 579),
(1054, '1986-10-04', NULL, 'Técnico de comunicaciones', 545),
(1055, '1999-11-30', NULL, 'Capitán', 498),
(1056, '1970-03-28', '1971-07-22', 'Soldado', 380),
(1057, '1980-11-25', '1983-02-24', 'Técnico de comunicaciones', 30),
(1058, '2018-02-25', NULL, NULL, 62),
(1059, '2005-01-29', NULL, 'Capitán', 797),
(1060, '1972-05-27', '1972-08-04', 'Médico', 70),
(1061, '1972-11-23', '1977-03-20', 'Técnico de comunicaciones', 768),
(1062, '1998-12-06', '1999-04-05', NULL, 439),
(1063, '1970-01-25', '1971-10-06', 'Técnico de comunicaciones', 42),
(1064, '1996-08-11', '1999-07-28', 'Médico', 465),
(1065, '1970-08-15', NULL, 'Capitán', 173),
(1066, '2000-01-11', NULL, 'Técnico de comunicaciones', 11),
(1067, '1998-03-07', NULL, 'Capitán', 621),
(1068, '2008-03-07', NULL, 'Técnico de comunicaciones', 419),
(1069, '1980-06-11', NULL, 'Científico', 377),
(1070, '1995-02-10', '1995-03-26', 'Soldado', 571),
(1071, '1970-01-20', '1970-09-30', 'Soldado', 7),
(1072, '1978-10-28', NULL, 'Técnico de comunicaciones', 438),
(1073, '2010-12-20', NULL, 'Técnico de comunicaciones', 76),
(1074, '2001-09-28', '2003-03-30', 'Médico', 21),
(1075, '1993-06-30', NULL, 'Capitán', 2),
(1076, '1972-08-17', '1973-10-12', 'Científico', 9),
(1077, '1984-06-13', '1989-02-25', 'Capitán', 403),
(1078, '1999-03-26', '2004-09-14', 'Científico', 409),
(1079, '1970-01-03', NULL, 'Capitán', 354),
(1080, '1981-02-01', NULL, 'Capitán', 280),
(1081, '2014-07-26', '2017-07-25', 'Médico', 482),
(1082, '1990-04-15', '1995-07-22', 'Técnico de comunicaciones', 3),
(1083, '2001-05-12', NULL, 'Soldado', 564),
(1084, '2006-06-15', '2007-06-30', 'Científico', 315),
(1085, '1996-06-11', NULL, 'Técnico de comunicaciones', 78),
(1086, '1993-06-29', NULL, 'Médico', 428),
(1087, '1970-03-01', '1973-09-09', 'Capitán', 513),
(1088, '1991-07-29', '1993-04-14', 'Soldado', 292),
(1089, '1986-11-27', NULL, NULL, 253),
(1090, '1970-01-05', '1974-02-28', 'Capitán', 403),
(1091, '1970-01-06', NULL, 'Técnico de comunicaciones', 733),
(1092, '1970-08-16', '1970-08-19', 'Soldado', 603),
(1093, '1984-10-04', '1988-06-26', 'Técnico de comunicaciones', 85),
(1094, '1970-02-13', NULL, 'Soldado', 696),
(1095, '1979-10-06', NULL, 'Soldado', 740),
(1096, '1972-08-05', NULL, 'Soldado', 594),
(1097, '1970-01-07', '1975-06-27', 'Capitán', 25),
(1098, '2013-08-21', '2017-08-03', 'Científico', 318),
(1099, '1984-01-28', NULL, 'Médico', 197),
(1100, '1978-03-30', NULL, 'Médico', 375),
(1101, '1982-02-26', '1982-05-13', 'Médico', 291),
(1102, '1971-09-09', NULL, 'Capitán', 79),
(1103, '1975-06-21', NULL, 'Técnico de comunicaciones', 132),
(1104, '1988-04-05', NULL, 'Técnico de comunicaciones', 246),
(1105, '1990-11-24', '1995-08-12', 'Capitán', 756),
(1106, '1970-01-08', '1973-07-21', 'Capitán', 633),
(1107, '1970-01-03', '1973-04-27', 'Técnico de comunicaciones', 445),
(1108, '2010-10-20', NULL, 'Soldado', 82),
(1109, '2004-11-01', '2004-11-21', 'Científico', 298),
(1110, '1983-10-08', '1984-03-19', 'Capitán', 41),
(1111, '1974-01-27', '1975-12-11', 'Médico', 4),
(1112, '1985-07-12', '1989-11-25', 'Capitán', 265),
(1113, '1978-03-06', '1980-10-05', 'Científico', 550),
(1114, '2004-05-08', '2007-03-09', 'Soldado', 175),
(1115, '1970-05-05', NULL, 'Médico', 42),
(1116, '1999-02-15', '2002-04-24', 'Técnico de comunicaciones', 730),
(1117, '1970-03-01', '1972-08-08', 'Técnico de comunicaciones', 504),
(1118, '1996-03-20', NULL, 'Científico', 380),
(1119, '1981-06-19', NULL, 'Científico', 103),
(1120, '1997-06-01', '1998-11-16', 'Científico', 529),
(1121, '1970-01-08', '1972-06-27', NULL, 469),
(1122, '1992-05-16', NULL, 'Médico', 432),
(1123, '2014-07-30', NULL, 'Científico', 2),
(1124, '1987-08-25', NULL, 'Técnico de comunicaciones', 350),
(1125, '1970-01-02', '1973-12-10', 'Capitán', 80),
(1126, '1972-02-05', '1976-07-17', 'Científico', 466),
(1127, '2009-04-12', NULL, NULL, 162),
(1128, '1995-06-09', '1997-08-26', 'Soldado', 17),
(1129, '1971-06-16', NULL, 'Médico', 260),
(1130, '1986-03-01', NULL, 'Médico', 645),
(1131, '1970-01-09', NULL, 'Médico', 681),
(1132, '1987-09-17', '1990-06-05', 'Capitán', 391),
(1133, '1970-01-06', '1975-05-02', NULL, 668),
(1134, '1977-07-22', '1981-08-22', 'Soldado', 265),
(1135, '1989-03-13', '1993-11-03', 'Científico', 586),
(1136, '2006-09-06', NULL, 'Científico', 723),
(1137, '1972-09-06', NULL, 'Médico', 489),
(1138, '1974-02-23', '1977-04-24', 'Capitán', 550),
(1139, '1988-01-28', '1988-09-20', 'Técnico de comunicaciones', 773),
(1140, '2015-10-06', NULL, 'Soldado', 179),
(1141, '2006-12-15', '2012-05-01', 'Médico', 161),
(1142, '1989-09-17', '1992-02-16', 'Científico', 338),
(1143, '1970-02-25', NULL, NULL, 9),
(1144, '1970-01-27', '1973-09-13', 'Médico', 278),
(1145, '1999-08-09', '2003-12-10', 'Científico', 609),
(1146, '1981-03-03', '1983-07-06', 'Científico', 5),
(1147, '1996-03-15', '1998-07-16', 'Científico', 500),
(1148, '1995-12-16', '1996-09-17', 'Científico', 289),
(1149, '1991-11-10', '1996-02-13', 'Soldado', 316),
(1150, '2006-05-25', NULL, 'Técnico de comunicaciones', 559),
(1151, '2018-08-30', '2019-07-14', 'Científico', 173),
(1152, '1970-01-01', NULL, 'Científico', 207),
(1153, '1993-11-18', '1996-06-04', 'Técnico de comunicaciones', 133),
(1154, '1970-03-19', NULL, 'Técnico de comunicaciones', 168),
(1155, '1985-01-20', NULL, 'Soldado', 544),
(1156, '2008-06-19', '2012-07-20', 'Científico', 595),
(1157, '1980-07-06', '1983-12-25', 'Médico', 589),
(1158, '2018-06-13', '2021-01-29', 'Soldado', 593),
(1159, '2017-12-28', NULL, 'Capitán', 631),
(1160, '2015-04-17', NULL, 'Médico', 167),
(1161, '2017-02-02', '2022-07-10', 'Capitán', 587),
(1162, '1972-06-02', '1975-01-15', 'Médico', 557),
(1163, '1984-12-31', NULL, 'Médico', 706),
(1164, '1972-09-01', '1976-01-14', 'Técnico de comunicaciones', 723),
(1165, '1981-06-26', NULL, NULL, 603),
(1166, '2015-11-19', '2016-06-16', 'Médico', 561),
(1167, '2012-11-23', '2015-03-10', 'Soldado', 795),
(1168, '1970-12-21', '1973-09-27', 'Médico', 239),
(1169, '2017-09-04', NULL, 'Soldado', 182),
(1170, '2004-06-21', '2007-12-01', 'Soldado', 492),
(1171, '2015-12-17', '2016-12-06', NULL, 338),
(1172, '1970-01-05', '1971-11-12', 'Técnico de comunicaciones', 111),
(1173, '2000-08-19', '2005-04-21', 'Médico', 470),
(1174, '2000-08-10', NULL, 'Científico', 520),
(1175, '2015-09-29', '2018-12-11', 'Capitán', 154),
(1176, '2003-05-21', '2003-08-12', 'Científico', 722),
(1177, '1970-06-10', NULL, 'Técnico de comunicaciones', 510),
(1178, '2016-07-06', '2018-07-20', 'Técnico de comunicaciones', 535),
(1179, '2004-11-09', '2005-05-15', 'Soldado', 185),
(1180, '1988-04-01', NULL, 'Médico', 637),
(1181, '1970-03-17', NULL, 'Soldado', 345),
(1182, '2011-02-16', NULL, 'Soldado', 521),
(1183, '1979-12-27', NULL, 'Técnico de comunicaciones', 5),
(1184, '2014-01-14', '2016-10-26', NULL, 538),
(1185, '1981-04-27', '1983-11-03', 'Científico', 385),
(1186, '2013-07-20', '2015-03-31', 'Capitán', 638),
(1187, '1986-06-09', '1991-07-16', NULL, 176),
(1188, '1970-03-18', '1973-02-23', 'Técnico de comunicaciones', 262),
(1189, '1970-03-01', NULL, 'Técnico de comunicaciones', 695),
(1190, '2013-02-22', NULL, 'Soldado', 779),
(1191, '1985-04-23', NULL, 'Capitán', 98),
(1192, '1996-03-20', NULL, 'Capitán', 369),
(1193, '1983-09-04', '1984-05-23', 'Soldado', 78),
(1194, '1970-01-04', '1974-01-18', 'Médico', 113),
(1195, '2009-04-30', NULL, NULL, 636),
(1196, '1970-01-09', '1974-02-15', 'Médico', 176),
(1197, '1970-04-06', '1974-01-04', 'Capitán', 323),
(1198, '1975-02-12', '1976-09-14', 'Científico', 462),
(1199, '1986-10-14', '1988-07-05', 'Capitán', 88),
(1200, '1990-09-07', NULL, 'Soldado', 246),
(1201, '1995-04-11', '1997-07-10', 'Médico', 148),
(1202, '1972-06-27', NULL, 'Médico', 731),
(1203, '2017-11-27', '2019-11-29', 'Soldado', 43),
(1204, '1985-03-16', NULL, 'Médico', 454),
(1205, '2008-08-30', '2012-01-26', 'Técnico de comunicaciones', 368),
(1206, '1978-07-11', NULL, 'Soldado', 20),
(1207, '1981-12-30', NULL, NULL, 616),
(1208, '2014-08-21', '2016-12-12', 'Capitán', 150),
(1209, '1994-08-25', '2000-01-19', 'Técnico de comunicaciones', 460),
(1210, '1970-01-04', NULL, 'Médico', 285),
(1211, '1970-03-19', NULL, 'Científico', 477),
(1212, '2014-11-14', '2016-07-09', 'Científico', 106),
(1213, '1981-04-30', NULL, NULL, 368),
(1214, '1970-01-27', '1972-03-09', 'Soldado', 12),
(1215, '2009-07-15', NULL, 'Médico', 541),
(1216, '2011-09-07', '2016-12-09', 'Soldado', 785),
(1217, '1998-06-14', NULL, 'Técnico de comunicaciones', 4),
(1218, '1991-01-03', NULL, 'Soldado', 7),
(1219, '1970-01-22', '1974-02-16', 'Capitán', 245),
(1220, '2012-04-26', NULL, 'Médico', 70),
(1221, '2009-06-15', '2012-04-22', 'Científico', 732),
(1222, '2009-01-02', '2009-11-11', 'Soldado', 796),
(1223, '1985-11-08', '1986-02-16', 'Capitán', 754),
(1224, '2006-03-05', NULL, 'Capitán', 539),
(1225, '1970-02-13', NULL, 'Científico', 88),
(1226, '1984-10-24', NULL, NULL, 180),
(1227, '2010-05-19', '2015-07-10', 'Médico', 527),
(1228, '2007-09-17', NULL, NULL, 703),
(1229, '1970-01-09', NULL, 'Capitán', 528),
(1230, '1970-05-15', '1973-04-24', 'Médico', 41),
(1231, '1982-09-20', '1986-09-13', 'Capitán', 135),
(1232, '1971-01-22', '1976-04-13', 'Capitán', 249),
(1233, '2012-07-16', NULL, 'Soldado', 368),
(1234, '1995-03-15', '1996-08-07', 'Médico', 298),
(1235, '1986-03-30', NULL, 'Científico', 643),
(1236, '1972-10-23', '1974-06-11', 'Técnico de comunicaciones', 225),
(1237, '2016-12-02', NULL, 'Médico', 333),
(1238, '2007-08-23', '2009-12-08', 'Médico', 474),
(1239, '1991-12-12', NULL, 'Técnico de comunicaciones', 702),
(1240, '1971-08-05', '1976-10-23', 'Médico', 119),
(1241, '2012-05-30', '2013-03-03', 'Capitán', 208),
(1242, '1974-12-25', '1979-10-10', NULL, 478),
(1243, '1970-02-10', '1974-01-09', 'Soldado', 449),
(1244, '1992-09-17', '1996-06-25', 'Científico', 243),
(1245, '2008-03-27', '2010-11-17', NULL, 537),
(1246, '1976-09-13', '1977-08-04', 'Soldado', 679),
(1247, '2000-03-04', NULL, 'Capitán', 625),
(1248, '1986-04-23', NULL, 'Técnico de comunicaciones', 404),
(1249, '1989-10-01', NULL, NULL, 354),
(1250, '2006-12-22', NULL, 'Técnico de comunicaciones', 104),
(1251, '2008-11-14', '2010-03-29', 'Científico', 744),
(1252, '1976-12-21', '1981-11-22', NULL, 751),
(1253, '1972-10-02', '1973-11-24', 'Médico', 797),
(1254, '1977-11-17', '1980-08-13', 'Soldado', 373),
(1255, '1996-07-11', '1996-08-06', 'Capitán', 79),
(1256, '1978-06-25', NULL, NULL, 72),
(1257, '1986-03-23', '1988-09-08', 'Médico', 403),
(1258, '1974-12-30', '1977-09-16', 'Capitán', 7),
(1259, '1970-02-25', NULL, 'Médico', 533),
(1260, '1973-11-08', NULL, 'Soldado', 763),
(1261, '1973-03-20', '1974-07-28', 'Científico', 762),
(1262, '1973-11-04', NULL, 'Capitán', 759),
(1263, '2010-11-01', '2013-05-23', 'Científico', 380),
(1264, '1993-01-30', '1997-03-08', 'Capitán', 485),
(1265, '2009-12-26', NULL, 'Técnico de comunicaciones', 365),
(1266, '1973-01-27', '1975-11-30', 'Técnico de comunicaciones', 7),
(1267, '1981-04-19', '1981-11-14', 'Capitán', 716),
(1268, '2012-12-17', '2017-05-18', 'Capitán', 279),
(1269, '1993-10-16', '1998-11-09', NULL, 477),
(1270, '1997-12-17', NULL, 'Capitán', 655),
(1271, '2011-08-15', '2016-03-13', 'Técnico de comunicaciones', 614),
(1272, '1971-03-03', NULL, 'Soldado', 389),
(1273, '1984-04-18', NULL, 'Soldado', 293),
(1274, '1972-10-07', '1974-06-15', 'Capitán', 100),
(1275, '2006-04-05', '2008-03-12', 'Médico', 482),
(1276, '2005-06-14', NULL, 'Científico', 271),
(1277, '1973-09-18', '1975-09-22', 'Capitán', 739),
(1278, '2000-12-08', '2002-05-12', 'Médico', 81),
(1279, '2004-04-09', '2005-10-04', 'Soldado', 731),
(1280, '1970-01-13', NULL, 'Soldado', 488),
(1281, '2009-04-03', '2012-09-13', 'Médico', 182),
(1282, '1970-02-26', NULL, 'Capitán', 514),
(1283, '1988-09-26', NULL, 'Técnico de comunicaciones', 466),
(1284, '2013-08-05', '2013-10-09', 'Capitán', 693),
(1285, '1970-03-05', '1975-07-29', 'Científico', 428),
(1286, '2001-10-16', '2003-09-25', 'Médico', 794),
(1287, '2014-11-12', '2020-03-04', 'Soldado', 460),
(1288, '1979-12-13', NULL, 'Científico', 754),
(1289, '1978-01-04', '1980-09-26', 'Soldado', 2),
(1290, '1972-04-14', NULL, 'Técnico de comunicaciones', 78),
(1291, '1970-02-11', '1971-04-10', 'Científico', 772),
(1292, '2006-07-10', NULL, 'Médico', 193),
(1293, '2016-01-07', '2021-06-19', NULL, 7),
(1294, '1970-01-09', '1975-02-24', NULL, 79),
(1295, '2012-07-01', NULL, 'Soldado', 773),
(1296, '1981-11-03', NULL, NULL, 230),
(1297, '1970-01-02', NULL, 'Técnico de comunicaciones', 794),
(1298, '1993-04-29', '1994-02-27', 'Soldado', 341),
(1299, '1973-12-26', '1976-12-22', 'Técnico de comunicaciones', 225),
(1300, '1970-03-26', '1973-02-18', 'Técnico de comunicaciones', 108),
(1301, '1992-10-15', '1996-05-18', 'Técnico de comunicaciones', 503),
(1302, '1972-04-06', '1975-09-02', 'Soldado', 489),
(1303, '1988-11-29', '1991-05-04', 'Científico', 460),
(1304, '2018-05-10', NULL, 'Soldado', 54),
(1305, '1970-03-16', NULL, 'Técnico de comunicaciones', 765),
(1306, '2012-10-30', '2013-08-25', 'Científico', 6),
(1307, '1992-07-28', '1992-11-21', 'Médico', 89),
(1308, '2009-07-04', NULL, 'Soldado', 96),
(1309, '1977-08-04', '1981-07-15', 'Científico', 81),
(1310, '2005-07-02', NULL, NULL, 540),
(1311, '2003-07-19', '2003-08-02', 'Técnico de comunicaciones', 384),
(1312, '1976-05-19', '1976-12-05', 'Capitán', 40),
(1313, '1985-10-06', NULL, 'Científico', 184),
(1314, '2004-08-30', NULL, 'Científico', 299),
(1315, '1997-12-19', '2000-04-08', 'Soldado', 431),
(1316, '1996-04-10', NULL, 'Soldado', 522),
(1317, '2017-06-22', '2017-08-20', NULL, 480),
(1318, '1985-04-28', '1988-11-23', 'Médico', 498),
(1319, '1984-08-16', NULL, 'Técnico de comunicaciones', 235),
(1320, '2007-01-22', '2009-01-15', 'Capitán', 400),
(1321, '1998-09-05', '1998-11-11', 'Soldado', 758),
(1322, '1971-06-28', NULL, 'Científico', 291),
(1323, '2001-11-25', '2002-03-28', 'Científico', 734),
(1324, '1977-10-31', '1981-02-19', 'Científico', 61),
(1325, '1991-12-05', '1992-06-11', 'Médico', 35),
(1326, '1992-11-14', '1994-05-23', NULL, 675),
(1327, '2006-01-28', '2010-02-24', 'Capitán', 69),
(1328, '1985-07-07', '1986-11-15', 'Científico', 769),
(1329, '2006-03-07', '2009-03-21', 'Científico', 132),
(1330, '1971-08-07', '1974-07-10', 'Capitán', 651),
(1331, '1971-09-05', NULL, 'Técnico de comunicaciones', 20),
(1332, '1976-08-01', NULL, 'Capitán', 323),
(1333, '1970-01-29', '1973-11-03', 'Soldado', 728),
(1334, '2016-04-23', '2020-07-04', 'Soldado', 213),
(1335, '1973-07-19', '1973-11-23', 'Soldado', 787),
(1336, '2011-09-22', NULL, 'Capitán', 11),
(1337, '1984-05-10', NULL, 'Médico', 733),
(1338, '1986-01-19', '1991-02-12', 'Capitán', 505),
(1339, '1987-10-23', '1993-03-20', NULL, 81),
(1340, '1979-05-23', '1984-09-24', 'Capitán', 430),
(1341, '1983-05-03', NULL, 'Técnico de comunicaciones', 679),
(1342, '1990-09-11', NULL, 'Técnico de comunicaciones', 290),
(1343, '1984-01-11', '1988-07-21', 'Técnico de comunicaciones', 40),
(1344, '1977-04-23', '1982-02-21', 'Soldado', 373),
(1345, '1986-06-18', '1991-12-08', 'Soldado', 326),
(1346, '1970-03-02', '1971-07-03', 'Capitán', 761),
(1347, '2016-01-21', NULL, 'Médico', 181),
(1348, '2014-04-21', '2014-10-24', 'Capitán', 208),
(1349, '2017-11-15', NULL, NULL, 96),
(1350, '2016-01-30', '2018-05-28', 'Soldado', 174),
(1351, '2004-11-16', NULL, 'Técnico de comunicaciones', 167),
(1352, '1970-01-02', NULL, 'Capitán', 236),
(1353, '1991-01-28', '1993-05-17', 'Técnico de comunicaciones', 76),
(1354, '1982-07-30', '1983-06-06', 'Científico', 101),
(1355, '1983-03-09', NULL, 'Técnico de comunicaciones', 3),
(1356, '1988-03-21', NULL, 'Capitán', 597),
(1357, '1996-10-22', '2000-10-25', 'Capitán', 8),
(1358, '2009-11-14', '2013-09-12', 'Científico', 739),
(1359, '2003-10-17', NULL, 'Técnico de comunicaciones', 306),
(1360, '1971-11-22', '1975-04-21', 'Técnico de comunicaciones', 205),
(1361, '1982-08-15', '1987-01-11', 'Técnico de comunicaciones', 5),
(1362, '1998-12-13', '2002-02-14', 'Médico', 35),
(1363, '1970-01-01', NULL, 'Soldado', 374),
(1364, '2003-05-15', NULL, 'Soldado', 4),
(1365, '2010-10-21', '2014-07-17', 'Científico', 246),
(1366, '1970-01-04', '1975-03-06', 'Científico', 74),
(1367, '1970-01-04', '1971-12-15', 'Capitán', 632),
(1368, '1970-01-03', NULL, 'Soldado', 764),
(1369, '1990-08-13', NULL, 'Médico', 27),
(1370, '2016-06-27', '2016-07-27', 'Científico', 777),
(1371, '2002-10-15', NULL, 'Capitán', 222),
(1372, '1991-04-21', NULL, 'Médico', 739),
(1373, '1970-01-10', '1973-07-05', 'Científico', 714),
(1374, '1987-03-18', '1990-08-17', 'Capitán', 404),
(1375, '2007-01-24', '2012-03-26', 'Técnico de comunicaciones', 733),
(1376, '2011-03-06', '2013-10-22', 'Capitán', 626),
(1377, '1987-10-19', NULL, 'Técnico de comunicaciones', 423),
(1378, '2005-06-19', '2006-04-29', 'Técnico de comunicaciones', 564),
(1379, '1970-01-27', NULL, 'Soldado', 175),
(1380, '1970-01-10', NULL, 'Médico', 389),
(1381, '1970-09-26', NULL, 'Científico', 688),
(1382, '1971-10-20', '1975-08-18', 'Científico', 94),
(1383, '2002-11-28', '2004-09-23', 'Científico', 660),
(1384, '1970-03-14', '1973-01-03', 'Médico', 452),
(1385, '1970-02-23', '1971-02-24', 'Soldado', 632),
(1386, '2005-02-16', NULL, NULL, 108),
(1387, '2004-10-28', NULL, 'Capitán', 386),
(1388, '1972-05-01', '1973-03-04', 'Capitán', 689),
(1389, '1970-01-06', '1974-08-27', NULL, 701),
(1390, '1976-09-04', '1981-05-22', NULL, 510),
(1391, '1977-06-09', '1980-09-28', 'Capitán', 524),
(1392, '1987-03-08', NULL, 'Capitán', 141),
(1393, '1974-01-10', '1977-07-03', 'Científico', 373),
(1394, '2015-10-05', NULL, 'Soldado', 795),
(1395, '1994-03-08', '1998-10-28', 'Médico', 9),
(1396, '1970-01-01', NULL, 'Capitán', 5),
(1397, '1972-05-14', '1974-03-05', 'Científico', 227),
(1398, '1976-06-16', NULL, 'Soldado', 450),
(1399, '1996-06-17', '1997-10-31', 'Técnico de comunicaciones', 92),
(1400, '1978-07-20', '1980-10-02', 'Médico', 369),
(1401, '1993-06-21', '1996-09-11', 'Técnico de comunicaciones', 3),
(1402, '1981-08-03', NULL, 'Soldado', 373),
(1403, '2009-08-24', NULL, 'Técnico de comunicaciones', 197),
(1404, '2018-11-13', NULL, 'Médico', 1),
(1405, '1970-01-07', NULL, 'Capitán', 377),
(1406, '1970-01-06', '1975-02-05', 'Médico', 680),
(1407, '2007-07-23', '2011-01-17', 'Médico', 753),
(1408, '2007-05-27', '2007-12-14', 'Médico', 247),
(1409, '1985-07-13', NULL, 'Capitán', 472),
(1410, '2000-12-11', '2002-09-25', 'Soldado', 589),
(1411, '1970-01-10', NULL, 'Médico', 4),
(1412, '1995-05-05', '1999-10-29', 'Técnico de comunicaciones', 1),
(1413, '1971-01-15', '1972-06-21', 'Técnico de comunicaciones', 211),
(1414, '1972-06-19', '1976-04-21', 'Técnico de comunicaciones', 577),
(1415, '1974-11-11', '1979-07-24', NULL, 418),
(1416, '1985-05-04', '1986-11-14', 'Capitán', 178),
(1417, '1971-06-08', '1971-12-27', 'Capitán', 161),
(1418, '2000-04-16', '2002-04-07', 'Médico', 47),
(1419, '1986-08-11', '1989-12-16', 'Capitán', 458),
(1420, '2000-06-12', '2004-09-10', 'Capitán', 241),
(1421, '1984-05-08', NULL, 'Médico', 287),
(1422, '1979-08-07', NULL, 'Técnico de comunicaciones', 571),
(1423, '1980-03-20', '1984-01-29', 'Científico', 248),
(1424, '1970-01-07', '1972-08-12', 'Capitán', 218),
(1425, '2014-10-04', '2015-02-27', 'Capitán', 293),
(1426, '2001-10-29', '2006-06-05', 'Soldado', 784),
(1427, '1974-05-03', NULL, 'Médico', 793),
(1428, '2001-09-13', '2003-08-10', 'Capitán', 6),
(1429, '2005-11-12', '2007-01-05', 'Soldado', 134),
(1430, '2011-03-07', '2015-12-21', 'Capitán', 15),
(1431, '1990-12-20', '1995-11-03', 'Científico', 78),
(1432, '1986-09-08', '1990-05-29', 'Soldado', 70),
(1433, '1996-05-05', '1999-04-12', NULL, 332),
(1434, '1974-06-13', '1978-04-29', 'Médico', 122),
(1435, '1974-02-05', '1976-09-04', 'Médico', 2),
(1436, '2018-09-13', NULL, 'Científico', 732),
(1437, '1970-03-22', NULL, 'Científico', 718),
(1438, '2000-09-21', NULL, 'Científico', 291),
(1439, '1980-01-18', NULL, 'Médico', 201),
(1440, '2014-01-29', NULL, 'Médico', 9),
(1441, '1995-04-07', '1997-01-16', 'Capitán', 492),
(1442, '1988-08-18', '1990-11-15', 'Técnico de comunicaciones', 638),
(1443, '2009-02-08', '2014-04-13', 'Soldado', 786),
(1444, '2017-07-27', '2018-11-06', 'Científico', 509),
(1445, '1972-05-17', NULL, 'Capitán', 459),
(1446, '1976-07-03', '1977-12-13', 'Soldado', 452),
(1447, '2007-06-03', '2012-07-06', 'Capitán', 550),
(1448, '1990-11-10', '1994-05-09', 'Técnico de comunicaciones', 186),
(1449, '2012-07-09', NULL, 'Capitán', 7),
(1450, '1982-01-15', NULL, 'Soldado', 180),
(1451, '1970-03-03', '1970-07-14', 'Capitán', 46),
(1452, '1970-02-25', NULL, 'Científico', 312),
(1453, '1984-07-04', '1987-01-14', 'Soldado', 433),
(1454, '1978-01-05', '1982-10-17', 'Capitán', 411),
(1455, '1971-08-23', NULL, 'Médico', 8),
(1456, '1979-08-16', '1983-04-09', 'Técnico de comunicaciones', 303),
(1457, '1970-01-10', NULL, 'Capitán', 61),
(1458, '2012-10-28', NULL, NULL, 366),
(1459, '1991-02-02', NULL, NULL, 157),
(1460, '1996-08-10', NULL, NULL, 217),
(1461, '1999-04-21', NULL, 'Capitán', 755),
(1462, '1970-01-04', '1972-11-22', 'Médico', 176),
(1463, '1977-05-16', '1981-08-11', 'Soldado', 97),
(1464, '2009-11-25', '2011-06-28', 'Científico', 316),
(1465, '1989-03-02', NULL, 'Médico', 139),
(1466, '1970-03-24', NULL, 'Científico', 193),
(1467, '1991-11-01', '1993-09-16', 'Soldado', 276),
(1468, '1971-03-13', '1972-08-19', 'Capitán', 592),
(1469, '2010-02-13', '2011-12-24', 'Capitán', 158),
(1470, '1990-11-14', '1994-04-14', 'Soldado', 625),
(1471, '2013-09-14', '2019-03-02', 'Científico', 400),
(1472, '1984-11-01', '1988-12-02', 'Científico', 547),
(1473, '1984-10-31', '1988-10-01', 'Técnico de comunicaciones', 324),
(1474, '1998-05-17', NULL, 'Capitán', 145),
(1475, '1988-09-15', NULL, 'Médico', 5),
(1476, '1970-02-10', '1974-03-31', 'Capitán', 281),
(1477, '2004-01-29', '2004-10-01', 'Médico', 531),
(1478, '1989-03-31', '1991-08-30', 'Soldado', 585),
(1479, '1970-01-06', '1975-06-04', 'Técnico de comunicaciones', 530),
(1480, '1970-02-01', '1974-03-18', NULL, 480),
(1481, '1976-11-04', '1980-02-02', 'Capitán', 142),
(1482, '1970-03-12', '1975-04-02', 'Científico', 471),
(1483, '1976-07-30', '1981-10-01', 'Capitán', 413),
(1484, '1972-07-15', '1973-01-07', 'Soldado', 123),
(1485, '1970-03-26', '1972-05-28', 'Técnico de comunicaciones', 373),
(1486, '1994-11-12', '1999-08-16', 'Técnico de comunicaciones', 166),
(1487, '1974-06-29', '1976-11-17', 'Soldado', 227),
(1488, '1989-05-01', '1992-01-12', NULL, 688),
(1489, '1972-09-15', '1977-03-12', 'Científico', 241),
(1490, '1982-01-19', '1986-04-14', 'Soldado', 786),
(1491, '1980-01-19', '1984-01-04', 'Capitán', 74),
(1492, '2011-09-03', '2014-10-31', 'Médico', 249),
(1493, '1999-12-03', '2005-03-17', 'Soldado', 7),
(1494, '2000-12-13', '2001-12-31', 'Técnico de comunicaciones', 494),
(1495, '1974-09-27', '1976-03-13', NULL, 495),
(1496, '1983-03-07', '1988-05-17', NULL, 748),
(1497, '1993-10-09', '1994-01-14', NULL, 8),
(1498, '1992-02-01', '1995-08-22', NULL, 165),
(1499, '2007-03-11', '2010-04-14', NULL, 764),
(1500, '1974-09-16', '1978-05-05', NULL, 148);

ALTER TABLE direcciones 
  ADD UNIQUE INDEX direccion(direccion);

ALTER TABLE nave 
  ADD UNIQUE INDEX identificador(identificador);
/*!40014 SET FOREIGN_KEY_CHECKS=@OLD_FOREIGN_KEY_CHECKS */;